// File generated by Gambit v4.9.4
// Link info: (409004 (js ((compactness 9))) "termite" (("termite")) (module_register entrypt_init returnpt_init ctrlpt_init parententrypt_init absent_obj vectorp make_u8vector flonumbox flonump eof_obj u8vector make_delay_promise symbol promise continuation_capture2 inttemp1 inttemp2 stringp make_interned_char jsnumberp build_rest cons build_key_rest values pairp structure current_processor r4 closure_alloc wrong_key_args build_key r3 peps make_interned_keyword r2 poll string base92_decode r1 r0 sp stack make_interned_symbol glo wrong_nargs nargs) (termite#linker ##with-exception-handler tcp-server-socket-info readtable-sharing-allowed?-set termite#dispatcher open-process make-thread ##error thread-receive thread-mailbox-rewind termite/utils#make-uuid ##load-module ##time->seconds mutex-lock! ##structure-copy ##table-length termite#*foreign->local* ##input-port-readtable-set! ##call-with-output-string ##table-ref ##direct-structure-set ##string-split-at-char-reversed termite#proxy-request-counter termite#self termite#publisher ##current-time ##make-table ##remove termite#proxy-counter termite#node1 thread-name ##with-output-to-port thread-terminate! ##read-subu8vector open-tcp-client ##port? ##close-output-port termite#*uuid->tag* ##input-port-readtable thread-send thread-mailbox-extract-and-rewind ##string-contains thread? thread-mailbox-next termite#file-output-log-handler termite#*event-manager-timeout* termite#*server-timeout* thread-join! ##force-output termite#spawner ##table-search display-exception-in-context ##get-subprocedure-from-name-and-id ##table-set! ##println termite#*global-mutex* termite#ping-server mailbox-receive-timeout-exception? termite#logger ##object->u8vector socket-info-port-number ##close-port make-mutex mutex-unlock! ##read-line ##write-subu8vector join-timeout-exception? termite#*local->foreign* ##open-output-file ##unknown-procedure-handler-set! ##table->list ##table-for-each open-tcp-server ##output-port-readtable-set! u8vector->object ##raise thread-start! termite#node2 termite#current-node ##output-port-readtable ##current-error-port thread-specific thread-specific-set!) (termite#linker termite#dispatcher termite#*foreign->local* termite#proxy-request-counter termite#self termite#publisher termite#proxy-counter termite#node1 termite#*uuid->tag* termite#file-output-log-handler termite#*event-manager-timeout* termite#*server-timeout* termite#spawner termite#*global-mutex* termite#ping-server termite#logger termite#*local->foreign* termite#node2 termite#current-node) (termite#linker termite#dispatcher termite#*foreign->local* termite#proxy-request-counter termite#self termite#publisher termite#proxy-counter termite#node1 termite#*uuid->tag* termite#file-output-log-handler termite#*event-manager-timeout* termite#*server-timeout* termite#spawner termite#*global-mutex* termite#ping-server termite#logger termite#*local->foreign* termite#node2 termite#current-node) #f)

_cst0__termite = _i("termite#current-node");

_cst1__termite = new _ScmString(_z("cJcOcRcEcDcOCcWcHcUcPcLcWcHCcPcXcWcHc["));

_cst2__termite = _i("make-mutex");

_cst3__termite = _i("termite#*global-mutex*");

_cst4__termite = _make_interned_keyword("weak-values");

_cst5__termite = _i("##make-table");

_cst6__termite = _i("termite#*foreign->local*");

_cst7__termite = _make_interned_keyword("weak-keys");

_cst8__termite = _i("termite#*local->foreign*");

_cst9__termite = _i("termite#*uuid->tag*");

_cst10__termite = _i("termite#self");

_cst11__termite = _i("current-thread");

_cst12__termite = _i("termite#proxy-counter");

_cst13__termite = _i("termite#proxy-request-counter");

_cst14__termite = _i("termite-dispatcher");

_cst15__termite = _make_interned_keyword("name");

_cst16__termite = _make_interned_keyword("links");

_cst17__termite = _i("anonymous");

_cst18__termite = _i("termite#dispatcher");

_cst19__termite = _i("termite-linker");

_cst20__termite = _i("make-thread");

_cst21__termite = _i("termite#linker");

_cst22__termite = _i("termite-spawner");

_cst23__termite = _i("thread-mailbox-next");

_cst24__termite = _i("##with-exception-handler");

_cst25__termite = _i("thread-specific-set!");

_cst26__termite = _i("termite#spawner");

_cst27__termite = _i("termite-publisher");

_cst28__termite = _i("thread-specific");

_cst29__termite = _i("thread-start!");

_cst30__termite = _i("termite#publisher");

_cst31__termite = _i("termite#*server-timeout*");

_cst32__termite = _i("termite#*event-manager-timeout*");

_cst34__termite = new _Structure([null,_i("##type-5"),_i("type"),8,!1,[_i("id"),1,!1,_i("name"),5,!1,_i("flags"),5,!1,_i("super"),5,!1,_i("fields"),5,!1]]);

_cst43__termite = _i("##type-4-1d3007b8-c5aa-4090-ab55-e352040a4498");

_cst46__termite = _i("init");

_cst47__termite = _i("notify");

_cst48__termite = _i("call");

_cst49__termite = _i("terminate");

_cst33__termite = new _Structure([_cst34__termite,_cst43__termite,_i("event-handler"),24,!1,[_cst46__termite,2,!1,_cst47__termite,2,!1,_cst48__termite,2,!1,_cst49__termite,2,!1]]);

_cst50__termite = _i("termite#file-output-log-handler");

_cst51__termite = _i("termite-logger");

_cst52__termite = _i("##type-3-6a3a285f-02c4-49ac-b00a-aa57b1ad02cf");

_cst53__termite = _i("anonymous-event-manager");

_cst54__termite = _i("##current-error-port");

_cst55__termite = _i("thread-mailbox-extract-and-rewind");

_cst56__termite = _make_interned_keyword("bad-match");

_cst57__termite = _i("##close-output-port");

_cst58__termite = _i("register");

_cst59__termite = new _Structure([_cst34__termite,_cst52__termite,_i("termite-exception"),24,!1,[_i("origin"),0,!1,_i("reason"),0,!1,_i("object"),0,!1]]);

_cst65__termite = _i("normal");

_cst66__termite = _i("thread-terminate!");

_cst67__termite = _i("##raise");

_cst68__termite = _i("link");

_cst69__termite = _make_interned_keyword("path");

_cst70__termite = _make_interned_keyword("create");

_cst71__termite = _i("maybe");

_cst72__termite = _make_interned_keyword("append");

_cst73__termite = _i("unregister");

_cst74__termite = _i("thread?");

_cst75__termite = _i("##open-output-file");

_cst76__termite = new _ScmString(_z("cBcWcHcUcPcLcWcHQcOcRcJ"));

_cst77__termite = _i("relay");

_cst78__termite = new _ScmString(_z("cGcLcVcScDcWcFcKcHcUCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH]C"));

_cst79__termite = new _ScmString(_z("cOcLcQcNcHcUCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH]C"));

_cst80__termite = _i("termite#logger");

_cst81__termite = _i("termite-ping-server");

_cst82__termite = _i("thread-send");

_cst83__termite = _i("##type-2-9e096e09-8c66-4058-bddb-e061f2209838");

_cst84__termite = new _ScmString(_z("cVcScDcZcQcHcUCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH]C"));

_cst85__termite = _i("termite#ping-server");

_cst86__termite = _i("##unknown-procedure-handler-set!");

_cst87__termite = new _ScmString(_z("cLcQcYcDcOcLcGPcPcHcVcVcDcJcHPcGcHcVcWcLcQcDcWcLcRcQ"));

_cst88__termite = _i("##error");

_cst89__termite = _i("warning");

_cst90__termite = _i("spawn");

_cst91__termite = _i("##remove");

_cst92__termite = _i("publish");

_cst93__termite = _make_interned_char(35);

_cst94__termite = _i("##symbol->string");

_cst95__termite = new _ScmString(_z("cOcRcFcDcOcKcRcVcW"));

_cst96__termite = _i("unpublish");

_cst97__termite = _i("##string-split-at-char-reversed");

_cst98__termite = _i("termite#node1");

_cst99__termite = new _ScmString(_z("cOcRcFcDcOcKcRcVcW"));

_cst100__termite = _i("##equal?");

_cst102__termite = _i("upid");

_cst104__termite = _i("tag");

_cst101__termite = new _Structure([_cst34__termite,_cst83__termite,_cst102__termite,24,!1,[_cst104__termite,0,!1,_i("node"),0,!1]]);

_cst106__termite = new _ScmString(_z("cScXcVcOcLcVcKcHcUCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH]C"));

_cst107__termite = _i("termite#node2");

_cst108__termite = _i("linker");

_cst109__termite = new _ScmString(_z("cLcQCcOcLcQcNcHcUPcOcRcRcS]CcXcQcNcQcRcZcQCcRcEcMcHcFcW"));

_cst110__termite = _i("##last");

_cst111__termite = _i("##load-module");

_cst112__termite = _i("##assoc");

_cst113__termite = _i("resolve");

_cst114__termite = _i("ping");

_cst115__termite = new _ScmString(_z("cScLcQcJPcVcHcUcYcHcUCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH"));

_cst116__termite = _i("##get-subprocedure-from-name-and-id");

_cst117__termite = _i("debug");

_cst118__termite = _i("dict-set!");

_cst119__termite = _i("pong");

_cst120__termite = _i("dict-ref");

_cst121__termite = _i("##current-time");

_cst122__termite = _i("##time->seconds");

_cst123__termite = new _ScmString(_z("cGcDcWcH"));

_cst124__termite = _i("open-process");

_cst125__termite = _i("##read-line");

_cst126__termite = _i("##close-port");

_cst127__termite = _i("##structure-copy");

_cst128__termite = _i("##direct-structure-set");

_cst129__termite = _i("##number?");

_cst130__termite = new _ScmString(_z("cVcWcUcLcQcJCcDcQcGCcQcXcPcEcHcUCcHc[cScHcFcWcHcG]"));

_cst131__termite = _i("##number->string");

_cst132__termite = new _ScmString(_z("]"));

_cst133__termite = _i("##string-append");

_cst134__termite = new _ScmString(_z("]"));

_cst135__termite = new _ScmString(_z("cQcRcGcHCcHc[cScHcFcWcHcG]"));

_cst136__termite = _i("##string-contains");

_cst137__termite = _i("##substring");

_cst138__termite = new _ScmString(_z("]"));

_cst139__termite = new _ScmString(_z("cQcRcGcHCcHc[cScHcFcWcHcG]"));

_cst140__termite = _i("##string->number");

_cst142__termite = _i("##type-1-efa4f5f8-c74c-465b-af93-720d44a08374");

_cst141__termite = new _Structure([_cst34__termite,_cst142__termite,_cst104__termite,24,!1,[_i("uuid"),8,!1]]);

_cst146__termite = _i("##type-1-1d0a2e32-ab57-4544-8c3f-2cf4af25f289");

_cst147__termite = _i("proxy");

_cst145__termite = new _Structure([_cst34__termite,_cst146__termite,_cst147__termite,24,!1,[_cst102__termite,0,!1]]);

_cst150__termite = _i("##type-1-01a2b160-0fe6-4cf0-911f-e76e085b1015");

_cst149__termite = new _Structure([_cst34__termite,_cst150__termite,_i("proxy-callback"),24,!1,[_i("thunk"),0,!1]]);

_cst154__termite = new _ScmString(_z(""));

_cst155__termite = _i("##call-with-output-string");

_cst156__termite = _i("display-exception-in-context");

_cst157__termite = _i("error");

_cst158__termite = _i("failure");

_cst159__termite = _i("anonymous-linked-to");

_cst160__termite = _i("anonymous-linked");

_cst161__termite = _i("anonymous-remote");

_cst162__termite = _i("spawner");

_cst163__termite = _i("terminated");

_cst164__termite = _i("##with-exception-catcher");

_cst165__termite = _i("thread-join!");

_cst166__termite = _i("join-timeout-exception?");

_cst167__termite = _i("mailbox-receive-timeout-exception?");

_cst168__termite = _i("thread-mailbox-rewind");

_cst169__termite = _i("thread-receive");

_cst170__termite = _i("timeout");

_cst172__termite = _i("##type-1-b0c30401-474c-4e83-94b4-d516e00fe363");

_cst173__termite = _i("termite-output-port");

_cst175__termite = _i("pid");

_cst171__termite = new _Structure([_cst34__termite,_cst172__termite,_cst173__termite,24,!1,[_cst175__termite,1,!1]]);

_cst177__termite = _i("##type-1-ebb22fcb-ca61-4765-9896-49e6716471c3");

_cst178__termite = _i("termite-input-port");

_cst176__termite = new _Structure([_cst34__termite,_cst177__termite,_cst178__termite,24,!1,[_cst175__termite,1,!1]]);

_cst180__termite = _i("##output-port-readtable");

_cst181__termite = _i("readtable-sharing-allowed?-set");

_cst182__termite = _i("##output-port-readtable-set!");

_cst183__termite = new _ScmString(_z("cXcQcNcQcRcZcQCcPcHcVcVcDcJcHCcVcHcQcWCcWcRCcRcXcWcScXcWCcScRcUcW]C"));

_cst184__termite = _i("##input-port-readtable");

_cst185__termite = _i("##input-port-readtable-set!");

_cst186__termite = new _ScmString(_z("cXcQcNcQcRcZcQCcPcHcVcVcDcJcHCcVcHcQcWCcWcRCcLcQcScXcWCcScRcUcW]C"));

_cst187__termite = _i("mutex-lock!");

_cst188__termite = _i("##table-ref");

_cst189__termite = _i("mutex-unlock!");

_cst190__termite = _i("termite/utils#make-uuid");

_cst191__termite = _i("##table-set!");

_cst192__termite = new _ScmString(_z("Pe-Cc3c5c2c;c<Cc,c1c)c2Cc+c(c$c'c(c5CPe-"));

_cst193__termite = _i("##println");

_cst194__termite = new _ScmString(_z("cScUcRc[c!PcFcRcXcQcWcHcU]C"));

_cst195__termite = new _ScmString(_z("cScUcRc[c!PcUcHcTcXcHcVcWPcFcRcXcQcWcHcU]C"));

_cst196__termite = new _ScmString(_z("PeD"));

_cst197__termite = _i("get");

_cst198__termite = new _ScmString(_z("c,cJcQcRcUcHCcPcVcJC"));

_cst199__termite = _i("clean");

_cst200__termite = _i("##port?");

_cst201__termite = new _ScmString(_z("cGcRcQJcWCcNcQcRcZCcKcRcZCcWcRCcXcScLcGPacScLcG"));

_cst202__termite = _i("##object->u8vector");

_cst203__termite = _i("##bitwise-and");

_cst204__termite = _i("##arithmetic-shift");

_cst205__termite = _i("##write-subu8vector");

_cst206__termite = _i("##read-subu8vector");

_cst207__termite = new _ScmString(_z("cGcHcVcHcUcLcDcOcLc]cDcWcLcRcQCcHcUcUcRcU"));

_cst208__termite = _i("##eqv?");

_cst209__termite = _i("u8vector->object");

_cst210__termite = _make_interned_keyword("len");

_cst211__termite = _make_interned_keyword("n");

_cst212__termite = new _ScmString(_z("cGcHcVcHcUcLcDcOcLc]cDcWcLcRcQCcHcUcUcRcU"));

_cst213__termite = _i("##vector->list");

_cst214__termite = _i("termite-serializing-output-port");

_cst215__termite = _i("write");

_cst216__termite = new _ScmString(_z("cVcHcUcLcDcOcLc]cLcQcJPcRcXcWcScXcWPcScRcUcWCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH]C"));

_cst217__termite = _i("##force-output");

_cst218__termite = _i("termite-serializing-active-input-port");

_cst219__termite = _i("ok");

_cst220__termite = _make_interned_keyword("local-address");

_cst221__termite = _make_interned_keyword("local-port-number");

_cst222__termite = _make_interned_keyword("coalesce");

_cst223__termite = _i("open-tcp-server");

_cst224__termite = _i("termite-tcp-server");

_cst225__termite = _i("##read");

_cst226__termite = new _ScmString(_z(""));

_cst227__termite = new _ScmString(_z("cOcRcFcDcOcKcRcVcW"));

_cst228__termite = _i("tcp-server-socket-info");

_cst229__termite = _i("socket-info-port-number");

_cst230__termite = _i("termite-outbound-messenger");

_cst231__termite = _make_interned_keyword("address");

_cst232__termite = _make_interned_keyword("port-number");

_cst233__termite = _i("open-tcp-client");

_cst234__termite = _i("termite-inbound-messenger");

_cst235__termite = new _ScmString(_z("cPcHcVcVcHcQcJcHcUPcOcRcRcSCcLcJcQcRcUcHcGCcPcHcVcVcDcJcH]C"));

_cst237__termite = _i("##type-4-2ca2d07c-5d6a-44a8-98eb-422b2b8e7296");

_cst240__termite = _i("cast");

_cst236__termite = new _Structure([_cst34__termite,_cst237__termite,_i("server-plugin"),24,!1,[_cst46__termite,2,!1,_cst48__termite,2,!1,_cst240__termite,2,!1,_cst49__termite,2,!1]]);

_cst241__termite = _i("stop");

_cst242__termite = _i("##call-with-values");

_cst243__termite = _i("anonymous-generic-server");

_cst244__termite = _i("anonymous-linked-generic-server");

_cst245__termite = _i("add-handler");

_cst246__termite = new _ScmString(_z("cKcDcQcGcOcHcUCcGcRcHcVcQJcWCcHc[cLcVcWcV"));

_cst247__termite = _i("anonymous-linked-event-manager");

_cst248__termite = _i("thread-name");

_cst249__termite = new _ScmString(_z("P"));

_cst250__termite = _i("cell");

_cst251__termite = _i("empty?");

_cst252__termite = _i("set!");

_cst253__termite = _i("ref");

_cst254__termite = _i("dictionary");

_cst255__termite = _make_interned_keyword("test");

_cst256__termite = _make_interned_keyword("init");

_cst257__termite = _i("dict?");

_cst258__termite = _i("dict-for-each");

_cst259__termite = _i("dict-length");

_cst260__termite = _i("dict-search");

_cst261__termite = _i("##table-for-each");

_cst262__termite = _i("##table-length");

_cst263__termite = _make_interned_keyword("ignored");

_cst264__termite = _i("dict->list");

_cst265__termite = _i("##table-search");

_cst266__termite = _i("##table->list");

_cst267__termite = _i("bag");

_cst268__termite = _i("bag-add!");

_cst269__termite = _i("bag?");

_cst270__termite = _i("bag-remove!");

_cst271__termite = _i("bag-length");

_cst272__termite = _i("bag-for-each");

_cst273__termite = _i("bag-member?");

_cst274__termite = _i("bag-search");

_cst275__termite = _i("bag->list");

_cst276__termite = _i("##call-with-current-continuation");

_cst277__termite = new _ScmString(_z("cFcDcWcFcKPcDcOcOCcUcXcOcHCcLcQcYcRcNcHcGCcLcQCcUcHcScRcUcWPcHcYcHcQcW"));

_cst278__termite = _i("##display");

_cst279__termite = _i("##newline0");

_cst280__termite = _i("##with-output-to-port");

_cst281__termite = new _ScmString(_z("c>"));

_cst282__termite = new _ScmString(_z("c@C"));

_cst283__termite = _i("info");

_cst284__termite = _i("ping-server");

_cst285__termite = _i("no-reply");

_cst286__termite = new _ScmString(_z(""));

_cst287__termite = new _ScmString(_z("cXcQcL}dWcWcLcDcOcLc]cHcGCcQcRcGcH"));

_m(_bb1_termite_23_ = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_);
}
_g["termite#current-node"] = _bb1_termite_23_current_2d_node;
_s[_t+1] = _r;
_a = _cst1__termite;
++_t;
return _p(_bb2_termite_23_);
},-1,_i("termite#"),!1,!0);

_j(_bb2_termite_23_ = () => {
_r = _bb3_termite_23_;
_n = 1;
return _g["make-mutex"]();
});

_k(_bb3_termite_23_ = () => {
_g["termite#*global-mutex*"] = _a;
_b = !0;
_a = _cst4__termite;
_r = _bb4_termite_23_;
_n = 2;
return _g["##make-table"]();
},1,1);

_k(_bb4_termite_23_ = () => {
_g["termite#*foreign->local*"] = _a;
_b = !0;
_a = _cst7__termite;
_r = _bb5_termite_23_;
_n = 2;
return _g["##make-table"]();
},1,1);

_k(_bb5_termite_23_ = () => {
_g["termite#*local->foreign*"] = _a;
_b = !0;
_a = _cst4__termite;
_r = _bb6_termite_23_;
_n = 2;
return _g["##make-table"]();
},1,1);

_k(_bb6_termite_23_ = () => {
_g["termite#*uuid->tag*"] = _a;
_g["termite#self"] = _e["current-thread"];
_g["termite#proxy-counter"] = 0;
_g["termite#proxy-request-counter"] = 0;
_a = _bb1328_termite_23_;
_c = _cst14__termite;
_b = _cst15__termite;
_r = _bb263_termite_23_;
_n = 3;
return _bb7_termite_23_();
},1,1);

_l(_bb1328_termite_23_ = () => {
if (_n !== 0) {
return _w(_bb1328_termite_23_);
}
_a = null;
return _p(_bb1331_termite_23_);
},-1);

_l(_bb7_termite_23_ = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb7_termite_23_,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb12_termite_23_,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb8_termite_23_);
},-1);

_k(_bb263_termite_23_ = () => {
_g["termite#dispatcher"] = _a;
_a = _bb1273_termite_23_;
_c = _cst19__termite;
_b = _cst15__termite;
_r = _bb388_termite_23_;
_n = 3;
return _bb264_termite_23_();
},1,1);

_j(_bb1331_termite_23_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb1332_termite_23_);
});

_l(_bb12_termite_23_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb13_termite_23_);
},1);

_j(_bb8_termite_23_ = () => {
_r = _bb9_termite_23_;
_n = 2;
--_t;
return _g["make-thread"]();
});

_l(_bb1273_termite_23_ = () => {
if (_n !== 0) {
return _w(_bb1273_termite_23_);
}
return _p(_bb1276_termite_23_);
},-1);

_l(_bb264_termite_23_ = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb264_termite_23_,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb269_termite_23_,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb265_termite_23_);
},-1);

_k(_bb388_termite_23_ = () => {
_g["termite#linker"] = _a;
_a = _bb1214_termite_23_;
_c = _cst22__termite;
_b = _cst15__termite;
_r = _bb579_termite_23_;
_n = 3;
return _bb389_termite_23_();
},1,1);

_j(_bb1332_termite_23_ = () => {
_r = _bb1333_termite_23_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb13_termite_23_ = () => {
_r = _bb14_termite_23_;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb9_termite_23_ = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb10_termite_23_;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb1276_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1277_termite_23_);
});

_l(_bb269_termite_23_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb270_termite_23_);
},1);

_j(_bb265_termite_23_ = () => {
_r = _bb266_termite_23_;
_n = 2;
--_t;
return _g["make-thread"]();
});

_l(_bb1214_termite_23_ = () => {
if (_n !== 0) {
return _w(_bb1214_termite_23_);
}
return _p(_bb1217_termite_23_);
},-1);

_l(_bb389_termite_23_ = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb389_termite_23_,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure2 = _closure_alloc([_bb394_termite_23_,_a]);
_s[_t+3] = closure2;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb390_termite_23_);
},-1);

_k(_bb579_termite_23_ = () => {
_g["termite#spawner"] = _a;
_a = _bb1092_termite_23_;
_c = _cst27__termite;
_b = _cst15__termite;
_r = _bb902_termite_23_;
_n = 3;
return _bb580_termite_23_();
},1,1);

_k(_bb1333_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1334_termite_23_;
_n = 1;
++_t;
return _bb1_termite_23_termite_2d_exception_3f_();
},2,1);

_k(_bb14_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _bb15_termite_23_;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb10_termite_23_ = () => {
_a = _s[_t];
_r = _bb11_termite_23_;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb1277_termite_23_ = () => {
_r = _bb1278_termite_23_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb270_termite_23_ = () => {
_r = _bb271_termite_23_;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb266_termite_23_ = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb267_termite_23_;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb1217_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1218_termite_23_);
});

_l(_bb394_termite_23_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb395_termite_23_);
},1);

_j(_bb390_termite_23_ = () => {
_r = _bb391_termite_23_;
_n = 2;
--_t;
return _g["make-thread"]();
});

_l(_bb1092_termite_23_ = () => {
if (_n !== 0) {
return _w(_bb1092_termite_23_);
}
_s[_t+1] = _r;
++_t;
return _p(_bb1093_termite_23_);
},-1);

_l(_bb580_termite_23_ = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb580_termite_23_,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure3 = _closure_alloc([_bb585_termite_23_,_a]);
_s[_t+3] = closure3;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb581_termite_23_);
},-1);

_k(_bb902_termite_23_ = () => {
_g["termite#publisher"] = _a;
_g["termite#*server-timeout*"] = 1;
_g["termite#*event-manager-timeout*"] = 1;
_a = new _Structure([_cst33__termite,_bb1084_termite_23_,_bb1_termite_23_report_2d_event,_bb1083_termite_23_,_bb1081_termite_23_]);
_g["termite#file-output-log-handler"] = _a;
_b = _cst51__termite;
_a = _cst15__termite;
_r = _bb905_termite_23_;
_n = 2;
return _bb903_termite_23_();
},1,1);

_k(_bb1334_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1335_termite_23_();
} else {
return _bb1336_termite_23_();
}
},3,1);

_k(_bb15_termite_23_ = () => {
_r = _bb261_termite_23_;
return _bb16_termite_23_();
},1,1);

_k(_bb11_termite_23_ = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_k(_bb1278_termite_23_ = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb1325_termite_23_();
} else {
return _bb1279_termite_23_();
}
},1,1);

_k(_bb271_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _bb272_termite_23_;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb267_termite_23_ = () => {
_a = _s[_t];
_r = _bb268_termite_23_;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb1218_termite_23_ = () => {
_r = _bb1219_termite_23_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb395_termite_23_ = () => {
_r = _bb396_termite_23_;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb391_termite_23_ = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb392_termite_23_;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb1093_termite_23_ = () => {
_r = _bb1094_termite_23_;
_n = 0;
return _bb1_termite_23_make_2d_dict();
});

_l(_bb585_termite_23_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb586_termite_23_);
},1);

_j(_bb581_termite_23_ = () => {
_r = _bb582_termite_23_;
_n = 2;
--_t;
return _g["make-thread"]();
});

_l(_bb1084_termite_23_ = () => {
if (_n !== 1) {
return _w(_bb1084_termite_23_);
}
if (_x(_a)) {
return _bb1085_termite_23_();
} else {
return _bb1090_termite_23_();
}
},-1);

_l(_bb1083_termite_23_ = () => {
if (_n !== 2) {
return _w(_bb1083_termite_23_);
}
_a = new _Values([void 0,_b]);
return _r;
},-1);

_l(_bb1081_termite_23_ = () => {
if (_n !== 2) {
return _w(_bb1081_termite_23_);
}
_a = _b;
return _p(_bb1082_termite_23_);
},-1);

_l(_bb903_termite_23_ = () => {
if (_n === 0) {
_a = _cst53__termite;
_b = null;
} else {
var error = _build_key_rest(0,2,[_cst15__termite,_cst53__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb903_termite_23_,error);
}
}
_c = _a;
_a = _bb1_termite_23_spawn;
return _p(_bb904_termite_23_);
},-1);

_k(_bb905_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb906_termite_23_;
_n = 0;
++_t;
return _g["##current-error-port"]();
},1,1);

_j(_bb1335_termite_23_ = () => {
_r = _bb1409_termite_23_;
return _bb1344_termite_23_();
});

_j(_bb1336_termite_23_ = () => {
if (_x(_s[_t])) {
return _bb1337_termite_23_();
} else {
return _bb1347_termite_23_();
}
});

_j(_bb16_termite_23_ = () => {
if (_x(_a)) {
return _bb20_termite_23_();
} else {
return _bb260_termite_23_();
}
});

_k(_bb261_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb262_termite_23_);
},1,1);

_j(_bb1325_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1326_termite_23_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1279_termite_23_ = () => {
if (_x(_a)) {
return _bb1280_termite_23_();
} else {
return _bb1322_termite_23_();
}
});

_k(_bb272_termite_23_ = () => {
_r = _bb386_termite_23_;
return _bb273_termite_23_();
},1,1);

_k(_bb268_termite_23_ = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_k(_bb1219_termite_23_ = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb1270_termite_23_();
} else {
return _bb1220_termite_23_();
}
},1,1);

_k(_bb396_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _bb397_termite_23_;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb392_termite_23_ = () => {
_a = _s[_t];
_r = _bb393_termite_23_;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb1094_termite_23_ = () => {
_r = _s[_t];
--_t;
return _p(_bb1097_termite_23_);
},1,1);

_j(_bb586_termite_23_ = () => {
_r = _bb587_termite_23_;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb582_termite_23_ = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb583_termite_23_;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb1085_termite_23_ = () => {
_b = _a.a;
_c = _a.b;
if (_c === null) {
return _bb1086_termite_23_();
} else {
return _bb1088_termite_23_();
}
});

_j(_bb1090_termite_23_ = () => {
_a = _X(_cst56__termite,_X(_a,null));
return _p(_bb1091_termite_23_);
});

_j(_bb1082_termite_23_ = () => {
_n = 1;
return _g["##close-output-port"]();
});

_j(_bb904_termite_23_ = () => {
_n = 3;
return _bb1_termite_23_internal_2d_event_2d_manager_2d_start();
});

_k(_bb906_termite_23_ = () => {
_b = _a;
_a = _bb1_termite_23_report_2d_event;
_r = _bb907_termite_23_;
_n = 2;
return _bb1_termite_23_make_2d_simple_2d_event_2d_handler();
},2,1);

_j(_bb1344_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1345_termite_23_);
});

_k(_bb1409_termite_23_ = () => {
_a = _s[_t];
_r = _s[_t-2];
return _p(_bb1410_termite_23_);
},3,1);

_j(_bb1337_termite_23_ = () => {
_a = _s[_t].b;
_b = _s[_t].a;
if (_b === _cst58__termite) {
return _bb1353_termite_23_();
} else {
return _bb1338_termite_23_();
}
});

_j(_bb1347_termite_23_ = () => {
_r = _bb1348_termite_23_;
return _bb1344_termite_23_();
});

_j(_bb20_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb21_termite_23_);
});

_j(_bb260_termite_23_ = () => {
_a = void 0;
return _r;
});

_j(_bb262_termite_23_ = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb1326_termite_23_ = () => {
_a = _s[_t];
_r = _bb1327_termite_23_;
_n = 1;
--_t;
return _g["##raise"]();
},2,1);

_j(_bb1280_termite_23_ = () => {
_b = _a.b;
_c = _a.a;
if (_c === _cst68__termite) {
return _bb1281_termite_23_();
} else {
return _bb1314_termite_23_();
}
});

_j(_bb1322_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1323_termite_23_;
++_t;
return _bb1315_termite_23_();
});

_j(_bb273_termite_23_ = () => {
if (_x(_a)) {
return _bb277_termite_23_();
} else {
return _bb385_termite_23_();
}
});

_k(_bb386_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb387_termite_23_);
},1,1);

_j(_bb1270_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1271_termite_23_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1220_termite_23_ = () => {
if (_x(_a)) {
return _bb1221_termite_23_();
} else {
return _bb1267_termite_23_();
}
});

_k(_bb397_termite_23_ = () => {
_r = _bb577_termite_23_;
return _bb398_termite_23_();
},1,1);

_k(_bb393_termite_23_ = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb1097_termite_23_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb1098_termite_23_);
});

_k(_bb587_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _bb588_termite_23_;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb583_termite_23_ = () => {
_a = _s[_t];
_r = _bb584_termite_23_;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb1086_termite_23_ = () => {
_a = _X(_cst69__termite,_X(_b,_X(_cst70__termite,_X(_cst71__termite,_X(_cst72__termite,_X(!0,null))))));
return _p(_bb1087_termite_23_);
});

_j(_bb1088_termite_23_ = () => {
_a = _X(_cst56__termite,_X(_a,null));
return _p(_bb1089_termite_23_);
});

_j(_bb1091_termite_23_ = () => {
_n = 1;
return _g["##raise"]();
});

_k(_bb907_termite_23_ = () => {
_b = _a;
_a = _s[_t];
_r = _bb908_termite_23_;
_n = 2;
return _bb1_termite_23_event_2d_manager_3a_add_2d_handler();
},2,1);

_j(_bb1345_termite_23_ = () => {
_r = _bb1346_termite_23_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1410_termite_23_ = () => {
_n = 1;
_t -= 3;
return _g["##raise"]();
});

_j(_bb1353_termite_23_ = () => {
if (_x(_a)) {
return _bb1354_termite_23_();
} else {
return _bb1362_termite_23_();
}
});

_j(_bb1338_termite_23_ = () => {
if (_b === _cst73__termite) {
return _bb1364_termite_23_();
} else {
return _bb1339_termite_23_();
}
});

_k(_bb1348_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb21_termite_23_ = () => {
_r = _bb22_termite_23_;
_n = 1;
return _g["thread?"]();
});

_k(_bb1327_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb1281_termite_23_ = () => {
if (_x(_b)) {
return _bb1282_termite_23_();
} else {
return _bb1313_termite_23_();
}
});

_j(_bb1314_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1318_termite_23_;
++_t;
return _bb1315_termite_23_();
});

_j(_bb1315_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1316_termite_23_);
});

_k(_bb1323_termite_23_ = () => {
_a = _s[_t];
_r = _bb1324_termite_23_;
--_t;
return _bb1306_termite_23_();
},2,1);

_j(_bb277_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb278_termite_23_);
});

_j(_bb385_termite_23_ = () => {
_a = void 0;
return _r;
});

_j(_bb387_termite_23_ = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb1271_termite_23_ = () => {
_a = _s[_t];
_r = _bb1272_termite_23_;
_n = 1;
--_t;
return _g["##raise"]();
},2,1);

_j(_bb1221_termite_23_ = () => {
_b = _a.b;
_c = _a.a;
if (_x(_b)) {
return _bb1222_termite_23_();
} else {
return _bb1264_termite_23_();
}
});

_j(_bb1267_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1268_termite_23_;
++_t;
return _bb1232_termite_23_();
});

_j(_bb398_termite_23_ = () => {
if (_x(_a)) {
return _bb402_termite_23_();
} else {
return _bb576_termite_23_();
}
});

_k(_bb577_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb578_termite_23_);
},1,1);

_j(_bb1098_termite_23_ = () => {
_r = _bb1099_termite_23_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb588_termite_23_ = () => {
_r = _bb900_termite_23_;
return _bb589_termite_23_();
},1,1);

_k(_bb584_termite_23_ = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb1087_termite_23_ = () => {
_n = 1;
return _g["##open-output-file"]();
});

_j(_bb1089_termite_23_ = () => {
_n = 1;
return _g["##raise"]();
});

_k(_bb908_termite_23_ = () => {
_a = _s[_t];
_c = _cst76__termite;
_b = _g["termite#file-output-log-handler"];
_r = _bb909_termite_23_;
_n = 3;
return _bb1_termite_23_event_2d_manager_3a_add_2d_handler();
},2,1);

_k(_bb1346_termite_23_ = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb1354_termite_23_ = () => {
_b = _a.b;
_a = _a.a;
if (_x(_b)) {
return _bb1355_termite_23_();
} else {
return _bb1360_termite_23_();
}
});

_j(_bb1362_termite_23_ = () => {
_r = _bb1363_termite_23_;
return _bb1344_termite_23_();
});

_j(_bb1364_termite_23_ = () => {
if (_x(_a)) {
return _bb1365_termite_23_();
} else {
return _bb1373_termite_23_();
}
});

_j(_bb1339_termite_23_ = () => {
if (_b === _cst77__termite) {
return _bb1340_termite_23_();
} else {
return _bb1375_termite_23_();
}
});

_j(_bb1350_termite_23_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _cst78__termite;
_t += 2;
return _p(_bb1351_termite_23_);
});

_k(_bb22_termite_23_ = () => {
if (!(_a === !1)) {
return _bb258_termite_23_();
} else {
return _bb23_termite_23_();
}
},4,1);

_j(_bb1275_termite_23_ = () => {
_r = _s[_t];
--_t;
return _p(_bb1276_termite_23_);
});

_j(_bb1282_termite_23_ = () => {
_c = _b.b;
_b = _b.a;
if (_x(_c)) {
return _bb1283_termite_23_();
} else {
return _bb1312_termite_23_();
}
});

_j(_bb1313_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1320_termite_23_;
++_t;
return _bb1315_termite_23_();
});

_k(_bb1318_termite_23_ = () => {
_a = _s[_t];
_r = _bb1319_termite_23_;
--_t;
return _bb1306_termite_23_();
},2,1);

_j(_bb1316_termite_23_ = () => {
_r = _bb1317_termite_23_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1306_termite_23_ = () => {
_b = _a;
_a = _cst79__termite;
return _p(_bb1307_termite_23_);
});

_k(_bb1324_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb278_termite_23_ = () => {
_r = _bb279_termite_23_;
_n = 1;
return _g["thread?"]();
});

_k(_bb1272_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb1222_termite_23_ = () => {
_d = _b.b;
_b = _b.a;
if (_x(_d)) {
return _bb1223_termite_23_();
} else {
return _bb1261_termite_23_();
}
});

_j(_bb1264_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1265_termite_23_;
++_t;
return _bb1232_termite_23_();
});

_j(_bb1232_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1233_termite_23_);
});

_k(_bb1268_termite_23_ = () => {
_a = _s[_t];
_r = _bb1269_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_j(_bb402_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb403_termite_23_);
});

_j(_bb576_termite_23_ = () => {
_a = void 0;
return _r;
});

_j(_bb578_termite_23_ = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb1099_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1100_termite_23_;
_n = 1;
++_t;
return _bb1_termite_23_termite_2d_exception_3f_();
},2,1);

_j(_bb589_termite_23_ = () => {
if (_x(_a)) {
return _bb593_termite_23_();
} else {
return _bb899_termite_23_();
}
});

_k(_bb900_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb901_termite_23_);
},1,1);

_k(_bb909_termite_23_ = () => {
_g["termite#logger"] = _s[_t];
_a = _bb1028_termite_23_;
_c = _cst81__termite;
_b = _cst15__termite;
_r = _bb1012_termite_23_;
_n = 3;
--_t;
return _bb910_termite_23_();
},2,1);

_j(_bb1355_termite_23_ = () => {
_c = _b.b;
_b = _b.a;
if (_c === null) {
return _bb1356_termite_23_();
} else {
return _bb1358_termite_23_();
}
});

_j(_bb1360_termite_23_ = () => {
_r = _bb1361_termite_23_;
return _bb1344_termite_23_();
});

_k(_bb1363_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb1365_termite_23_ = () => {
_b = _a.b;
_a = _a.a;
if (_b === null) {
return _bb1366_termite_23_();
} else {
return _bb1371_termite_23_();
}
});

_j(_bb1373_termite_23_ = () => {
_r = _bb1374_termite_23_;
return _bb1344_termite_23_();
});

_j(_bb1340_termite_23_ = () => {
if (_x(_a)) {
return _bb1341_termite_23_();
} else {
return _bb1377_termite_23_();
}
});

_j(_bb1375_termite_23_ = () => {
_r = _bb1376_termite_23_;
return _bb1344_termite_23_();
});

_j(_bb1351_termite_23_ = () => {
_r = _bb1352_termite_23_;
_n = 2;
return _bb1_termite_23_warning();
});

_j(_bb258_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb259_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb23_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb24_termite_23_();
} else {
return _bb257_termite_23_();
}
});

_j(_bb1283_termite_23_ = () => {
_d = _c.b;
_c = _c.a;
if (_d === null) {
return _bb1284_termite_23_();
} else {
return _bb1303_termite_23_();
}
});

_j(_bb1312_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1305_termite_23_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb1320_termite_23_ = () => {
_a = _s[_t];
_r = _bb1321_termite_23_;
--_t;
return _bb1306_termite_23_();
},2,1);

_k(_bb1319_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_k(_bb1317_termite_23_ = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb1307_termite_23_ = () => {
_n = 2;
return _bb1308_termite_23_();
});

_k(_bb279_termite_23_ = () => {
if (!(_a === !1)) {
return _bb383_termite_23_();
} else {
return _bb280_termite_23_();
}
},4,1);

_j(_bb1216_termite_23_ = () => {
_r = _s[_t];
--_t;
return _p(_bb1217_termite_23_);
});

_j(_bb1223_termite_23_ = () => {
_r = _d.b;
_d = _d.a;
if (_x(_d)) {
return _bb1224_termite_23_();
} else {
return _bb1258_termite_23_();
}
});

_j(_bb1261_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1262_termite_23_;
++_t;
return _bb1232_termite_23_();
});

_k(_bb1265_termite_23_ = () => {
_a = _s[_t];
_r = _bb1266_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_j(_bb1233_termite_23_ = () => {
_r = _bb1234_termite_23_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1237_termite_23_ = () => {
_b = _a;
_a = _cst84__termite;
return _p(_bb1238_termite_23_);
});

_k(_bb1269_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb403_termite_23_ = () => {
_r = _bb404_termite_23_;
_n = 1;
return _g["thread?"]();
});

_k(_bb1100_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1101_termite_23_();
} else {
return _bb1102_termite_23_();
}
},3,1);

_j(_bb593_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb594_termite_23_);
});

_j(_bb899_termite_23_ = () => {
_a = void 0;
return _r;
});

_j(_bb901_termite_23_ = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_l(_bb1028_termite_23_ = () => {
if (_n !== 0) {
return _w(_bb1028_termite_23_);
}
return _p(_bb1031_termite_23_);
},-1);

_l(_bb910_termite_23_ = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb910_termite_23_,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure4 = _closure_alloc([_bb915_termite_23_,_a]);
_s[_t+3] = closure4;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb911_termite_23_);
},-1);

_k(_bb1012_termite_23_ = () => {
_g["termite#ping-server"] = _a;
_a = _bb1017_termite_23_;
_r = _bb1013_termite_23_;
_n = 1;
return _g["##unknown-procedure-handler-set!"]();
},1,1);

_j(_bb1356_termite_23_ = () => {
_s[_t] = _a;
_s[_t+1] = _b;
_r = _bb1357_termite_23_;
++_t;
return _bb1344_termite_23_();
});

_j(_bb1358_termite_23_ = () => {
_r = _bb1359_termite_23_;
return _bb1344_termite_23_();
});

_k(_bb1361_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb1366_termite_23_ = () => {
_s[_t] = _a;
_r = _bb1367_termite_23_;
return _bb1344_termite_23_();
});

_j(_bb1371_termite_23_ = () => {
_r = _bb1372_termite_23_;
return _bb1344_termite_23_();
});

_k(_bb1374_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb1341_termite_23_ = () => {
_b = _a.b;
_a = _a.a;
if (_x(_b)) {
return _bb1342_termite_23_();
} else {
return _bb1379_termite_23_();
}
});

_j(_bb1377_termite_23_ = () => {
_r = _bb1378_termite_23_;
return _bb1344_termite_23_();
});

_k(_bb1376_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_k(_bb1352_termite_23_ = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb1331_termite_23_);
},2,1);

_k(_bb259_termite_23_ = () => {
return _bb27_termite_23_();
},2,1);

_j(_bb24_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb25_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb257_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb26_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1284_termite_23_ = () => {
_s[_t+1] = _b;
_s[_t+2] = _c;
_r = _bb1285_termite_23_;
_n = 0;
_t += 2;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1303_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1304_termite_23_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb1305_termite_23_ = () => {
_a = _s[_t];
_r = _bb1310_termite_23_;
--_t;
return _bb1306_termite_23_();
},2,1);

_k(_bb1321_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_l(_bb1308_termite_23_ = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1308_termite_23_);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb1309_termite_23_);
},-1);

_j(_bb383_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb384_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb280_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb281_termite_23_();
} else {
return _bb382_termite_23_();
}
});

_j(_bb1224_termite_23_ = () => {
_s[_t+1] = _d.b;
_d = _d.a;
if (_d === _cst90__termite) {
++_t;
return _bb1225_termite_23_();
} else {
++_t;
return _bb1255_termite_23_();
}
});

_j(_bb1258_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1259_termite_23_;
++_t;
return _bb1232_termite_23_();
});

_k(_bb1262_termite_23_ = () => {
_a = _s[_t];
_r = _bb1263_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1266_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_k(_bb1234_termite_23_ = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb1238_termite_23_ = () => {
_n = 2;
return _bb1239_termite_23_();
});

_k(_bb404_termite_23_ = () => {
if (!(_a === !1)) {
return _bb574_termite_23_();
} else {
return _bb405_termite_23_();
}
},4,1);

_j(_bb1101_termite_23_ = () => {
_r = _bb1212_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1102_termite_23_ = () => {
if (_x(_s[_t])) {
return _bb1103_termite_23_();
} else {
return _bb1116_termite_23_();
}
});

_j(_bb594_termite_23_ = () => {
_r = _bb595_termite_23_;
_n = 1;
return _g["thread?"]();
});

_j(_bb1031_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1032_termite_23_);
});

_l(_bb915_termite_23_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb916_termite_23_);
},1);

_j(_bb911_termite_23_ = () => {
_r = _bb912_termite_23_;
_n = 2;
--_t;
return _g["make-thread"]();
});

_l(_bb1017_termite_23_ = () => {
if (_n !== 2) {
return _w(_bb1017_termite_23_);
}
var tmp5 = _a.d;
_c = _y(tmp5) ? !1 : tmp5;
if (!(_c === !1)) {
return _bb1019_termite_23_();
} else {
return _bb1027_termite_23_();
}
},-1);

_k(_bb1013_termite_23_ = () => {
_a = _current_processor.a[14];
_b = null;
_r = _bb1014_termite_23_;
_n = 2;
return _g["thread-specific-set!"]();
},1,1);

_k(_bb1357_termite_23_ = () => {
_a = _X(_s[_t],_s[_t-1]);
_a = _X(_a,_s[_t-2]);
_r = _s[_t-3];
_t -= 4;
return _p(_bb1331_termite_23_);
},4,1);

_k(_bb1359_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_k(_bb1367_termite_23_ = () => {
var closure6 = _closure_alloc([_bb1369_termite_23_,_s[_t]]);
_s[_t+1] = closure6;
_a = _s[_t+1];
_b = _s[_t-1];
_r = _bb1368_termite_23_;
_n = 2;
_t -= 2;
return _g["##remove"]();
},3,1);

_k(_bb1372_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb1342_termite_23_ = () => {
_c = _b.b;
_b = _b.a;
if (_c === null) {
return _bb1381_termite_23_();
} else {
return _bb1343_termite_23_();
}
});

_j(_bb1379_termite_23_ = () => {
_r = _bb1380_termite_23_;
return _bb1344_termite_23_();
});

_k(_bb1378_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb27_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb28_termite_23_();
} else {
return _bb256_termite_23_();
}
});

_k(_bb25_termite_23_ = () => {
return _bb27_termite_23_();
},2,1);

_k(_bb26_termite_23_ = () => {
return _bb27_termite_23_();
},2,1);

_k(_bb1285_termite_23_ = () => {
_a = _s[_t-1];
_r = _bb1286_termite_23_;
_n = 1;
return _g["thread?"]();
},3,1);

_k(_bb1304_termite_23_ = () => {
_a = _s[_t];
_r = _bb1311_termite_23_;
--_t;
return _bb1306_termite_23_();
},2,1);

_k(_bb1310_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb1309_termite_23_ = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_k(_bb384_termite_23_ = () => {
return _bb284_termite_23_();
},2,1);

_j(_bb281_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb282_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb382_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb283_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1225_termite_23_ = () => {
if (_x(_s[_t])) {
return _bb1226_termite_23_();
} else {
return _bb1252_termite_23_();
}
});

_j(_bb1255_termite_23_ = () => {
_s[_t] = _a;
_r = _bb1256_termite_23_;
return _bb1232_termite_23_();
});

_k(_bb1259_termite_23_ = () => {
_a = _s[_t];
_r = _bb1260_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1263_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_l(_bb1239_termite_23_ = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1239_termite_23_);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb1240_termite_23_);
},-1);

_j(_bb574_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb575_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb405_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb406_termite_23_();
} else {
return _bb573_termite_23_();
}
});

_j(_bb1113_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1114_termite_23_);
});

_k(_bb1212_termite_23_ = () => {
_a = _s[_t];
_r = _bb1213_termite_23_;
_n = 1;
--_t;
return _g["##raise"]();
},3,1);

_j(_bb1103_termite_23_ = () => {
_a = _s[_t].b;
_b = _s[_t].a;
if (_b === _cst92__termite) {
return _bb1123_termite_23_();
} else {
return _bb1104_termite_23_();
}
});

_j(_bb1116_termite_23_ = () => {
_r = _bb1117_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb595_termite_23_ = () => {
if (!(_a === !1)) {
return _bb897_termite_23_();
} else {
return _bb596_termite_23_();
}
},4,1);

_j(_bb1032_termite_23_ = () => {
_r = _bb1033_termite_23_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb916_termite_23_ = () => {
_r = _bb917_termite_23_;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb912_termite_23_ = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb913_termite_23_;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb1019_termite_23_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _c;
_b = _cst93__termite;
_t += 3;
return _p(_bb1020_termite_23_);
});

_j(_bb1027_termite_23_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_r = _bb1018_termite_23_;
_n = 1;
_t += 3;
return _e["##symbol->string"]();
});

_k(_bb1014_termite_23_ = () => {
_b = 3001;
_a = _cst95__termite;
_r = _bb1015_termite_23_;
_n = 2;
return _bb1_termite_23_make_2d_node();
},1,1);

_l(_bb1369_termite_23_ = () => {
if (_n !== 1) {
return _w(_d);
}
_b = _d(!0)[1];
_a = _a.b;
return _p(_bb1370_termite_23_);
},1);

_k(_bb1368_termite_23_ = () => {
_r = _s[_t];
--_t;
return _p(_bb1331_termite_23_);
},1,1);

_j(_bb1381_termite_23_ = () => {
_s[_t] = _a;
_s[_t+1] = _b;
_r = _bb1382_termite_23_;
++_t;
return _bb1344_termite_23_();
});

_j(_bb1343_termite_23_ = () => {
_r = _bb1349_termite_23_;
return _bb1344_termite_23_();
});

_k(_bb1380_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_j(_bb28_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb29_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb256_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1286_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1300_termite_23_();
} else {
return _bb1287_termite_23_();
}
},3,1);

_k(_bb1311_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb284_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb285_termite_23_();
} else {
return _bb381_termite_23_();
}
});

_k(_bb282_termite_23_ = () => {
return _bb284_termite_23_();
},2,1);

_k(_bb283_termite_23_ = () => {
return _bb284_termite_23_();
},2,1);

_j(_bb1226_termite_23_ = () => {
_d = _s[_t].b;
_s[_t] = _s[_t].a;
if (_x(_d)) {
return _bb1227_termite_23_();
} else {
return _bb1249_termite_23_();
}
});

_j(_bb1252_termite_23_ = () => {
_s[_t] = _a;
_r = _bb1253_termite_23_;
return _bb1232_termite_23_();
});

_k(_bb1256_termite_23_ = () => {
_a = _s[_t];
_r = _bb1257_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1260_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb1240_termite_23_ = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_k(_bb575_termite_23_ = () => {
return _bb409_termite_23_();
},2,1);

_j(_bb406_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb407_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb573_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb408_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1114_termite_23_ = () => {
_r = _bb1115_termite_23_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb1213_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1123_termite_23_ = () => {
if (_x(_a)) {
return _bb1124_termite_23_();
} else {
return _bb1161_termite_23_();
}
});

_j(_bb1104_termite_23_ = () => {
if (_b === _cst96__termite) {
return _bb1164_termite_23_();
} else {
return _bb1105_termite_23_();
}
});

_k(_bb1117_termite_23_ = () => {
_a = _s[_t];
_r = _bb1122_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_j(_bb897_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb898_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb596_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb597_termite_23_();
} else {
return _bb896_termite_23_();
}
});

_k(_bb1033_termite_23_ = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb1078_termite_23_();
} else {
return _bb1034_termite_23_();
}
},1,1);

_k(_bb917_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _bb918_termite_23_;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb913_termite_23_ = () => {
_a = _s[_t];
_r = _bb914_termite_23_;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb1020_termite_23_ = () => {
_r = _bb1021_termite_23_;
_n = 2;
return _g["##string-split-at-char-reversed"]();
});

_k(_bb1018_termite_23_ = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _bb1019_termite_23_();
},3,1);

_k(_bb1015_termite_23_ = () => {
_g["termite#node1"] = _a;
_b = 3002;
_a = _cst99__termite;
_r = _bb1016_termite_23_;
_n = 2;
return _bb1_termite_23_make_2d_node();
},1,1);

_j(_bb1370_termite_23_ = () => {
_n = 2;
return _e["##equal?"]();
});

_k(_bb1382_termite_23_ = () => {
_a = _s[_t-1].a[2];
_s[_t+1] = _a;
_r = _bb1383_termite_23_;
_n = 0;
++_t;
return _g["termite#current-node"]();
},4,1);

_k(_bb1349_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb1350_termite_23_);
},3,1);

_k(_bb29_termite_23_ = () => {
if (!(_a === !1)) {
return _bb254_termite_23_();
} else {
return _bb30_termite_23_();
}
},4,1);

_j(_bb1300_termite_23_ = () => {
_a = _s[_t-1];
_r = _bb1301_termite_23_;
_n = 1;
return _g["thread-specific"]();
});

_j(_bb1287_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1292_termite_23_();
} else {
return _bb1288_termite_23_();
}
});

_j(_bb285_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb286_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb381_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb1227_termite_23_ = () => {
_s[_t+1] = _d.b;
_d = _d.a;
if (_x(_s[_t+1])) {
++_t;
return _bb1228_termite_23_();
} else {
++_t;
return _bb1246_termite_23_();
}
});

_j(_bb1249_termite_23_ = () => {
_s[_t] = _a;
_r = _bb1250_termite_23_;
return _bb1232_termite_23_();
});

_k(_bb1253_termite_23_ = () => {
_a = _s[_t];
_r = _bb1254_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1257_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb409_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb410_termite_23_();
} else {
return _bb572_termite_23_();
}
});

_k(_bb407_termite_23_ = () => {
return _bb409_termite_23_();
},2,1);

_k(_bb408_termite_23_ = () => {
return _bb409_termite_23_();
},2,1);

_k(_bb1115_termite_23_ = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb1096_termite_23_ = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb1097_termite_23_);
});

_j(_bb1124_termite_23_ = () => {
_b = _a.b;
_a = _a.a;
if (_x(_b)) {
return _bb1125_termite_23_();
} else {
return _bb1158_termite_23_();
}
});

_j(_bb1161_termite_23_ = () => {
_r = _bb1162_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1164_termite_23_ = () => {
if (_x(_a)) {
return _bb1165_termite_23_();
} else {
return _bb1188_termite_23_();
}
});

_j(_bb1105_termite_23_ = () => {
if (_x(_a)) {
return _bb1106_termite_23_();
} else {
return _bb1191_termite_23_();
}
});

_j(_bb1119_termite_23_ = () => {
_b = _a;
_a = _cst106__termite;
return _p(_bb1120_termite_23_);
});

_k(_bb1122_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb898_termite_23_ = () => {
return _bb600_termite_23_();
},2,1);

_j(_bb597_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb598_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb896_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb599_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1078_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1079_termite_23_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1034_termite_23_ = () => {
if (_x(_a)) {
return _bb1035_termite_23_();
} else {
return _bb1075_termite_23_();
}
});

_k(_bb918_termite_23_ = () => {
_r = _bb1010_termite_23_;
return _bb919_termite_23_();
},1,1);

_k(_bb914_termite_23_ = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_k(_bb1021_termite_23_ = () => {
_b = _a.b;
if (_x(_b)) {
return _bb1022_termite_23_();
} else {
return _bb1026_termite_23_();
}
},3,1);

_k(_bb1016_termite_23_ = () => {
_g["termite#node2"] = _a;
_a = void 0;
--_t;
return _s[_t+1]();
},1,1);

_k(_bb1383_termite_23_ = () => {
_b = _a;
_a = _s[_t];
_r = _bb1384_termite_23_;
_n = 2;
return _e["##equal?"]();
},5,1);

_j(_bb254_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb255_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb30_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb31_termite_23_();
} else {
return _bb253_termite_23_();
}
});

_k(_bb1301_termite_23_ = () => {
_a = _X(_s[_t],_a);
_b = _a;
_a = _s[_t-1];
_r = _bb1302_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-specific-set!"]();
},3,1);

_j(_bb1292_termite_23_ = () => {
_a = _s[_t-1].a[2];
_a = new _Structure([_cst101__termite,_cst108__termite,_a]);
_b = _X(_cst68__termite,_X(_s[_t-1],_X(_s[_t],null)));
_s[_t-1] = _a;
_s[_t] = _b;
_r = _bb1293_termite_23_;
_n = 1;
return _g["thread?"]();
});

_j(_bb1288_termite_23_ = () => {
_a = _cst109__termite;
_r = _bb1291_termite_23_;
_n = 1;
_t -= 2;
return _bb1289_termite_23_();
});

_k(_bb286_termite_23_ = () => {
if (!(_a === !1)) {
return _bb379_termite_23_();
} else {
return _bb287_termite_23_();
}
},4,1);

_j(_bb1228_termite_23_ = () => {
_s[_t+1] = _s[_t].b;
_s[_t] = _s[_t].a;
if (_s[_t+1] === null) {
++_t;
return _bb1229_termite_23_();
} else {
++_t;
return _bb1231_termite_23_();
}
});

_j(_bb1246_termite_23_ = () => {
_s[_t-1] = _a;
_r = _bb1247_termite_23_;
--_t;
return _bb1232_termite_23_();
});

_k(_bb1250_termite_23_ = () => {
_a = _s[_t];
_r = _bb1251_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1254_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb410_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb411_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb572_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb1125_termite_23_ = () => {
_c = _b.b;
_b = _b.a;
if (_c === null) {
return _bb1126_termite_23_();
} else {
return _bb1143_termite_23_();
}
});

_j(_bb1158_termite_23_ = () => {
_r = _bb1159_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1162_termite_23_ = () => {
_a = _s[_t];
_r = _bb1163_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_j(_bb1165_termite_23_ = () => {
_b = _a.b;
_a = _a.a;
if (_x(_b)) {
return _bb1166_termite_23_();
} else {
return _bb1185_termite_23_();
}
});

_j(_bb1188_termite_23_ = () => {
_r = _bb1189_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1106_termite_23_ = () => {
_c = _a.b;
_a = _a.a;
if (_x(_c)) {
return _bb1107_termite_23_();
} else {
return _bb1194_termite_23_();
}
});

_j(_bb1191_termite_23_ = () => {
_r = _bb1192_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1120_termite_23_ = () => {
_n = 2;
return _bb1_termite_23_warning();
});

_j(_bb600_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb601_termite_23_();
} else {
return _bb895_termite_23_();
}
});

_k(_bb598_termite_23_ = () => {
return _bb600_termite_23_();
},2,1);

_k(_bb599_termite_23_ = () => {
return _bb600_termite_23_();
},2,1);

_k(_bb1079_termite_23_ = () => {
_a = _s[_t];
_r = _bb1080_termite_23_;
_n = 1;
--_t;
return _g["##raise"]();
},2,1);

_j(_bb1035_termite_23_ = () => {
_b = _a.b;
_c = _a.a;
if (_x(_b)) {
return _bb1036_termite_23_();
} else {
return _bb1072_termite_23_();
}
});

_j(_bb1075_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1076_termite_23_;
++_t;
return _bb1067_termite_23_();
});

_j(_bb919_termite_23_ = () => {
if (_x(_a)) {
return _bb923_termite_23_();
} else {
return _bb1009_termite_23_();
}
});

_k(_bb1010_termite_23_ = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb1011_termite_23_);
},1,1);

_j(_bb1022_termite_23_ = () => {
_r = _bb1023_termite_23_;
_n = 1;
return _e["##last"]();
});

_j(_bb1026_termite_23_ = () => {
_a = !1;
_t -= 3;
return _s[_t+1]();
});

_k(_bb1384_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1398_termite_23_();
} else {
return _bb1385_termite_23_();
}
},5,1);

_k(_bb255_termite_23_ = () => {
return _bb34_termite_23_();
},2,1);

_j(_bb31_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb32_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb253_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb33_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb1302_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_k(_bb1293_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1298_termite_23_();
} else {
return _bb1294_termite_23_();
}
},3,1);

_l(_bb1289_termite_23_ = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1289_termite_23_);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb1290_termite_23_);
},-1);

_k(_bb1291_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb379_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb380_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb287_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb288_termite_23_();
} else {
return _bb378_termite_23_();
}
});

_j(_bb1229_termite_23_ = () => {
if (_r === null) {
return _bb1243_termite_23_();
} else {
return _bb1230_termite_23_();
}
});

_j(_bb1231_termite_23_ = () => {
_s[_t-2] = _a;
_r = _bb1235_termite_23_;
_t -= 2;
return _bb1232_termite_23_();
});

_k(_bb1247_termite_23_ = () => {
_a = _s[_t];
_r = _bb1248_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1251_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_k(_bb411_termite_23_ = () => {
if (!(_a === !1)) {
return _bb570_termite_23_();
} else {
return _bb412_termite_23_();
}
},4,1);

_j(_bb1126_termite_23_ = () => {
_s[_t] = _a;
_s[_t+1] = _b;
_r = _bb1127_termite_23_;
++_t;
return _bb1113_termite_23_();
});

_j(_bb1143_termite_23_ = () => {
if (_x(_b)) {
return _bb1144_termite_23_();
} else {
return _bb1155_termite_23_();
}
});

_k(_bb1159_termite_23_ = () => {
_a = _s[_t];
_r = _bb1160_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1163_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1166_termite_23_ = () => {
_c = _b.b;
_b = _b.a;
if (_c === null) {
return _bb1167_termite_23_();
} else {
return _bb1170_termite_23_();
}
});

_j(_bb1185_termite_23_ = () => {
_r = _bb1186_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1189_termite_23_ = () => {
_a = _s[_t];
_r = _bb1190_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_j(_bb1107_termite_23_ = () => {
_d = _c.b;
_c = _c.a;
if (_x(_c)) {
return _bb1108_termite_23_();
} else {
return _bb1197_termite_23_();
}
});

_j(_bb1194_termite_23_ = () => {
_r = _bb1195_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1192_termite_23_ = () => {
_a = _s[_t];
_r = _bb1193_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_j(_bb601_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb602_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb895_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1080_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_j(_bb1036_termite_23_ = () => {
_d = _b.b;
_b = _b.a;
if (_x(_d)) {
return _bb1037_termite_23_();
} else {
return _bb1066_termite_23_();
}
});

_j(_bb1072_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1073_termite_23_;
++_t;
return _bb1067_termite_23_();
});

_j(_bb1067_termite_23_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb1068_termite_23_);
});

_k(_bb1076_termite_23_ = () => {
_a = _s[_t];
_r = _bb1077_termite_23_;
--_t;
return _bb1051_termite_23_();
},2,1);

_j(_bb923_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb924_termite_23_);
});

_j(_bb1009_termite_23_ = () => {
_a = void 0;
return _r;
});

_j(_bb1011_termite_23_ = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb1023_termite_23_ = () => {
_a = _i(_a.toString());
_r = _bb1024_termite_23_;
_n = 1;
return _g["##load-module"]();
},3,1);

_j(_bb1398_termite_23_ = () => {
_a = _s[_t-2];
_r = _bb1399_termite_23_;
_n = 1;
--_t;
return _bb1_termite_23_upid_2d__3e_pid();
});

_j(_bb1385_termite_23_ = () => {
_b = _s[_t-3];
_a = _s[_t];
_r = _bb1386_termite_23_;
_n = 2;
return _e["##assoc"]();
});

_j(_bb34_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb35_termite_23_();
} else {
return _bb252_termite_23_();
}
});

_k(_bb32_termite_23_ = () => {
return _bb34_termite_23_();
},2,1);

_k(_bb33_termite_23_ = () => {
return _bb34_termite_23_();
},2,1);

_j(_bb1298_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1299_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1294_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1295_termite_23_();
} else {
return _bb1297_termite_23_();
}
});

_j(_bb1290_termite_23_ = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_k(_bb380_termite_23_ = () => {
return _bb291_termite_23_();
},2,1);

_j(_bb288_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb289_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb378_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb290_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1243_termite_23_ = () => {
_s[_t] = _b;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb1244_termite_23_;
_n = 0;
_t += 2;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1230_termite_23_ = () => {
_s[_t-2] = _a;
_r = _bb1236_termite_23_;
_t -= 2;
return _bb1232_termite_23_();
});

_k(_bb1235_termite_23_ = () => {
_a = _s[_t];
_r = _bb1242_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1248_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb570_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb571_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb412_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb413_termite_23_();
} else {
return _bb569_termite_23_();
}
});

_k(_bb1127_termite_23_ = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _bb1142_termite_23_;
_n = 3;
_t -= 2;
return _bb1128_termite_23_();
},4,1);

_j(_bb1144_termite_23_ = () => {
_a = _b.b;
_b = _b.a;
if (_b === _cst113__termite) {
return _bb1145_termite_23_();
} else {
return _bb1152_termite_23_();
}
});

_j(_bb1155_termite_23_ = () => {
_r = _bb1156_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1160_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1167_termite_23_ = () => {
_s[_t] = _a;
_r = _bb1168_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1170_termite_23_ = () => {
if (_x(_b)) {
return _bb1171_termite_23_();
} else {
return _bb1182_termite_23_();
}
});

_k(_bb1186_termite_23_ = () => {
_a = _s[_t];
_r = _bb1187_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1190_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1108_termite_23_ = () => {
_r = _c.b;
_c = _c.a;
if (_c === _cst113__termite) {
return _bb1109_termite_23_();
} else {
return _bb1200_termite_23_();
}
});

_j(_bb1197_termite_23_ = () => {
_r = _bb1198_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1195_termite_23_ = () => {
_a = _s[_t];
_r = _bb1196_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1193_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb602_termite_23_ = () => {
if (!(_a === !1)) {
return _bb893_termite_23_();
} else {
return _bb603_termite_23_();
}
},4,1);

_j(_bb1030_termite_23_ = () => {
_r = _s[_t];
--_t;
return _p(_bb1031_termite_23_);
});

_j(_bb1037_termite_23_ = () => {
_r = _d.b;
_d = _d.a;
if (_d === _cst114__termite) {
return _bb1038_termite_23_();
} else {
return _bb1065_termite_23_();
}
});

_j(_bb1066_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1070_termite_23_;
++_t;
return _bb1067_termite_23_();
});

_k(_bb1073_termite_23_ = () => {
_a = _s[_t];
_r = _bb1074_termite_23_;
--_t;
return _bb1051_termite_23_();
},2,1);

_j(_bb1068_termite_23_ = () => {
_r = _bb1069_termite_23_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1051_termite_23_ = () => {
_b = _a;
_a = _cst115__termite;
return _p(_bb1052_termite_23_);
});

_k(_bb1077_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_j(_bb924_termite_23_ = () => {
_r = _bb925_termite_23_;
_n = 1;
return _g["thread?"]();
});

_k(_bb1024_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1025_termite_23_;
_n = 2;
_t -= 2;
return _g["##get-subprocedure-from-name-and-id"]();
},3,1);

_k(_bb1399_termite_23_ = () => {
_s[_t-1] = _a;
_r = _bb1400_termite_23_;
_n = 1;
return _g["thread?"]();
},4,1);

_k(_bb1386_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1390_termite_23_();
} else {
return _bb1387_termite_23_();
}
},5,1);

_j(_bb35_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb36_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb252_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1299_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb1295_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1296_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1297_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1274_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb291_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb292_termite_23_();
} else {
return _bb377_termite_23_();
}
});

_k(_bb289_termite_23_ = () => {
return _bb291_termite_23_();
},2,1);

_k(_bb290_termite_23_ = () => {
return _bb291_termite_23_();
},2,1);

_k(_bb1244_termite_23_ = () => {
_s[_t+1] = _s[_t];
_s[_t] = _s[_t-4];
_s[_t-4] = _s[_t+1];
_s[_t+1] = _cst16__termite;
_c = _s[_t-3];
_a = _s[_t-4];
_b = _cst15__termite;
_r = _bb1245_termite_23_;
_n = 5;
++_t;
return _bb1_termite_23_spawn();
},6,1);

_k(_bb1236_termite_23_ = () => {
_a = _s[_t];
_r = _bb1241_termite_23_;
--_t;
return _bb1237_termite_23_();
},2,1);

_k(_bb1242_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_k(_bb571_termite_23_ = () => {
return _bb416_termite_23_();
},2,1);

_j(_bb413_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb414_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb569_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb415_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_l(_bb1128_termite_23_ = () => {
if (_n === 1) {
_b = null;
} else {
if (!_build_rest(1)) {
return _w(_bb1128_termite_23_);
}
}
if (_x(_b)) {
return _bb1129_termite_23_();
} else {
return _bb1140_termite_23_();
}
},-1);

_k(_bb1142_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1145_termite_23_ = () => {
if (_x(_a)) {
return _bb1146_termite_23_();
} else {
return _bb1149_termite_23_();
}
});

_j(_bb1152_termite_23_ = () => {
_r = _bb1153_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1156_termite_23_ = () => {
_a = _s[_t];
_r = _bb1157_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1168_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1169_termite_23_;
_n = 2;
--_t;
return _bb1_termite_23_dict_2d_set_21_();
},3,1);

_j(_bb1171_termite_23_ = () => {
_a = _b.b;
_b = _b.a;
if (_b === _cst113__termite) {
return _bb1172_termite_23_();
} else {
return _bb1179_termite_23_();
}
});

_j(_bb1182_termite_23_ = () => {
_r = _bb1183_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1187_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1109_termite_23_ = () => {
if (_x(_r)) {
return _bb1110_termite_23_();
} else {
return _bb1203_termite_23_();
}
});

_j(_bb1200_termite_23_ = () => {
_r = _bb1201_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1198_termite_23_ = () => {
_a = _s[_t];
_r = _bb1199_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1196_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb893_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb894_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb603_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb604_termite_23_();
} else {
return _bb892_termite_23_();
}
});

_j(_bb1038_termite_23_ = () => {
if (_r === null) {
return _bb1039_termite_23_();
} else {
return _bb1048_termite_23_();
}
});

_j(_bb1065_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1050_termite_23_;
++_t;
return _bb1067_termite_23_();
});

_k(_bb1070_termite_23_ = () => {
_a = _s[_t];
_r = _bb1071_termite_23_;
--_t;
return _bb1051_termite_23_();
},2,1);

_k(_bb1074_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_k(_bb1069_termite_23_ = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb1052_termite_23_ = () => {
_n = 2;
return _bb1053_termite_23_();
});

_k(_bb925_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1007_termite_23_();
} else {
return _bb926_termite_23_();
}
},4,1);

_k(_bb1025_termite_23_ = () => {
--_t;
return _s[_t+1]();
},1,1);

_k(_bb1400_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1407_termite_23_();
} else {
return _bb1401_termite_23_();
}
},4,1);

_j(_bb1390_termite_23_ = () => {
_a = _a.b;
_b = _X(_cst77__termite,_X(_s[_t-2],_X(_s[_t-1],null)));
_s[_t-2] = _a;
_s[_t-1] = _b;
_r = _bb1391_termite_23_;
_n = 1;
--_t;
return _g["thread?"]();
});

_j(_bb1387_termite_23_ = () => {
_a = _s[_t];
_r = _bb1388_termite_23_;
_n = 1;
return _bb1_termite_23_initiate_2d_messenger();
});

_k(_bb36_termite_23_ = () => {
if (!(_a === !1)) {
return _bb250_termite_23_();
} else {
return _bb37_termite_23_();
}
},4,1);

_k(_bb1296_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_k(_bb1274_termite_23_ = () => {
return _bb1275_termite_23_();
},1,1);

_j(_bb292_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb293_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb377_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1245_termite_23_ = () => {
_b = _X(_s[_t-1],_X(_a,null));
_a = _s[_t];
_r = _bb1215_termite_23_;
_n = 2;
_t -= 4;
return _bb1_termite_23__21_();
},5,1);

_k(_bb1241_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb416_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb417_termite_23_();
} else {
return _bb568_termite_23_();
}
});

_k(_bb414_termite_23_ = () => {
return _bb416_termite_23_();
},2,1);

_k(_bb415_termite_23_ = () => {
return _bb416_termite_23_();
},2,1);

_j(_bb1129_termite_23_ = () => {
_c = _b.b;
_d = _b.a;
if (_c === null) {
return _bb1130_termite_23_();
} else {
return _bb1132_termite_23_();
}
});

_j(_bb1140_termite_23_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb1141_termite_23_);
});

_j(_bb1146_termite_23_ = () => {
_r = _bb1147_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1149_termite_23_ = () => {
_r = _bb1150_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1153_termite_23_ = () => {
_a = _s[_t];
_r = _bb1154_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1157_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb1169_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1172_termite_23_ = () => {
if (_x(_a)) {
return _bb1173_termite_23_();
} else {
return _bb1176_termite_23_();
}
});

_j(_bb1179_termite_23_ = () => {
_r = _bb1180_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1183_termite_23_ = () => {
_a = _s[_t];
_r = _bb1184_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_j(_bb1110_termite_23_ = () => {
_c = _r.b;
_r = _r.a;
if (_c === null) {
return _bb1111_termite_23_();
} else {
return _bb1206_termite_23_();
}
});

_j(_bb1203_termite_23_ = () => {
_r = _bb1204_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1201_termite_23_ = () => {
_a = _s[_t];
_r = _bb1202_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1199_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb894_termite_23_ = () => {
return _bb607_termite_23_();
},2,1);

_j(_bb604_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb605_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb892_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb606_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1039_termite_23_ = () => {
_s[_t+1] = _b;
_s[_t+2] = _c;
_r = _bb1040_termite_23_;
_n = 0;
_t += 2;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb1048_termite_23_ = () => {
_s[_t+1] = _a;
_r = _bb1049_termite_23_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb1050_termite_23_ = () => {
_a = _s[_t];
_r = _bb1063_termite_23_;
--_t;
return _bb1051_termite_23_();
},2,1);

_k(_bb1071_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_l(_bb1053_termite_23_ = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1053_termite_23_);
}
}
_b = _current_processor.a[14];
_a = _X(_cst117__termite,_X(_b,_X(_a,null)));
_a = _X(_cst47__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#logger"];
_t += 2;
return _p(_bb1054_termite_23_);
},-1);

_j(_bb1007_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1008_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb926_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb927_termite_23_();
} else {
return _bb1006_termite_23_();
}
});

_j(_bb1407_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1408_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1401_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1402_termite_23_();
} else {
return _bb1406_termite_23_();
}
});

_k(_bb1391_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1396_termite_23_();
} else {
return _bb1392_termite_23_();
}
},4,1);

_k(_bb1388_termite_23_ = () => {
_s[_t+1] = _a;
_b = _X(_cst77__termite,_X(_s[_t-2],_X(_s[_t-1],null)));
_r = _bb1389_termite_23_;
_n = 2;
++_t;
return _bb1_termite_23__21_();
},5,1);

_j(_bb250_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb251_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb37_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb38_termite_23_();
} else {
return _bb249_termite_23_();
}
});

_k(_bb293_termite_23_ = () => {
if (!(_a === !1)) {
return _bb375_termite_23_();
} else {
return _bb294_termite_23_();
}
},4,1);

_k(_bb1215_termite_23_ = () => {
return _bb1216_termite_23_();
},1,1);

_j(_bb417_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb418_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb568_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb1130_termite_23_ = () => {
_b = _X(_cst118__termite,_X(_d,null));
return _p(_bb1131_termite_23_);
});

_j(_bb1132_termite_23_ = () => {
if (_x(_c)) {
return _bb1133_termite_23_();
} else {
return _bb1138_termite_23_();
}
});

_j(_bb1141_termite_23_ = () => {
_n = 1;
return _g["##raise"]();
});

_k(_bb1147_termite_23_ = () => {
_a = _s[_t];
_r = _bb1148_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1150_termite_23_ = () => {
_a = _s[_t];
_r = _bb1151_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1154_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1173_termite_23_ = () => {
_r = _bb1174_termite_23_;
return _bb1113_termite_23_();
});

_j(_bb1176_termite_23_ = () => {
_r = _bb1177_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1180_termite_23_ = () => {
_a = _s[_t];
_r = _bb1181_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1184_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1111_termite_23_ = () => {
if (_d === null) {
return _bb1209_termite_23_();
} else {
return _bb1112_termite_23_();
}
});

_j(_bb1206_termite_23_ = () => {
_r = _bb1207_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1204_termite_23_ = () => {
_a = _s[_t];
_r = _bb1205_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1202_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb607_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb608_termite_23_();
} else {
return _bb891_termite_23_();
}
});

_k(_bb605_termite_23_ = () => {
return _bb607_termite_23_();
},2,1);

_k(_bb606_termite_23_ = () => {
return _bb607_termite_23_();
},2,1);

_k(_bb1040_termite_23_ = () => {
_a = _X(_s[_t-1],_X(_cst119__termite,null));
_s[_t-1] = _a;
_a = _s[_t];
_r = _bb1041_termite_23_;
_n = 1;
return _g["thread?"]();
},3,1);

_k(_bb1049_termite_23_ = () => {
_a = _s[_t];
_r = _bb1064_termite_23_;
--_t;
return _bb1051_termite_23_();
},2,1);

_k(_bb1063_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_j(_bb1054_termite_23_ = () => {
_r = _bb1055_termite_23_;
_n = 1;
return _g["thread?"]();
});

_k(_bb1008_termite_23_ = () => {
return _bb930_termite_23_();
},2,1);

_j(_bb927_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb928_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1006_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb929_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb1408_termite_23_ = () => {
return _bb1405_termite_23_();
},2,1);

_j(_bb1402_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1403_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1406_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1404_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1396_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1397_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1392_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1393_termite_23_();
} else {
return _bb1395_termite_23_();
}
});

_k(_bb1389_termite_23_ = () => {
_a = _X(_s[_t-1],_s[_t]);
_a = _X(_a,_s[_t-4]);
_r = _s[_t-5];
_t -= 6;
return _p(_bb1331_termite_23_);
},6,1);

_k(_bb251_termite_23_ = () => {
return _bb41_termite_23_();
},2,1);

_j(_bb38_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb39_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb249_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb40_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb375_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb376_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb294_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb295_termite_23_();
} else {
return _bb374_termite_23_();
}
});

_k(_bb418_termite_23_ = () => {
if (!(_a === !1)) {
return _bb566_termite_23_();
} else {
return _bb419_termite_23_();
}
},4,1);

_j(_bb1131_termite_23_ = () => {
_n = 2;
return _bb1_termite_23__21_();
});

_j(_bb1133_termite_23_ = () => {
_s[_t+1] = _c.b;
_c = _c.a;
if (_s[_t+1] === null) {
++_t;
return _bb1134_termite_23_();
} else {
++_t;
return _bb1136_termite_23_();
}
});

_j(_bb1138_termite_23_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb1139_termite_23_);
});

_k(_bb1148_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb1151_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb1174_termite_23_ = () => {
_a = _s[_t];
_r = _bb1175_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1177_termite_23_ = () => {
_a = _s[_t];
_r = _bb1178_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1181_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb1209_termite_23_ = () => {
_s[_t] = _r;
_s[_t+1] = _a;
_s[_t+2] = _b;
_r = _bb1210_termite_23_;
_t += 2;
return _bb1113_termite_23_();
});

_j(_bb1112_termite_23_ = () => {
_r = _bb1118_termite_23_;
return _bb1113_termite_23_();
});

_k(_bb1207_termite_23_ = () => {
_a = _s[_t];
_r = _bb1208_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1205_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb608_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb609_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb891_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1041_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1046_termite_23_();
} else {
return _bb1042_termite_23_();
}
},3,1);

_k(_bb1064_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_k(_bb1055_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1056_termite_23_();
} else {
return _bb1058_termite_23_();
}
},2,1);

_j(_bb930_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb931_termite_23_();
} else {
return _bb1005_termite_23_();
}
});

_k(_bb928_termite_23_ = () => {
return _bb930_termite_23_();
},2,1);

_k(_bb929_termite_23_ = () => {
return _bb930_termite_23_();
},2,1);

_j(_bb1405_termite_23_ = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb1331_termite_23_);
});

_k(_bb1403_termite_23_ = () => {
return _bb1405_termite_23_();
},2,1);

_k(_bb1404_termite_23_ = () => {
return _bb1405_termite_23_();
},2,1);

_k(_bb1397_termite_23_ = () => {
return _bb1330_termite_23_();
},2,1);

_j(_bb1393_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1394_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1395_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1329_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb41_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb42_termite_23_();
} else {
return _bb248_termite_23_();
}
});

_k(_bb39_termite_23_ = () => {
return _bb41_termite_23_();
},2,1);

_k(_bb40_termite_23_ = () => {
return _bb41_termite_23_();
},2,1);

_k(_bb376_termite_23_ = () => {
return _bb298_termite_23_();
},2,1);

_j(_bb295_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb296_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb374_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb297_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb566_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb567_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb419_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb420_termite_23_();
} else {
return _bb565_termite_23_();
}
});

_j(_bb1134_termite_23_ = () => {
_b = _X(_cst118__termite,_X(_d,_X(_c,null)));
return _p(_bb1135_termite_23_);
});

_j(_bb1136_termite_23_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb1137_termite_23_);
});

_j(_bb1139_termite_23_ = () => {
_n = 1;
return _g["##raise"]();
});

_k(_bb1175_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb1178_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb1210_termite_23_ = () => {
_b = _X(_cst120__termite,_X(_s[_t-2],null));
_a = _s[_t-3];
_r = _bb1211_termite_23_;
_n = 2;
return _bb1_termite_23__21__3f_();
},5,1);

_k(_bb1118_termite_23_ = () => {
_a = _s[_t];
_r = _bb1121_termite_23_;
--_t;
return _bb1119_termite_23_();
},3,1);

_k(_bb1208_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb609_termite_23_ = () => {
if (!(_a === !1)) {
return _bb889_termite_23_();
} else {
return _bb610_termite_23_();
}
},4,1);

_j(_bb1046_termite_23_ = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _bb1047_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1042_termite_23_ = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb1043_termite_23_();
} else {
return _bb1045_termite_23_();
}
});

_j(_bb1056_termite_23_ = () => {
_b = _s[_t];
_a = _g["termite#logger"];
_r = _s[_t-1];
return _p(_bb1057_termite_23_);
});

_j(_bb1058_termite_23_ = () => {
if (_g["termite#logger"] instanceof _Structure && _g["termite#logger"].a[0].a[1] === _cst83__termite) {
return _bb1059_termite_23_();
} else {
return _bb1061_termite_23_();
}
});

_j(_bb931_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb932_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb1005_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb1330_termite_23_ = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb1331_termite_23_);
});

_k(_bb1394_termite_23_ = () => {
return _bb1330_termite_23_();
},2,1);

_k(_bb1329_termite_23_ = () => {
return _bb1330_termite_23_();
},2,1);

_j(_bb42_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb43_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb248_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb298_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb299_termite_23_();
} else {
return _bb373_termite_23_();
}
});

_k(_bb296_termite_23_ = () => {
return _bb298_termite_23_();
},2,1);

_k(_bb297_termite_23_ = () => {
return _bb298_termite_23_();
},2,1);

_k(_bb567_termite_23_ = () => {
return _bb423_termite_23_();
},2,1);

_j(_bb420_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb421_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb565_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb422_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1135_termite_23_ = () => {
_n = 2;
--_t;
return _bb1_termite_23__21_();
});

_j(_bb1137_termite_23_ = () => {
_n = 1;
--_t;
return _g["##raise"]();
});

_k(_bb1211_termite_23_ = () => {
_b = _X(_s[_t-1],_X(_a,null));
_a = _s[_t];
_r = _bb1095_termite_23_;
_n = 2;
_t -= 3;
return _bb1_termite_23__21_();
},5,1);

_k(_bb1121_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_j(_bb889_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb890_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb610_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb611_termite_23_();
} else {
return _bb888_termite_23_();
}
});

_k(_bb1047_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_j(_bb1043_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-1],null)));
_a = _g["termite#dispatcher"];
_r = _bb1044_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1045_termite_23_ = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _bb1029_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1057_termite_23_ = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1059_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_g["termite#logger"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb1060_termite_23_);
});

_j(_bb1061_termite_23_ = () => {
_b = _g["termite#logger"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb1062_termite_23_);
});

_k(_bb932_termite_23_ = () => {
if (!(_a === !1)) {
return _bb1003_termite_23_();
} else {
return _bb933_termite_23_();
}
},4,1);

_k(_bb43_termite_23_ = () => {
if (!(_a === !1)) {
return _bb246_termite_23_();
} else {
return _bb44_termite_23_();
}
},4,1);

_j(_bb299_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb300_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb373_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb423_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb424_termite_23_();
} else {
return _bb564_termite_23_();
}
});

_k(_bb421_termite_23_ = () => {
return _bb423_termite_23_();
},2,1);

_k(_bb422_termite_23_ = () => {
return _bb423_termite_23_();
},2,1);

_k(_bb1095_termite_23_ = () => {
return _bb1096_termite_23_();
},2,1);

_k(_bb890_termite_23_ = () => {
return _bb614_termite_23_();
},2,1);

_j(_bb611_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb612_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb888_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb613_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb1044_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_k(_bb1029_termite_23_ = () => {
return _bb1030_termite_23_();
},1,1);

_j(_bb1060_termite_23_ = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1062_termite_23_ = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1003_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1004_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb933_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb934_termite_23_();
} else {
return _bb1002_termite_23_();
}
});

_j(_bb246_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb247_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb44_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb45_termite_23_();
} else {
return _bb245_termite_23_();
}
});

_k(_bb300_termite_23_ = () => {
if (!(_a === !1)) {
return _bb371_termite_23_();
} else {
return _bb301_termite_23_();
}
},4,1);

_j(_bb424_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb425_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb564_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb614_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb615_termite_23_();
} else {
return _bb887_termite_23_();
}
});

_k(_bb612_termite_23_ = () => {
return _bb614_termite_23_();
},2,1);

_k(_bb613_termite_23_ = () => {
return _bb614_termite_23_();
},2,1);

_k(_bb1004_termite_23_ = () => {
return _bb937_termite_23_();
},2,1);

_j(_bb934_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb935_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1002_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb936_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb247_termite_23_ = () => {
return _bb48_termite_23_();
},2,1);

_j(_bb45_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb46_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb245_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb47_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb371_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb372_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb301_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb302_termite_23_();
} else {
return _bb370_termite_23_();
}
});

_k(_bb425_termite_23_ = () => {
if (!(_a === !1)) {
return _bb562_termite_23_();
} else {
return _bb426_termite_23_();
}
},4,1);

_j(_bb615_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb616_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb887_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb937_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb938_termite_23_();
} else {
return _bb1001_termite_23_();
}
});

_k(_bb935_termite_23_ = () => {
return _bb937_termite_23_();
},2,1);

_k(_bb936_termite_23_ = () => {
return _bb937_termite_23_();
},2,1);

_j(_bb48_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb49_termite_23_();
} else {
return _bb244_termite_23_();
}
});

_k(_bb46_termite_23_ = () => {
return _bb48_termite_23_();
},2,1);

_k(_bb47_termite_23_ = () => {
return _bb48_termite_23_();
},2,1);

_k(_bb372_termite_23_ = () => {
return _bb305_termite_23_();
},2,1);

_j(_bb302_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb303_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb370_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb304_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb562_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb563_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb426_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb427_termite_23_();
} else {
return _bb561_termite_23_();
}
});

_k(_bb616_termite_23_ = () => {
if (!(_a === !1)) {
return _bb885_termite_23_();
} else {
return _bb617_termite_23_();
}
},4,1);

_j(_bb938_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb939_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb1001_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb49_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb50_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb244_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb305_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb306_termite_23_();
} else {
return _bb369_termite_23_();
}
});

_k(_bb303_termite_23_ = () => {
return _bb305_termite_23_();
},2,1);

_k(_bb304_termite_23_ = () => {
return _bb305_termite_23_();
},2,1);

_k(_bb563_termite_23_ = () => {
return _bb430_termite_23_();
},2,1);

_j(_bb427_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb428_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb561_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb429_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb885_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb886_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb617_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb618_termite_23_();
} else {
return _bb884_termite_23_();
}
});

_k(_bb939_termite_23_ = () => {
if (!(_a === !1)) {
return _bb999_termite_23_();
} else {
return _bb940_termite_23_();
}
},4,1);

_k(_bb50_termite_23_ = () => {
if (!(_a === !1)) {
return _bb242_termite_23_();
} else {
return _bb51_termite_23_();
}
},4,1);

_j(_bb306_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb307_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb369_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb430_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb431_termite_23_();
} else {
return _bb560_termite_23_();
}
});

_k(_bb428_termite_23_ = () => {
return _bb430_termite_23_();
},2,1);

_k(_bb429_termite_23_ = () => {
return _bb430_termite_23_();
},2,1);

_k(_bb886_termite_23_ = () => {
return _bb621_termite_23_();
},2,1);

_j(_bb618_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb619_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb884_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb620_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb999_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1000_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb940_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb941_termite_23_();
} else {
return _bb998_termite_23_();
}
});

_j(_bb242_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb243_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb51_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb52_termite_23_();
} else {
return _bb241_termite_23_();
}
});

_k(_bb307_termite_23_ = () => {
if (!(_a === !1)) {
return _bb367_termite_23_();
} else {
return _bb308_termite_23_();
}
},4,1);

_j(_bb431_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb432_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb560_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb621_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb622_termite_23_();
} else {
return _bb883_termite_23_();
}
});

_k(_bb619_termite_23_ = () => {
return _bb621_termite_23_();
},2,1);

_k(_bb620_termite_23_ = () => {
return _bb621_termite_23_();
},2,1);

_k(_bb1000_termite_23_ = () => {
return _bb944_termite_23_();
},2,1);

_j(_bb941_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb942_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb998_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb943_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb243_termite_23_ = () => {
return _bb55_termite_23_();
},2,1);

_j(_bb52_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb53_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb241_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb54_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb367_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb368_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb308_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb309_termite_23_();
} else {
return _bb366_termite_23_();
}
});

_k(_bb432_termite_23_ = () => {
if (!(_a === !1)) {
return _bb558_termite_23_();
} else {
return _bb433_termite_23_();
}
},4,1);

_j(_bb622_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb623_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb883_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb944_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb945_termite_23_();
} else {
return _bb997_termite_23_();
}
});

_k(_bb942_termite_23_ = () => {
return _bb944_termite_23_();
},2,1);

_k(_bb943_termite_23_ = () => {
return _bb944_termite_23_();
},2,1);

_j(_bb55_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb56_termite_23_();
} else {
return _bb240_termite_23_();
}
});

_k(_bb53_termite_23_ = () => {
return _bb55_termite_23_();
},2,1);

_k(_bb54_termite_23_ = () => {
return _bb55_termite_23_();
},2,1);

_k(_bb368_termite_23_ = () => {
return _bb312_termite_23_();
},2,1);

_j(_bb309_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb310_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb366_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb311_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb558_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb559_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb433_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb434_termite_23_();
} else {
return _bb557_termite_23_();
}
});

_k(_bb623_termite_23_ = () => {
if (!(_a === !1)) {
return _bb881_termite_23_();
} else {
return _bb624_termite_23_();
}
},4,1);

_j(_bb945_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb946_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb997_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb56_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb57_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb240_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb312_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb313_termite_23_();
} else {
return _bb365_termite_23_();
}
});

_k(_bb310_termite_23_ = () => {
return _bb312_termite_23_();
},2,1);

_k(_bb311_termite_23_ = () => {
return _bb312_termite_23_();
},2,1);

_k(_bb559_termite_23_ = () => {
return _bb437_termite_23_();
},2,1);

_j(_bb434_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb435_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb557_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb436_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb881_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb882_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb624_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb625_termite_23_();
} else {
return _bb880_termite_23_();
}
});

_k(_bb946_termite_23_ = () => {
if (!(_a === !1)) {
return _bb995_termite_23_();
} else {
return _bb947_termite_23_();
}
},4,1);

_k(_bb57_termite_23_ = () => {
if (!(_a === !1)) {
return _bb238_termite_23_();
} else {
return _bb58_termite_23_();
}
},4,1);

_j(_bb313_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb314_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb365_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb437_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb438_termite_23_();
} else {
return _bb556_termite_23_();
}
});

_k(_bb435_termite_23_ = () => {
return _bb437_termite_23_();
},2,1);

_k(_bb436_termite_23_ = () => {
return _bb437_termite_23_();
},2,1);

_k(_bb882_termite_23_ = () => {
return _bb628_termite_23_();
},2,1);

_j(_bb625_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb626_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb880_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb627_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb995_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb996_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb947_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb948_termite_23_();
} else {
return _bb994_termite_23_();
}
});

_j(_bb238_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb239_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb58_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb59_termite_23_();
} else {
return _bb237_termite_23_();
}
});

_k(_bb314_termite_23_ = () => {
if (!(_a === !1)) {
return _bb363_termite_23_();
} else {
return _bb315_termite_23_();
}
},4,1);

_j(_bb438_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb439_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb556_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb628_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb629_termite_23_();
} else {
return _bb879_termite_23_();
}
});

_k(_bb626_termite_23_ = () => {
return _bb628_termite_23_();
},2,1);

_k(_bb627_termite_23_ = () => {
return _bb628_termite_23_();
},2,1);

_k(_bb996_termite_23_ = () => {
return _bb951_termite_23_();
},2,1);

_j(_bb948_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb949_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb994_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb950_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb239_termite_23_ = () => {
return _bb62_termite_23_();
},2,1);

_j(_bb59_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb60_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb237_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb61_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb363_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb364_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb315_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb316_termite_23_();
} else {
return _bb362_termite_23_();
}
});

_k(_bb439_termite_23_ = () => {
if (!(_a === !1)) {
return _bb554_termite_23_();
} else {
return _bb440_termite_23_();
}
},4,1);

_j(_bb629_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb630_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb879_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb951_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb952_termite_23_();
} else {
return _bb993_termite_23_();
}
});

_k(_bb949_termite_23_ = () => {
return _bb951_termite_23_();
},2,1);

_k(_bb950_termite_23_ = () => {
return _bb951_termite_23_();
},2,1);

_j(_bb62_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb63_termite_23_();
} else {
return _bb236_termite_23_();
}
});

_k(_bb60_termite_23_ = () => {
return _bb62_termite_23_();
},2,1);

_k(_bb61_termite_23_ = () => {
return _bb62_termite_23_();
},2,1);

_k(_bb364_termite_23_ = () => {
return _bb319_termite_23_();
},2,1);

_j(_bb316_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb317_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb362_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb318_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb554_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb555_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb440_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb441_termite_23_();
} else {
return _bb553_termite_23_();
}
});

_k(_bb630_termite_23_ = () => {
if (!(_a === !1)) {
return _bb877_termite_23_();
} else {
return _bb631_termite_23_();
}
},4,1);

_j(_bb952_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb953_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb993_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb63_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb64_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb236_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb319_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb320_termite_23_();
} else {
return _bb361_termite_23_();
}
});

_k(_bb317_termite_23_ = () => {
return _bb319_termite_23_();
},2,1);

_k(_bb318_termite_23_ = () => {
return _bb319_termite_23_();
},2,1);

_k(_bb555_termite_23_ = () => {
return _bb444_termite_23_();
},2,1);

_j(_bb441_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb442_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb553_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb443_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb877_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb878_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb631_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb632_termite_23_();
} else {
return _bb876_termite_23_();
}
});

_k(_bb953_termite_23_ = () => {
if (!(_a === !1)) {
return _bb991_termite_23_();
} else {
return _bb954_termite_23_();
}
},4,1);

_k(_bb64_termite_23_ = () => {
if (!(_a === !1)) {
return _bb234_termite_23_();
} else {
return _bb65_termite_23_();
}
},4,1);

_j(_bb320_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb321_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb361_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb444_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb445_termite_23_();
} else {
return _bb552_termite_23_();
}
});

_k(_bb442_termite_23_ = () => {
return _bb444_termite_23_();
},2,1);

_k(_bb443_termite_23_ = () => {
return _bb444_termite_23_();
},2,1);

_k(_bb878_termite_23_ = () => {
return _bb635_termite_23_();
},2,1);

_j(_bb632_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb633_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb876_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb634_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb991_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb992_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb954_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb955_termite_23_();
} else {
return _bb990_termite_23_();
}
});

_j(_bb234_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb235_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb65_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb66_termite_23_();
} else {
return _bb233_termite_23_();
}
});

_k(_bb321_termite_23_ = () => {
if (!(_a === !1)) {
return _bb359_termite_23_();
} else {
return _bb322_termite_23_();
}
},4,1);

_j(_bb445_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb446_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb552_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb635_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb636_termite_23_();
} else {
return _bb875_termite_23_();
}
});

_k(_bb633_termite_23_ = () => {
return _bb635_termite_23_();
},2,1);

_k(_bb634_termite_23_ = () => {
return _bb635_termite_23_();
},2,1);

_k(_bb992_termite_23_ = () => {
return _bb958_termite_23_();
},2,1);

_j(_bb955_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb956_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb990_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb957_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb235_termite_23_ = () => {
return _bb69_termite_23_();
},2,1);

_j(_bb66_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb67_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb233_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb68_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb359_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb360_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb322_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb323_termite_23_();
} else {
return _bb358_termite_23_();
}
});

_k(_bb446_termite_23_ = () => {
if (!(_a === !1)) {
return _bb550_termite_23_();
} else {
return _bb447_termite_23_();
}
},4,1);

_j(_bb636_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb637_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb875_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb958_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb959_termite_23_();
} else {
return _bb989_termite_23_();
}
});

_k(_bb956_termite_23_ = () => {
return _bb958_termite_23_();
},2,1);

_k(_bb957_termite_23_ = () => {
return _bb958_termite_23_();
},2,1);

_j(_bb69_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb70_termite_23_();
} else {
return _bb232_termite_23_();
}
});

_k(_bb67_termite_23_ = () => {
return _bb69_termite_23_();
},2,1);

_k(_bb68_termite_23_ = () => {
return _bb69_termite_23_();
},2,1);

_k(_bb360_termite_23_ = () => {
return _bb326_termite_23_();
},2,1);

_j(_bb323_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb324_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb358_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb325_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb550_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb551_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb447_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb448_termite_23_();
} else {
return _bb549_termite_23_();
}
});

_k(_bb637_termite_23_ = () => {
if (!(_a === !1)) {
return _bb873_termite_23_();
} else {
return _bb638_termite_23_();
}
},4,1);

_j(_bb959_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb960_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb989_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb70_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb71_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb232_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb326_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb327_termite_23_();
} else {
return _bb357_termite_23_();
}
});

_k(_bb324_termite_23_ = () => {
return _bb326_termite_23_();
},2,1);

_k(_bb325_termite_23_ = () => {
return _bb326_termite_23_();
},2,1);

_k(_bb551_termite_23_ = () => {
return _bb451_termite_23_();
},2,1);

_j(_bb448_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb449_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb549_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb450_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb873_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb874_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb638_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb639_termite_23_();
} else {
return _bb872_termite_23_();
}
});

_k(_bb960_termite_23_ = () => {
if (!(_a === !1)) {
return _bb987_termite_23_();
} else {
return _bb961_termite_23_();
}
},4,1);

_k(_bb71_termite_23_ = () => {
if (!(_a === !1)) {
return _bb230_termite_23_();
} else {
return _bb72_termite_23_();
}
},4,1);

_j(_bb327_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb328_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb357_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb451_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb452_termite_23_();
} else {
return _bb548_termite_23_();
}
});

_k(_bb449_termite_23_ = () => {
return _bb451_termite_23_();
},2,1);

_k(_bb450_termite_23_ = () => {
return _bb451_termite_23_();
},2,1);

_k(_bb874_termite_23_ = () => {
return _bb642_termite_23_();
},2,1);

_j(_bb639_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb640_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb872_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb641_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb987_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb988_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb961_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb962_termite_23_();
} else {
return _bb986_termite_23_();
}
});

_j(_bb230_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb231_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb72_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb73_termite_23_();
} else {
return _bb229_termite_23_();
}
});

_k(_bb328_termite_23_ = () => {
if (!(_a === !1)) {
return _bb355_termite_23_();
} else {
return _bb329_termite_23_();
}
},4,1);

_j(_bb452_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb453_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb548_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb642_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb643_termite_23_();
} else {
return _bb871_termite_23_();
}
});

_k(_bb640_termite_23_ = () => {
return _bb642_termite_23_();
},2,1);

_k(_bb641_termite_23_ = () => {
return _bb642_termite_23_();
},2,1);

_k(_bb988_termite_23_ = () => {
return _bb965_termite_23_();
},2,1);

_j(_bb962_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb963_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb986_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb964_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb231_termite_23_ = () => {
return _bb76_termite_23_();
},2,1);

_j(_bb73_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb74_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb229_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb75_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb355_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb356_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb329_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb330_termite_23_();
} else {
return _bb354_termite_23_();
}
});

_k(_bb453_termite_23_ = () => {
if (!(_a === !1)) {
return _bb546_termite_23_();
} else {
return _bb454_termite_23_();
}
},4,1);

_j(_bb643_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb644_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb871_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb965_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb966_termite_23_();
} else {
return _bb985_termite_23_();
}
});

_k(_bb963_termite_23_ = () => {
return _bb965_termite_23_();
},2,1);

_k(_bb964_termite_23_ = () => {
return _bb965_termite_23_();
},2,1);

_j(_bb76_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb77_termite_23_();
} else {
return _bb228_termite_23_();
}
});

_k(_bb74_termite_23_ = () => {
return _bb76_termite_23_();
},2,1);

_k(_bb75_termite_23_ = () => {
return _bb76_termite_23_();
},2,1);

_k(_bb356_termite_23_ = () => {
return _bb333_termite_23_();
},2,1);

_j(_bb330_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb331_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb354_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb332_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb546_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb547_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb454_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb455_termite_23_();
} else {
return _bb545_termite_23_();
}
});

_k(_bb644_termite_23_ = () => {
if (!(_a === !1)) {
return _bb869_termite_23_();
} else {
return _bb645_termite_23_();
}
},4,1);

_j(_bb966_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb967_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb985_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb77_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb78_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb228_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb333_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb334_termite_23_();
} else {
return _bb353_termite_23_();
}
});

_k(_bb331_termite_23_ = () => {
return _bb333_termite_23_();
},2,1);

_k(_bb332_termite_23_ = () => {
return _bb333_termite_23_();
},2,1);

_k(_bb547_termite_23_ = () => {
return _bb458_termite_23_();
},2,1);

_j(_bb455_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb456_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb545_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb457_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb869_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb870_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb645_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb646_termite_23_();
} else {
return _bb868_termite_23_();
}
});

_k(_bb967_termite_23_ = () => {
if (!(_a === !1)) {
return _bb983_termite_23_();
} else {
return _bb968_termite_23_();
}
},4,1);

_k(_bb78_termite_23_ = () => {
if (!(_a === !1)) {
return _bb226_termite_23_();
} else {
return _bb79_termite_23_();
}
},4,1);

_j(_bb334_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb335_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb353_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb458_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb459_termite_23_();
} else {
return _bb544_termite_23_();
}
});

_k(_bb456_termite_23_ = () => {
return _bb458_termite_23_();
},2,1);

_k(_bb457_termite_23_ = () => {
return _bb458_termite_23_();
},2,1);

_k(_bb870_termite_23_ = () => {
return _bb649_termite_23_();
},2,1);

_j(_bb646_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb647_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb868_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb648_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb983_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb984_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb968_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb969_termite_23_();
} else {
return _bb982_termite_23_();
}
});

_j(_bb226_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb227_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb79_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb80_termite_23_();
} else {
return _bb225_termite_23_();
}
});

_k(_bb335_termite_23_ = () => {
if (!(_a === !1)) {
return _bb351_termite_23_();
} else {
return _bb336_termite_23_();
}
},4,1);

_j(_bb459_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb460_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb544_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb649_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb650_termite_23_();
} else {
return _bb867_termite_23_();
}
});

_k(_bb647_termite_23_ = () => {
return _bb649_termite_23_();
},2,1);

_k(_bb648_termite_23_ = () => {
return _bb649_termite_23_();
},2,1);

_k(_bb984_termite_23_ = () => {
return _bb972_termite_23_();
},2,1);

_j(_bb969_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb970_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb982_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb971_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb227_termite_23_ = () => {
return _bb83_termite_23_();
},2,1);

_j(_bb80_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb81_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb225_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb82_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb351_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb352_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb336_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb337_termite_23_();
} else {
return _bb350_termite_23_();
}
});

_k(_bb460_termite_23_ = () => {
if (!(_a === !1)) {
return _bb542_termite_23_();
} else {
return _bb461_termite_23_();
}
},4,1);

_j(_bb650_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb651_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb867_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb972_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb973_termite_23_();
} else {
return _bb981_termite_23_();
}
});

_k(_bb970_termite_23_ = () => {
return _bb972_termite_23_();
},2,1);

_k(_bb971_termite_23_ = () => {
return _bb972_termite_23_();
},2,1);

_j(_bb83_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb84_termite_23_();
} else {
return _bb224_termite_23_();
}
});

_k(_bb81_termite_23_ = () => {
return _bb83_termite_23_();
},2,1);

_k(_bb82_termite_23_ = () => {
return _bb83_termite_23_();
},2,1);

_k(_bb352_termite_23_ = () => {
return _bb340_termite_23_();
},2,1);

_j(_bb337_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb338_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb350_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb339_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb542_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb543_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb461_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb462_termite_23_();
} else {
return _bb541_termite_23_();
}
});

_k(_bb651_termite_23_ = () => {
if (!(_a === !1)) {
return _bb865_termite_23_();
} else {
return _bb652_termite_23_();
}
},4,1);

_j(_bb973_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb974_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb981_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb84_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb85_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb224_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb340_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb341_termite_23_();
} else {
return _bb349_termite_23_();
}
});

_k(_bb338_termite_23_ = () => {
return _bb340_termite_23_();
},2,1);

_k(_bb339_termite_23_ = () => {
return _bb340_termite_23_();
},2,1);

_k(_bb543_termite_23_ = () => {
return _bb465_termite_23_();
},2,1);

_j(_bb462_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb463_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb541_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb464_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb865_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb866_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb652_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb653_termite_23_();
} else {
return _bb864_termite_23_();
}
});

_k(_bb974_termite_23_ = () => {
if (!(_a === !1)) {
return _bb979_termite_23_();
} else {
return _bb975_termite_23_();
}
},4,1);

_k(_bb85_termite_23_ = () => {
if (!(_a === !1)) {
return _bb222_termite_23_();
} else {
return _bb86_termite_23_();
}
},4,1);

_j(_bb341_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb342_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb349_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb465_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb466_termite_23_();
} else {
return _bb540_termite_23_();
}
});

_k(_bb463_termite_23_ = () => {
return _bb465_termite_23_();
},2,1);

_k(_bb464_termite_23_ = () => {
return _bb465_termite_23_();
},2,1);

_k(_bb866_termite_23_ = () => {
return _bb656_termite_23_();
},2,1);

_j(_bb653_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb654_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb864_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb655_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb979_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb980_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb975_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb976_termite_23_();
} else {
return _bb978_termite_23_();
}
});

_j(_bb222_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb223_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb86_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb87_termite_23_();
} else {
return _bb221_termite_23_();
}
});

_k(_bb342_termite_23_ = () => {
if (!(_a === !1)) {
return _bb347_termite_23_();
} else {
return _bb343_termite_23_();
}
},4,1);

_j(_bb466_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb467_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb540_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb656_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb657_termite_23_();
} else {
return _bb863_termite_23_();
}
});

_k(_bb654_termite_23_ = () => {
return _bb656_termite_23_();
},2,1);

_k(_bb655_termite_23_ = () => {
return _bb656_termite_23_();
},2,1);

_k(_bb980_termite_23_ = () => {
return _bb921_termite_23_();
},2,1);

_j(_bb976_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb977_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb978_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb920_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb223_termite_23_ = () => {
return _bb90_termite_23_();
},2,1);

_j(_bb87_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb88_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb221_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb89_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb347_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb348_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb343_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb344_termite_23_();
} else {
return _bb346_termite_23_();
}
});

_k(_bb467_termite_23_ = () => {
if (!(_a === !1)) {
return _bb538_termite_23_();
} else {
return _bb468_termite_23_();
}
},4,1);

_j(_bb657_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb658_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb863_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb921_termite_23_ = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb922_termite_23_);
});

_k(_bb977_termite_23_ = () => {
return _bb921_termite_23_();
},2,1);

_k(_bb920_termite_23_ = () => {
return _bb921_termite_23_();
},2,1);

_j(_bb90_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb91_termite_23_();
} else {
return _bb220_termite_23_();
}
});

_k(_bb88_termite_23_ = () => {
return _bb90_termite_23_();
},2,1);

_k(_bb89_termite_23_ = () => {
return _bb90_termite_23_();
},2,1);

_k(_bb348_termite_23_ = () => {
return _bb275_termite_23_();
},2,1);

_j(_bb344_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb345_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb346_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb274_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb538_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb539_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb468_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb469_termite_23_();
} else {
return _bb537_termite_23_();
}
});

_k(_bb658_termite_23_ = () => {
if (!(_a === !1)) {
return _bb861_termite_23_();
} else {
return _bb659_termite_23_();
}
},4,1);

_j(_bb922_termite_23_ = () => {
if (_x(_a)) {
return _bb923_termite_23_();
} else {
return _bb1009_termite_23_();
}
});

_j(_bb91_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb92_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb220_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb275_termite_23_ = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb276_termite_23_);
});

_k(_bb345_termite_23_ = () => {
return _bb275_termite_23_();
},2,1);

_k(_bb274_termite_23_ = () => {
return _bb275_termite_23_();
},2,1);

_k(_bb539_termite_23_ = () => {
return _bb472_termite_23_();
},2,1);

_j(_bb469_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb470_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb537_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb471_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb861_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb862_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb659_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb660_termite_23_();
} else {
return _bb860_termite_23_();
}
});

_k(_bb92_termite_23_ = () => {
if (!(_a === !1)) {
return _bb218_termite_23_();
} else {
return _bb93_termite_23_();
}
},4,1);

_j(_bb276_termite_23_ = () => {
if (_x(_a)) {
return _bb277_termite_23_();
} else {
return _bb385_termite_23_();
}
});

_j(_bb472_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb473_termite_23_();
} else {
return _bb536_termite_23_();
}
});

_k(_bb470_termite_23_ = () => {
return _bb472_termite_23_();
},2,1);

_k(_bb471_termite_23_ = () => {
return _bb472_termite_23_();
},2,1);

_k(_bb862_termite_23_ = () => {
return _bb663_termite_23_();
},2,1);

_j(_bb660_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb661_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb860_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb662_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb218_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb219_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb93_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb94_termite_23_();
} else {
return _bb217_termite_23_();
}
});

_j(_bb473_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb474_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb536_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb663_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb664_termite_23_();
} else {
return _bb859_termite_23_();
}
});

_k(_bb661_termite_23_ = () => {
return _bb663_termite_23_();
},2,1);

_k(_bb662_termite_23_ = () => {
return _bb663_termite_23_();
},2,1);

_k(_bb219_termite_23_ = () => {
return _bb97_termite_23_();
},2,1);

_j(_bb94_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb95_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb217_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb96_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb474_termite_23_ = () => {
if (!(_a === !1)) {
return _bb534_termite_23_();
} else {
return _bb475_termite_23_();
}
},4,1);

_j(_bb664_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb665_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb859_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb97_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb98_termite_23_();
} else {
return _bb216_termite_23_();
}
});

_k(_bb95_termite_23_ = () => {
return _bb97_termite_23_();
},2,1);

_k(_bb96_termite_23_ = () => {
return _bb97_termite_23_();
},2,1);

_j(_bb534_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb535_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb475_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb476_termite_23_();
} else {
return _bb533_termite_23_();
}
});

_k(_bb665_termite_23_ = () => {
if (!(_a === !1)) {
return _bb857_termite_23_();
} else {
return _bb666_termite_23_();
}
},4,1);

_j(_bb98_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb99_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb216_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb535_termite_23_ = () => {
return _bb479_termite_23_();
},2,1);

_j(_bb476_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb477_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb533_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb478_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb857_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb858_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb666_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb667_termite_23_();
} else {
return _bb856_termite_23_();
}
});

_k(_bb99_termite_23_ = () => {
if (!(_a === !1)) {
return _bb214_termite_23_();
} else {
return _bb100_termite_23_();
}
},4,1);

_j(_bb479_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb480_termite_23_();
} else {
return _bb532_termite_23_();
}
});

_k(_bb477_termite_23_ = () => {
return _bb479_termite_23_();
},2,1);

_k(_bb478_termite_23_ = () => {
return _bb479_termite_23_();
},2,1);

_k(_bb858_termite_23_ = () => {
return _bb670_termite_23_();
},2,1);

_j(_bb667_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb668_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb856_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb669_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb214_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb215_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb100_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb101_termite_23_();
} else {
return _bb213_termite_23_();
}
});

_j(_bb480_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb481_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb532_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb670_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb671_termite_23_();
} else {
return _bb855_termite_23_();
}
});

_k(_bb668_termite_23_ = () => {
return _bb670_termite_23_();
},2,1);

_k(_bb669_termite_23_ = () => {
return _bb670_termite_23_();
},2,1);

_k(_bb215_termite_23_ = () => {
return _bb104_termite_23_();
},2,1);

_j(_bb101_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb102_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb213_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb103_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb481_termite_23_ = () => {
if (!(_a === !1)) {
return _bb530_termite_23_();
} else {
return _bb482_termite_23_();
}
},4,1);

_j(_bb671_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb672_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb855_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb104_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb105_termite_23_();
} else {
return _bb212_termite_23_();
}
});

_k(_bb102_termite_23_ = () => {
return _bb104_termite_23_();
},2,1);

_k(_bb103_termite_23_ = () => {
return _bb104_termite_23_();
},2,1);

_j(_bb530_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb531_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb482_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb483_termite_23_();
} else {
return _bb529_termite_23_();
}
});

_k(_bb672_termite_23_ = () => {
if (!(_a === !1)) {
return _bb853_termite_23_();
} else {
return _bb673_termite_23_();
}
},4,1);

_j(_bb105_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb106_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb212_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb531_termite_23_ = () => {
return _bb486_termite_23_();
},2,1);

_j(_bb483_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb484_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb529_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb485_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb853_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb854_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb673_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb674_termite_23_();
} else {
return _bb852_termite_23_();
}
});

_k(_bb106_termite_23_ = () => {
if (!(_a === !1)) {
return _bb210_termite_23_();
} else {
return _bb107_termite_23_();
}
},4,1);

_j(_bb486_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb487_termite_23_();
} else {
return _bb528_termite_23_();
}
});

_k(_bb484_termite_23_ = () => {
return _bb486_termite_23_();
},2,1);

_k(_bb485_termite_23_ = () => {
return _bb486_termite_23_();
},2,1);

_k(_bb854_termite_23_ = () => {
return _bb677_termite_23_();
},2,1);

_j(_bb674_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb675_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb852_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb676_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb210_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb211_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb107_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb108_termite_23_();
} else {
return _bb209_termite_23_();
}
});

_j(_bb487_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb488_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb528_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb677_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb678_termite_23_();
} else {
return _bb851_termite_23_();
}
});

_k(_bb675_termite_23_ = () => {
return _bb677_termite_23_();
},2,1);

_k(_bb676_termite_23_ = () => {
return _bb677_termite_23_();
},2,1);

_k(_bb211_termite_23_ = () => {
return _bb111_termite_23_();
},2,1);

_j(_bb108_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb109_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb209_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb110_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb488_termite_23_ = () => {
if (!(_a === !1)) {
return _bb526_termite_23_();
} else {
return _bb489_termite_23_();
}
},4,1);

_j(_bb678_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb679_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb851_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb111_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb112_termite_23_();
} else {
return _bb208_termite_23_();
}
});

_k(_bb109_termite_23_ = () => {
return _bb111_termite_23_();
},2,1);

_k(_bb110_termite_23_ = () => {
return _bb111_termite_23_();
},2,1);

_j(_bb526_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb527_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb489_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb490_termite_23_();
} else {
return _bb525_termite_23_();
}
});

_k(_bb679_termite_23_ = () => {
if (!(_a === !1)) {
return _bb849_termite_23_();
} else {
return _bb680_termite_23_();
}
},4,1);

_j(_bb112_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb113_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb208_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb527_termite_23_ = () => {
return _bb493_termite_23_();
},2,1);

_j(_bb490_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb491_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb525_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb492_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb849_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb850_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb680_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb681_termite_23_();
} else {
return _bb848_termite_23_();
}
});

_k(_bb113_termite_23_ = () => {
if (!(_a === !1)) {
return _bb206_termite_23_();
} else {
return _bb114_termite_23_();
}
},4,1);

_j(_bb493_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb494_termite_23_();
} else {
return _bb524_termite_23_();
}
});

_k(_bb491_termite_23_ = () => {
return _bb493_termite_23_();
},2,1);

_k(_bb492_termite_23_ = () => {
return _bb493_termite_23_();
},2,1);

_k(_bb850_termite_23_ = () => {
return _bb684_termite_23_();
},2,1);

_j(_bb681_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb682_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb848_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb683_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb206_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb207_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb114_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb115_termite_23_();
} else {
return _bb205_termite_23_();
}
});

_j(_bb494_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb495_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb524_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb684_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb685_termite_23_();
} else {
return _bb847_termite_23_();
}
});

_k(_bb682_termite_23_ = () => {
return _bb684_termite_23_();
},2,1);

_k(_bb683_termite_23_ = () => {
return _bb684_termite_23_();
},2,1);

_k(_bb207_termite_23_ = () => {
return _bb118_termite_23_();
},2,1);

_j(_bb115_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb116_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb205_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb117_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb495_termite_23_ = () => {
if (!(_a === !1)) {
return _bb522_termite_23_();
} else {
return _bb496_termite_23_();
}
},4,1);

_j(_bb685_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb686_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb847_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb118_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb119_termite_23_();
} else {
return _bb204_termite_23_();
}
});

_k(_bb116_termite_23_ = () => {
return _bb118_termite_23_();
},2,1);

_k(_bb117_termite_23_ = () => {
return _bb118_termite_23_();
},2,1);

_j(_bb522_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb523_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb496_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb497_termite_23_();
} else {
return _bb521_termite_23_();
}
});

_k(_bb686_termite_23_ = () => {
if (!(_a === !1)) {
return _bb845_termite_23_();
} else {
return _bb687_termite_23_();
}
},4,1);

_j(_bb119_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb120_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb204_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb523_termite_23_ = () => {
return _bb500_termite_23_();
},2,1);

_j(_bb497_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb498_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb521_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb499_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb845_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb846_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb687_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb688_termite_23_();
} else {
return _bb844_termite_23_();
}
});

_k(_bb120_termite_23_ = () => {
if (!(_a === !1)) {
return _bb202_termite_23_();
} else {
return _bb121_termite_23_();
}
},4,1);

_j(_bb500_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb501_termite_23_();
} else {
return _bb520_termite_23_();
}
});

_k(_bb498_termite_23_ = () => {
return _bb500_termite_23_();
},2,1);

_k(_bb499_termite_23_ = () => {
return _bb500_termite_23_();
},2,1);

_k(_bb846_termite_23_ = () => {
return _bb691_termite_23_();
},2,1);

_j(_bb688_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb689_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb844_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb690_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb202_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb203_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb121_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb122_termite_23_();
} else {
return _bb201_termite_23_();
}
});

_j(_bb501_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb502_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb520_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb691_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb692_termite_23_();
} else {
return _bb843_termite_23_();
}
});

_k(_bb689_termite_23_ = () => {
return _bb691_termite_23_();
},2,1);

_k(_bb690_termite_23_ = () => {
return _bb691_termite_23_();
},2,1);

_k(_bb203_termite_23_ = () => {
return _bb125_termite_23_();
},2,1);

_j(_bb122_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb123_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb201_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb124_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb502_termite_23_ = () => {
if (!(_a === !1)) {
return _bb518_termite_23_();
} else {
return _bb503_termite_23_();
}
},4,1);

_j(_bb692_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb693_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb843_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb125_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb126_termite_23_();
} else {
return _bb200_termite_23_();
}
});

_k(_bb123_termite_23_ = () => {
return _bb125_termite_23_();
},2,1);

_k(_bb124_termite_23_ = () => {
return _bb125_termite_23_();
},2,1);

_j(_bb518_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb519_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb503_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb504_termite_23_();
} else {
return _bb517_termite_23_();
}
});

_k(_bb693_termite_23_ = () => {
if (!(_a === !1)) {
return _bb841_termite_23_();
} else {
return _bb694_termite_23_();
}
},4,1);

_j(_bb126_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb127_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb200_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb519_termite_23_ = () => {
return _bb507_termite_23_();
},2,1);

_j(_bb504_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb505_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb517_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb506_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb841_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb842_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb694_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb695_termite_23_();
} else {
return _bb840_termite_23_();
}
});

_k(_bb127_termite_23_ = () => {
if (!(_a === !1)) {
return _bb198_termite_23_();
} else {
return _bb128_termite_23_();
}
},4,1);

_j(_bb507_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb508_termite_23_();
} else {
return _bb516_termite_23_();
}
});

_k(_bb505_termite_23_ = () => {
return _bb507_termite_23_();
},2,1);

_k(_bb506_termite_23_ = () => {
return _bb507_termite_23_();
},2,1);

_k(_bb842_termite_23_ = () => {
return _bb698_termite_23_();
},2,1);

_j(_bb695_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb696_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb840_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb697_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb198_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb199_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb128_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb129_termite_23_();
} else {
return _bb197_termite_23_();
}
});

_j(_bb508_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb509_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb516_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb698_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb699_termite_23_();
} else {
return _bb839_termite_23_();
}
});

_k(_bb696_termite_23_ = () => {
return _bb698_termite_23_();
},2,1);

_k(_bb697_termite_23_ = () => {
return _bb698_termite_23_();
},2,1);

_k(_bb199_termite_23_ = () => {
return _bb132_termite_23_();
},2,1);

_j(_bb129_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb130_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb197_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb131_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb509_termite_23_ = () => {
if (!(_a === !1)) {
return _bb514_termite_23_();
} else {
return _bb510_termite_23_();
}
},4,1);

_j(_bb699_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb700_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb839_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb132_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb133_termite_23_();
} else {
return _bb196_termite_23_();
}
});

_k(_bb130_termite_23_ = () => {
return _bb132_termite_23_();
},2,1);

_k(_bb131_termite_23_ = () => {
return _bb132_termite_23_();
},2,1);

_j(_bb514_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb515_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb510_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb511_termite_23_();
} else {
return _bb513_termite_23_();
}
});

_k(_bb700_termite_23_ = () => {
if (!(_a === !1)) {
return _bb837_termite_23_();
} else {
return _bb701_termite_23_();
}
},4,1);

_j(_bb133_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb134_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb196_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb515_termite_23_ = () => {
return _bb400_termite_23_();
},2,1);

_j(_bb511_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb512_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb513_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb399_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb837_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb838_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb701_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb702_termite_23_();
} else {
return _bb836_termite_23_();
}
});

_k(_bb134_termite_23_ = () => {
if (!(_a === !1)) {
return _bb194_termite_23_();
} else {
return _bb135_termite_23_();
}
},4,1);

_j(_bb400_termite_23_ = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb401_termite_23_);
});

_k(_bb512_termite_23_ = () => {
return _bb400_termite_23_();
},2,1);

_k(_bb399_termite_23_ = () => {
return _bb400_termite_23_();
},2,1);

_k(_bb838_termite_23_ = () => {
return _bb705_termite_23_();
},2,1);

_j(_bb702_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb703_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb836_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb704_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb194_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb195_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb135_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb136_termite_23_();
} else {
return _bb193_termite_23_();
}
});

_j(_bb401_termite_23_ = () => {
if (_x(_a)) {
return _bb402_termite_23_();
} else {
return _bb576_termite_23_();
}
});

_j(_bb705_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb706_termite_23_();
} else {
return _bb835_termite_23_();
}
});

_k(_bb703_termite_23_ = () => {
return _bb705_termite_23_();
},2,1);

_k(_bb704_termite_23_ = () => {
return _bb705_termite_23_();
},2,1);

_k(_bb195_termite_23_ = () => {
return _bb139_termite_23_();
},2,1);

_j(_bb136_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb137_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb193_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb138_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb706_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb707_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb835_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb139_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb140_termite_23_();
} else {
return _bb192_termite_23_();
}
});

_k(_bb137_termite_23_ = () => {
return _bb139_termite_23_();
},2,1);

_k(_bb138_termite_23_ = () => {
return _bb139_termite_23_();
},2,1);

_k(_bb707_termite_23_ = () => {
if (!(_a === !1)) {
return _bb833_termite_23_();
} else {
return _bb708_termite_23_();
}
},4,1);

_j(_bb140_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb141_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb192_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb833_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb834_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb708_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb709_termite_23_();
} else {
return _bb832_termite_23_();
}
});

_k(_bb141_termite_23_ = () => {
if (!(_a === !1)) {
return _bb190_termite_23_();
} else {
return _bb142_termite_23_();
}
},4,1);

_k(_bb834_termite_23_ = () => {
return _bb712_termite_23_();
},2,1);

_j(_bb709_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb710_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb832_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb711_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb190_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb191_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb142_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb143_termite_23_();
} else {
return _bb189_termite_23_();
}
});

_j(_bb712_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb713_termite_23_();
} else {
return _bb831_termite_23_();
}
});

_k(_bb710_termite_23_ = () => {
return _bb712_termite_23_();
},2,1);

_k(_bb711_termite_23_ = () => {
return _bb712_termite_23_();
},2,1);

_k(_bb191_termite_23_ = () => {
return _bb146_termite_23_();
},2,1);

_j(_bb143_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb144_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb189_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb145_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb713_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb714_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb831_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb146_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb147_termite_23_();
} else {
return _bb188_termite_23_();
}
});

_k(_bb144_termite_23_ = () => {
return _bb146_termite_23_();
},2,1);

_k(_bb145_termite_23_ = () => {
return _bb146_termite_23_();
},2,1);

_k(_bb714_termite_23_ = () => {
if (!(_a === !1)) {
return _bb829_termite_23_();
} else {
return _bb715_termite_23_();
}
},4,1);

_j(_bb147_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb148_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb188_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb829_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb830_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb715_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb716_termite_23_();
} else {
return _bb828_termite_23_();
}
});

_k(_bb148_termite_23_ = () => {
if (!(_a === !1)) {
return _bb186_termite_23_();
} else {
return _bb149_termite_23_();
}
},4,1);

_k(_bb830_termite_23_ = () => {
return _bb719_termite_23_();
},2,1);

_j(_bb716_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb717_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb828_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb718_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb186_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb187_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb149_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb150_termite_23_();
} else {
return _bb185_termite_23_();
}
});

_j(_bb719_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb720_termite_23_();
} else {
return _bb827_termite_23_();
}
});

_k(_bb717_termite_23_ = () => {
return _bb719_termite_23_();
},2,1);

_k(_bb718_termite_23_ = () => {
return _bb719_termite_23_();
},2,1);

_k(_bb187_termite_23_ = () => {
return _bb153_termite_23_();
},2,1);

_j(_bb150_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb151_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb185_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb152_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb720_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb721_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb827_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb153_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb154_termite_23_();
} else {
return _bb184_termite_23_();
}
});

_k(_bb151_termite_23_ = () => {
return _bb153_termite_23_();
},2,1);

_k(_bb152_termite_23_ = () => {
return _bb153_termite_23_();
},2,1);

_k(_bb721_termite_23_ = () => {
if (!(_a === !1)) {
return _bb825_termite_23_();
} else {
return _bb722_termite_23_();
}
},4,1);

_j(_bb154_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb155_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb184_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb825_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb826_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb722_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb723_termite_23_();
} else {
return _bb824_termite_23_();
}
});

_k(_bb155_termite_23_ = () => {
if (!(_a === !1)) {
return _bb182_termite_23_();
} else {
return _bb156_termite_23_();
}
},4,1);

_k(_bb826_termite_23_ = () => {
return _bb726_termite_23_();
},2,1);

_j(_bb723_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb724_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb824_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb725_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb182_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb183_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb156_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb157_termite_23_();
} else {
return _bb181_termite_23_();
}
});

_j(_bb726_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb727_termite_23_();
} else {
return _bb823_termite_23_();
}
});

_k(_bb724_termite_23_ = () => {
return _bb726_termite_23_();
},2,1);

_k(_bb725_termite_23_ = () => {
return _bb726_termite_23_();
},2,1);

_k(_bb183_termite_23_ = () => {
return _bb160_termite_23_();
},2,1);

_j(_bb157_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb158_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb181_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb159_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb727_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb728_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb823_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb160_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb161_termite_23_();
} else {
return _bb180_termite_23_();
}
});

_k(_bb158_termite_23_ = () => {
return _bb160_termite_23_();
},2,1);

_k(_bb159_termite_23_ = () => {
return _bb160_termite_23_();
},2,1);

_k(_bb728_termite_23_ = () => {
if (!(_a === !1)) {
return _bb821_termite_23_();
} else {
return _bb729_termite_23_();
}
},4,1);

_j(_bb161_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb162_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb180_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb821_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb822_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb729_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb730_termite_23_();
} else {
return _bb820_termite_23_();
}
});

_k(_bb162_termite_23_ = () => {
if (!(_a === !1)) {
return _bb178_termite_23_();
} else {
return _bb163_termite_23_();
}
},4,1);

_k(_bb822_termite_23_ = () => {
return _bb733_termite_23_();
},2,1);

_j(_bb730_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb731_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb820_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb732_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb178_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb179_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb163_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb164_termite_23_();
} else {
return _bb177_termite_23_();
}
});

_j(_bb733_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb734_termite_23_();
} else {
return _bb819_termite_23_();
}
});

_k(_bb731_termite_23_ = () => {
return _bb733_termite_23_();
},2,1);

_k(_bb732_termite_23_ = () => {
return _bb733_termite_23_();
},2,1);

_k(_bb179_termite_23_ = () => {
return _bb167_termite_23_();
},2,1);

_j(_bb164_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb165_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb177_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb166_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb734_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb735_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb819_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb167_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb168_termite_23_();
} else {
return _bb176_termite_23_();
}
});

_k(_bb165_termite_23_ = () => {
return _bb167_termite_23_();
},2,1);

_k(_bb166_termite_23_ = () => {
return _bb167_termite_23_();
},2,1);

_k(_bb735_termite_23_ = () => {
if (!(_a === !1)) {
return _bb817_termite_23_();
} else {
return _bb736_termite_23_();
}
},4,1);

_j(_bb168_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb169_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb176_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb817_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb818_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb736_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb737_termite_23_();
} else {
return _bb816_termite_23_();
}
});

_k(_bb169_termite_23_ = () => {
if (!(_a === !1)) {
return _bb174_termite_23_();
} else {
return _bb170_termite_23_();
}
},4,1);

_k(_bb818_termite_23_ = () => {
return _bb740_termite_23_();
},2,1);

_j(_bb737_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb738_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb816_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb739_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb174_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb175_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb170_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb171_termite_23_();
} else {
return _bb173_termite_23_();
}
});

_j(_bb740_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb741_termite_23_();
} else {
return _bb815_termite_23_();
}
});

_k(_bb738_termite_23_ = () => {
return _bb740_termite_23_();
},2,1);

_k(_bb739_termite_23_ = () => {
return _bb740_termite_23_();
},2,1);

_k(_bb175_termite_23_ = () => {
return _bb18_termite_23_();
},2,1);

_j(_bb171_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb172_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb173_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb17_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb741_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb742_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb815_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb18_termite_23_ = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb19_termite_23_);
});

_k(_bb172_termite_23_ = () => {
return _bb18_termite_23_();
},2,1);

_k(_bb17_termite_23_ = () => {
return _bb18_termite_23_();
},2,1);

_k(_bb742_termite_23_ = () => {
if (!(_a === !1)) {
return _bb813_termite_23_();
} else {
return _bb743_termite_23_();
}
},4,1);

_j(_bb19_termite_23_ = () => {
if (_x(_a)) {
return _bb20_termite_23_();
} else {
return _bb260_termite_23_();
}
});

_j(_bb813_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb814_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb743_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb744_termite_23_();
} else {
return _bb812_termite_23_();
}
});

_k(_bb814_termite_23_ = () => {
return _bb747_termite_23_();
},2,1);

_j(_bb744_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb745_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb812_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb746_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb747_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb748_termite_23_();
} else {
return _bb811_termite_23_();
}
});

_k(_bb745_termite_23_ = () => {
return _bb747_termite_23_();
},2,1);

_k(_bb746_termite_23_ = () => {
return _bb747_termite_23_();
},2,1);

_j(_bb748_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb749_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb811_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb749_termite_23_ = () => {
if (!(_a === !1)) {
return _bb809_termite_23_();
} else {
return _bb750_termite_23_();
}
},4,1);

_j(_bb809_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb810_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb750_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb751_termite_23_();
} else {
return _bb808_termite_23_();
}
});

_k(_bb810_termite_23_ = () => {
return _bb754_termite_23_();
},2,1);

_j(_bb751_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb752_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb808_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb753_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb754_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb755_termite_23_();
} else {
return _bb807_termite_23_();
}
});

_k(_bb752_termite_23_ = () => {
return _bb754_termite_23_();
},2,1);

_k(_bb753_termite_23_ = () => {
return _bb754_termite_23_();
},2,1);

_j(_bb755_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb756_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb807_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb756_termite_23_ = () => {
if (!(_a === !1)) {
return _bb805_termite_23_();
} else {
return _bb757_termite_23_();
}
},4,1);

_j(_bb805_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb806_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb757_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb758_termite_23_();
} else {
return _bb804_termite_23_();
}
});

_k(_bb806_termite_23_ = () => {
return _bb761_termite_23_();
},2,1);

_j(_bb758_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb759_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb804_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb760_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb761_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb762_termite_23_();
} else {
return _bb803_termite_23_();
}
});

_k(_bb759_termite_23_ = () => {
return _bb761_termite_23_();
},2,1);

_k(_bb760_termite_23_ = () => {
return _bb761_termite_23_();
},2,1);

_j(_bb762_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb763_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb803_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb763_termite_23_ = () => {
if (!(_a === !1)) {
return _bb801_termite_23_();
} else {
return _bb764_termite_23_();
}
},4,1);

_j(_bb801_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb802_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb764_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb765_termite_23_();
} else {
return _bb800_termite_23_();
}
});

_k(_bb802_termite_23_ = () => {
return _bb768_termite_23_();
},2,1);

_j(_bb765_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb766_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb800_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb767_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb768_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb769_termite_23_();
} else {
return _bb799_termite_23_();
}
});

_k(_bb766_termite_23_ = () => {
return _bb768_termite_23_();
},2,1);

_k(_bb767_termite_23_ = () => {
return _bb768_termite_23_();
},2,1);

_j(_bb769_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb770_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb799_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb770_termite_23_ = () => {
if (!(_a === !1)) {
return _bb797_termite_23_();
} else {
return _bb771_termite_23_();
}
},4,1);

_j(_bb797_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb798_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb771_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb772_termite_23_();
} else {
return _bb796_termite_23_();
}
});

_k(_bb798_termite_23_ = () => {
return _bb775_termite_23_();
},2,1);

_j(_bb772_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb773_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb796_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb774_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb775_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb776_termite_23_();
} else {
return _bb795_termite_23_();
}
});

_k(_bb773_termite_23_ = () => {
return _bb775_termite_23_();
},2,1);

_k(_bb774_termite_23_ = () => {
return _bb775_termite_23_();
},2,1);

_j(_bb776_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb777_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb795_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb777_termite_23_ = () => {
if (!(_a === !1)) {
return _bb793_termite_23_();
} else {
return _bb778_termite_23_();
}
},4,1);

_j(_bb793_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb794_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb778_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb779_termite_23_();
} else {
return _bb792_termite_23_();
}
});

_k(_bb794_termite_23_ = () => {
return _bb782_termite_23_();
},2,1);

_j(_bb779_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb780_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb792_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb781_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb782_termite_23_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb783_termite_23_();
} else {
return _bb791_termite_23_();
}
});

_k(_bb780_termite_23_ = () => {
return _bb782_termite_23_();
},2,1);

_k(_bb781_termite_23_ = () => {
return _bb782_termite_23_();
},2,1);

_j(_bb783_termite_23_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb784_termite_23_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb791_termite_23_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb784_termite_23_ = () => {
if (!(_a === !1)) {
return _bb789_termite_23_();
} else {
return _bb785_termite_23_();
}
},4,1);

_j(_bb789_termite_23_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb790_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb785_termite_23_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb786_termite_23_();
} else {
return _bb788_termite_23_();
}
});

_k(_bb790_termite_23_ = () => {
return _bb591_termite_23_();
},2,1);

_j(_bb786_termite_23_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb787_termite_23_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb788_termite_23_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb590_termite_23_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb591_termite_23_ = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb592_termite_23_);
});

_k(_bb787_termite_23_ = () => {
return _bb591_termite_23_();
},2,1);

_k(_bb590_termite_23_ = () => {
return _bb591_termite_23_();
},2,1);

_j(_bb592_termite_23_ = () => {
if (_x(_a)) {
return _bb593_termite_23_();
} else {
return _bb899_termite_23_();
}
});



_m(_bb1_termite_23_now = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_now);
}
_s[_t+1] = _r;
++_t;
return _p(_bb2_termite_23_now);
},-1,_i("termite#now"),!1,!0);

_j(_bb2_termite_23_now = () => {
_r = _bb3_termite_23_now;
_n = 0;
return _g["##current-time"]();
});

_k(_bb3_termite_23_now = () => {
_r = _s[_t];
return _p(_bb4_termite_23_now);
},1,1);

_j(_bb4_termite_23_now = () => {
_n = 1;
--_t;
return _g["##time->seconds"]();
});



_m(_bb1_termite_23_formatted_2d_current_2d_time = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_formatted_2d_current_2d_time);
}
_s[_t+1] = _r;
_a = _cst123__termite;
++_t;
return _p(_bb2_termite_23_formatted_2d_current_2d_time);
},-1,_i("termite#formatted-current-time"),!1,!0);

_j(_bb2_termite_23_formatted_2d_current_2d_time = () => {
_r = _bb3_termite_23_formatted_2d_current_2d_time;
_n = 1;
return _g["open-process"]();
});

_k(_bb3_termite_23_formatted_2d_current_2d_time = () => {
_s[_t+1] = _a;
_r = _bb4_termite_23_formatted_2d_current_2d_time;
_n = 1;
++_t;
return _g["##read-line"]();
},1,1);

_k(_bb4_termite_23_formatted_2d_current_2d_time = () => {
_s[_t+1] = _a;
_a = _s[_t];
_r = _bb5_termite_23_formatted_2d_current_2d_time;
_n = 1;
++_t;
return _g["##close-port"]();
},2,1);

_k(_bb5_termite_23_formatted_2d_current_2d_time = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);



_m(_bb1_termite_23_process_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_process_3f_);
}
return _p(_bb2_termite_23_process_3f_);
},-1,_i("termite#process?"),!1,!0);

_j(_bb2_termite_23_process_3f_ = () => {
_n = 1;
return _g["thread?"]();
});



_m(_bb1_termite_23_process_2d_links = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_process_2d_links);
}
return _p(_bb2_termite_23_process_2d_links);
},-1,_i("termite#process-links"),!1,!0);

_j(_bb2_termite_23_process_2d_links = () => {
_n = 1;
return _g["thread-specific"]();
});



_m(_bb1_termite_23_process_2d_links_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_process_2d_links_2d_set_21_);
}
return _p(_bb2_termite_23_process_2d_links_2d_set_21_);
},-1,_i("termite#process-links-set!"),!1,!0);

_j(_bb2_termite_23_process_2d_links_2d_set_21_ = () => {
_n = 2;
return _g["thread-specific-set!"]();
});



_m(_bb1_termite_23_make_2d_upid = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_make_2d_upid);
}
_a = new _Structure([_cst101__termite,_a,_b]);
return _r;
},-1,_i("termite#make-upid"),!1,!0);



_m(_bb1_termite_23_upid_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_upid_2d_copy);
}
return _p(_bb2_termite_23_upid_2d_copy);
},-1,_i("termite#upid-copy"),!1,!0);

_j(_bb2_termite_23_upid_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_upid_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_upid_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst83__termite;
return _r;
},-1,_i("termite#upid?"),!1,!0);



_m(_bb1_termite_23_upid_2d_tag = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_upid_2d_tag);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#upid-tag"),!1,!0);



_m(_bb1_termite_23_upid_2d_tag_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_upid_2d_tag_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#upid-tag-set!"),!1,!0);



_m(_bb1_termite_23_upid_2d_tag_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_upid_2d_tag_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_upid_2d_tag_2d_set;
_b = _cst101__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_upid_2d_tag_2d_set);
},-1,_i("termite#upid-tag-set"),!1,!0);

_j(_bb2_termite_23_upid_2d_tag_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_upid_2d_node = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_upid_2d_node);
}
_a = _a.a[2];
return _r;
},-1,_i("termite#upid-node"),!1,!0);



_m(_bb1_termite_23_upid_2d_node_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_upid_2d_node_2d_set_21_);
}
_a.a[2] = _b;
_a = _a;
return _r;
},-1,_i("termite#upid-node-set!"),!1,!0);



_m(_bb1_termite_23_upid_2d_node_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_upid_2d_node_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_upid_2d_node_2d_set;
_b = _cst101__termite;
_a = 2;
_t += 2;
return _p(_bb2_termite_23_upid_2d_node_2d_set);
},-1,_i("termite#upid-node-set"),!1,!0);

_j(_bb2_termite_23_upid_2d_node_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_make_2d_node = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_make_2d_node);
}
if (_stringp(_a)) {
return _bb9_termite_23_make_2d_node();
} else {
return _bb4_termite_23_make_2d_node();
}
},-1,_i("termite#make-node"),!1,!0);

_j(_bb9_termite_23_make_2d_node = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_r = _bb2_termite_23_make_2d_node;
_n = 1;
_t += 3;
return _e["##number?"]();
});

_j(_bb4_termite_23_make_2d_node = () => {
_c = _b;
_b = _a;
_a = _cst130__termite;
return _p(_bb5_termite_23_make_2d_node);
});

_k(_bb2_termite_23_make_2d_node = () => {
if (!(_a === !1)) {
return _bb6_termite_23_make_2d_node();
} else {
return _bb3_termite_23_make_2d_node();
}
},3,1);

_j(_bb5_termite_23_make_2d_node = () => {
_n = 3;
return _g["##error"]();
});

_j(_bb6_termite_23_make_2d_node = () => {
_a = _s[_t];
_r = _bb7_termite_23_make_2d_node;
_n = 1;
--_t;
return _e["##number->string"]();
});

_j(_bb3_termite_23_make_2d_node = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _bb4_termite_23_make_2d_node();
});

_k(_bb7_termite_23_make_2d_node = () => {
_c = _a;
_a = _s[_t];
_b = _cst132__termite;
_r = _s[_t-1];
return _p(_bb8_termite_23_make_2d_node);
},2,1);

_j(_bb8_termite_23_make_2d_node = () => {
_n = 3;
_t -= 2;
return _e["##string-append"]();
});



_m(_bb1_termite_23_node_2d_host = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_node_2d_host);
}
if (_stringp(_a)) {
return _bb2_termite_23_node_2d_host();
} else {
return _bb8_termite_23_node_2d_host();
}
},-1,_i("termite#node-host"),!1,!0);

_j(_bb2_termite_23_node_2d_host = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_b = _cst134__termite;
_t += 2;
return _p(_bb3_termite_23_node_2d_host);
});

_j(_bb8_termite_23_node_2d_host = () => {
_b = _a;
_a = _cst135__termite;
return _p(_bb9_termite_23_node_2d_host);
});

_j(_bb3_termite_23_node_2d_host = () => {
_r = _bb4_termite_23_node_2d_host;
_n = 2;
return _g["##string-contains"]();
});

_j(_bb9_termite_23_node_2d_host = () => {
_n = 2;
return _g["##error"]();
});

_k(_bb4_termite_23_node_2d_host = () => {
if (!(_a === !1)) {
return _bb5_termite_23_node_2d_host();
} else {
return _bb7_termite_23_node_2d_host();
}
},2,1);

_j(_bb5_termite_23_node_2d_host = () => {
_c = _a;
_a = _s[_t];
_b = 0;
_r = _s[_t-1];
return _p(_bb6_termite_23_node_2d_host);
});

_j(_bb7_termite_23_node_2d_host = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
});

_j(_bb6_termite_23_node_2d_host = () => {
_n = 3;
_t -= 2;
return _e["##substring"]();
});



_m(_bb1_termite_23_node_2d_port = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_node_2d_port);
}
if (_stringp(_a)) {
return _bb2_termite_23_node_2d_port();
} else {
return _bb16_termite_23_node_2d_port();
}
},-1,_i("termite#node-port"),!1,!0);

_j(_bb2_termite_23_node_2d_port = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_b = _cst138__termite;
_t += 2;
return _p(_bb3_termite_23_node_2d_port);
});

_j(_bb16_termite_23_node_2d_port = () => {
_b = _a;
_a = _cst139__termite;
return _p(_bb17_termite_23_node_2d_port);
});

_j(_bb3_termite_23_node_2d_port = () => {
_r = _bb4_termite_23_node_2d_port;
_n = 2;
return _g["##string-contains"]();
});

_j(_bb17_termite_23_node_2d_port = () => {
_n = 2;
return _g["##error"]();
});

_k(_bb4_termite_23_node_2d_port = () => {
if (!(_a === !1)) {
return _bb5_termite_23_node_2d_port();
} else {
return _bb15_termite_23_node_2d_port();
}
},2,1);

_j(_bb5_termite_23_node_2d_port = () => {
if (_y(_a)) {
return _bb6_termite_23_node_2d_port();
} else {
return _bb14_termite_23_node_2d_port();
}
});

_j(_bb15_termite_23_node_2d_port = () => {
_a = 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb6_termite_23_node_2d_port = () => {
_b = (_h = (_o = _a + 1)<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb8_termite_23_node_2d_port();
} else {
return _bb14_termite_23_node_2d_port();
}
});

_j(_bb14_termite_23_node_2d_port = () => {
_b = 1;
_r = _bb7_termite_23_node_2d_port;
_n = 2;
return _e["##+"]();
});

_j(_bb8_termite_23_node_2d_port = () => {
_c = _s[_t].a.length;
_a = _s[_t];
_r = _bb9_termite_23_node_2d_port;
_n = 3;
return _e["##substring"]();
});

_k(_bb7_termite_23_node_2d_port = () => {
_b = _a;
return _bb8_termite_23_node_2d_port();
},2,1);

_k(_bb9_termite_23_node_2d_port = () => {
_r = _bb10_termite_23_node_2d_port;
_n = 1;
return _e["##string->number"]();
},2,1);

_k(_bb10_termite_23_node_2d_port = () => {
if (!(_a === !1)) {
return _bb13_termite_23_node_2d_port();
} else {
return _bb11_termite_23_node_2d_port();
}
},2,1);

_j(_bb13_termite_23_node_2d_port = () => {
_t -= 2;
return _s[_t+1]();
});

_j(_bb11_termite_23_node_2d_port = () => {
_b = _s[_t];
_a = _cst139__termite;
_r = _s[_t-1];
return _p(_bb12_termite_23_node_2d_port);
});

_j(_bb12_termite_23_node_2d_port = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});



_m(_bb1_termite_23_make_2d_tag = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_make_2d_tag);
}
_a = new _Structure([_cst141__termite,!1]);
return _r;
},-1,_i("termite#make-tag"),!1,!0);



_m(_bb1_termite_23_tag_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_tag_2d_copy);
}
return _p(_bb2_termite_23_tag_2d_copy);
},-1,_i("termite#tag-copy"),!1,!0);

_j(_bb2_termite_23_tag_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_tag_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_tag_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst142__termite;
return _r;
},-1,_i("termite#tag?"),!1,!0);



_m(_bb1_termite_23_tag_2d_uuid = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_tag_2d_uuid);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#tag-uuid"),!1,!0);



_m(_bb1_termite_23_tag_2d_uuid_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_tag_2d_uuid_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#tag-uuid-set!"),!1,!0);



_m(_bb1_termite_23_tag_2d_uuid_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_tag_2d_uuid_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_tag_2d_uuid_2d_set;
_b = _cst141__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_tag_2d_uuid_2d_set);
},-1,_i("termite#tag-uuid-set"),!1,!0);

_j(_bb2_termite_23_tag_2d_uuid_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_make_2d_proxy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_make_2d_proxy);
}
_a = new _Structure([_cst145__termite,_a]);
return _r;
},-1,_i("termite#make-proxy"),!1,!0);



_m(_bb1_termite_23_proxy_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_proxy_2d_copy);
}
return _p(_bb2_termite_23_proxy_2d_copy);
},-1,_i("termite#proxy-copy"),!1,!0);

_j(_bb2_termite_23_proxy_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_proxy_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_proxy_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst146__termite;
return _r;
},-1,_i("termite#proxy?"),!1,!0);



_m(_bb1_termite_23_proxy_2d_upid = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_proxy_2d_upid);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#proxy-upid"),!1,!0);



_m(_bb1_termite_23_proxy_2d_upid_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_proxy_2d_upid_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#proxy-upid-set!"),!1,!0);



_m(_bb1_termite_23_proxy_2d_upid_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_proxy_2d_upid_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_proxy_2d_upid_2d_set;
_b = _cst145__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_proxy_2d_upid_2d_set);
},-1,_i("termite#proxy-upid-set"),!1,!0);

_j(_bb2_termite_23_proxy_2d_upid_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_make_2d_proxy_2d_callback = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_make_2d_proxy_2d_callback);
}
_a = new _Structure([_cst149__termite,_a]);
return _r;
},-1,_i("termite#make-proxy-callback"),!1,!0);



_m(_bb1_termite_23_proxy_2d_callback_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_proxy_2d_callback_2d_copy);
}
return _p(_bb2_termite_23_proxy_2d_callback_2d_copy);
},-1,_i("termite#proxy-callback-copy"),!1,!0);

_j(_bb2_termite_23_proxy_2d_callback_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_proxy_2d_callback_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_proxy_2d_callback_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst150__termite;
return _r;
},-1,_i("termite#proxy-callback?"),!1,!0);



_m(_bb1_termite_23_proxy_2d_callback_2d_thunk = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_proxy_2d_callback_2d_thunk);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#proxy-callback-thunk"),!1,!0);



_m(_bb1_termite_23_proxy_2d_callback_2d_thunk_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_proxy_2d_callback_2d_thunk_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#proxy-callback-thunk-set!"),!1,!0);



_m(_bb1_termite_23_proxy_2d_callback_2d_thunk_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_proxy_2d_callback_2d_thunk_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_proxy_2d_callback_2d_thunk_2d_set;
_b = _cst149__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_proxy_2d_callback_2d_thunk_2d_set);
},-1,_i("termite#proxy-callback-thunk-set"),!1,!0);

_j(_bb2_termite_23_proxy_2d_callback_2d_thunk_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_pid_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_pid_3f_);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb2_termite_23_pid_3f_);
},-1,_i("termite#pid?"),!1,!0);

_j(_bb2_termite_23_pid_3f_ = () => {
_r = _bb3_termite_23_pid_3f_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_pid_3f_ = () => {
if (!(_a === !1)) {
return _bb4_termite_23_pid_3f_();
} else {
return _bb5_termite_23_pid_3f_();
}
},2,1);

_j(_bb4_termite_23_pid_3f_ = () => {
_t -= 2;
return _s[_t+1]();
});

_j(_bb5_termite_23_pid_3f_ = () => {
_a = _s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite;
_t -= 2;
return _s[_t+1]();
});



_m(_bb1_termite_23_make_2d_termite_2d_exception = () => {
if (_n !== 3) {
return _w(_bb1_termite_23_make_2d_termite_2d_exception);
}
_a = new _Structure([_cst59__termite,_a,_b,_c]);
return _r;
},-1,_i("termite#make-termite-exception"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_exception_2d_copy);
}
return _p(_bb2_termite_23_termite_2d_exception_2d_copy);
},-1,_i("termite#termite-exception-copy"),!1,!0);

_j(_bb2_termite_23_termite_2d_exception_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_termite_2d_exception_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_exception_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst52__termite;
return _r;
},-1,_i("termite#termite-exception?"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_origin = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_exception_2d_origin);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#termite-exception-origin"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_origin_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_exception_2d_origin_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#termite-exception-origin-set!"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_origin_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_exception_2d_origin_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_termite_2d_exception_2d_origin_2d_set;
_b = _cst59__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_termite_2d_exception_2d_origin_2d_set);
},-1,_i("termite#termite-exception-origin-set"),!1,!0);

_j(_bb2_termite_23_termite_2d_exception_2d_origin_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_termite_2d_exception_2d_reason = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_exception_2d_reason);
}
_a = _a.a[2];
return _r;
},-1,_i("termite#termite-exception-reason"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_reason_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_exception_2d_reason_2d_set_21_);
}
_a.a[2] = _b;
_a = _a;
return _r;
},-1,_i("termite#termite-exception-reason-set!"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_reason_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_exception_2d_reason_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_termite_2d_exception_2d_reason_2d_set;
_b = _cst59__termite;
_a = 2;
_t += 2;
return _p(_bb2_termite_23_termite_2d_exception_2d_reason_2d_set);
},-1,_i("termite#termite-exception-reason-set"),!1,!0);

_j(_bb2_termite_23_termite_2d_exception_2d_reason_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_termite_2d_exception_2d_object = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_exception_2d_object);
}
_a = _a.a[3];
return _r;
},-1,_i("termite#termite-exception-object"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_object_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_exception_2d_object_2d_set_21_);
}
_a.a[3] = _b;
_a = _a;
return _r;
},-1,_i("termite#termite-exception-object-set!"),!1,!0);



_m(_bb1_termite_23_termite_2d_exception_2d_object_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_exception_2d_object_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_termite_2d_exception_2d_object_2d_set;
_b = _cst59__termite;
_a = 3;
_t += 2;
return _p(_bb2_termite_23_termite_2d_exception_2d_object_2d_set);
},-1,_i("termite#termite-exception-object-set"),!1,!0);

_j(_bb2_termite_23_termite_2d_exception_2d_object_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_base_2d_exception_2d_handler = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_base_2d_exception_2d_handler);
}
_s[_t+1] = _a;
_a = _bb3_termite_23_base_2d_exception_2d_handler;
_b = _s[_t+1];
++_t;
return _p(_bb2_termite_23_base_2d_exception_2d_handler);
},-1,_i("termite#base-exception-handler"),!1,!0);

_l(_bb3_termite_23_base_2d_exception_2d_handler = () => {
if (_n !== 2) {
return _w(_bb3_termite_23_base_2d_exception_2d_handler);
}
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb4_termite_23_base_2d_exception_2d_handler();
} else {
return _bb42_termite_23_base_2d_exception_2d_handler();
}
},-1);

_j(_bb2_termite_23_base_2d_exception_2d_handler = () => {
--_t;
return _continuation_capture2();
});

_j(_bb4_termite_23_base_2d_exception_2d_handler = () => {
_c = _b.a[2];
if (_c === _cst65__termite) {
return _bb6_termite_23_base_2d_exception_2d_handler();
} else {
return _bb41_termite_23_base_2d_exception_2d_handler();
}
});

_j(_bb42_termite_23_base_2d_exception_2d_handler = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_r = _bb55_termite_23_base_2d_exception_2d_handler;
_t += 2;
return _p(_bb43_termite_23_base_2d_exception_2d_handler);
});

_j(_bb6_termite_23_base_2d_exception_2d_handler = () => {
_a = _current_processor.a[14];
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb7_termite_23_base_2d_exception_2d_handler);
});

_j(_bb41_termite_23_base_2d_exception_2d_handler = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_b = _b.a[3];
_r = _bb5_termite_23_base_2d_exception_2d_handler;
_t += 2;
return _p(_bb43_termite_23_base_2d_exception_2d_handler);
});

_j(_bb43_termite_23_base_2d_exception_2d_handler = () => {
_s[_t+1] = _r;
var closure0 = _closure_alloc([_bb53_termite_23_base_2d_exception_2d_handler,_b,_a]);
_s[_t+2] = closure0;
_b = _s[_t+2];
_a = _cst154__termite;
_t += 2;
return _p(_bb44_termite_23_base_2d_exception_2d_handler);
});

_k(_bb55_termite_23_base_2d_exception_2d_handler = () => {
_a = _current_processor.a[14];
_r = _bb27_termite_23_base_2d_exception_2d_handler;
_n = 1;
return _g["thread-specific"]();
},2,1);

_j(_bb7_termite_23_base_2d_exception_2d_handler = () => {
_r = _bb8_termite_23_base_2d_exception_2d_handler;
_n = 1;
return _g["thread-specific"]();
});

_k(_bb5_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _bb6_termite_23_base_2d_exception_2d_handler();
},2,1);

_l(_bb53_termite_23_base_2d_exception_2d_handler = () => {
if (_n !== 1) {
return _w(_d);
}
_c = _a;
_b = _d(!0)[2];
_a = _d(!0)[1];
return _p(_bb54_termite_23_base_2d_exception_2d_handler);
},2);

_j(_bb44_termite_23_base_2d_exception_2d_handler = () => {
_r = _bb45_termite_23_base_2d_exception_2d_handler;
_n = 2;
--_t;
return _g["##call-with-output-string"]();
});

_k(_bb27_termite_23_base_2d_exception_2d_handler = () => {
_b = _a;
_a = _s[_t];
_r = _bb36_termite_23_base_2d_exception_2d_handler;
--_t;
return _bb28_termite_23_base_2d_exception_2d_handler();
},2,1);

_k(_bb8_termite_23_base_2d_exception_2d_handler = () => {
_b = _a;
_a = _s[_t];
_r = _bb36_termite_23_base_2d_exception_2d_handler;
--_t;
return _bb9_termite_23_base_2d_exception_2d_handler();
},2,1);

_j(_bb54_termite_23_base_2d_exception_2d_handler = () => {
_n = 3;
return _g["display-exception-in-context"]();
});

_k(_bb45_termite_23_base_2d_exception_2d_handler = () => {
_a = _X(_a,null);
_b = _current_processor.a[14];
_a = _X(_cst157__termite,_X(_b,_X(_a,null)));
_a = _X(_cst47__termite,_X(_a,null));
_s[_t+1] = _a;
_a = _g["termite#logger"];
_r = _bb46_termite_23_base_2d_exception_2d_handler;
_n = 1;
++_t;
return _g["thread?"]();
},1,1);

_j(_bb28_termite_23_base_2d_exception_2d_handler = () => {
if (_x(_b)) {
return _bb29_termite_23_base_2d_exception_2d_handler();
} else {
return _bb38_termite_23_base_2d_exception_2d_handler();
}
});

_k(_bb36_termite_23_base_2d_exception_2d_handler = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb37_termite_23_base_2d_exception_2d_handler);
},1,1);

_j(_bb9_termite_23_base_2d_exception_2d_handler = () => {
if (_x(_b)) {
return _bb12_termite_23_base_2d_exception_2d_handler();
} else {
return _bb38_termite_23_base_2d_exception_2d_handler();
}
});

_k(_bb46_termite_23_base_2d_exception_2d_handler = () => {
if (!(_a === !1)) {
return _bb47_termite_23_base_2d_exception_2d_handler();
} else {
return _bb48_termite_23_base_2d_exception_2d_handler();
}
},2,1);

_j(_bb29_termite_23_base_2d_exception_2d_handler = () => {
_c = _b.a;
_d = _current_processor.a[14];
_d = new _Structure([_cst59__termite,_d,_cst158__termite,_a]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_s[_t+5] = _d;
_a = _c;
_t += 5;
return _p(_bb30_termite_23_base_2d_exception_2d_handler);
});

_j(_bb38_termite_23_base_2d_exception_2d_handler = () => {
_a = void 0;
return _r;
});

_j(_bb37_termite_23_base_2d_exception_2d_handler = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb12_termite_23_base_2d_exception_2d_handler = () => {
_c = _b.a;
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_b = _a;
_a = _c;
_t += 3;
return _p(_bb13_termite_23_base_2d_exception_2d_handler);
});

_j(_bb47_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t];
_a = _g["termite#logger"];
_r = _s[_t-1];
return _p(_bb50_termite_23_base_2d_exception_2d_handler);
});

_j(_bb48_termite_23_base_2d_exception_2d_handler = () => {
if (_g["termite#logger"] instanceof _Structure && _g["termite#logger"].a[0].a[1] === _cst83__termite) {
return _bb49_termite_23_base_2d_exception_2d_handler();
} else {
return _bb51_termite_23_base_2d_exception_2d_handler();
}
});

_j(_bb30_termite_23_base_2d_exception_2d_handler = () => {
_r = _bb31_termite_23_base_2d_exception_2d_handler;
_n = 1;
return _g["thread?"]();
});

_j(_bb13_termite_23_base_2d_exception_2d_handler = () => {
_r = _bb14_termite_23_base_2d_exception_2d_handler;
_n = 2;
return _bb1_termite_23__21_();
});

_j(_bb50_termite_23_base_2d_exception_2d_handler = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb49_termite_23_base_2d_exception_2d_handler = () => {
_b = _X(_cst77__termite,_X(_g["termite#logger"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb50_termite_23_base_2d_exception_2d_handler);
});

_j(_bb51_termite_23_base_2d_exception_2d_handler = () => {
_b = _g["termite#logger"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb52_termite_23_base_2d_exception_2d_handler);
});

_k(_bb31_termite_23_base_2d_exception_2d_handler = () => {
if (!(_a === !1)) {
return _bb35_termite_23_base_2d_exception_2d_handler();
} else {
return _bb32_termite_23_base_2d_exception_2d_handler();
}
},5,1);

_k(_bb14_termite_23_base_2d_exception_2d_handler = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb15_termite_23_base_2d_exception_2d_handler();
} else {
return _bb18_termite_23_base_2d_exception_2d_handler();
}
},3,1);

_j(_bb52_termite_23_base_2d_exception_2d_handler = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb35_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb16_termite_23_base_2d_exception_2d_handler;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb32_termite_23_base_2d_exception_2d_handler = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb33_termite_23_base_2d_exception_2d_handler();
} else {
return _bb34_termite_23_base_2d_exception_2d_handler();
}
});

_j(_bb15_termite_23_base_2d_exception_2d_handler = () => {
_b = _a.a;
_s[_t] = _a;
_s[_t+1] = _b;
_b = _s[_t-1];
_a = _s[_t+1];
_r = _bb10_termite_23_base_2d_exception_2d_handler;
_n = 2;
return _bb1_termite_23__21_();
});

_j(_bb18_termite_23_base_2d_exception_2d_handler = () => {
_a = void 0;
_t -= 3;
return _s[_t+1]();
});

_k(_bb16_termite_23_base_2d_exception_2d_handler = () => {
return _bb17_termite_23_base_2d_exception_2d_handler();
},3,1);

_j(_bb33_termite_23_base_2d_exception_2d_handler = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb16_termite_23_base_2d_exception_2d_handler;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb34_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb16_termite_23_base_2d_exception_2d_handler;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb10_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t].b;
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb11_termite_23_base_2d_exception_2d_handler);
},3,1);

_j(_bb17_termite_23_base_2d_exception_2d_handler = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb19_termite_23_base_2d_exception_2d_handler();
} else {
return _bb18_termite_23_base_2d_exception_2d_handler();
}
});

_j(_bb11_termite_23_base_2d_exception_2d_handler = () => {
if (_x(_b)) {
return _bb12_termite_23_base_2d_exception_2d_handler();
} else {
return _bb38_termite_23_base_2d_exception_2d_handler();
}
});

_j(_bb19_termite_23_base_2d_exception_2d_handler = () => {
_b = _a.a;
_s[_t] = _a;
_s[_t+1] = _b;
_c = _s[_t-1];
_b = _cst158__termite;
_a = _current_processor.a[14];
_r = _bb20_termite_23_base_2d_exception_2d_handler;
_n = 3;
++_t;
return _bb1_termite_23_make_2d_termite_2d_exception();
});

_k(_bb20_termite_23_base_2d_exception_2d_handler = () => {
_s[_t+1] = _a;
_a = _s[_t];
_r = _bb21_termite_23_base_2d_exception_2d_handler;
_n = 1;
++_t;
return _g["thread?"]();
},4,1);

_k(_bb21_termite_23_base_2d_exception_2d_handler = () => {
if (!(_a === !1)) {
return _bb40_termite_23_base_2d_exception_2d_handler();
} else {
return _bb22_termite_23_base_2d_exception_2d_handler();
}
},5,1);

_j(_bb40_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb24_termite_23_base_2d_exception_2d_handler;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb22_termite_23_base_2d_exception_2d_handler = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb23_termite_23_base_2d_exception_2d_handler();
} else {
return _bb39_termite_23_base_2d_exception_2d_handler();
}
});

_k(_bb24_termite_23_base_2d_exception_2d_handler = () => {
return _bb25_termite_23_base_2d_exception_2d_handler();
},3,1);

_j(_bb23_termite_23_base_2d_exception_2d_handler = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb24_termite_23_base_2d_exception_2d_handler;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb39_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb24_termite_23_base_2d_exception_2d_handler;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb25_termite_23_base_2d_exception_2d_handler = () => {
_b = _s[_t].b;
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb26_termite_23_base_2d_exception_2d_handler);
});

_j(_bb26_termite_23_base_2d_exception_2d_handler = () => {
if (_x(_b)) {
return _bb29_termite_23_base_2d_exception_2d_handler();
} else {
return _bb38_termite_23_base_2d_exception_2d_handler();
}
});



_m(_bb1_termite_23_spawn = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_spawn,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb6_termite_23_spawn,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb2_termite_23_spawn);
},-1,_i("termite#spawn"),!1,!0);

_l(_bb6_termite_23_spawn = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb7_termite_23_spawn);
},1);

_j(_bb2_termite_23_spawn = () => {
_r = _bb3_termite_23_spawn;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb7_termite_23_spawn = () => {
_r = _bb8_termite_23_spawn;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb3_termite_23_spawn = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb4_termite_23_spawn;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb8_termite_23_spawn = () => {
_r = _s[_t];
return _p(_bb9_termite_23_spawn);
},1,1);

_k(_bb4_termite_23_spawn = () => {
_a = _s[_t];
_r = _bb5_termite_23_spawn;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb9_termite_23_spawn = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_k(_bb5_termite_23_spawn = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);



_m(_bb1_termite_23_spawn_2d_linked_2d_to = () => {
var error = _build_key(2,3,[_cst15__termite,_cst159__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_spawn_2d_linked_2d_to,error);
}
_s[_t+1] = _b;
_s[_t+2] = _cst16__termite;
_a = _X(_a,null);
_b = _cst15__termite;
_t += 2;
return _p(_bb2_termite_23_spawn_2d_linked_2d_to);
},-1,_i("termite#spawn-linked-to"),!1,!0);

_j(_bb2_termite_23_spawn_2d_linked_2d_to = () => {
_n = 5;
return _bb3_termite_23_spawn_2d_linked_2d_to();
});

_l(_bb3_termite_23_spawn_2d_linked_2d_to = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_spawn_2d_linked_2d_to,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb8_termite_23_spawn_2d_linked_2d_to,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb4_termite_23_spawn_2d_linked_2d_to);
},-1);

_l(_bb8_termite_23_spawn_2d_linked_2d_to = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb9_termite_23_spawn_2d_linked_2d_to);
},1);

_j(_bb4_termite_23_spawn_2d_linked_2d_to = () => {
_r = _bb5_termite_23_spawn_2d_linked_2d_to;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb9_termite_23_spawn_2d_linked_2d_to = () => {
_r = _bb10_termite_23_spawn_2d_linked_2d_to;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb5_termite_23_spawn_2d_linked_2d_to = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb6_termite_23_spawn_2d_linked_2d_to;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb10_termite_23_spawn_2d_linked_2d_to = () => {
_r = _s[_t];
return _p(_bb11_termite_23_spawn_2d_linked_2d_to);
},1,1);

_k(_bb6_termite_23_spawn_2d_linked_2d_to = () => {
_a = _s[_t];
_r = _bb7_termite_23_spawn_2d_linked_2d_to;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb11_termite_23_spawn_2d_linked_2d_to = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_k(_bb7_termite_23_spawn_2d_linked_2d_to = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);



_m(_bb1_termite_23_spawn_2d_link = () => {
var error = _build_key(1,2,[_cst15__termite,_cst160__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_spawn_2d_link,error);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _cst16__termite;
_c = _b;
_b = _cst15__termite;
_a = _current_processor.a[14];
_a = _X(_a,null);
_t += 3;
return _p(_bb2_termite_23_spawn_2d_link);
},-1,_i("termite#spawn-link"),!1,!0);

_j(_bb2_termite_23_spawn_2d_link = () => {
_r = _bb12_termite_23_spawn_2d_link;
_n = 5;
return _bb3_termite_23_spawn_2d_link();
});

_l(_bb3_termite_23_spawn_2d_link = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_spawn_2d_link,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb8_termite_23_spawn_2d_link,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb4_termite_23_spawn_2d_link);
},-1);

_k(_bb12_termite_23_spawn_2d_link = () => {
_s[_t+1] = _a;
_r = _bb13_termite_23_spawn_2d_link;
_n = 1;
++_t;
return _bb1_termite_23_outbound_2d_link();
},1,1);

_l(_bb8_termite_23_spawn_2d_link = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb9_termite_23_spawn_2d_link);
},1);

_j(_bb4_termite_23_spawn_2d_link = () => {
_r = _bb5_termite_23_spawn_2d_link;
_n = 2;
--_t;
return _g["make-thread"]();
});

_k(_bb13_termite_23_spawn_2d_link = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_j(_bb9_termite_23_spawn_2d_link = () => {
_r = _bb10_termite_23_spawn_2d_link;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb5_termite_23_spawn_2d_link = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb6_termite_23_spawn_2d_link;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb10_termite_23_spawn_2d_link = () => {
_r = _s[_t];
return _p(_bb11_termite_23_spawn_2d_link);
},1,1);

_k(_bb6_termite_23_spawn_2d_link = () => {
_a = _s[_t];
_r = _bb7_termite_23_spawn_2d_link;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb11_termite_23_spawn_2d_link = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_k(_bb7_termite_23_spawn_2d_link = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);



_m(_bb1_termite_23_remote_2d_spawn = () => {
var error = _build_key(2,4,[_cst16__termite,null,_cst15__termite,_cst161__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_remote_2d_spawn,error);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_t += 4;
return _p(_bb2_termite_23_remote_2d_spawn);
},-1,_i("termite#remote-spawn"),!1,!0);

_j(_bb2_termite_23_remote_2d_spawn = () => {
_r = _bb3_termite_23_remote_2d_spawn;
_n = 0;
return _g["termite#current-node"]();
});

_k(_bb3_termite_23_remote_2d_spawn = () => {
_b = _a;
_a = _s[_t-4];
_r = _bb4_termite_23_remote_2d_spawn;
_n = 2;
return _e["##equal?"]();
},5,2);

_k(_bb4_termite_23_remote_2d_spawn = () => {
if (!(_a === !1)) {
return _bb5_termite_23_remote_2d_spawn();
} else {
return _bb7_termite_23_remote_2d_spawn();
}
},5,2);

_j(_bb5_termite_23_remote_2d_spawn = () => {
_s[_t-4] = _s[_t-2];
_s[_t-2] = _s[_t-3];
_s[_t-3] = _cst16__termite;
_c = _s[_t];
_a = _s[_t-1];
_b = _cst15__termite;
_r = _s[_t-2];
return _p(_bb6_termite_23_remote_2d_spawn);
});

_j(_bb7_termite_23_remote_2d_spawn = () => {
_b = _X(_cst90__termite,_X(_s[_t-2],_X(_s[_t-1],_X(_s[_t],null))));
_a = new _Structure([_cst101__termite,_cst162__termite,_s[_t-4]]);
_r = _s[_t-3];
return _p(_bb8_termite_23_remote_2d_spawn);
});

_j(_bb6_termite_23_remote_2d_spawn = () => {
_n = 5;
_t -= 3;
return _bb1_termite_23_spawn();
});

_j(_bb8_termite_23_remote_2d_spawn = () => {
_n = 2;
_t -= 5;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_remote_2d_spawn_2d_link = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_remote_2d_spawn_2d_link);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _b;
_b = _current_processor.a[14];
_c = _X(_b,null);
_b = _cst16__termite;
_t += 2;
return _p(_bb2_termite_23_remote_2d_spawn_2d_link);
},-1,_i("termite#remote-spawn-link"),!1,!0);

_j(_bb2_termite_23_remote_2d_spawn_2d_link = () => {
_r = _bb11_termite_23_remote_2d_spawn_2d_link;
_n = 4;
return _bb3_termite_23_remote_2d_spawn_2d_link();
});

_l(_bb3_termite_23_remote_2d_spawn_2d_link = () => {
var error = _build_key(2,4,[_cst16__termite,null,_cst15__termite,_cst161__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_remote_2d_spawn_2d_link,error);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_t += 4;
return _p(_bb4_termite_23_remote_2d_spawn_2d_link);
},-1);

_k(_bb11_termite_23_remote_2d_spawn_2d_link = () => {
_s[_t+1] = _a;
_r = _bb12_termite_23_remote_2d_spawn_2d_link;
_n = 1;
++_t;
return _bb1_termite_23_outbound_2d_link();
},1,1);

_j(_bb4_termite_23_remote_2d_spawn_2d_link = () => {
_r = _bb5_termite_23_remote_2d_spawn_2d_link;
_n = 0;
return _g["termite#current-node"]();
});

_k(_bb12_termite_23_remote_2d_spawn_2d_link = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_k(_bb5_termite_23_remote_2d_spawn_2d_link = () => {
_b = _a;
_a = _s[_t-4];
_r = _bb6_termite_23_remote_2d_spawn_2d_link;
_n = 2;
return _e["##equal?"]();
},5,2);

_k(_bb6_termite_23_remote_2d_spawn_2d_link = () => {
if (!(_a === !1)) {
return _bb7_termite_23_remote_2d_spawn_2d_link();
} else {
return _bb9_termite_23_remote_2d_spawn_2d_link();
}
},5,2);

_j(_bb7_termite_23_remote_2d_spawn_2d_link = () => {
_s[_t-4] = _s[_t-2];
_s[_t-2] = _s[_t-3];
_s[_t-3] = _cst16__termite;
_c = _s[_t];
_a = _s[_t-1];
_b = _cst15__termite;
_r = _s[_t-2];
return _p(_bb8_termite_23_remote_2d_spawn_2d_link);
});

_j(_bb9_termite_23_remote_2d_spawn_2d_link = () => {
_b = _X(_cst90__termite,_X(_s[_t-2],_X(_s[_t-1],_X(_s[_t],null))));
_a = new _Structure([_cst101__termite,_cst162__termite,_s[_t-4]]);
_r = _s[_t-3];
return _p(_bb10_termite_23_remote_2d_spawn_2d_link);
});

_j(_bb8_termite_23_remote_2d_spawn_2d_link = () => {
_n = 5;
_t -= 3;
return _bb1_termite_23_spawn();
});

_j(_bb10_termite_23_remote_2d_spawn_2d_link = () => {
_n = 2;
_t -= 5;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_shutdown_21_ = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_shutdown_21_);
}
_a = _current_processor.a[14];
_s[_t+1] = _r;
++_t;
return _p(_bb2_termite_23_shutdown_21_);
},-1,_i("termite#shutdown!"),!1,!0);

_j(_bb2_termite_23_shutdown_21_ = () => {
_r = _bb3_termite_23_shutdown_21_;
_n = 1;
return _g["thread-specific"]();
});

_k(_bb3_termite_23_shutdown_21_ = () => {
_r = _bb25_termite_23_shutdown_21_;
return _bb4_termite_23_shutdown_21_();
},1,1);

_j(_bb4_termite_23_shutdown_21_ = () => {
if (_x(_a)) {
return _bb8_termite_23_shutdown_21_();
} else {
return _bb24_termite_23_shutdown_21_();
}
});

_k(_bb25_termite_23_shutdown_21_ = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb26_termite_23_shutdown_21_);
},1,1);

_j(_bb8_termite_23_shutdown_21_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb9_termite_23_shutdown_21_);
});

_j(_bb24_termite_23_shutdown_21_ = () => {
_a = void 0;
return _r;
});

_j(_bb26_termite_23_shutdown_21_ = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb9_termite_23_shutdown_21_ = () => {
_r = _bb10_termite_23_shutdown_21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb10_termite_23_shutdown_21_ = () => {
if (!(_a === !1)) {
return _bb23_termite_23_shutdown_21_();
} else {
return _bb11_termite_23_shutdown_21_();
}
},4,1);

_j(_bb23_termite_23_shutdown_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb13_termite_23_shutdown_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb11_termite_23_shutdown_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb12_termite_23_shutdown_21_();
} else {
return _bb22_termite_23_shutdown_21_();
}
});

_k(_bb13_termite_23_shutdown_21_ = () => {
return _bb14_termite_23_shutdown_21_();
},2,1);

_j(_bb12_termite_23_shutdown_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb13_termite_23_shutdown_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb22_termite_23_shutdown_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb13_termite_23_shutdown_21_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb14_termite_23_shutdown_21_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb15_termite_23_shutdown_21_();
} else {
return _bb21_termite_23_shutdown_21_();
}
});

_j(_bb15_termite_23_shutdown_21_ = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb16_termite_23_shutdown_21_;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb21_termite_23_shutdown_21_ = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb16_termite_23_shutdown_21_ = () => {
if (!(_a === !1)) {
return _bb20_termite_23_shutdown_21_();
} else {
return _bb17_termite_23_shutdown_21_();
}
},4,1);

_j(_bb20_termite_23_shutdown_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb5_termite_23_shutdown_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb17_termite_23_shutdown_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb18_termite_23_shutdown_21_();
} else {
return _bb19_termite_23_shutdown_21_();
}
});

_k(_bb5_termite_23_shutdown_21_ = () => {
return _bb6_termite_23_shutdown_21_();
},2,1);

_j(_bb18_termite_23_shutdown_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb5_termite_23_shutdown_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb19_termite_23_shutdown_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb5_termite_23_shutdown_21_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb6_termite_23_shutdown_21_ = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb7_termite_23_shutdown_21_);
});

_j(_bb7_termite_23_shutdown_21_ = () => {
if (_x(_a)) {
return _bb8_termite_23_shutdown_21_();
} else {
return _bb24_termite_23_shutdown_21_();
}
});



_m(_bb1_termite_23_halt_21_ = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_halt_21_);
}
_a = _current_processor.a[14];
return _p(_bb2_termite_23_halt_21_);
},-1,_i("termite#halt!"),!1,!0);

_j(_bb2_termite_23_halt_21_ = () => {
_n = 1;
return _g["thread-terminate!"]();
});



_m(_bb1_termite_23_terminate_21_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_terminate_21_);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb2_termite_23_terminate_21_);
},-1,_i("termite#terminate!"),!1,!0);

_j(_bb2_termite_23_terminate_21_ = () => {
_r = _bb3_termite_23_terminate_21_;
_n = 1;
return _g["thread-terminate!"]();
});

_k(_bb3_termite_23_terminate_21_ = () => {
_a = _s[_t];
_r = _bb4_termite_23_terminate_21_;
_n = 1;
return _g["thread-specific"]();
},2,1);

_k(_bb4_termite_23_terminate_21_ = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb7_termite_23_terminate_21_);
},2,1);

_j(_bb7_termite_23_terminate_21_ = () => {
if (_x(_b)) {
return _bb8_termite_23_terminate_21_();
} else {
return _bb25_termite_23_terminate_21_();
}
});

_j(_bb8_termite_23_terminate_21_ = () => {
_c = _b.a;
_d = new _Structure([_cst59__termite,_a,_cst163__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_s[_t+5] = _d;
_a = _c;
_t += 5;
return _p(_bb9_termite_23_terminate_21_);
});

_j(_bb25_termite_23_terminate_21_ = () => {
_a = void 0;
return _r;
});

_j(_bb9_termite_23_terminate_21_ = () => {
_r = _bb10_termite_23_terminate_21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb10_termite_23_terminate_21_ = () => {
if (!(_a === !1)) {
return _bb24_termite_23_terminate_21_();
} else {
return _bb11_termite_23_terminate_21_();
}
},5,1);

_j(_bb24_termite_23_terminate_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb13_termite_23_terminate_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb11_termite_23_terminate_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb12_termite_23_terminate_21_();
} else {
return _bb23_termite_23_terminate_21_();
}
});

_k(_bb13_termite_23_terminate_21_ = () => {
return _bb14_termite_23_terminate_21_();
},3,1);

_j(_bb12_termite_23_terminate_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb13_termite_23_terminate_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb23_termite_23_terminate_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb13_termite_23_terminate_21_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb14_termite_23_terminate_21_ = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb15_termite_23_terminate_21_();
} else {
return _bb22_termite_23_terminate_21_();
}
});

_j(_bb15_termite_23_terminate_21_ = () => {
_b = _a.a;
_s[_t] = _a;
_s[_t+1] = _b;
_a = _s[_t-1];
_c = !1;
_b = _cst163__termite;
_r = _bb16_termite_23_terminate_21_;
_n = 3;
++_t;
return _bb1_termite_23_make_2d_termite_2d_exception();
});

_j(_bb22_termite_23_terminate_21_ = () => {
_a = void 0;
_t -= 3;
return _s[_t+1]();
});

_k(_bb16_termite_23_terminate_21_ = () => {
_s[_t+1] = _a;
_a = _s[_t];
_r = _bb17_termite_23_terminate_21_;
_n = 1;
++_t;
return _g["thread?"]();
},4,1);

_k(_bb17_termite_23_terminate_21_ = () => {
if (!(_a === !1)) {
return _bb21_termite_23_terminate_21_();
} else {
return _bb18_termite_23_terminate_21_();
}
},5,1);

_j(_bb21_termite_23_terminate_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb5_termite_23_terminate_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb18_termite_23_terminate_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb19_termite_23_terminate_21_();
} else {
return _bb20_termite_23_terminate_21_();
}
});

_k(_bb5_termite_23_terminate_21_ = () => {
return _bb6_termite_23_terminate_21_();
},3,1);

_j(_bb19_termite_23_terminate_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb5_termite_23_terminate_21_;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb20_termite_23_terminate_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb5_termite_23_terminate_21_;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb6_termite_23_terminate_21_ = () => {
_b = _s[_t].b;
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb7_termite_23_terminate_21_);
});



_m(_bb1_termite_23_wait_2d_for = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_wait_2d_for);
}
_s[_t+1] = _bb6_termite_23_wait_2d_for;
var closure0 = _closure_alloc([_bb3_termite_23_wait_2d_for,_a]);
_s[_t+2] = closure0;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb2_termite_23_wait_2d_for);
},-1,_i("termite#wait-for"),!1,!0);

_l(_bb6_termite_23_wait_2d_for = () => {
if (_n !== 1) {
return _w(_bb6_termite_23_wait_2d_for);
}
_a = void 0;
return _r;
},-1);

_l(_bb3_termite_23_wait_2d_for = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_a = _d(!0)[1];
++_t;
return _p(_bb4_termite_23_wait_2d_for);
},1);

_j(_bb2_termite_23_wait_2d_for = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_j(_bb4_termite_23_wait_2d_for = () => {
_r = _bb5_termite_23_wait_2d_for;
_n = 1;
return _g["thread-join!"]();
});

_k(_bb5_termite_23_wait_2d_for = () => {
_a = void 0;
--_t;
return _s[_t+1]();
},1,1);



_m(_bb1_termite_23_alive_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_alive_3f_);
}
return _p(_bb2_termite_23_alive_3f_);
},-1,_i("termite#alive?"),!1,!0);

_j(_bb2_termite_23_alive_3f_ = () => {
_n = 1;
return _bb1_termite_23__25_alive_3f_();
});



_m(_bb1_termite_23__25_wait_2d_for = () => {
if (_n !== 1) {
return _w(_bb1_termite_23__25_wait_2d_for);
}
_s[_t+1] = _bb6_termite_23__25_wait_2d_for;
var closure0 = _closure_alloc([_bb3_termite_23__25_wait_2d_for,_a]);
_s[_t+2] = closure0;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb2_termite_23__25_wait_2d_for);
},-1,_i("termite#%wait-for"),!1,!0);

_l(_bb6_termite_23__25_wait_2d_for = () => {
if (_n !== 1) {
return _w(_bb6_termite_23__25_wait_2d_for);
}
_a = void 0;
return _r;
},-1);

_l(_bb3_termite_23__25_wait_2d_for = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_a = _d(!0)[1];
++_t;
return _p(_bb4_termite_23__25_wait_2d_for);
},1);

_j(_bb2_termite_23__25_wait_2d_for = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_j(_bb4_termite_23__25_wait_2d_for = () => {
_r = _bb5_termite_23__25_wait_2d_for;
_n = 1;
return _g["thread-join!"]();
});

_k(_bb5_termite_23__25_wait_2d_for = () => {
_a = void 0;
--_t;
return _s[_t+1]();
},1,1);



_m(_bb1_termite_23__25_alive_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23__25_alive_3f_);
}
_s[_t+1] = _bb6_termite_23__25_alive_3f_;
var closure0 = _closure_alloc([_bb3_termite_23__25_alive_3f_,_a]);
_s[_t+2] = closure0;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb2_termite_23__25_alive_3f_);
},-1,_i("termite#%alive?"),!1,!0);

_l(_bb6_termite_23__25_alive_3f_ = () => {
if (_n !== 1) {
return _w(_bb6_termite_23__25_alive_3f_);
}
return _p(_bb7_termite_23__25_alive_3f_);
},-1);

_l(_bb3_termite_23__25_alive_3f_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_a = _d(!0)[1];
_b = 0;
++_t;
return _p(_bb4_termite_23__25_alive_3f_);
},1);

_j(_bb2_termite_23__25_alive_3f_ = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_j(_bb7_termite_23__25_alive_3f_ = () => {
_n = 1;
return _g["join-timeout-exception?"]();
});

_j(_bb4_termite_23__25_alive_3f_ = () => {
_r = _bb5_termite_23__25_alive_3f_;
_n = 2;
return _g["thread-join!"]();
});

_k(_bb5_termite_23__25_alive_3f_ = () => {
_a = !1;
--_t;
return _s[_t+1]();
},1,1);



_m(_bb1_termite_23__21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23__21_);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23__21_);
},-1,_i("termite#!"),!1,!0);

_j(_bb2_termite_23__21_ = () => {
_r = _bb3_termite_23__21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23__21_ = () => {
if (!(_a === !1)) {
return _bb4_termite_23__21_();
} else {
return _bb5_termite_23__21_();
}
},3,1);

_j(_bb4_termite_23__21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23__21_);
});

_j(_bb5_termite_23__21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23__21_();
} else {
return _bb8_termite_23__21_();
}
});

_j(_bb7_termite_23__21_ = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23__21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23__21_);
});

_j(_bb8_termite_23__21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23__21_);
});

_j(_bb9_termite_23__21_ = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23__3f_ = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1_termite_23__3f_);
}
}
if (_a === null) {
return _bb2_termite_23__3f_();
} else {
return _bb15_termite_23__3f_();
}
},-1,_i("termite#?"),!1,!0);

_j(_bb2_termite_23__3f_ = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb3_termite_23__3f_);
});

_j(_bb15_termite_23__3f_ = () => {
if (_x(_a)) {
return _bb16_termite_23__3f_();
} else {
return _bb22_termite_23__3f_();
}
});

_j(_bb3_termite_23__3f_ = () => {
_r = _bb4_termite_23__3f_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb16_termite_23__3f_ = () => {
_b = _a.a;
_c = _a.b;
if (_c === null) {
return _bb17_termite_23__3f_();
} else {
return _bb18_termite_23__3f_();
}
});

_j(_bb22_termite_23__3f_ = () => {
_a = _X(_cst56__termite,_X(_a,null));
return _p(_bb23_termite_23__3f_);
});

_k(_bb4_termite_23__3f_ = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb5_termite_23__3f_();
} else {
return _bb13_termite_23__3f_();
}
},1,1);

_j(_bb17_termite_23__3f_ = () => {
_s[_t+1] = _bb33_termite_23__3f_;
var closure0 = _closure_alloc([_bb24_termite_23__3f_,_b]);
_s[_t+2] = closure0;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb21_termite_23__3f_);
});

_j(_bb18_termite_23__3f_ = () => {
if (_x(_c)) {
return _bb19_termite_23__3f_();
} else {
return _bb22_termite_23__3f_();
}
});

_j(_bb23_termite_23__3f_ = () => {
_n = 1;
return _g["##raise"]();
});

_j(_bb5_termite_23__3f_ = () => {
_s[_t+1] = _a;
_r = _bb6_termite_23__3f_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb13_termite_23__3f_ = () => {
_s[_t+1] = _a;
_r = _bb14_termite_23__3f_;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_l(_bb33_termite_23__3f_ = () => {
if (_n !== 1) {
return _w(_bb33_termite_23__3f_);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb34_termite_23__3f_);
},-1);

_l(_bb24_termite_23__3f_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_a = _d(!0)[1];
++_t;
return _p(_bb25_termite_23__3f_);
},1);

_j(_bb21_termite_23__3f_ = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_j(_bb19_termite_23__3f_ = () => {
_d = _c.a;
_c = _c.b;
if (_c === null) {
return _bb20_termite_23__3f_();
} else {
return _bb22_termite_23__3f_();
}
});

_k(_bb6_termite_23__3f_ = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb9_termite_23__3f_);
},2,1);

_k(_bb14_termite_23__3f_ = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_j(_bb34_termite_23__3f_ = () => {
_r = _bb7_termite_23__3f_;
_n = 1;
return _g["mailbox-receive-timeout-exception?"]();
});

_j(_bb25_termite_23__3f_ = () => {
_r = _bb4_termite_23__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_j(_bb20_termite_23__3f_ = () => {
var closure1 = _closure_alloc([_bb26_termite_23__3f_,_d]);
_s[_t+1] = closure1;
var closure2 = _closure_alloc([_bb24_termite_23__3f_,_b]);
_s[_t+2] = closure2;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb21_termite_23__3f_);
});

_j(_bb9_termite_23__3f_ = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_k(_bb7_termite_23__3f_ = () => {
if (!(_a === !1)) {
return _bb10_termite_23__3f_();
} else {
return _bb8_termite_23__3f_();
}
},2,1);

_l(_bb26_termite_23__3f_ = () => {
if (_n !== 1) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_t += 3;
return _p(_bb27_termite_23__3f_);
},1);

_j(_bb10_termite_23__3f_ = () => {
_r = _bb11_termite_23__3f_;
_n = 0;
--_t;
return _g["thread-mailbox-rewind"]();
});

_j(_bb8_termite_23__3f_ = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb9_termite_23__3f_);
});

_j(_bb27_termite_23__3f_ = () => {
_r = _bb28_termite_23__3f_;
_n = 1;
return _g["mailbox-receive-timeout-exception?"]();
});

_k(_bb11_termite_23__3f_ = () => {
_a = 0;
_r = _s[_t];
return _p(_bb12_termite_23__3f_);
},1,1);

_k(_bb28_termite_23__3f_ = () => {
if (!(_a === !1)) {
return _bb31_termite_23__3f_();
} else {
return _bb29_termite_23__3f_();
}
},3,1);

_j(_bb12_termite_23__3f_ = () => {
_n = 1;
--_t;
return _g["thread-receive"]();
});

_j(_bb31_termite_23__3f_ = () => {
_r = _bb32_termite_23__3f_;
_n = 0;
return _g["thread-mailbox-rewind"]();
});

_j(_bb29_termite_23__3f_ = () => {
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb30_termite_23__3f_);
});

_k(_bb32_termite_23__3f_ = () => {
_a = _s[_t](!0)[1];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb30_termite_23__3f_ = () => {
_n = 1;
_t -= 3;
return _g["##raise"]();
});



_m(_bb1_termite_23__3f__3f_ = () => {
if (_n === 1) {
_b = null;
} else {
if (!_build_rest(1)) {
return _w(_bb1_termite_23__3f__3f_);
}
}
if (_b === null) {
return _bb2_termite_23__3f__3f_();
} else {
return _bb21_termite_23__3f__3f_();
}
},-1,_i("termite#??"),!1,!0);

_j(_bb2_termite_23__3f__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb3_termite_23__3f__3f_);
});

_j(_bb21_termite_23__3f__3f_ = () => {
if (_x(_b)) {
return _bb22_termite_23__3f__3f_();
} else {
return _bb28_termite_23__3f__3f_();
}
});

_j(_bb3_termite_23__3f__3f_ = () => {
_r = _bb4_termite_23__3f__3f_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb22_termite_23__3f__3f_ = () => {
_c = _b.a;
_d = _b.b;
if (_d === null) {
return _bb23_termite_23__3f__3f_();
} else {
return _bb24_termite_23__3f__3f_();
}
});

_j(_bb28_termite_23__3f__3f_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb29_termite_23__3f__3f_);
});

_k(_bb4_termite_23__3f__3f_ = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb5_termite_23__3f__3f_);
},2,1);

_j(_bb23_termite_23__3f__3f_ = () => {
_s[_t+1] = _bb61_termite_23__3f__3f_;
var closure0 = _closure_alloc([_bb59_termite_23__3f__3f_,_c,_a]);
_s[_t+2] = closure0;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb27_termite_23__3f__3f_);
});

_j(_bb24_termite_23__3f__3f_ = () => {
if (_x(_d)) {
return _bb25_termite_23__3f__3f_();
} else {
return _bb28_termite_23__3f__3f_();
}
});

_j(_bb29_termite_23__3f__3f_ = () => {
_n = 1;
return _g["##raise"]();
});

_j(_bb5_termite_23__3f__3f_ = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb6_termite_23__3f__3f_();
} else {
return _bb15_termite_23__3f__3f_();
}
});

_l(_bb61_termite_23__3f__3f_ = () => {
if (_n !== 1) {
return _w(_bb61_termite_23__3f__3f_);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb62_termite_23__3f__3f_);
},-1);

_l(_bb59_termite_23__3f__3f_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_a = _d(!0)[1];
_t += 2;
return _p(_bb60_termite_23__3f__3f_);
},2);

_j(_bb27_termite_23__3f__3f_ = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_j(_bb25_termite_23__3f__3f_ = () => {
_s[_t+1] = _d.a;
_d = _d.b;
if (_d === null) {
++_t;
return _bb26_termite_23__3f__3f_();
} else {
++_t;
return _bb30_termite_23__3f__3f_();
}
});

_j(_bb6_termite_23__3f__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb7_termite_23__3f__3f_);
});

_j(_bb15_termite_23__3f__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_t += 3;
return _p(_bb16_termite_23__3f__3f_);
});

_j(_bb62_termite_23__3f__3f_ = () => {
_r = _bb9_termite_23__3f__3f_;
_n = 1;
return _g["mailbox-receive-timeout-exception?"]();
});

_j(_bb60_termite_23__3f__3f_ = () => {
_r = _bb47_termite_23__3f__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_j(_bb26_termite_23__3f__3f_ = () => {
var closure1 = _closure_alloc([_bb52_termite_23__3f__3f_,_s[_t]]);
_s[_t+1] = closure1;
_s[_t] = _s[_t+1];
var closure2 = _closure_alloc([_bb32_termite_23__3f__3f_,_c,_a]);
_s[_t+1] = closure2;
_b = _s[_t+1];
_a = _s[_t];
++_t;
return _p(_bb27_termite_23__3f__3f_);
});

_j(_bb30_termite_23__3f__3f_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb31_termite_23__3f__3f_);
});

_j(_bb7_termite_23__3f__3f_ = () => {
_r = _bb8_termite_23__3f__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb16_termite_23__3f__3f_ = () => {
_r = _bb17_termite_23__3f__3f_;
_n = 1;
return _s[_t-1]();
});

_k(_bb9_termite_23__3f__3f_ = () => {
if (!(_a === !1)) {
return _bb12_termite_23__3f__3f_();
} else {
return _bb10_termite_23__3f__3f_();
}
},2,1);

_k(_bb47_termite_23__3f__3f_ = () => {
_c = _a;
_b = _s[_t](!0)[1];
_a = _s[_t](!0)[2];
_r = _s[_t-1];
_t -= 2;
return _p(_bb48_termite_23__3f__3f_);
},2,1);

_l(_bb52_termite_23__3f__3f_ = () => {
if (_n !== 1) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_t += 3;
return _p(_bb53_termite_23__3f__3f_);
},1);

_l(_bb32_termite_23__3f__3f_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_a = _d(!0)[1];
_t += 2;
return _p(_bb33_termite_23__3f__3f_);
},2);

_j(_bb31_termite_23__3f__3f_ = () => {
_n = 1;
--_t;
return _g["##raise"]();
});

_k(_bb8_termite_23__3f__3f_ = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb11_termite_23__3f__3f_);
},2,1);

_k(_bb17_termite_23__3f__3f_ = () => {
if (!(_a === !1)) {
return _bb18_termite_23__3f__3f_();
} else {
return _bb20_termite_23__3f__3f_();
}
},3,1);

_j(_bb12_termite_23__3f__3f_ = () => {
_r = _bb13_termite_23__3f__3f_;
_n = 0;
--_t;
return _g["thread-mailbox-rewind"]();
});

_j(_bb10_termite_23__3f__3f_ = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb11_termite_23__3f__3f_);
});

_j(_bb48_termite_23__3f__3f_ = () => {
if (_c instanceof _Structure && _c.a[0].a[1] === _cst52__termite) {
return _bb37_termite_23__3f__3f_();
} else {
return _bb49_termite_23__3f__3f_();
}
});

_j(_bb53_termite_23__3f__3f_ = () => {
_r = _bb54_termite_23__3f__3f_;
_n = 1;
return _g["mailbox-receive-timeout-exception?"]();
});

_j(_bb33_termite_23__3f__3f_ = () => {
_r = _bb34_termite_23__3f__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_j(_bb11_termite_23__3f__3f_ = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb18_termite_23__3f__3f_ = () => {
_r = _bb19_termite_23__3f__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb20_termite_23__3f__3f_ = () => {
_r = _bb4_termite_23__3f__3f_;
_n = 0;
--_t;
return _g["thread-mailbox-next"]();
});

_k(_bb13_termite_23__3f__3f_ = () => {
_a = 0;
_r = _s[_t];
return _p(_bb14_termite_23__3f__3f_);
},1,1);

_j(_bb37_termite_23__3f__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _c;
_t += 2;
return _p(_bb38_termite_23__3f__3f_);
});

_j(_bb49_termite_23__3f__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _c;
_t += 4;
return _p(_bb50_termite_23__3f__3f_);
});

_k(_bb54_termite_23__3f__3f_ = () => {
if (!(_a === !1)) {
return _bb57_termite_23__3f__3f_();
} else {
return _bb55_termite_23__3f__3f_();
}
},3,1);

_k(_bb34_termite_23__3f__3f_ = () => {
_c = _a;
_b = _s[_t](!0)[1];
_a = _s[_t](!0)[2];
_r = _s[_t-1];
_t -= 2;
return _p(_bb36_termite_23__3f__3f_);
},2,1);

_k(_bb19_termite_23__3f__3f_ = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb14_termite_23__3f__3f_ = () => {
_n = 1;
--_t;
return _g["thread-receive"]();
});

_j(_bb38_termite_23__3f__3f_ = () => {
_r = _bb8_termite_23__3f__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb50_termite_23__3f__3f_ = () => {
_r = _bb42_termite_23__3f__3f_;
_n = 1;
return _s[_t-2]();
});

_j(_bb57_termite_23__3f__3f_ = () => {
_r = _bb58_termite_23__3f__3f_;
_n = 0;
return _g["thread-mailbox-rewind"]();
});

_j(_bb55_termite_23__3f__3f_ = () => {
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb56_termite_23__3f__3f_);
});

_j(_bb36_termite_23__3f__3f_ = () => {
if (_c instanceof _Structure && _c.a[0].a[1] === _cst52__termite) {
return _bb37_termite_23__3f__3f_();
} else {
return _bb39_termite_23__3f__3f_();
}
});

_k(_bb42_termite_23__3f__3f_ = () => {
if (!(_a === !1)) {
return _bb43_termite_23__3f__3f_();
} else {
return _bb45_termite_23__3f__3f_();
}
},4,1);

_k(_bb58_termite_23__3f__3f_ = () => {
_a = _s[_t](!0)[1];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb56_termite_23__3f__3f_ = () => {
_n = 1;
_t -= 3;
return _g["##raise"]();
});

_j(_bb39_termite_23__3f__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _c;
_t += 4;
return _p(_bb40_termite_23__3f__3f_);
});

_j(_bb43_termite_23__3f__3f_ = () => {
_r = _bb44_termite_23__3f__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb45_termite_23__3f__3f_ = () => {
_a = _s[_t-1];
_r = _bb46_termite_23__3f__3f_;
_n = 1;
--_t;
return _g["thread-mailbox-next"]();
});

_j(_bb40_termite_23__3f__3f_ = () => {
_r = _bb41_termite_23__3f__3f_;
_n = 1;
return _s[_t-2]();
});

_k(_bb44_termite_23__3f__3f_ = () => {
_a = _s[_t];
_t -= 4;
return _s[_t+1]();
},4,1);

_k(_bb46_termite_23__3f__3f_ = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb48_termite_23__3f__3f_);
},3,1);

_k(_bb41_termite_23__3f__3f_ = () => {
if (!(_a === !1)) {
return _bb43_termite_23__3f__3f_();
} else {
return _bb51_termite_23__3f__3f_();
}
},4,1);

_j(_bb51_termite_23__3f__3f_ = () => {
_a = _s[_t-1];
_r = _bb35_termite_23__3f__3f_;
_n = 1;
--_t;
return _g["thread-mailbox-next"]();
});

_k(_bb35_termite_23__3f__3f_ = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb36_termite_23__3f__3f_);
},3,1);



_m(_bb1_termite_23__21__3f_ = () => {
if (_n === 2) {
_c = null;
} else {
if (!_build_rest(2)) {
return _w(_bb1_termite_23__21__3f_);
}
}
_d = new _Structure([_cst141__termite,!1]);
_s[_t+1] = _current_processor.a[14];
_b = _X(_s[_t+1],_X(_d,_X(_b,null)));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_s[_t+5] = _d;
_t += 5;
return _p(_bb2_termite_23__21__3f_);
},-1,_i("termite#!?"),!1,!0);

_j(_bb2_termite_23__21__3f_ = () => {
_r = _bb3_termite_23__21__3f_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23__21__3f_ = () => {
if (!(_a === !1)) {
return _bb74_termite_23__21__3f_();
} else {
return _bb4_termite_23__21__3f_();
}
},5,1);

_j(_bb74_termite_23__21__3f_ = () => {
_b = _s[_t-2];
_a = _s[_t-3];
_r = _bb6_termite_23__21__3f_;
_n = 2;
return _g["thread-send"]();
});

_j(_bb4_termite_23__21__3f_ = () => {
if (_s[_t-3] instanceof _Structure && _s[_t-3].a[0].a[1] === _cst83__termite) {
return _bb5_termite_23__21__3f_();
} else {
return _bb73_termite_23__21__3f_();
}
});

_k(_bb6_termite_23__21__3f_ = () => {
if (_s[_t-1] === null) {
return _bb59_termite_23__21__3f_();
} else {
return _bb7_termite_23__21__3f_();
}
},5,1);

_j(_bb5_termite_23__21__3f_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-3],_X(_s[_t-2],null)));
_a = _g["termite#dispatcher"];
_r = _bb6_termite_23__21__3f_;
_n = 2;
return _g["thread-send"]();
});

_j(_bb73_termite_23__21__3f_ = () => {
_b = _s[_t-3];
_a = _cst87__termite;
_r = _bb6_termite_23__21__3f_;
_n = 2;
return _g["##error"]();
});

_j(_bb59_termite_23__21__3f_ = () => {
_r = _bb60_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb7_termite_23__21__3f_ = () => {
if (_x(_s[_t-1])) {
return _bb8_termite_23__21__3f_();
} else {
return _bb14_termite_23__21__3f_();
}
});

_k(_bb60_termite_23__21__3f_ = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-4];
_t -= 5;
return _p(_bb62_termite_23__21__3f_);
},5,1);

_j(_bb8_termite_23__21__3f_ = () => {
_a = _s[_t-1].a;
_b = _s[_t-1].b;
if (_b === null) {
return _bb9_termite_23__21__3f_();
} else {
return _bb10_termite_23__21__3f_();
}
});

_j(_bb14_termite_23__21__3f_ = () => {
_a = _X(_cst56__termite,_X(_s[_t-1],null));
_r = _s[_t-4];
return _p(_bb15_termite_23__21__3f_);
});

_j(_bb62_termite_23__21__3f_ = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb63_termite_23__21__3f_();
} else {
return _bb65_termite_23__21__3f_();
}
});

_j(_bb9_termite_23__21__3f_ = () => {
_s[_t-3] = _bb57_termite_23__21__3f_;
var closure0 = _closure_alloc([_bb54_termite_23__21__3f_,_a,_s[_t]]);
_s[_t+1] = closure0;
_b = _s[_t+1];
_r = _s[_t-4];
_a = _s[_t-3];
++_t;
return _p(_bb13_termite_23__21__3f_);
});

_j(_bb10_termite_23__21__3f_ = () => {
if (_x(_b)) {
return _bb11_termite_23__21__3f_();
} else {
return _bb14_termite_23__21__3f_();
}
});

_j(_bb15_termite_23__21__3f_ = () => {
_n = 1;
_t -= 5;
return _g["##raise"]();
});

_j(_bb63_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb64_termite_23__21__3f_);
});

_j(_bb65_termite_23__21__3f_ = () => {
if (_x(_b)) {
return _bb66_termite_23__21__3f_();
} else {
return _bb71_termite_23__21__3f_();
}
});

_l(_bb57_termite_23__21__3f_ = () => {
if (_n !== 1) {
return _w(_bb57_termite_23__21__3f_);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb58_termite_23__21__3f_);
},-1);

_l(_bb54_termite_23__21__3f_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_a = _d(!0)[1];
_t += 2;
return _p(_bb55_termite_23__21__3f_);
},2);

_j(_bb13_termite_23__21__3f_ = () => {
_n = 2;
_t -= 6;
return _e["##with-exception-catcher"]();
});

_j(_bb11_termite_23__21__3f_ = () => {
_c = _b.a;
_b = _b.b;
if (_b === null) {
return _bb12_termite_23__21__3f_();
} else {
return _bb14_termite_23__21__3f_();
}
});

_j(_bb64_termite_23__21__3f_ = () => {
_r = _bb23_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb66_termite_23__21__3f_ = () => {
_c = _b.b;
_b = _b.a;
if (_b === _a) {
return _bb67_termite_23__21__3f_();
} else {
return _bb71_termite_23__21__3f_();
}
});

_j(_bb71_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb72_termite_23__21__3f_);
});

_j(_bb58_termite_23__21__3f_ = () => {
_r = _bb24_termite_23__21__3f_;
_n = 1;
return _g["mailbox-receive-timeout-exception?"]();
});

_j(_bb55_termite_23__21__3f_ = () => {
_r = _bb56_termite_23__21__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_j(_bb12_termite_23__21__3f_ = () => {
var closure1 = _closure_alloc([_bb47_termite_23__21__3f_,_c]);
_s[_t+1] = closure1;
_s[_t-3] = _s[_t+1];
var closure2 = _closure_alloc([_bb16_termite_23__21__3f_,_a,_s[_t]]);
_s[_t+1] = closure2;
_b = _s[_t+1];
_r = _s[_t-4];
_a = _s[_t-3];
++_t;
return _p(_bb13_termite_23__21__3f_);
});

_k(_bb23_termite_23__21__3f_ = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb26_termite_23__21__3f_);
},2,1);

_j(_bb67_termite_23__21__3f_ = () => {
if (_x(_c)) {
return _bb68_termite_23__21__3f_();
} else {
return _bb71_termite_23__21__3f_();
}
});

_j(_bb72_termite_23__21__3f_ = () => {
_r = _bb61_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb24_termite_23__21__3f_ = () => {
if (!(_a === !1)) {
return _bb27_termite_23__21__3f_();
} else {
return _bb25_termite_23__21__3f_();
}
},2,1);

_k(_bb56_termite_23__21__3f_ = () => {
_c = _a;
_b = _s[_t](!0)[1];
_a = _s[_t](!0)[2];
_r = _s[_t-1];
_t -= 2;
return _p(_bb35_termite_23__21__3f_);
},2,1);

_l(_bb47_termite_23__21__3f_ = () => {
if (_n !== 1) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_t += 3;
return _p(_bb48_termite_23__21__3f_);
},1);

_l(_bb16_termite_23__21__3f_ = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_a = _d(!0)[1];
_t += 2;
return _p(_bb17_termite_23__21__3f_);
},2);

_j(_bb26_termite_23__21__3f_ = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb68_termite_23__21__3f_ = () => {
_b = _c.b;
_c = _c.a;
if (_b === null) {
return _bb69_termite_23__21__3f_();
} else {
return _bb71_termite_23__21__3f_();
}
});

_k(_bb61_termite_23__21__3f_ = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb62_termite_23__21__3f_);
},2,1);

_j(_bb27_termite_23__21__3f_ = () => {
_r = _bb28_termite_23__21__3f_;
_n = 0;
--_t;
return _g["thread-mailbox-rewind"]();
});

_j(_bb25_termite_23__21__3f_ = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb26_termite_23__21__3f_);
});

_j(_bb35_termite_23__21__3f_ = () => {
if (_c instanceof _Structure && _c.a[0].a[1] === _cst52__termite) {
return _bb21_termite_23__21__3f_();
} else {
return _bb36_termite_23__21__3f_();
}
});

_j(_bb48_termite_23__21__3f_ = () => {
_r = _bb49_termite_23__21__3f_;
_n = 1;
return _g["mailbox-receive-timeout-exception?"]();
});

_j(_bb17_termite_23__21__3f_ = () => {
_r = _bb18_termite_23__21__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_j(_bb69_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _c;
_t += 2;
return _p(_bb70_termite_23__21__3f_);
});

_k(_bb28_termite_23__21__3f_ = () => {
_a = _cst170__termite;
_r = _s[_t];
return _p(_bb29_termite_23__21__3f_);
},1,1);

_j(_bb21_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _c;
_t += 2;
return _p(_bb22_termite_23__21__3f_);
});

_j(_bb36_termite_23__21__3f_ = () => {
if (_x(_c)) {
return _bb37_termite_23__21__3f_();
} else {
return _bb43_termite_23__21__3f_();
}
});

_k(_bb49_termite_23__21__3f_ = () => {
if (!(_a === !1)) {
return _bb52_termite_23__21__3f_();
} else {
return _bb50_termite_23__21__3f_();
}
},3,1);

_k(_bb18_termite_23__21__3f_ = () => {
_c = _a;
_b = _s[_t](!0)[1];
_a = _s[_t](!0)[2];
_r = _s[_t-1];
_t -= 2;
return _p(_bb20_termite_23__21__3f_);
},2,1);

_j(_bb70_termite_23__21__3f_ = () => {
_r = _bb42_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb29_termite_23__21__3f_ = () => {
_n = 1;
--_t;
return _g["##raise"]();
});

_j(_bb22_termite_23__21__3f_ = () => {
_r = _bb23_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb37_termite_23__21__3f_ = () => {
_d = _c.b;
_c = _c.a;
if (_c === _a) {
return _bb38_termite_23__21__3f_();
} else {
return _bb43_termite_23__21__3f_();
}
});

_j(_bb43_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_t += 3;
return _p(_bb44_termite_23__21__3f_);
});

_j(_bb52_termite_23__21__3f_ = () => {
_r = _bb53_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-rewind"]();
});

_j(_bb50_termite_23__21__3f_ = () => {
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb51_termite_23__21__3f_);
});

_j(_bb20_termite_23__21__3f_ = () => {
if (_c instanceof _Structure && _c.a[0].a[1] === _cst52__termite) {
return _bb21_termite_23__21__3f_();
} else {
return _bb30_termite_23__21__3f_();
}
});

_k(_bb42_termite_23__21__3f_ = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_j(_bb38_termite_23__21__3f_ = () => {
if (_x(_d)) {
return _bb39_termite_23__21__3f_();
} else {
return _bb43_termite_23__21__3f_();
}
});

_j(_bb44_termite_23__21__3f_ = () => {
_r = _bb34_termite_23__21__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_k(_bb53_termite_23__21__3f_ = () => {
_a = _s[_t](!0)[1];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb51_termite_23__21__3f_ = () => {
_n = 1;
_t -= 3;
return _g["##raise"]();
});

_j(_bb30_termite_23__21__3f_ = () => {
if (_x(_c)) {
return _bb31_termite_23__21__3f_();
} else {
return _bb45_termite_23__21__3f_();
}
});

_j(_bb39_termite_23__21__3f_ = () => {
_c = _d.b;
_d = _d.a;
if (_c === null) {
return _bb40_termite_23__21__3f_();
} else {
return _bb43_termite_23__21__3f_();
}
});

_k(_bb34_termite_23__21__3f_ = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb35_termite_23__21__3f_);
},3,1);

_j(_bb31_termite_23__21__3f_ = () => {
_d = _c.b;
_c = _c.a;
if (_c === _a) {
return _bb32_termite_23__21__3f_();
} else {
return _bb45_termite_23__21__3f_();
}
});

_j(_bb45_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_t += 3;
return _p(_bb46_termite_23__21__3f_);
});

_j(_bb40_termite_23__21__3f_ = () => {
_s[_t+1] = _r;
_s[_t+2] = _d;
_t += 2;
return _p(_bb41_termite_23__21__3f_);
});

_j(_bb32_termite_23__21__3f_ = () => {
if (_x(_d)) {
return _bb33_termite_23__21__3f_();
} else {
return _bb45_termite_23__21__3f_();
}
});

_j(_bb46_termite_23__21__3f_ = () => {
_r = _bb19_termite_23__21__3f_;
_n = 1;
return _g["thread-mailbox-next"]();
});

_j(_bb41_termite_23__21__3f_ = () => {
_r = _bb42_termite_23__21__3f_;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb33_termite_23__21__3f_ = () => {
_c = _d.b;
_d = _d.a;
if (_c === null) {
return _bb40_termite_23__21__3f_();
} else {
return _bb45_termite_23__21__3f_();
}
});

_k(_bb19_termite_23__21__3f_ = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb20_termite_23__21__3f_);
},3,1);



_m(_bb1_termite_23_on = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_on);
}
_c = new _Structure([_cst141__termite,!1]);
_d = _current_processor.a[14];
_s[_t+1] = _r;
_s[_t+2] = _c;
var closure0 = _closure_alloc([_bb27_termite_23_on,_d,_c,_b]);
_s[_t+3] = closure0;
_b = _s[_t+3];
_t += 3;
return _p(_bb2_termite_23_on);
},-1,_i("termite#on"),!1,!0);

_l(_bb27_termite_23_on = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_t += 2;
return _p(_bb28_termite_23_on);
},3);

_j(_bb2_termite_23_on = () => {
_r = _bb11_termite_23_on;
_n = 2;
--_t;
return _bb3_termite_23_on();
});

_j(_bb28_termite_23_on = () => {
_r = _bb29_termite_23_on;
_n = 0;
return _d(!0)[3]();
});

_l(_bb3_termite_23_on = () => {
var error = _build_key(2,4,[_cst16__termite,null,_cst15__termite,_cst161__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_on,error);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_t += 4;
return _p(_bb4_termite_23_on);
},-1);

_k(_bb11_termite_23_on = () => {
_r = _bb12_termite_23_on;
_n = 0;
return _g["thread-mailbox-next"]();
},2,1);

_k(_bb29_termite_23_on = () => {
_r = _s[_t](!0)[2];
_b = _X(_r,_X(_a,null));
_a = _s[_t](!0)[1];
_r = _s[_t-1];
return _p(_bb30_termite_23_on);
},2,1);

_j(_bb4_termite_23_on = () => {
_r = _bb5_termite_23_on;
_n = 0;
return _g["termite#current-node"]();
});

_k(_bb12_termite_23_on = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb13_termite_23_on);
},2,1);

_j(_bb30_termite_23_on = () => {
_n = 2;
_t -= 2;
return _bb1_termite_23__21_();
});

_k(_bb5_termite_23_on = () => {
_b = _a;
_a = _s[_t-4];
_r = _bb6_termite_23_on;
_n = 2;
return _e["##equal?"]();
},5,2);

_j(_bb13_termite_23_on = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb14_termite_23_on();
} else {
return _bb18_termite_23_on();
}
});

_k(_bb6_termite_23_on = () => {
if (!(_a === !1)) {
return _bb7_termite_23_on();
} else {
return _bb9_termite_23_on();
}
},5,2);

_j(_bb14_termite_23_on = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb15_termite_23_on);
});

_j(_bb18_termite_23_on = () => {
if (_x(_b)) {
return _bb19_termite_23_on();
} else {
return _bb25_termite_23_on();
}
});

_j(_bb7_termite_23_on = () => {
_s[_t-4] = _s[_t-2];
_s[_t-2] = _s[_t-3];
_s[_t-3] = _cst16__termite;
_c = _s[_t];
_a = _s[_t-1];
_b = _cst15__termite;
_r = _s[_t-2];
return _p(_bb8_termite_23_on);
});

_j(_bb9_termite_23_on = () => {
_b = _X(_cst90__termite,_X(_s[_t-2],_X(_s[_t-1],_X(_s[_t],null))));
_a = new _Structure([_cst101__termite,_cst162__termite,_s[_t-4]]);
_r = _s[_t-3];
return _p(_bb10_termite_23_on);
});

_j(_bb15_termite_23_on = () => {
_r = _bb16_termite_23_on;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb19_termite_23_on = () => {
_c = _b.a;
_b = _b.b;
if (_c === _a) {
return _bb20_termite_23_on();
} else {
return _bb25_termite_23_on();
}
});

_j(_bb25_termite_23_on = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb26_termite_23_on);
});

_j(_bb8_termite_23_on = () => {
_n = 5;
_t -= 3;
return _bb1_termite_23_spawn();
});

_j(_bb10_termite_23_on = () => {
_n = 2;
_t -= 5;
return _bb1_termite_23__21__3f_();
});

_k(_bb16_termite_23_on = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb17_termite_23_on);
},2,1);

_j(_bb20_termite_23_on = () => {
if (_x(_b)) {
return _bb21_termite_23_on();
} else {
return _bb25_termite_23_on();
}
});

_j(_bb26_termite_23_on = () => {
_r = _bb12_termite_23_on;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb17_termite_23_on = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb21_termite_23_on = () => {
_c = _b.a;
_b = _b.b;
if (_b === null) {
return _bb22_termite_23_on();
} else {
return _bb25_termite_23_on();
}
});

_j(_bb22_termite_23_on = () => {
_s[_t+1] = _r;
_s[_t+2] = _c;
_t += 2;
return _p(_bb23_termite_23_on);
});

_j(_bb23_termite_23_on = () => {
_r = _bb24_termite_23_on;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb24_termite_23_on = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);



_m(_bb1_termite_23_handle_2d_exception_2d_message = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_handle_2d_exception_2d_message);
}
return _p(_bb2_termite_23_handle_2d_exception_2d_message);
},-1,_i("termite#handle-exception-message"),!1,!0);

_j(_bb2_termite_23_handle_2d_exception_2d_message = () => {
_n = 1;
return _g["##raise"]();
});



_m(_bb1_termite_23_inbound_2d_link = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_inbound_2d_link);
}
_b = _current_processor.a[14];
_a = _X(_cst68__termite,_X(_a,_X(_b,null)));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#linker"];
_t += 2;
return _p(_bb2_termite_23_inbound_2d_link);
},-1,_i("termite#inbound-link"),!1,!0);

_j(_bb2_termite_23_inbound_2d_link = () => {
_r = _bb3_termite_23_inbound_2d_link;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_inbound_2d_link = () => {
if (!(_a === !1)) {
return _bb4_termite_23_inbound_2d_link();
} else {
return _bb5_termite_23_inbound_2d_link();
}
},2,1);

_j(_bb4_termite_23_inbound_2d_link = () => {
_b = _s[_t];
_a = _g["termite#linker"];
_r = _s[_t-1];
return _p(_bb7_termite_23_inbound_2d_link);
});

_j(_bb5_termite_23_inbound_2d_link = () => {
if (_g["termite#linker"] instanceof _Structure && _g["termite#linker"].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_inbound_2d_link();
} else {
return _bb8_termite_23_inbound_2d_link();
}
});

_j(_bb7_termite_23_inbound_2d_link = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb6_termite_23_inbound_2d_link = () => {
_b = _X(_cst77__termite,_X(_g["termite#linker"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb7_termite_23_inbound_2d_link);
});

_j(_bb8_termite_23_inbound_2d_link = () => {
_b = _g["termite#linker"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb9_termite_23_inbound_2d_link);
});

_j(_bb9_termite_23_inbound_2d_link = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});



_m(_bb1_termite_23_outbound_2d_link = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_outbound_2d_link);
}
_b = _current_processor.a[14];
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _b;
_t += 2;
return _p(_bb2_termite_23_outbound_2d_link);
},-1,_i("termite#outbound-link"),!1,!0);

_j(_bb2_termite_23_outbound_2d_link = () => {
_r = _bb3_termite_23_outbound_2d_link;
_n = 1;
return _g["thread-specific"]();
});

_k(_bb3_termite_23_outbound_2d_link = () => {
_s[_t+1] = _a;
_b = _a;
_a = _s[_t];
_r = _bb10_termite_23_outbound_2d_link;
++_t;
return _bb4_termite_23_outbound_2d_link();
},2,1);

_j(_bb4_termite_23_outbound_2d_link = () => {
if (_x(_b)) {
return _bb7_termite_23_outbound_2d_link();
} else {
return _bb9_termite_23_outbound_2d_link();
}
});

_k(_bb10_termite_23_outbound_2d_link = () => {
if (!(_a === !1)) {
return _bb13_termite_23_outbound_2d_link();
} else {
return _bb11_termite_23_outbound_2d_link();
}
},3,1);

_j(_bb7_termite_23_outbound_2d_link = () => {
_c = _b.a;
if (_a === _c) {
return _bb8_termite_23_outbound_2d_link();
} else {
return _bb5_termite_23_outbound_2d_link();
}
});

_j(_bb9_termite_23_outbound_2d_link = () => {
_a = !1;
return _r;
});

_j(_bb13_termite_23_outbound_2d_link = () => {
_a = void 0;
_t -= 3;
return _s[_t+1]();
});

_j(_bb11_termite_23_outbound_2d_link = () => {
_a = _current_processor.a[14];
_b = _X(_s[_t-1],_s[_t]);
_r = _s[_t-2];
return _p(_bb12_termite_23_outbound_2d_link);
});

_j(_bb8_termite_23_outbound_2d_link = () => {
_a = _b;
return _r;
});

_j(_bb5_termite_23_outbound_2d_link = () => {
_b = _b.b;
return _p(_bb6_termite_23_outbound_2d_link);
});

_j(_bb12_termite_23_outbound_2d_link = () => {
_n = 2;
_t -= 3;
return _g["thread-specific-set!"]();
});

_j(_bb6_termite_23_outbound_2d_link = () => {
if (_x(_b)) {
return _bb7_termite_23_outbound_2d_link();
} else {
return _bb9_termite_23_outbound_2d_link();
}
});



_m(_bb1_termite_23_full_2d_link = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_full_2d_link);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb2_termite_23_full_2d_link);
},-1,_i("termite#full-link"),!1,!0);

_j(_bb2_termite_23_full_2d_link = () => {
_r = _bb3_termite_23_full_2d_link;
_n = 1;
return _bb1_termite_23_inbound_2d_link();
});

_k(_bb3_termite_23_full_2d_link = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb4_termite_23_full_2d_link);
},2,1);

_j(_bb4_termite_23_full_2d_link = () => {
_n = 1;
_t -= 2;
return _bb1_termite_23_outbound_2d_link();
});



_m(_bb1_termite_23_make_2d_termite_2d_output_2d_port = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_make_2d_termite_2d_output_2d_port);
}
_a = new _Structure([_cst171__termite,_a]);
return _r;
},-1,_i("termite#make-termite-output-port"),!1,!0);



_m(_bb1_termite_23_termite_2d_output_2d_port_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_output_2d_port_2d_copy);
}
return _p(_bb2_termite_23_termite_2d_output_2d_port_2d_copy);
},-1,_i("termite#termite-output-port-copy"),!1,!0);

_j(_bb2_termite_23_termite_2d_output_2d_port_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_termite_2d_output_2d_port_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_output_2d_port_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst172__termite;
return _r;
},-1,_i("termite#termite-output-port?"),!1,!0);



_m(_bb1_termite_23_termite_2d_output_2d_port_2d_pid = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_output_2d_port_2d_pid);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#termite-output-port-pid"),!1,!0);



_m(_bb1_termite_23_termite_2d_output_2d_port_2d_pid_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_output_2d_port_2d_pid_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#termite-output-port-pid-set!"),!1,!0);



_m(_bb1_termite_23_termite_2d_output_2d_port_2d_pid_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_output_2d_port_2d_pid_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_termite_2d_output_2d_port_2d_pid_2d_set;
_b = _cst171__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_termite_2d_output_2d_port_2d_pid_2d_set);
},-1,_i("termite#termite-output-port-pid-set"),!1,!0);

_j(_bb2_termite_23_termite_2d_output_2d_port_2d_pid_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_make_2d_termite_2d_input_2d_port = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_make_2d_termite_2d_input_2d_port);
}
_a = new _Structure([_cst176__termite,_a]);
return _r;
},-1,_i("termite#make-termite-input-port"),!1,!0);



_m(_bb1_termite_23_termite_2d_input_2d_port_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_input_2d_port_2d_copy);
}
return _p(_bb2_termite_23_termite_2d_input_2d_port_2d_copy);
},-1,_i("termite#termite-input-port-copy"),!1,!0);

_j(_bb2_termite_23_termite_2d_input_2d_port_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_termite_2d_input_2d_port_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_input_2d_port_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst177__termite;
return _r;
},-1,_i("termite#termite-input-port?"),!1,!0);



_m(_bb1_termite_23_termite_2d_input_2d_port_2d_pid = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_termite_2d_input_2d_port_2d_pid);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#termite-input-port-pid"),!1,!0);



_m(_bb1_termite_23_termite_2d_input_2d_port_2d_pid_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_input_2d_port_2d_pid_2d_set_21_);
}
_a.a[1] = _b;
_a = _a;
return _r;
},-1,_i("termite#termite-input-port-pid-set!"),!1,!0);



_m(_bb1_termite_23_termite_2d_input_2d_port_2d_pid_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_input_2d_port_2d_pid_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_termite_2d_input_2d_port_2d_pid_2d_set;
_b = _cst176__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_termite_2d_input_2d_port_2d_pid_2d_set);
},-1,_i("termite#termite-input-port-pid-set"),!1,!0);

_j(_bb2_termite_23_termite_2d_input_2d_port_2d_pid_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_spawn_2d_output_2d_port = () => {
if (_n === 1) {
_b = !1;
} else {
if (_n !== 2) {
return _w(_bb1_termite_23_spawn_2d_output_2d_port);
}
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_spawn_2d_output_2d_port);
},-1,_i("termite#spawn-output-port"),!1,!0);

_j(_bb2_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb3_termite_23_spawn_2d_output_2d_port;
_n = 1;
return _g["##output-port-readtable"]();
});

_k(_bb3_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_r = _bb4_termite_23_spawn_2d_output_2d_port;
_n = 2;
--_t;
return _g["readtable-sharing-allowed?-set"]();
},3,1);

_k(_bb4_termite_23_spawn_2d_output_2d_port = () => {
_b = _a;
_a = _s[_t];
_r = _bb5_termite_23_spawn_2d_output_2d_port;
_n = 2;
return _g["##output-port-readtable-set!"]();
},2,1);

_k(_bb5_termite_23_spawn_2d_output_2d_port = () => {
var closure0 = _closure_alloc([_bb55_termite_23_spawn_2d_output_2d_port,_s[_t]]);
_s[_t+1] = closure0;
_a = _s[_t+1];
_c = _cst173__termite;
_b = _cst15__termite;
_r = _bb54_termite_23_spawn_2d_output_2d_port;
_n = 3;
--_t;
return _bb6_termite_23_spawn_2d_output_2d_port();
},2,1);

_l(_bb55_termite_23_spawn_2d_output_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _p(_bb58_termite_23_spawn_2d_output_2d_port);
},1);

_l(_bb6_termite_23_spawn_2d_output_2d_port = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb6_termite_23_spawn_2d_output_2d_port,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb11_termite_23_spawn_2d_output_2d_port,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb7_termite_23_spawn_2d_output_2d_port);
},-1);

_k(_bb54_termite_23_spawn_2d_output_2d_port = () => {
_a = new _Structure([_cst171__termite,_a]);
--_t;
return _s[_t+1]();
},1,1);

_j(_bb58_termite_23_spawn_2d_output_2d_port = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb59_termite_23_spawn_2d_output_2d_port);
});

_l(_bb11_termite_23_spawn_2d_output_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb12_termite_23_spawn_2d_output_2d_port);
},1);

_j(_bb7_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb8_termite_23_spawn_2d_output_2d_port;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb59_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb60_termite_23_spawn_2d_output_2d_port;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb12_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb13_termite_23_spawn_2d_output_2d_port;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb8_termite_23_spawn_2d_output_2d_port = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb9_termite_23_spawn_2d_output_2d_port;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb60_termite_23_spawn_2d_output_2d_port = () => {
_s[_t+1] = _a;
_r = _bb61_termite_23_spawn_2d_output_2d_port;
_n = 1;
++_t;
return _bb1_termite_23_termite_2d_exception_3f_();
},2,1);

_k(_bb13_termite_23_spawn_2d_output_2d_port = () => {
_a = _current_processor.a[14];
_r = _bb14_termite_23_spawn_2d_output_2d_port;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb9_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t];
_r = _bb10_termite_23_spawn_2d_output_2d_port;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb61_termite_23_spawn_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb62_termite_23_spawn_2d_output_2d_port();
} else {
return _bb63_termite_23_spawn_2d_output_2d_port();
}
},3,1);

_k(_bb14_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb52_termite_23_spawn_2d_output_2d_port;
return _bb15_termite_23_spawn_2d_output_2d_port();
},1,1);

_k(_bb10_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb62_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb80_termite_23_spawn_2d_output_2d_port;
return _bb65_termite_23_spawn_2d_output_2d_port();
});

_j(_bb63_termite_23_spawn_2d_output_2d_port = () => {
if (typeof _s[_t] === "function" && !Object.prototype.hasOwnProperty.call(_s[_t],"h")) {
return _bb68_termite_23_spawn_2d_output_2d_port();
} else {
return _bb64_termite_23_spawn_2d_output_2d_port();
}
});

_j(_bb15_termite_23_spawn_2d_output_2d_port = () => {
if (_x(_a)) {
return _bb19_termite_23_spawn_2d_output_2d_port();
} else {
return _bb51_termite_23_spawn_2d_output_2d_port();
}
});

_k(_bb52_termite_23_spawn_2d_output_2d_port = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb53_termite_23_spawn_2d_output_2d_port);
},1,1);

_j(_bb65_termite_23_spawn_2d_output_2d_port = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb66_termite_23_spawn_2d_output_2d_port);
});

_k(_bb80_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t];
_r = _bb56_termite_23_spawn_2d_output_2d_port;
_n = 1;
--_t;
return _g["##raise"]();
},3,1);

_j(_bb68_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb69_termite_23_spawn_2d_output_2d_port;
return _bb65_termite_23_spawn_2d_output_2d_port();
});

_j(_bb64_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb70_termite_23_spawn_2d_output_2d_port;
return _bb65_termite_23_spawn_2d_output_2d_port();
});

_j(_bb19_termite_23_spawn_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb20_termite_23_spawn_2d_output_2d_port);
});

_j(_bb51_termite_23_spawn_2d_output_2d_port = () => {
_a = void 0;
return _r;
});

_j(_bb53_termite_23_spawn_2d_output_2d_port = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb66_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb67_termite_23_spawn_2d_output_2d_port;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb56_termite_23_spawn_2d_output_2d_port = () => {
return _bb57_termite_23_spawn_2d_output_2d_port();
},2,1);

_k(_bb69_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t-1];
_r = _bb56_termite_23_spawn_2d_output_2d_port;
_n = 1;
--_t;
return _s[_t+1]();
},3,1);

_k(_bb70_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_a = _cst183__termite;
_r = _bb56_termite_23_spawn_2d_output_2d_port;
_n = 2;
--_t;
return _bb71_termite_23_spawn_2d_output_2d_port();
},3,1);

_j(_bb20_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb21_termite_23_spawn_2d_output_2d_port;
_n = 1;
return _g["thread?"]();
});

_k(_bb67_termite_23_spawn_2d_output_2d_port = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb57_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb58_termite_23_spawn_2d_output_2d_port);
});

_l(_bb71_termite_23_spawn_2d_output_2d_port = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb71_termite_23_spawn_2d_output_2d_port);
}
}
_b = _current_processor.a[14];
_a = _X(_cst89__termite,_X(_b,_X(_a,null)));
_a = _X(_cst47__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#logger"];
_t += 2;
return _p(_bb72_termite_23_spawn_2d_output_2d_port);
},-1);

_k(_bb21_termite_23_spawn_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb50_termite_23_spawn_2d_output_2d_port();
} else {
return _bb22_termite_23_spawn_2d_output_2d_port();
}
},4,1);

_j(_bb72_termite_23_spawn_2d_output_2d_port = () => {
_r = _bb73_termite_23_spawn_2d_output_2d_port;
_n = 1;
return _g["thread?"]();
});

_j(_bb50_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb24_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb22_termite_23_spawn_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb23_termite_23_spawn_2d_output_2d_port();
} else {
return _bb49_termite_23_spawn_2d_output_2d_port();
}
});

_k(_bb73_termite_23_spawn_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb74_termite_23_spawn_2d_output_2d_port();
} else {
return _bb75_termite_23_spawn_2d_output_2d_port();
}
},2,1);

_k(_bb24_termite_23_spawn_2d_output_2d_port = () => {
return _bb25_termite_23_spawn_2d_output_2d_port();
},2,1);

_j(_bb23_termite_23_spawn_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb24_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb49_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb24_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb74_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_a = _g["termite#logger"];
_r = _s[_t-1];
return _p(_bb77_termite_23_spawn_2d_output_2d_port);
});

_j(_bb75_termite_23_spawn_2d_output_2d_port = () => {
if (_g["termite#logger"] instanceof _Structure && _g["termite#logger"].a[0].a[1] === _cst83__termite) {
return _bb76_termite_23_spawn_2d_output_2d_port();
} else {
return _bb78_termite_23_spawn_2d_output_2d_port();
}
});

_j(_bb25_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb26_termite_23_spawn_2d_output_2d_port();
} else {
return _bb44_termite_23_spawn_2d_output_2d_port();
}
});

_j(_bb77_termite_23_spawn_2d_output_2d_port = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb76_termite_23_spawn_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_g["termite#logger"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb77_termite_23_spawn_2d_output_2d_port);
});

_j(_bb78_termite_23_spawn_2d_output_2d_port = () => {
_b = _g["termite#logger"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb79_termite_23_spawn_2d_output_2d_port);
});

_j(_bb26_termite_23_spawn_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb27_termite_23_spawn_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb44_termite_23_spawn_2d_output_2d_port = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb79_termite_23_spawn_2d_output_2d_port = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb27_termite_23_spawn_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb48_termite_23_spawn_2d_output_2d_port();
} else {
return _bb28_termite_23_spawn_2d_output_2d_port();
}
},4,1);

_j(_bb48_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb30_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb28_termite_23_spawn_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb29_termite_23_spawn_2d_output_2d_port();
} else {
return _bb47_termite_23_spawn_2d_output_2d_port();
}
});

_k(_bb30_termite_23_spawn_2d_output_2d_port = () => {
return _bb31_termite_23_spawn_2d_output_2d_port();
},2,1);

_j(_bb29_termite_23_spawn_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb30_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb47_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb30_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb31_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb32_termite_23_spawn_2d_output_2d_port();
} else {
return _bb44_termite_23_spawn_2d_output_2d_port();
}
});

_j(_bb32_termite_23_spawn_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb33_termite_23_spawn_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb33_termite_23_spawn_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb46_termite_23_spawn_2d_output_2d_port();
} else {
return _bb34_termite_23_spawn_2d_output_2d_port();
}
},4,1);

_j(_bb46_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb36_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb34_termite_23_spawn_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb35_termite_23_spawn_2d_output_2d_port();
} else {
return _bb45_termite_23_spawn_2d_output_2d_port();
}
});

_k(_bb36_termite_23_spawn_2d_output_2d_port = () => {
return _bb37_termite_23_spawn_2d_output_2d_port();
},2,1);

_j(_bb35_termite_23_spawn_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb36_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb45_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb36_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb37_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb38_termite_23_spawn_2d_output_2d_port();
} else {
return _bb44_termite_23_spawn_2d_output_2d_port();
}
});

_j(_bb38_termite_23_spawn_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb39_termite_23_spawn_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb39_termite_23_spawn_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb43_termite_23_spawn_2d_output_2d_port();
} else {
return _bb40_termite_23_spawn_2d_output_2d_port();
}
},4,1);

_j(_bb43_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb16_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb40_termite_23_spawn_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb41_termite_23_spawn_2d_output_2d_port();
} else {
return _bb42_termite_23_spawn_2d_output_2d_port();
}
});

_k(_bb16_termite_23_spawn_2d_output_2d_port = () => {
return _bb17_termite_23_spawn_2d_output_2d_port();
},2,1);

_j(_bb41_termite_23_spawn_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb16_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb42_termite_23_spawn_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb16_termite_23_spawn_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb17_termite_23_spawn_2d_output_2d_port = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb18_termite_23_spawn_2d_output_2d_port);
});

_j(_bb18_termite_23_spawn_2d_output_2d_port = () => {
if (_x(_a)) {
return _bb19_termite_23_spawn_2d_output_2d_port();
} else {
return _bb51_termite_23_spawn_2d_output_2d_port();
}
});



_m(_bb1_termite_23_spawn_2d_input_2d_port = () => {
if (_n === 1) {
_b = !1;
} else {
if (_n !== 2) {
return _w(_bb1_termite_23_spawn_2d_input_2d_port);
}
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_spawn_2d_input_2d_port);
},-1,_i("termite#spawn-input-port"),!1,!0);

_j(_bb2_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb3_termite_23_spawn_2d_input_2d_port;
_n = 1;
return _g["##input-port-readtable"]();
});

_k(_bb3_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_r = _bb4_termite_23_spawn_2d_input_2d_port;
_n = 2;
--_t;
return _g["readtable-sharing-allowed?-set"]();
},3,1);

_k(_bb4_termite_23_spawn_2d_input_2d_port = () => {
_b = _a;
_a = _s[_t];
_r = _bb5_termite_23_spawn_2d_input_2d_port;
_n = 2;
return _g["##input-port-readtable-set!"]();
},2,1);

_k(_bb5_termite_23_spawn_2d_input_2d_port = () => {
var closure0 = _closure_alloc([_bb103_termite_23_spawn_2d_input_2d_port,_s[_t]]);
_s[_t+1] = closure0;
_a = _s[_t+1];
_c = _cst178__termite;
_b = _cst15__termite;
_r = _bb102_termite_23_spawn_2d_input_2d_port;
_n = 3;
--_t;
return _bb6_termite_23_spawn_2d_input_2d_port();
},2,1);

_l(_bb103_termite_23_spawn_2d_input_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _p(_bb106_termite_23_spawn_2d_input_2d_port);
},1);

_l(_bb6_termite_23_spawn_2d_input_2d_port = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb6_termite_23_spawn_2d_input_2d_port,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb11_termite_23_spawn_2d_input_2d_port,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb7_termite_23_spawn_2d_input_2d_port);
},-1);

_k(_bb102_termite_23_spawn_2d_input_2d_port = () => {
_a = new _Structure([_cst176__termite,_a]);
--_t;
return _s[_t+1]();
},1,1);

_j(_bb106_termite_23_spawn_2d_input_2d_port = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb107_termite_23_spawn_2d_input_2d_port);
});

_l(_bb11_termite_23_spawn_2d_input_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb12_termite_23_spawn_2d_input_2d_port);
},1);

_j(_bb7_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb8_termite_23_spawn_2d_input_2d_port;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb107_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb108_termite_23_spawn_2d_input_2d_port;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb12_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb13_termite_23_spawn_2d_input_2d_port;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb8_termite_23_spawn_2d_input_2d_port = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb9_termite_23_spawn_2d_input_2d_port;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb108_termite_23_spawn_2d_input_2d_port = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb126_termite_23_spawn_2d_input_2d_port();
} else {
return _bb109_termite_23_spawn_2d_input_2d_port();
}
},2,1);

_k(_bb13_termite_23_spawn_2d_input_2d_port = () => {
_a = _current_processor.a[14];
_r = _bb14_termite_23_spawn_2d_input_2d_port;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb9_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t];
_r = _bb10_termite_23_spawn_2d_input_2d_port;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb126_termite_23_spawn_2d_input_2d_port = () => {
_s[_t+1] = _a;
_r = _bb127_termite_23_spawn_2d_input_2d_port;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb109_termite_23_spawn_2d_input_2d_port = () => {
if (_x(_a)) {
return _bb110_termite_23_spawn_2d_input_2d_port();
} else {
return _bb115_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb14_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb100_termite_23_spawn_2d_input_2d_port;
return _bb15_termite_23_spawn_2d_input_2d_port();
},1,1);

_k(_bb10_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_k(_bb127_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t];
_r = _bb104_termite_23_spawn_2d_input_2d_port;
_n = 1;
--_t;
return _g["##raise"]();
},3,1);

_j(_bb110_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.b;
_c = _a.a;
if (_x(_b)) {
return _bb111_termite_23_spawn_2d_input_2d_port();
} else {
return _bb115_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb115_termite_23_spawn_2d_input_2d_port = () => {
_s[_t+1] = _a;
_r = _bb119_termite_23_spawn_2d_input_2d_port;
++_t;
return _bb116_termite_23_spawn_2d_input_2d_port();
});

_j(_bb15_termite_23_spawn_2d_input_2d_port = () => {
if (_x(_a)) {
return _bb19_termite_23_spawn_2d_input_2d_port();
} else {
return _bb99_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb100_termite_23_spawn_2d_input_2d_port = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb101_termite_23_spawn_2d_input_2d_port);
},1,1);

_k(_bb104_termite_23_spawn_2d_input_2d_port = () => {
return _bb105_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb111_termite_23_spawn_2d_input_2d_port = () => {
_d = _b.b;
_b = _b.a;
if (_x(_d)) {
return _bb112_termite_23_spawn_2d_input_2d_port();
} else {
return _bb115_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb116_termite_23_spawn_2d_input_2d_port = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb117_termite_23_spawn_2d_input_2d_port);
});

_k(_bb119_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t];
_r = _bb104_termite_23_spawn_2d_input_2d_port;
--_t;
return _bb120_termite_23_spawn_2d_input_2d_port();
},3,1);

_j(_bb19_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb20_termite_23_spawn_2d_input_2d_port);
});

_j(_bb99_termite_23_spawn_2d_input_2d_port = () => {
_a = void 0;
return _r;
});

_j(_bb101_termite_23_spawn_2d_input_2d_port = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb105_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb106_termite_23_spawn_2d_input_2d_port);
});

_j(_bb112_termite_23_spawn_2d_input_2d_port = () => {
_r = _d.b;
_d = _d.a;
if (_r === null) {
return _bb113_termite_23_spawn_2d_input_2d_port();
} else {
return _bb115_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb117_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb118_termite_23_spawn_2d_input_2d_port;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb120_termite_23_spawn_2d_input_2d_port = () => {
_b = _a;
_a = _cst186__termite;
return _p(_bb121_termite_23_spawn_2d_input_2d_port);
});

_j(_bb20_termite_23_spawn_2d_input_2d_port = () => {
_r = _bb21_termite_23_spawn_2d_input_2d_port;
_n = 1;
return _g["thread?"]();
});

_j(_bb113_termite_23_spawn_2d_input_2d_port = () => {
if (typeof _d === "function" && !Object.prototype.hasOwnProperty.call(_d,"h")) {
return _bb114_termite_23_spawn_2d_input_2d_port();
} else {
return _bb115_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb118_termite_23_spawn_2d_input_2d_port = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb121_termite_23_spawn_2d_input_2d_port = () => {
_n = 2;
return _bb122_termite_23_spawn_2d_input_2d_port();
});

_k(_bb21_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb98_termite_23_spawn_2d_input_2d_port();
} else {
return _bb22_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb114_termite_23_spawn_2d_input_2d_port = () => {
_s[_t+1] = _b;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb124_termite_23_spawn_2d_input_2d_port;
_t += 3;
return _bb116_termite_23_spawn_2d_input_2d_port();
});

_l(_bb122_termite_23_spawn_2d_input_2d_port = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb122_termite_23_spawn_2d_input_2d_port);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb123_termite_23_spawn_2d_input_2d_port);
},-1);

_j(_bb98_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb24_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb22_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb23_termite_23_spawn_2d_input_2d_port();
} else {
return _bb97_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb124_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t-3];
_r = _bb125_termite_23_spawn_2d_input_2d_port;
_n = 1;
--_t;
return _s[_t+1]();
},5,1);

_j(_bb123_termite_23_spawn_2d_input_2d_port = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_k(_bb24_termite_23_spawn_2d_input_2d_port = () => {
return _bb25_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb23_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb24_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb97_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb24_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb125_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_s[_t-1],_X(_a,null));
_a = _s[_t];
_r = _bb104_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _bb1_termite_23__21_();
},4,1);

_j(_bb25_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb26_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb26_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb27_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb80_termite_23_spawn_2d_input_2d_port = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb27_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb96_termite_23_spawn_2d_input_2d_port();
} else {
return _bb28_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb96_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb30_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb28_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb29_termite_23_spawn_2d_input_2d_port();
} else {
return _bb95_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb30_termite_23_spawn_2d_input_2d_port = () => {
return _bb31_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb29_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb30_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb95_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb30_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb31_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb32_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb32_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb33_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb33_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb94_termite_23_spawn_2d_input_2d_port();
} else {
return _bb34_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb94_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb36_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb34_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb35_termite_23_spawn_2d_input_2d_port();
} else {
return _bb93_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb36_termite_23_spawn_2d_input_2d_port = () => {
return _bb37_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb35_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb36_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb93_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb36_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb37_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb38_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb38_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb39_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb39_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb92_termite_23_spawn_2d_input_2d_port();
} else {
return _bb40_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb92_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb42_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb40_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb41_termite_23_spawn_2d_input_2d_port();
} else {
return _bb91_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb42_termite_23_spawn_2d_input_2d_port = () => {
return _bb43_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb41_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb42_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb91_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb42_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb43_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb44_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb44_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb45_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb45_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb90_termite_23_spawn_2d_input_2d_port();
} else {
return _bb46_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb90_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb48_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb46_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb47_termite_23_spawn_2d_input_2d_port();
} else {
return _bb89_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb48_termite_23_spawn_2d_input_2d_port = () => {
return _bb49_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb47_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb48_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb89_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb48_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb49_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb50_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb50_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb51_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb51_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb88_termite_23_spawn_2d_input_2d_port();
} else {
return _bb52_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb88_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb54_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb52_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb53_termite_23_spawn_2d_input_2d_port();
} else {
return _bb87_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb54_termite_23_spawn_2d_input_2d_port = () => {
return _bb55_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb53_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb54_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb87_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb54_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb55_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb56_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb56_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb57_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb57_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb86_termite_23_spawn_2d_input_2d_port();
} else {
return _bb58_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb86_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb60_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb58_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb59_termite_23_spawn_2d_input_2d_port();
} else {
return _bb85_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb60_termite_23_spawn_2d_input_2d_port = () => {
return _bb61_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb59_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb60_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb85_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb60_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb61_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb62_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb62_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb63_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb63_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb84_termite_23_spawn_2d_input_2d_port();
} else {
return _bb64_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb84_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb66_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb64_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb65_termite_23_spawn_2d_input_2d_port();
} else {
return _bb83_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb66_termite_23_spawn_2d_input_2d_port = () => {
return _bb67_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb65_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb66_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb83_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb66_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb67_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb68_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb68_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb69_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb69_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb82_termite_23_spawn_2d_input_2d_port();
} else {
return _bb70_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb82_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb72_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb70_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb71_termite_23_spawn_2d_input_2d_port();
} else {
return _bb81_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb72_termite_23_spawn_2d_input_2d_port = () => {
return _bb73_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb71_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb72_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb81_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb72_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb73_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb74_termite_23_spawn_2d_input_2d_port();
} else {
return _bb80_termite_23_spawn_2d_input_2d_port();
}
});

_j(_bb74_termite_23_spawn_2d_input_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb75_termite_23_spawn_2d_input_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb75_termite_23_spawn_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb79_termite_23_spawn_2d_input_2d_port();
} else {
return _bb76_termite_23_spawn_2d_input_2d_port();
}
},4,1);

_j(_bb79_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb16_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb76_termite_23_spawn_2d_input_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb77_termite_23_spawn_2d_input_2d_port();
} else {
return _bb78_termite_23_spawn_2d_input_2d_port();
}
});

_k(_bb16_termite_23_spawn_2d_input_2d_port = () => {
return _bb17_termite_23_spawn_2d_input_2d_port();
},2,1);

_j(_bb77_termite_23_spawn_2d_input_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb16_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb78_termite_23_spawn_2d_input_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb16_termite_23_spawn_2d_input_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb17_termite_23_spawn_2d_input_2d_port = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb18_termite_23_spawn_2d_input_2d_port);
});

_j(_bb18_termite_23_spawn_2d_input_2d_port = () => {
if (_x(_a)) {
return _bb19_termite_23_spawn_2d_input_2d_port();
} else {
return _bb99_termite_23_spawn_2d_input_2d_port();
}
});



_m(_bb1_termite_23_pid_2d__3e_upid = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_pid_2d__3e_upid);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#*global-mutex*"];
_t += 2;
return _p(_bb2_termite_23_pid_2d__3e_upid);
},-1,_i("termite#pid->upid"),!1,!0);

_j(_bb2_termite_23_pid_2d__3e_upid = () => {
_r = _bb3_termite_23_pid_2d__3e_upid;
_n = 1;
return _g["mutex-lock!"]();
});

_k(_bb3_termite_23_pid_2d__3e_upid = () => {
_b = _s[_t];
_c = !1;
_a = _g["termite#*local->foreign*"];
_r = _bb4_termite_23_pid_2d__3e_upid;
_n = 3;
return _g["##table-ref"]();
},2,1);

_k(_bb4_termite_23_pid_2d__3e_upid = () => {
if (!(_a === !1)) {
return _bb5_termite_23_pid_2d__3e_upid();
} else {
return _bb7_termite_23_pid_2d__3e_upid();
}
},2,1);

_j(_bb5_termite_23_pid_2d__3e_upid = () => {
_s[_t] = _a;
_a = _g["termite#*global-mutex*"];
_r = _bb6_termite_23_pid_2d__3e_upid;
_n = 1;
return _g["mutex-unlock!"]();
});

_j(_bb7_termite_23_pid_2d__3e_upid = () => {
_r = _bb8_termite_23_pid_2d__3e_upid;
_n = 0;
return _g["termite/utils#make-uuid"]();
});

_k(_bb6_termite_23_pid_2d__3e_upid = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_k(_bb8_termite_23_pid_2d__3e_upid = () => {
_s[_t+1] = _a;
_r = _bb9_termite_23_pid_2d__3e_upid;
_n = 0;
++_t;
return _g["termite#current-node"]();
},2,1);

_k(_bb9_termite_23_pid_2d__3e_upid = () => {
_a = new _Structure([_cst101__termite,_s[_t],_a]);
_s[_t] = _a;
_c = _a;
_b = _s[_t-1];
_a = _g["termite#*local->foreign*"];
_r = _bb10_termite_23_pid_2d__3e_upid;
_n = 3;
return _g["##table-set!"]();
},3,1);

_k(_bb10_termite_23_pid_2d__3e_upid = () => {
_c = _s[_t-1];
_b = _s[_t];
_a = _g["termite#*foreign->local*"];
_r = _bb11_termite_23_pid_2d__3e_upid;
_n = 3;
return _g["##table-set!"]();
},3,1);

_k(_bb11_termite_23_pid_2d__3e_upid = () => {
_a = _g["termite#*global-mutex*"];
_r = _bb12_termite_23_pid_2d__3e_upid;
_n = 1;
return _g["mutex-unlock!"]();
},3,1);

_k(_bb12_termite_23_pid_2d__3e_upid = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);



_m(_bb1_termite_23_tag_2d__3e_utag = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_tag_2d__3e_utag);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#*global-mutex*"];
_t += 2;
return _p(_bb2_termite_23_tag_2d__3e_utag);
},-1,_i("termite#tag->utag"),!1,!0);

_j(_bb2_termite_23_tag_2d__3e_utag = () => {
_r = _bb3_termite_23_tag_2d__3e_utag;
_n = 1;
return _g["mutex-lock!"]();
});

_k(_bb3_termite_23_tag_2d__3e_utag = () => {
_a = _s[_t].a[1];
if (!(_a === !1)) {
return _bb4_termite_23_tag_2d__3e_utag();
} else {
return _bb6_termite_23_tag_2d__3e_utag();
}
},2,1);

_j(_bb4_termite_23_tag_2d__3e_utag = () => {
_a = _g["termite#*global-mutex*"];
_r = _bb5_termite_23_tag_2d__3e_utag;
_n = 1;
return _g["mutex-unlock!"]();
});

_j(_bb6_termite_23_tag_2d__3e_utag = () => {
_r = _bb7_termite_23_tag_2d__3e_utag;
_n = 0;
return _g["termite/utils#make-uuid"]();
});

_k(_bb5_termite_23_tag_2d__3e_utag = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_k(_bb7_termite_23_tag_2d__3e_utag = () => {
_s[_t].a[1] = _a;
_c = _s[_t];
_b = _a;
_a = _g["termite#*uuid->tag*"];
_r = _bb8_termite_23_tag_2d__3e_utag;
_n = 3;
return _g["##table-set!"]();
},2,1);

_k(_bb8_termite_23_tag_2d__3e_utag = () => {
_a = _g["termite#*global-mutex*"];
_r = _bb5_termite_23_tag_2d__3e_utag;
_n = 1;
return _g["mutex-unlock!"]();
},2,1);



_m(_bb1_termite_23_proxy_2d_reset_2d_counter = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_proxy_2d_reset_2d_counter);
}
_g["termite#proxy-counter"] = 0;
_g["termite#proxy-request-counter"] = 0;
_a = void 0;
return _r;
},-1,_i("termite#proxy-reset-counter"),!1,!0);



_m(_bb1_termite_23_proxy_2d_print_2d_debugging_2d_info = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_proxy_2d_print_2d_debugging_2d_info);
}
_s[_t+1] = _r;
_a = _cst192__termite;
++_t;
return _p(_bb2_termite_23_proxy_2d_print_2d_debugging_2d_info);
},-1,_i("termite#proxy-print-debugging-info"),!1,!0);

_j(_bb2_termite_23_proxy_2d_print_2d_debugging_2d_info = () => {
_r = _bb3_termite_23_proxy_2d_print_2d_debugging_2d_info;
_n = 1;
return _g["##println"]();
});

_k(_bb3_termite_23_proxy_2d_print_2d_debugging_2d_info = () => {
_b = _g["termite#proxy-counter"];
_a = _cst194__termite;
_r = _bb4_termite_23_proxy_2d_print_2d_debugging_2d_info;
_n = 2;
return _g["##println"]();
},1,1);

_k(_bb4_termite_23_proxy_2d_print_2d_debugging_2d_info = () => {
_b = _g["termite#proxy-request-counter"];
_a = _cst195__termite;
_r = _bb5_termite_23_proxy_2d_print_2d_debugging_2d_info;
_n = 2;
return _g["##println"]();
},1,1);

_k(_bb5_termite_23_proxy_2d_print_2d_debugging_2d_info = () => {
_a = _cst196__termite;
_r = _s[_t];
return _p(_bb6_termite_23_proxy_2d_print_2d_debugging_2d_info);
},1,1);

_j(_bb6_termite_23_proxy_2d_print_2d_debugging_2d_info = () => {
_n = 1;
--_t;
return _g["##println"]();
});



_m(_bb1_termite_23_make_2d_element_2d_proxy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_make_2d_element_2d_proxy);
}
_s[_t+1] = _r;
var closure0 = _closure_alloc([_bb137_termite_23_make_2d_element_2d_proxy,_a]);
_s[_t+2] = closure0;
_a = _s[_t+2];
_c = _cst147__termite;
_b = _cst15__termite;
_t += 2;
return _p(_bb2_termite_23_make_2d_element_2d_proxy);
},-1,_i("termite#make-element-proxy"),!1,!0);

_l(_bb137_termite_23_make_2d_element_2d_proxy = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _p(_bb140_termite_23_make_2d_element_2d_proxy);
},1);

_j(_bb2_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb131_termite_23_make_2d_element_2d_proxy;
_n = 3;
--_t;
return _bb3_termite_23_make_2d_element_2d_proxy();
});

_j(_bb140_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb141_termite_23_make_2d_element_2d_proxy);
});

_l(_bb3_termite_23_make_2d_element_2d_proxy = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_make_2d_element_2d_proxy,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb8_termite_23_make_2d_element_2d_proxy,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb4_termite_23_make_2d_element_2d_proxy);
},-1);

_k(_bb131_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _g["termite#proxy-counter"];
if (_y(_s[_t+1])) {
++_t;
return _bb132_termite_23_make_2d_element_2d_proxy();
} else {
++_t;
return _bb136_termite_23_make_2d_element_2d_proxy();
}
},1,1);

_j(_bb141_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb142_termite_23_make_2d_element_2d_proxy;
_n = 0;
return _g["thread-mailbox-next"]();
});

_l(_bb8_termite_23_make_2d_element_2d_proxy = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb9_termite_23_make_2d_element_2d_proxy);
},1);

_j(_bb4_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb5_termite_23_make_2d_element_2d_proxy;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb132_termite_23_make_2d_element_2d_proxy = () => {
_b = (_h = (_o = _s[_t] + 1)<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb134_termite_23_make_2d_element_2d_proxy();
} else {
return _bb136_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb136_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _a;
_a = _s[_t];
_b = 1;
_r = _bb133_termite_23_make_2d_element_2d_proxy;
_n = 2;
++_t;
return _e["##+"]();
});

_k(_bb142_termite_23_make_2d_element_2d_proxy = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb143_termite_23_make_2d_element_2d_proxy();
} else {
return _bb144_termite_23_make_2d_element_2d_proxy();
}
},2,1);

_j(_bb9_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb10_termite_23_make_2d_element_2d_proxy;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb5_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb6_termite_23_make_2d_element_2d_proxy;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb134_termite_23_make_2d_element_2d_proxy = () => {
_g["termite#proxy-counter"] = _b;
_r = _s[_t-1];
return _p(_bb135_termite_23_make_2d_element_2d_proxy);
});

_k(_bb133_termite_23_make_2d_element_2d_proxy = () => {
_b = _a;
_a = _s[_t];
--_t;
return _bb134_termite_23_make_2d_element_2d_proxy();
},3,1);

_j(_bb143_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _a;
_r = _bb168_termite_23_make_2d_element_2d_proxy;
++_t;
return _bb151_termite_23_make_2d_element_2d_proxy();
});

_j(_bb144_termite_23_make_2d_element_2d_proxy = () => {
if (_x(_a)) {
return _bb145_termite_23_make_2d_element_2d_proxy();
} else {
return _bb155_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb10_termite_23_make_2d_element_2d_proxy = () => {
_a = _current_processor.a[14];
_r = _bb11_termite_23_make_2d_element_2d_proxy;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb6_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t];
_r = _bb7_termite_23_make_2d_element_2d_proxy;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb135_termite_23_make_2d_element_2d_proxy = () => {
_n = 1;
_t -= 2;
return _bb1_termite_23_pid_2d__3e_upid();
});

_j(_bb151_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb152_termite_23_make_2d_element_2d_proxy);
});

_k(_bb168_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t];
_r = _bb138_termite_23_make_2d_element_2d_proxy;
_n = 1;
--_t;
return _g["##raise"]();
},3,1);

_j(_bb145_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.b;
_c = _a.a;
if (_x(_b)) {
return _bb146_termite_23_make_2d_element_2d_proxy();
} else {
return _bb155_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb155_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _a;
_r = _bb156_termite_23_make_2d_element_2d_proxy;
++_t;
return _bb151_termite_23_make_2d_element_2d_proxy();
});

_k(_bb11_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb129_termite_23_make_2d_element_2d_proxy;
return _bb12_termite_23_make_2d_element_2d_proxy();
},1,1);

_k(_bb7_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb152_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb153_termite_23_make_2d_element_2d_proxy;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb138_termite_23_make_2d_element_2d_proxy = () => {
return _bb139_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb146_termite_23_make_2d_element_2d_proxy = () => {
_d = _b.b;
_b = _b.a;
if (_x(_d)) {
return _bb147_termite_23_make_2d_element_2d_proxy();
} else {
return _bb155_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb156_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t];
_r = _bb138_termite_23_make_2d_element_2d_proxy;
--_t;
return _bb157_termite_23_make_2d_element_2d_proxy();
},3,1);

_j(_bb12_termite_23_make_2d_element_2d_proxy = () => {
if (_x(_a)) {
return _bb16_termite_23_make_2d_element_2d_proxy();
} else {
return _bb128_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb129_termite_23_make_2d_element_2d_proxy = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb130_termite_23_make_2d_element_2d_proxy);
},1,1);

_k(_bb153_termite_23_make_2d_element_2d_proxy = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb139_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb140_termite_23_make_2d_element_2d_proxy);
});

_j(_bb147_termite_23_make_2d_element_2d_proxy = () => {
_r = _d.b;
_d = _d.a;
if (_d === _cst197__termite) {
return _bb154_termite_23_make_2d_element_2d_proxy();
} else {
return _bb148_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb157_termite_23_make_2d_element_2d_proxy = () => {
_b = _a;
_a = _cst198__termite;
return _p(_bb158_termite_23_make_2d_element_2d_proxy);
});

_j(_bb16_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb17_termite_23_make_2d_element_2d_proxy);
});

_j(_bb128_termite_23_make_2d_element_2d_proxy = () => {
_a = void 0;
return _r;
});

_j(_bb130_termite_23_make_2d_element_2d_proxy = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb154_termite_23_make_2d_element_2d_proxy = () => {
if (_r === null) {
return _bb161_termite_23_make_2d_element_2d_proxy();
} else {
return _bb155_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb148_termite_23_make_2d_element_2d_proxy = () => {
if (_d === _cst199__termite) {
return _bb149_termite_23_make_2d_element_2d_proxy();
} else {
return _bb155_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb158_termite_23_make_2d_element_2d_proxy = () => {
_n = 2;
return _bb159_termite_23_make_2d_element_2d_proxy();
});

_j(_bb17_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb18_termite_23_make_2d_element_2d_proxy;
_n = 1;
return _g["thread?"]();
});

_j(_bb161_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _b;
_s[_t+2] = _c;
_r = _bb162_termite_23_make_2d_element_2d_proxy;
_t += 2;
return _bb151_termite_23_make_2d_element_2d_proxy();
});

_j(_bb149_termite_23_make_2d_element_2d_proxy = () => {
if (_r === null) {
return _bb150_termite_23_make_2d_element_2d_proxy();
} else {
return _bb155_termite_23_make_2d_element_2d_proxy();
}
});

_l(_bb159_termite_23_make_2d_element_2d_proxy = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb159_termite_23_make_2d_element_2d_proxy);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb160_termite_23_make_2d_element_2d_proxy);
},-1);

_k(_bb18_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb127_termite_23_make_2d_element_2d_proxy();
} else {
return _bb19_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_k(_bb162_termite_23_make_2d_element_2d_proxy = () => {
_s[_t+1] = _g["termite#proxy-request-counter"];
if (_y(_s[_t+1])) {
++_t;
return _bb163_termite_23_make_2d_element_2d_proxy();
} else {
++_t;
return _bb167_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb150_termite_23_make_2d_element_2d_proxy = () => {
_r = _bb138_termite_23_make_2d_element_2d_proxy;
return _bb151_termite_23_make_2d_element_2d_proxy();
});

_j(_bb160_termite_23_make_2d_element_2d_proxy = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_j(_bb127_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb21_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb19_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb20_termite_23_make_2d_element_2d_proxy();
} else {
return _bb126_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb163_termite_23_make_2d_element_2d_proxy = () => {
_a = (_h = (_o = _s[_t] + 1)<<2>>2) === _o && _h;
if (!(_a === !1)) {
return _bb164_termite_23_make_2d_element_2d_proxy();
} else {
return _bb167_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb167_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t];
_b = 1;
_r = _bb165_termite_23_make_2d_element_2d_proxy;
_n = 2;
--_t;
return _e["##+"]();
});

_k(_bb21_termite_23_make_2d_element_2d_proxy = () => {
return _bb22_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb20_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb21_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb126_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb21_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb164_termite_23_make_2d_element_2d_proxy = () => {
--_t;
return _bb166_termite_23_make_2d_element_2d_proxy();
});

_k(_bb165_termite_23_make_2d_element_2d_proxy = () => {
return _bb166_termite_23_make_2d_element_2d_proxy();
},4,1);

_j(_bb22_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb23_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb166_termite_23_make_2d_element_2d_proxy = () => {
_g["termite#proxy-request-counter"] = _a;
_b = _X(_s[_t-1],_X(_s[_t-2],null));
_a = _s[_t];
_r = _bb138_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _bb1_termite_23__21_();
});

_j(_bb23_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb24_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb101_termite_23_make_2d_element_2d_proxy = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb24_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb125_termite_23_make_2d_element_2d_proxy();
} else {
return _bb25_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb125_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb27_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb25_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb26_termite_23_make_2d_element_2d_proxy();
} else {
return _bb124_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb27_termite_23_make_2d_element_2d_proxy = () => {
return _bb28_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb26_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb27_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb124_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb27_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb28_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb29_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb29_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb30_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb30_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb123_termite_23_make_2d_element_2d_proxy();
} else {
return _bb31_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb123_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb33_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb31_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb32_termite_23_make_2d_element_2d_proxy();
} else {
return _bb122_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb33_termite_23_make_2d_element_2d_proxy = () => {
return _bb34_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb32_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb33_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb122_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb33_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb34_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb35_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb35_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb36_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb36_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb121_termite_23_make_2d_element_2d_proxy();
} else {
return _bb37_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb121_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb39_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb37_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb38_termite_23_make_2d_element_2d_proxy();
} else {
return _bb120_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb39_termite_23_make_2d_element_2d_proxy = () => {
return _bb40_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb38_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb39_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb120_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb39_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb40_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb41_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb41_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb42_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb42_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb119_termite_23_make_2d_element_2d_proxy();
} else {
return _bb43_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb119_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb45_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb43_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb44_termite_23_make_2d_element_2d_proxy();
} else {
return _bb118_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb45_termite_23_make_2d_element_2d_proxy = () => {
return _bb46_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb44_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb45_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb118_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb45_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb46_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb47_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb47_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb48_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb48_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb117_termite_23_make_2d_element_2d_proxy();
} else {
return _bb49_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb117_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb51_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb49_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb50_termite_23_make_2d_element_2d_proxy();
} else {
return _bb116_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb51_termite_23_make_2d_element_2d_proxy = () => {
return _bb52_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb50_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb51_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb116_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb51_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb52_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb53_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb53_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb54_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb54_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb115_termite_23_make_2d_element_2d_proxy();
} else {
return _bb55_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb115_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb57_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb55_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb56_termite_23_make_2d_element_2d_proxy();
} else {
return _bb114_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb57_termite_23_make_2d_element_2d_proxy = () => {
return _bb58_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb56_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb57_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb114_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb57_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb58_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb59_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb59_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb60_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb60_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb113_termite_23_make_2d_element_2d_proxy();
} else {
return _bb61_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb113_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb63_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb61_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb62_termite_23_make_2d_element_2d_proxy();
} else {
return _bb112_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb63_termite_23_make_2d_element_2d_proxy = () => {
return _bb64_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb62_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb63_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb112_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb63_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb64_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb65_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb65_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb66_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb66_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb111_termite_23_make_2d_element_2d_proxy();
} else {
return _bb67_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb111_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb69_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb67_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb68_termite_23_make_2d_element_2d_proxy();
} else {
return _bb110_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb69_termite_23_make_2d_element_2d_proxy = () => {
return _bb70_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb68_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb69_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb110_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb69_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb70_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb71_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb71_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb72_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb72_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb109_termite_23_make_2d_element_2d_proxy();
} else {
return _bb73_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb109_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb75_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb73_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb74_termite_23_make_2d_element_2d_proxy();
} else {
return _bb108_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb75_termite_23_make_2d_element_2d_proxy = () => {
return _bb76_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb74_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb75_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb108_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb75_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb76_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb77_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb77_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb78_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb78_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb107_termite_23_make_2d_element_2d_proxy();
} else {
return _bb79_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb107_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb81_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb79_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb80_termite_23_make_2d_element_2d_proxy();
} else {
return _bb106_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb81_termite_23_make_2d_element_2d_proxy = () => {
return _bb82_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb80_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb81_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb106_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb81_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb82_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb83_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb83_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb84_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb84_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb105_termite_23_make_2d_element_2d_proxy();
} else {
return _bb85_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb105_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb87_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb85_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb86_termite_23_make_2d_element_2d_proxy();
} else {
return _bb104_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb87_termite_23_make_2d_element_2d_proxy = () => {
return _bb88_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb86_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb87_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb104_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb87_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb88_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb89_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb89_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb90_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb90_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb103_termite_23_make_2d_element_2d_proxy();
} else {
return _bb91_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb103_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb93_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb91_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb92_termite_23_make_2d_element_2d_proxy();
} else {
return _bb102_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb93_termite_23_make_2d_element_2d_proxy = () => {
return _bb94_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb92_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb93_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb102_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb93_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb94_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb95_termite_23_make_2d_element_2d_proxy();
} else {
return _bb101_termite_23_make_2d_element_2d_proxy();
}
});

_j(_bb95_termite_23_make_2d_element_2d_proxy = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb96_termite_23_make_2d_element_2d_proxy;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb96_termite_23_make_2d_element_2d_proxy = () => {
if (!(_a === !1)) {
return _bb100_termite_23_make_2d_element_2d_proxy();
} else {
return _bb97_termite_23_make_2d_element_2d_proxy();
}
},4,1);

_j(_bb100_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb13_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb97_termite_23_make_2d_element_2d_proxy = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb98_termite_23_make_2d_element_2d_proxy();
} else {
return _bb99_termite_23_make_2d_element_2d_proxy();
}
});

_k(_bb13_termite_23_make_2d_element_2d_proxy = () => {
return _bb14_termite_23_make_2d_element_2d_proxy();
},2,1);

_j(_bb98_termite_23_make_2d_element_2d_proxy = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb13_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb99_termite_23_make_2d_element_2d_proxy = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb13_termite_23_make_2d_element_2d_proxy;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb14_termite_23_make_2d_element_2d_proxy = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb15_termite_23_make_2d_element_2d_proxy);
});

_j(_bb15_termite_23_make_2d_element_2d_proxy = () => {
if (_x(_a)) {
return _bb16_termite_23_make_2d_element_2d_proxy();
} else {
return _bb128_termite_23_make_2d_element_2d_proxy();
}
});



_m(_bb1_termite_23_serialize_2d_hook = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_serialize_2d_hook);
}
if (_a instanceof _ScmPromise) {
return _bb2_termite_23_serialize_2d_hook();
} else {
return _bb5_termite_23_serialize_2d_hook();
}
},-1,_i("termite#serialize-hook"),!1,!0);

_j(_bb2_termite_23_serialize_2d_hook = () => {
_a = _a.a;
_b = _a[0];
if (_a === _b) {
return _bb3_termite_23_serialize_2d_hook();
} else {
return _bb4_termite_23_serialize_2d_hook();
}
});

_j(_bb5_termite_23_serialize_2d_hook = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst146__termite) {
return _bb18_termite_23_serialize_2d_hook();
} else {
return _bb6_termite_23_serialize_2d_hook();
}
});

_j(_bb3_termite_23_serialize_2d_hook = () => {
_a = _a[1];
_a = new _Structure([_cst149__termite,_a]);
return _r;
});

_j(_bb4_termite_23_serialize_2d_hook = () => {
return _r;
});

_j(_bb18_termite_23_serialize_2d_hook = () => {
_b = _a.a[1];
_a.a[1] = _b;
return _r;
});

_j(_bb6_termite_23_serialize_2d_hook = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb7_termite_23_serialize_2d_hook);
});

_j(_bb7_termite_23_serialize_2d_hook = () => {
_r = _bb8_termite_23_serialize_2d_hook;
_n = 1;
return _g["thread?"]();
});

_k(_bb8_termite_23_serialize_2d_hook = () => {
if (!(_a === !1)) {
return _bb9_termite_23_serialize_2d_hook();
} else {
return _bb11_termite_23_serialize_2d_hook();
}
},2,1);

_j(_bb9_termite_23_serialize_2d_hook = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb10_termite_23_serialize_2d_hook);
});

_j(_bb11_termite_23_serialize_2d_hook = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst142__termite) {
return _bb12_termite_23_serialize_2d_hook();
} else {
return _bb14_termite_23_serialize_2d_hook();
}
});

_j(_bb10_termite_23_serialize_2d_hook = () => {
_n = 1;
_t -= 2;
return _bb1_termite_23_pid_2d__3e_upid();
});

_j(_bb12_termite_23_serialize_2d_hook = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb13_termite_23_serialize_2d_hook);
});

_j(_bb14_termite_23_serialize_2d_hook = () => {
_a = _s[_t];
_r = _bb15_termite_23_serialize_2d_hook;
_n = 1;
return _g["##port?"]();
});

_j(_bb13_termite_23_serialize_2d_hook = () => {
_n = 1;
_t -= 2;
return _bb1_termite_23_tag_2d__3e_utag();
});

_k(_bb15_termite_23_serialize_2d_hook = () => {
if (!(_a === !1)) {
return _bb16_termite_23_serialize_2d_hook();
} else {
return _bb17_termite_23_serialize_2d_hook();
}
},2,1);

_j(_bb16_termite_23_serialize_2d_hook = () => {
_a = !1;
_t -= 2;
return _s[_t+1]();
});

_j(_bb17_termite_23_serialize_2d_hook = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
});



_m(_bb1_termite_23_upid_2d__3e_pid = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_upid_2d__3e_pid);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_b = _a;
_c = !1;
_a = _g["termite#*foreign->local*"];
_t += 2;
return _p(_bb2_termite_23_upid_2d__3e_pid);
},-1,_i("termite#upid->pid"),!1,!0);

_j(_bb2_termite_23_upid_2d__3e_pid = () => {
_r = _bb3_termite_23_upid_2d__3e_pid;
_n = 3;
return _g["##table-ref"]();
});

_k(_bb3_termite_23_upid_2d__3e_pid = () => {
if (!(_a === !1)) {
return _bb13_termite_23_upid_2d__3e_pid();
} else {
return _bb4_termite_23_upid_2d__3e_pid();
}
},2,1);

_j(_bb13_termite_23_upid_2d__3e_pid = () => {
_t -= 2;
return _s[_t+1]();
});

_j(_bb4_termite_23_upid_2d__3e_pid = () => {
_a = _s[_t].a[1];
if (_a instanceof _ScmSymbol) {
return _bb5_termite_23_upid_2d__3e_pid();
} else {
return _bb9_termite_23_upid_2d__3e_pid();
}
});

_j(_bb5_termite_23_upid_2d__3e_pid = () => {
_a = _s[_t].a[1];
_r = _bb8_termite_23_upid_2d__3e_pid;
_n = 1;
--_t;
return _bb6_termite_23_upid_2d__3e_pid();
});

_j(_bb9_termite_23_upid_2d__3e_pid = () => {
_a = !1;
if (!(_a === !1)) {
--_t;
return _bb12_termite_23_upid_2d__3e_pid();
} else {
--_t;
return _bb10_termite_23_upid_2d__3e_pid();
}
});

_l(_bb6_termite_23_upid_2d__3e_pid = () => {
if (_n === 1) {
_b = !1;
} else {
if (_n !== 2) {
return _w(_bb6_termite_23_upid_2d__3e_pid);
}
}
_b = _X(_cst113__termite,_X(_a,null));
_a = _g["termite#publisher"];
return _p(_bb7_termite_23_upid_2d__3e_pid);
},-1);

_k(_bb8_termite_23_upid_2d__3e_pid = () => {
if (!(_a === !1)) {
return _bb12_termite_23_upid_2d__3e_pid();
} else {
return _bb10_termite_23_upid_2d__3e_pid();
}
},1,1);

_j(_bb12_termite_23_upid_2d__3e_pid = () => {
--_t;
return _s[_t+1]();
});

_j(_bb10_termite_23_upid_2d__3e_pid = () => {
_a = _cst201__termite;
_r = _s[_t];
return _p(_bb11_termite_23_upid_2d__3e_pid);
});

_j(_bb7_termite_23_upid_2d__3e_pid = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});

_j(_bb11_termite_23_upid_2d__3e_pid = () => {
_n = 1;
--_t;
return _g["##error"]();
});



_m(_bb1_termite_23_utag_2d__3e_tag = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_utag_2d__3e_tag);
}
_b = _a.a[1];
_s[_t+1] = _r;
_s[_t+2] = _a;
_c = !1;
_a = _g["termite#*uuid->tag*"];
_t += 2;
return _p(_bb2_termite_23_utag_2d__3e_tag);
},-1,_i("termite#utag->tag"),!1,!0);

_j(_bb2_termite_23_utag_2d__3e_tag = () => {
_r = _bb3_termite_23_utag_2d__3e_tag;
_n = 3;
return _g["##table-ref"]();
});

_k(_bb3_termite_23_utag_2d__3e_tag = () => {
if (!(_a === !1)) {
return _bb4_termite_23_utag_2d__3e_tag();
} else {
return _bb5_termite_23_utag_2d__3e_tag();
}
},2,1);

_j(_bb4_termite_23_utag_2d__3e_tag = () => {
_t -= 2;
return _s[_t+1]();
});

_j(_bb5_termite_23_utag_2d__3e_tag = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
});



_m(_bb1_termite_23_deserialize_2d_hook = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_deserialize_2d_hook);
}
if (_a instanceof _Structure && _a.a[0].a[1] === _cst83__termite) {
return _bb2_termite_23_deserialize_2d_hook();
} else {
return _bb9_termite_23_deserialize_2d_hook();
}
},-1,_i("termite#deserialize-hook"),!1,!0);

_j(_bb2_termite_23_deserialize_2d_hook = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb3_termite_23_deserialize_2d_hook);
});

_j(_bb9_termite_23_deserialize_2d_hook = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst150__termite) {
return _bb17_termite_23_deserialize_2d_hook();
} else {
return _bb10_termite_23_deserialize_2d_hook();
}
});

_j(_bb3_termite_23_deserialize_2d_hook = () => {
_r = _bb4_termite_23_deserialize_2d_hook;
_n = 0;
return _g["termite#current-node"]();
});

_j(_bb17_termite_23_deserialize_2d_hook = () => {
_a = _a.a[1];
_a = _make_delay_promise(_a);
return _r;
});

_j(_bb10_termite_23_deserialize_2d_hook = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst146__termite) {
return _bb11_termite_23_deserialize_2d_hook();
} else {
return _bb13_termite_23_deserialize_2d_hook();
}
});

_k(_bb4_termite_23_deserialize_2d_hook = () => {
_b = _a;
_a = _s[_t].a[2];
_r = _bb5_termite_23_deserialize_2d_hook;
_n = 2;
return _e["##equal?"]();
},2,1);

_j(_bb11_termite_23_deserialize_2d_hook = () => {
_a = _a.a[1];
_s[_t+1] = _a;
_c = _cst77__termite;
_b = 360;
_a = _cst197__termite;
++_t;
return _p(_bb12_termite_23_deserialize_2d_hook);
});

_j(_bb13_termite_23_deserialize_2d_hook = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst142__termite) {
return _bb14_termite_23_deserialize_2d_hook();
} else {
return _bb16_termite_23_deserialize_2d_hook();
}
});

_k(_bb5_termite_23_deserialize_2d_hook = () => {
if (!(_a === !1)) {
return _bb6_termite_23_deserialize_2d_hook();
} else {
return _bb8_termite_23_deserialize_2d_hook();
}
},2,1);

_j(_bb12_termite_23_deserialize_2d_hook = () => {
_n = 4;
return _bb1_termite_23__21__3f_();
});

_j(_bb14_termite_23_deserialize_2d_hook = () => {
return _p(_bb15_termite_23_deserialize_2d_hook);
});

_j(_bb16_termite_23_deserialize_2d_hook = () => {
return _r;
});

_j(_bb6_termite_23_deserialize_2d_hook = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb7_termite_23_deserialize_2d_hook);
});

_j(_bb8_termite_23_deserialize_2d_hook = () => {
_a = _s[_t];
_r = _s[_t-1];
if (_a instanceof _Structure && _a.a[0].a[1] === _cst150__termite) {
_t -= 2;
return _bb17_termite_23_deserialize_2d_hook();
} else {
_t -= 2;
return _bb10_termite_23_deserialize_2d_hook();
}
});

_j(_bb15_termite_23_deserialize_2d_hook = () => {
_n = 1;
return _bb1_termite_23_utag_2d__3e_tag();
});

_j(_bb7_termite_23_deserialize_2d_hook = () => {
_n = 1;
_t -= 2;
return _bb1_termite_23_upid_2d__3e_pid();
});



_m(_bb1_termite_23_serialize = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_serialize);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
_b = _bb1_termite_23_serialize_2d_hook;
_t += 2;
return _p(_bb2_termite_23_serialize);
},-1,_i("termite#serialize"),!1,!0);

_j(_bb2_termite_23_serialize = () => {
_r = _bb3_termite_23_serialize;
_n = 2;
return _g["##object->u8vector"]();
});

_k(_bb3_termite_23_serialize = () => {
_b = _a.a.length;
if (_y(_b)) {
return _bb4_termite_23_serialize();
} else {
return _bb24_termite_23_serialize();
}
},2,1);

_j(_bb4_termite_23_serialize = () => {
_c = _b & 255;
return _bb6_termite_23_serialize();
});

_j(_bb24_termite_23_serialize = () => {
_s[_t+1] = _a;
_s[_t+2] = _b;
_a = _b;
_b = 255;
_r = _bb5_termite_23_serialize;
_n = 2;
_t += 2;
return _e["##bitwise-and"]();
});

_j(_bb6_termite_23_serialize = () => {
_s[_t+1] = _a;
_s[_t+2] = _b;
_s[_t+3] = _c;
_a = _b;
_b = -8;
_r = _bb7_termite_23_serialize;
_n = 2;
_t += 3;
return _e["##arithmetic-shift"]();
});

_k(_bb5_termite_23_serialize = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_t -= 2;
return _bb6_termite_23_serialize();
},4,1);

_k(_bb7_termite_23_serialize = () => {
if (_y(_a)) {
return _bb8_termite_23_serialize();
} else {
return _bb23_termite_23_serialize();
}
},5,1);

_j(_bb8_termite_23_serialize = () => {
_a = _a & 255;
return _bb10_termite_23_serialize();
});

_j(_bb23_termite_23_serialize = () => {
_b = 255;
_r = _bb9_termite_23_serialize;
_n = 2;
return _e["##bitwise-and"]();
});

_j(_bb10_termite_23_serialize = () => {
_s[_t+1] = _a;
_a = _s[_t-1];
_b = -16;
_r = _bb11_termite_23_serialize;
_n = 2;
++_t;
return _e["##arithmetic-shift"]();
});

_k(_bb9_termite_23_serialize = () => {
return _bb10_termite_23_serialize();
},5,1);

_k(_bb11_termite_23_serialize = () => {
if (_y(_a)) {
return _bb12_termite_23_serialize();
} else {
return _bb22_termite_23_serialize();
}
},6,1);

_j(_bb12_termite_23_serialize = () => {
_a = _a & 255;
return _bb14_termite_23_serialize();
});

_j(_bb22_termite_23_serialize = () => {
_b = 255;
_r = _bb13_termite_23_serialize;
_n = 2;
return _e["##bitwise-and"]();
});

_j(_bb14_termite_23_serialize = () => {
_s[_t+1] = _a;
_a = _s[_t-2];
_b = -24;
_r = _bb15_termite_23_serialize;
_n = 2;
++_t;
return _e["##arithmetic-shift"]();
});

_k(_bb13_termite_23_serialize = () => {
return _bb14_termite_23_serialize();
},6,1);

_k(_bb15_termite_23_serialize = () => {
if (_y(_a)) {
return _bb16_termite_23_serialize();
} else {
return _bb21_termite_23_serialize();
}
},7,1);

_j(_bb16_termite_23_serialize = () => {
_a = _a & 255;
return _bb18_termite_23_serialize();
});

_j(_bb21_termite_23_serialize = () => {
_b = 255;
_r = _bb17_termite_23_serialize;
_n = 2;
return _e["##bitwise-and"]();
});

_j(_bb18_termite_23_serialize = () => {
_a = new _U8Vector(new Uint8Array([_s[_t-2],_s[_t-1],_s[_t],_a]));
_s[_t-2] = _a;
_c = _s[_t-5];
_b = 4;
_a = 0;
_r = _bb19_termite_23_serialize;
_n = 4;
_t -= 2;
return _g["##write-subu8vector"]();
});

_k(_bb17_termite_23_serialize = () => {
return _bb18_termite_23_serialize();
},7,1);

_k(_bb19_termite_23_serialize = () => {
_s[_t+1] = _s[_t-3];
_s[_t-3] = _s[_t-1];
_c = _s[_t-2];
_b = _s[_t];
_a = 0;
_r = _s[_t+1];
++_t;
return _p(_bb20_termite_23_serialize);
},4,1);

_j(_bb20_termite_23_serialize = () => {
_n = 4;
_t -= 4;
return _g["##write-subu8vector"]();
});



_m(_bb1_termite_23_deserialize = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_deserialize);
}
_b = new _U8Vector(new Uint8Array([0,0,0,0]));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _b;
_c = _a;
_b = 4;
_a = 0;
_t += 4;
return _p(_bb2_termite_23_deserialize);
},-1,_i("termite#deserialize"),!1,!0);

_j(_bb2_termite_23_deserialize = () => {
_r = _bb3_termite_23_deserialize;
_n = 4;
return _g["##read-subu8vector"]();
});

_k(_bb3_termite_23_deserialize = () => {
if (_y(_a)) {
return _bb4_termite_23_deserialize();
} else {
return _bb46_termite_23_deserialize();
}
},3,1);

_j(_bb4_termite_23_deserialize = () => {
if (0 === _a) {
return _bb44_termite_23_deserialize();
} else {
return _bb5_termite_23_deserialize();
}
});

_j(_bb46_termite_23_deserialize = () => {
_s[_t+1] = _a;
_b = _a;
_a = 0;
_r = _bb6_termite_23_deserialize;
_n = 2;
++_t;
return _e["##="]();
});

_j(_bb44_termite_23_deserialize = () => {
_a = _eof_obj;
_t -= 3;
return _s[_t+1]();
});

_j(_bb5_termite_23_deserialize = () => {
if (_y(_a)) {
return _bb8_termite_23_deserialize();
} else {
return _bb45_termite_23_deserialize();
}
});

_k(_bb6_termite_23_deserialize = () => {
if (!(_a === !1)) {
return _bb43_termite_23_deserialize();
} else {
return _bb7_termite_23_deserialize();
}
},4,1);

_j(_bb8_termite_23_deserialize = () => {
if (4 === _a) {
return _bb12_termite_23_deserialize();
} else {
return _bb9_termite_23_deserialize();
}
});

_j(_bb45_termite_23_deserialize = () => {
_b = _a;
_a = 4;
_r = _bb11_termite_23_deserialize;
_n = 2;
return _e["##="]();
});

_j(_bb43_termite_23_deserialize = () => {
--_t;
return _bb44_termite_23_deserialize();
});

_j(_bb7_termite_23_deserialize = () => {
_a = _s[_t];
if (_y(_a)) {
--_t;
return _bb8_termite_23_deserialize();
} else {
--_t;
return _bb45_termite_23_deserialize();
}
});

_j(_bb12_termite_23_deserialize = () => {
_a = _s[_t].a[0];
_s[_t+1] = _a;
_a = _s[_t].a[1];
_b = 8;
_r = _bb13_termite_23_deserialize;
_n = 2;
++_t;
return _e["##arithmetic-shift"]();
});

_j(_bb9_termite_23_deserialize = () => {
_a = _cst207__termite;
_r = _s[_t-2];
return _p(_bb10_termite_23_deserialize);
});

_k(_bb11_termite_23_deserialize = () => {
if (!(_a === !1)) {
return _bb12_termite_23_deserialize();
} else {
return _bb9_termite_23_deserialize();
}
},3,1);

_k(_bb13_termite_23_deserialize = () => {
_s[_t+1] = _a;
_a = _s[_t-1].a[2];
_b = 16;
_r = _bb14_termite_23_deserialize;
_n = 2;
++_t;
return _e["##arithmetic-shift"]();
},4,1);

_j(_bb10_termite_23_deserialize = () => {
_n = 1;
_t -= 3;
return _g["##error"]();
});

_k(_bb14_termite_23_deserialize = () => {
_s[_t+1] = _a;
_a = _s[_t-2].a[3];
_b = 24;
_r = _bb15_termite_23_deserialize;
_n = 2;
++_t;
return _e["##arithmetic-shift"]();
},5,1);

_k(_bb15_termite_23_deserialize = () => {
if (_y(_a)) {
return _bb16_termite_23_deserialize();
} else {
return _bb35_termite_23_deserialize();
}
},6,1);

_j(_bb16_termite_23_deserialize = () => {
if (_y(_s[_t])) {
return _bb17_termite_23_deserialize();
} else {
return _bb35_termite_23_deserialize();
}
});

_j(_bb35_termite_23_deserialize = () => {
if (_f(_a)) {
return _bb36_termite_23_deserialize();
} else {
return _bb42_termite_23_deserialize();
}
});

_j(_bb17_termite_23_deserialize = () => {
if (_y(_s[_t-1])) {
return _bb18_termite_23_deserialize();
} else {
return _bb35_termite_23_deserialize();
}
});

_j(_bb36_termite_23_deserialize = () => {
if (_f(_s[_t])) {
return _bb37_termite_23_deserialize();
} else {
return _bb42_termite_23_deserialize();
}
});

_j(_bb42_termite_23_deserialize = () => {
_s[_t-3] = _s[_t-2];
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _bb40_termite_23_deserialize;
_n = 4;
_t -= 3;
return _e["##+"]();
});

_j(_bb18_termite_23_deserialize = () => {
if (_y(_s[_t-2])) {
return _bb19_termite_23_deserialize();
} else {
return _bb35_termite_23_deserialize();
}
});

_j(_bb37_termite_23_deserialize = () => {
if (_f(_s[_t-1])) {
return _bb38_termite_23_deserialize();
} else {
return _bb42_termite_23_deserialize();
}
});

_k(_bb40_termite_23_deserialize = () => {
return _bb41_termite_23_deserialize();
},2,1);

_j(_bb19_termite_23_deserialize = () => {
_b = (_h = (_o = _s[_t-2] + _s[_t-1])<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb20_termite_23_deserialize();
} else {
return _bb34_termite_23_deserialize();
}
});

_j(_bb38_termite_23_deserialize = () => {
if (_f(_s[_t-2])) {
return _bb39_termite_23_deserialize();
} else {
return _bb42_termite_23_deserialize();
}
});

_j(_bb41_termite_23_deserialize = () => {
_b = _a;
return _bb24_termite_23_deserialize();
});

_j(_bb20_termite_23_deserialize = () => {
_b = (_h = (_o = _b + _s[_t])<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb21_termite_23_deserialize();
} else {
return _bb34_termite_23_deserialize();
}
});

_j(_bb34_termite_23_deserialize = () => {
_s[_t-3] = _s[_t-2];
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _bb23_termite_23_deserialize;
_n = 4;
_t -= 3;
return _e["##+"]();
});

_j(_bb39_termite_23_deserialize = () => {
_b = _F(_s[_t-2].a + _s[_t-1].a);
_b = _F(_b.a + _s[_t].a);
_a = _F(_b.a + _a.a);
_t -= 4;
return _bb41_termite_23_deserialize();
});

_j(_bb24_termite_23_deserialize = () => {
_a = _make_u8vector(_b,0);
_s[_t+1] = _a;
_s[_t+2] = _b;
_s[_t+3] = _a;
_c = _s[_t];
_a = 0;
_r = _bb25_termite_23_deserialize;
_n = 4;
_t += 3;
return _g["##read-subu8vector"]();
});

_j(_bb21_termite_23_deserialize = () => {
_b = (_h = (_o = _b + _a)<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb22_termite_23_deserialize();
} else {
return _bb34_termite_23_deserialize();
}
});

_k(_bb23_termite_23_deserialize = () => {
_b = _a;
return _bb24_termite_23_deserialize();
},2,1);

_k(_bb25_termite_23_deserialize = () => {
_s[_t-2] = _a;
_b = _a;
_a = _s[_t];
_r = _bb26_termite_23_deserialize;
_n = 2;
return _e["##eqv?"]();
},4,1);

_j(_bb22_termite_23_deserialize = () => {
_t -= 4;
return _bb24_termite_23_deserialize();
});

_k(_bb26_termite_23_deserialize = () => {
if (!(_a === !1)) {
return _bb29_termite_23_deserialize();
} else {
return _bb27_termite_23_deserialize();
}
},4,1);

_j(_bb29_termite_23_deserialize = () => {
_a = _s[_t-1];
_b = _bb1_termite_23_deserialize_2d_hook;
_r = _bb30_termite_23_deserialize;
_n = 2;
_t -= 3;
return _g["u8vector->object"]();
});

_j(_bb27_termite_23_deserialize = () => {
_b = _X(_cst210__termite,_X(_s[_t],_X(_cst211__termite,_X(_s[_t-2],null))));
_a = _cst212__termite;
_r = _s[_t-3];
return _p(_bb28_termite_23_deserialize);
});

_k(_bb30_termite_23_deserialize = () => {
if (_v(_a)) {
return _bb31_termite_23_deserialize();
} else {
return _bb33_termite_23_deserialize();
}
},1,1);

_j(_bb28_termite_23_deserialize = () => {
_n = 2;
_t -= 4;
return _g["##error"]();
});

_j(_bb31_termite_23_deserialize = () => {
_r = _s[_t];
return _p(_bb32_termite_23_deserialize);
});

_j(_bb33_termite_23_deserialize = () => {
--_t;
return _s[_t+1]();
});

_j(_bb32_termite_23_deserialize = () => {
_n = 1;
--_t;
return _e["##vector->list"]();
});



_m(_bb1_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_start_2d_serializing_2d_output_2d_port);
}
var closure0 = _closure_alloc([_bb87_termite_23_start_2d_serializing_2d_output_2d_port,_a]);
_s[_t+1] = closure0;
_a = _s[_t+1];
_c = _cst214__termite;
_b = _cst15__termite;
++_t;
return _p(_bb2_termite_23_start_2d_serializing_2d_output_2d_port);
},-1,_i("termite#start-serializing-output-port"),!1,!0);

_l(_bb87_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _p(_bb90_termite_23_start_2d_serializing_2d_output_2d_port);
},1);

_j(_bb2_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_n = 3;
--_t;
return _bb3_termite_23_start_2d_serializing_2d_output_2d_port();
});

_j(_bb90_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb91_termite_23_start_2d_serializing_2d_output_2d_port);
});

_l(_bb3_termite_23_start_2d_serializing_2d_output_2d_port = () => {
var error = _build_key(1,2,[_cst15__termite,_cst160__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_start_2d_serializing_2d_output_2d_port,error);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _cst16__termite;
_c = _b;
_b = _cst15__termite;
_a = _current_processor.a[14];
_a = _X(_a,null);
_t += 3;
return _p(_bb4_termite_23_start_2d_serializing_2d_output_2d_port);
},-1);

_j(_bb91_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb92_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb4_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb85_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 5;
return _bb5_termite_23_start_2d_serializing_2d_output_2d_port();
});

_k(_bb92_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb93_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb94_termite_23_start_2d_serializing_2d_output_2d_port();
}
},2,1);

_l(_bb5_termite_23_start_2d_serializing_2d_output_2d_port = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb5_termite_23_start_2d_serializing_2d_output_2d_port,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb10_termite_23_start_2d_serializing_2d_output_2d_port,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb6_termite_23_start_2d_serializing_2d_output_2d_port);
},-1);

_k(_bb85_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _a;
_r = _bb86_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
++_t;
return _bb1_termite_23_outbound_2d_link();
},1,1);

_j(_bb93_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _a;
_r = _bb110_termite_23_start_2d_serializing_2d_output_2d_port;
++_t;
return _bb99_termite_23_start_2d_serializing_2d_output_2d_port();
});

_j(_bb94_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_x(_a)) {
return _bb95_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb102_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_l(_bb10_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb11_termite_23_start_2d_serializing_2d_output_2d_port);
},1);

_j(_bb6_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb7_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
--_t;
return _g["make-thread"]();
});

_k(_bb86_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
},2,1);

_j(_bb99_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb100_termite_23_start_2d_serializing_2d_output_2d_port);
});

_k(_bb110_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_r = _bb88_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
--_t;
return _g["##raise"]();
},3,1);

_j(_bb95_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.b;
_c = _a.a;
if (_c === _cst215__termite) {
return _bb96_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb102_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb102_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _a;
_r = _bb103_termite_23_start_2d_serializing_2d_output_2d_port;
++_t;
return _bb99_termite_23_start_2d_serializing_2d_output_2d_port();
});

_j(_bb11_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb12_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb7_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb8_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb100_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb101_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb88_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb89_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb96_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_x(_b)) {
return _bb97_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb102_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb103_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_r = _bb88_termite_23_start_2d_serializing_2d_output_2d_port;
--_t;
return _bb104_termite_23_start_2d_serializing_2d_output_2d_port();
},3,1);

_k(_bb12_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _current_processor.a[14];
_r = _bb13_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb8_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_r = _bb9_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb101_termite_23_start_2d_serializing_2d_output_2d_port = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb89_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb90_termite_23_start_2d_serializing_2d_output_2d_port);
});

_j(_bb97_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_c = _b.b;
_b = _b.a;
if (_c === null) {
return _bb98_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb102_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb104_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a;
_a = _cst216__termite;
return _p(_bb105_termite_23_start_2d_serializing_2d_output_2d_port);
});

_k(_bb13_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb83_termite_23_start_2d_serializing_2d_output_2d_port;
return _bb14_termite_23_start_2d_serializing_2d_output_2d_port();
},1,1);

_k(_bb9_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb98_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_s[_t+1] = _b;
_r = _bb108_termite_23_start_2d_serializing_2d_output_2d_port;
++_t;
return _bb99_termite_23_start_2d_serializing_2d_output_2d_port();
});

_j(_bb105_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_n = 2;
return _bb106_termite_23_start_2d_serializing_2d_output_2d_port();
});

_j(_bb14_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_x(_a)) {
return _bb18_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb82_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb83_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb84_termite_23_start_2d_serializing_2d_output_2d_port);
},1,1);

_k(_bb108_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _bb109_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
--_t;
return _bb1_termite_23_serialize();
},3,1);

_l(_bb106_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb106_termite_23_start_2d_serializing_2d_output_2d_port);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb107_termite_23_start_2d_serializing_2d_output_2d_port);
},-1);

_j(_bb18_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb19_termite_23_start_2d_serializing_2d_output_2d_port);
});

_j(_bb82_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = void 0;
return _r;
});

_j(_bb84_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb109_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t];
_r = _bb88_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
return _g["##force-output"]();
},2,1);

_j(_bb107_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_j(_bb19_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_r = _bb20_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
return _g["thread?"]();
});

_k(_bb20_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb81_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb21_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb81_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb23_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb21_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb22_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb80_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb23_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb24_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb22_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb23_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb80_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb23_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb24_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb25_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb25_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb26_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb67_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb26_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb79_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb27_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb79_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb29_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb27_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb28_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb78_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb29_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb30_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb28_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb29_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb78_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb29_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb30_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb31_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb31_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb32_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb32_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb77_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb33_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb77_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb35_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb33_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb34_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb76_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb35_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb36_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb34_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb35_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb76_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb35_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb36_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb37_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb37_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb38_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb38_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb75_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb39_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb75_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb41_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb39_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb40_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb74_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb41_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb42_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb40_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb41_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb74_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb41_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb42_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb43_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb43_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb44_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb44_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb73_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb45_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb73_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb47_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb45_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb46_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb72_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb47_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb48_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb46_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb47_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb72_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb47_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb48_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb49_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb49_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb50_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb50_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb71_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb51_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb71_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb53_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb51_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb52_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb70_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb53_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb54_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb52_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb53_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb70_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb53_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb54_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb55_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb55_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb56_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb56_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb69_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb57_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb69_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb59_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb57_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb58_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb68_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb59_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb60_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb58_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb59_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb68_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb59_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb60_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb61_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb67_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_j(_bb61_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb62_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb62_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (!(_a === !1)) {
return _bb66_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb63_termite_23_start_2d_serializing_2d_output_2d_port();
}
},4,1);

_j(_bb66_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb15_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb63_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb64_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb65_termite_23_start_2d_serializing_2d_output_2d_port();
}
});

_k(_bb15_termite_23_start_2d_serializing_2d_output_2d_port = () => {
return _bb16_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb64_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb15_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb65_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb15_termite_23_start_2d_serializing_2d_output_2d_port;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb16_termite_23_start_2d_serializing_2d_output_2d_port = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb17_termite_23_start_2d_serializing_2d_output_2d_port);
});

_j(_bb17_termite_23_start_2d_serializing_2d_output_2d_port = () => {
if (_x(_a)) {
return _bb18_termite_23_start_2d_serializing_2d_output_2d_port();
} else {
return _bb82_termite_23_start_2d_serializing_2d_output_2d_port();
}
});



_m(_bb1_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
}
var closure0 = _closure_alloc([_bb31_termite_23_start_2d_serializing_2d_active_2d_input_2d_port,_a,_b]);
_s[_t+1] = closure0;
_a = _s[_t+1];
_c = _cst218__termite;
_b = _cst15__termite;
++_t;
return _p(_bb2_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},-1,_i("termite#start-serializing-active-input-port"),!1,!0);

_l(_bb31_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_b = _d(!0)[2];
_a = _d(!0)[1];
return _p(_bb33_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},2);

_j(_bb2_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_n = 3;
--_t;
return _bb3_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
});

_j(_bb33_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb34_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
});

_l(_bb3_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
var error = _build_key(1,2,[_cst15__termite,_cst160__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_start_2d_serializing_2d_active_2d_input_2d_port,error);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _cst16__termite;
_c = _b;
_b = _cst15__termite;
_a = _current_processor.a[14];
_a = _X(_a,null);
_t += 3;
return _p(_bb4_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},-1);

_j(_bb34_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_r = _bb35_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 1;
return _bb1_termite_23_deserialize();
});

_j(_bb4_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_r = _bb14_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 5;
return _bb5_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
});

_k(_bb35_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_s[_t+1] = _a;
_b = _cst219__termite;
_a = 0;
_r = _bb36_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 2;
++_t;
return _bb1_termite_23__3f_();
},3,1);

_l(_bb5_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb5_termite_23_start_2d_serializing_2d_active_2d_input_2d_port,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb10_termite_23_start_2d_serializing_2d_active_2d_input_2d_port,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb6_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},-1);

_k(_bb14_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_b = _current_processor.a[14];
_s[_t+1] = _a;
_a = _b;
_r = _bb15_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 1;
++_t;
return _g["thread-specific"]();
},1,1);

_k(_bb36_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (_s[_t] === _eof_obj) {
return _bb37_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb39_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
},4,1);

_l(_bb10_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb11_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},1);

_j(_bb6_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_r = _bb7_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 2;
--_t;
return _g["make-thread"]();
});

_k(_bb15_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_s[_t+1] = _a;
_b = _a;
_a = _s[_t];
_r = _bb26_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
++_t;
return _bb16_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
},2,1);

_j(_bb37_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_r = _bb38_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 0;
return _bb1_termite_23_shutdown_21_();
});

_j(_bb39_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = _current_processor.a[14];
_b = _X(_a,_X(_s[_t],null));
_a = _s[_t-1];
_r = _bb32_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 2;
--_t;
return _bb1_termite_23__21_();
});

_j(_bb11_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_r = _bb12_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb7_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb8_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb16_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (_x(_b)) {
return _bb23_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb25_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});

_k(_bb26_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (!(_a === !1)) {
return _bb27_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb30_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
},3,1);

_k(_bb38_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
return _bb39_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
},4,1);

_k(_bb32_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb33_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},3,1);

_k(_bb12_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_r = _s[_t];
return _p(_bb13_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
},1,1);

_k(_bb8_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = _s[_t];
_r = _bb9_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb23_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_c = _b.a;
if (_a === _c) {
return _bb24_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb17_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});

_j(_bb25_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = !1;
return _r;
});

_j(_bb27_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
--_t;
return _bb29_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
});

_j(_bb30_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = _X(_s[_t-1],_s[_t]);
_b = _current_processor.a[14];
_s[_t] = _b;
_b = _a;
_a = _s[_t];
_r = _bb28_termite_23_start_2d_serializing_2d_active_2d_input_2d_port;
_n = 2;
--_t;
return _g["thread-specific-set!"]();
});

_j(_bb13_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_k(_bb9_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb24_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = _b;
return _r;
});

_j(_bb17_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_b = _b.b;
if (_x(_b)) {
return _bb18_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb25_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});

_j(_bb29_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
});

_k(_bb28_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
return _bb29_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
},2,1);

_j(_bb18_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_c = _b.a;
if (_a === _c) {
return _bb24_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb19_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});

_j(_bb19_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_b = _b.b;
if (_x(_b)) {
return _bb20_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb25_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});

_j(_bb20_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_c = _b.a;
if (_a === _c) {
return _bb24_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb21_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});

_j(_bb21_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
_b = _b.b;
return _p(_bb22_termite_23_start_2d_serializing_2d_active_2d_input_2d_port);
});

_j(_bb22_termite_23_start_2d_serializing_2d_active_2d_input_2d_port = () => {
if (_x(_b)) {
return _bb23_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
} else {
return _bb25_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
}
});



_m(_bb1_termite_23_start_2d_tcp_2d_server = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_start_2d_tcp_2d_server);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_start_2d_tcp_2d_server);
},-1,_i("termite#start-tcp-server"),!1,!0);

_j(_bb2_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb3_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _bb1_termite_23_node_2d_host();
});

_k(_bb3_termite_23_start_2d_tcp_2d_server = () => {
_s[_t+1] = _a;
_a = _s[_t-1];
_r = _bb4_termite_23_start_2d_tcp_2d_server;
_n = 1;
++_t;
return _bb1_termite_23_node_2d_port();
},3,1);

_k(_bb4_termite_23_start_2d_tcp_2d_server = () => {
_a = _X(_cst220__termite,_X(_s[_t],_X(_cst221__termite,_X(_a,_X(_cst222__termite,_X(!1,null))))));
_r = _bb5_termite_23_start_2d_tcp_2d_server;
_n = 1;
--_t;
return _g["open-tcp-server"]();
},4,1);

_k(_bb5_termite_23_start_2d_tcp_2d_server = () => {
_s[_t+1] = _a;
var closure0 = _closure_alloc([_bb74_termite_23_start_2d_tcp_2d_server,_s[_t],_a]);
_s[_t+2] = closure0;
_a = _s[_t+2];
_c = _cst224__termite;
_b = _cst15__termite;
_r = _bb15_termite_23_start_2d_tcp_2d_server;
_n = 3;
++_t;
return _bb6_termite_23_start_2d_tcp_2d_server();
},3,1);

_l(_bb74_termite_23_start_2d_tcp_2d_server = () => {
if (_n !== 0) {
return _w(_d);
}
_b = _d(!0)[2];
_a = _d(!0)[1];
return _p(_bb76_termite_23_start_2d_tcp_2d_server);
},2);

_l(_bb6_termite_23_start_2d_tcp_2d_server = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb6_termite_23_start_2d_tcp_2d_server,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb11_termite_23_start_2d_tcp_2d_server,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb7_termite_23_start_2d_tcp_2d_server);
},-1);

_k(_bb15_termite_23_start_2d_tcp_2d_server = () => {
if (_stringp(_s[_t-2])) {
return _bb16_termite_23_start_2d_tcp_2d_server();
} else {
return _bb73_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_j(_bb76_termite_23_start_2d_tcp_2d_server = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_r = _bb77_termite_23_start_2d_tcp_2d_server;
_n = 1;
_t += 3;
return _e["##read"]();
});

_l(_bb11_termite_23_start_2d_tcp_2d_server = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb12_termite_23_start_2d_tcp_2d_server);
},1);

_j(_bb7_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb8_termite_23_start_2d_tcp_2d_server;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb16_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-2];
_b = _cst134__termite;
_r = _bb17_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##string-contains"]();
});

_j(_bb73_termite_23_start_2d_tcp_2d_server = () => {
_b = _s[_t-2];
_a = _cst135__termite;
_r = _bb19_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##error"]();
});

_k(_bb77_termite_23_start_2d_tcp_2d_server = () => {
return _p(_bb78_termite_23_start_2d_tcp_2d_server);
},3,1);

_j(_bb12_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb13_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb8_termite_23_start_2d_tcp_2d_server = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb9_termite_23_start_2d_tcp_2d_server;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb17_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb72_termite_23_start_2d_tcp_2d_server();
} else {
return _bb18_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb19_termite_23_start_2d_tcp_2d_server = () => {
return _bb20_termite_23_start_2d_tcp_2d_server();
},4,1);

_j(_bb78_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb79_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _s[_t-1]();
});

_k(_bb13_termite_23_start_2d_tcp_2d_server = () => {
_r = _s[_t];
return _p(_bb14_termite_23_start_2d_tcp_2d_server);
},1,1);

_k(_bb9_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_r = _bb10_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb72_termite_23_start_2d_tcp_2d_server = () => {
_c = _a;
_a = _s[_t-2];
_b = 0;
_r = _bb19_termite_23_start_2d_tcp_2d_server;
_n = 3;
return _e["##substring"]();
});

_j(_bb18_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-2];
return _bb20_termite_23_start_2d_tcp_2d_server();
});

_j(_bb20_termite_23_start_2d_tcp_2d_server = () => {
_b = _a;
_a = _cst226__termite;
_r = _bb21_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _e["##equal?"]();
});

_k(_bb79_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_r = _bb80_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##read"]();
},3,1);

_j(_bb14_termite_23_start_2d_tcp_2d_server = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_k(_bb10_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_k(_bb21_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb22_termite_23_start_2d_tcp_2d_server();
} else {
return _bb69_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb80_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb81_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _s[_t-1]();
},3,1);

_j(_bb22_termite_23_start_2d_tcp_2d_server = () => {
_a = _cst227__termite;
if (_stringp(_s[_t-2])) {
return _bb25_termite_23_start_2d_tcp_2d_server();
} else {
return _bb68_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb69_termite_23_start_2d_tcp_2d_server = () => {
if (_stringp(_s[_t-2])) {
return _bb70_termite_23_start_2d_tcp_2d_server();
} else {
return _bb71_termite_23_start_2d_tcp_2d_server();
}
});

_k(_bb81_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_r = _bb82_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##read"]();
},3,1);

_j(_bb25_termite_23_start_2d_tcp_2d_server = () => {
_s[_t-1] = _a;
_a = _s[_t-2];
_b = _cst138__termite;
_r = _bb26_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##string-contains"]();
});

_j(_bb68_termite_23_start_2d_tcp_2d_server = () => {
_s[_t-1] = _a;
_b = _s[_t-2];
_a = _cst139__termite;
_r = _bb62_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##error"]();
});

_j(_bb70_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-2];
_b = _cst134__termite;
_r = _bb23_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##string-contains"]();
});

_j(_bb71_termite_23_start_2d_tcp_2d_server = () => {
_b = _s[_t-2];
_a = _cst135__termite;
_r = _bb67_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##error"]();
});

_k(_bb82_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb83_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _s[_t-1]();
},3,1);

_k(_bb26_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb27_termite_23_start_2d_tcp_2d_server();
} else {
return _bb34_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb62_termite_23_start_2d_tcp_2d_server = () => {
if (_y(_a)) {
return _bb35_termite_23_start_2d_tcp_2d_server();
} else {
return _bb63_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb23_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb66_termite_23_start_2d_tcp_2d_server();
} else {
return _bb24_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb67_termite_23_start_2d_tcp_2d_server = () => {
if (_stringp(_s[_t-2])) {
return _bb25_termite_23_start_2d_tcp_2d_server();
} else {
return _bb68_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb83_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_r = _bb84_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##read"]();
},3,1);

_j(_bb27_termite_23_start_2d_tcp_2d_server = () => {
if (_y(_a)) {
return _bb28_termite_23_start_2d_tcp_2d_server();
} else {
return _bb65_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb34_termite_23_start_2d_tcp_2d_server = () => {
_a = 0;
if (_y(_a)) {
return _bb35_termite_23_start_2d_tcp_2d_server();
} else {
return _bb63_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb35_termite_23_start_2d_tcp_2d_server = () => {
if (0 === _a) {
return _bb60_termite_23_start_2d_tcp_2d_server();
} else {
return _bb36_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb63_termite_23_start_2d_tcp_2d_server = () => {
_b = _a;
_a = 0;
_r = _bb59_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _e["##="]();
});

_j(_bb66_termite_23_start_2d_tcp_2d_server = () => {
_c = _a;
_a = _s[_t-2];
_b = 0;
_r = _bb67_termite_23_start_2d_tcp_2d_server;
_n = 3;
return _e["##substring"]();
});

_j(_bb24_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-2];
if (_stringp(_s[_t-2])) {
return _bb25_termite_23_start_2d_tcp_2d_server();
} else {
return _bb68_termite_23_start_2d_tcp_2d_server();
}
});

_k(_bb84_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb85_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _s[_t-1]();
},3,1);

_j(_bb28_termite_23_start_2d_tcp_2d_server = () => {
_b = (_h = (_o = _a + 1)<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb30_termite_23_start_2d_tcp_2d_server();
} else {
return _bb65_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb65_termite_23_start_2d_tcp_2d_server = () => {
_b = 1;
_r = _bb29_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _e["##+"]();
});

_j(_bb60_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_r = _bb61_termite_23_start_2d_tcp_2d_server;
_n = 1;
--_t;
return _g["tcp-server-socket-info"]();
});

_j(_bb36_termite_23_start_2d_tcp_2d_server = () => {
if (_stringp(_s[_t-2])) {
return _bb37_termite_23_start_2d_tcp_2d_server();
} else {
return _bb58_termite_23_start_2d_tcp_2d_server();
}
});

_k(_bb59_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb60_termite_23_start_2d_tcp_2d_server();
} else {
return _bb36_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_k(_bb85_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t];
_r = _bb86_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##read"]();
},3,1);

_j(_bb30_termite_23_start_2d_tcp_2d_server = () => {
_c = _s[_t-2].a.length;
_a = _s[_t-2];
_r = _bb31_termite_23_start_2d_tcp_2d_server;
_n = 3;
return _e["##substring"]();
});

_k(_bb29_termite_23_start_2d_tcp_2d_server = () => {
_b = _a;
return _bb30_termite_23_start_2d_tcp_2d_server();
},4,1);

_k(_bb61_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb56_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _g["socket-info-port-number"]();
},3,1);

_j(_bb37_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-2];
_b = _cst138__termite;
_r = _bb38_termite_23_start_2d_tcp_2d_server;
_n = 2;
--_t;
return _g["##string-contains"]();
});

_j(_bb58_termite_23_start_2d_tcp_2d_server = () => {
_b = _s[_t-2];
_a = _cst139__termite;
_r = _bb56_termite_23_start_2d_tcp_2d_server;
_n = 2;
--_t;
return _g["##error"]();
});

_k(_bb86_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb75_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _s[_t-1]();
},3,1);

_k(_bb31_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb32_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##string->number"]();
},4,1);

_k(_bb56_termite_23_start_2d_tcp_2d_server = () => {
if (_stringp(_s[_t])) {
return _bb54_termite_23_start_2d_tcp_2d_server();
} else {
return _bb48_termite_23_start_2d_tcp_2d_server();
}
},3,1);

_k(_bb38_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb39_termite_23_start_2d_tcp_2d_server();
} else {
return _bb53_termite_23_start_2d_tcp_2d_server();
}
},3,1);

_k(_bb75_termite_23_start_2d_tcp_2d_server = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb76_termite_23_start_2d_tcp_2d_server);
},3,1);

_k(_bb32_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb33_termite_23_start_2d_tcp_2d_server();
} else {
return _bb64_termite_23_start_2d_tcp_2d_server();
}
},4,1);

_j(_bb54_termite_23_start_2d_tcp_2d_server = () => {
_s[_t-1] = _a;
_r = _bb46_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##number?"]();
});

_j(_bb48_termite_23_start_2d_tcp_2d_server = () => {
_c = _a;
_b = _s[_t];
_a = _cst130__termite;
_r = _s[_t-2];
return _p(_bb49_termite_23_start_2d_tcp_2d_server);
});

_j(_bb39_termite_23_start_2d_tcp_2d_server = () => {
if (_y(_a)) {
return _bb40_termite_23_start_2d_tcp_2d_server();
} else {
return _bb57_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb53_termite_23_start_2d_tcp_2d_server = () => {
_a = 0;
if (_stringp(_s[_t])) {
return _bb54_termite_23_start_2d_tcp_2d_server();
} else {
return _bb48_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb33_termite_23_start_2d_tcp_2d_server = () => {
if (_y(_a)) {
return _bb35_termite_23_start_2d_tcp_2d_server();
} else {
return _bb63_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb64_termite_23_start_2d_tcp_2d_server = () => {
_b = _s[_t-2];
_a = _cst139__termite;
_r = _bb62_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##error"]();
});

_k(_bb46_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb50_termite_23_start_2d_tcp_2d_server();
} else {
return _bb47_termite_23_start_2d_tcp_2d_server();
}
},3,1);

_j(_bb49_termite_23_start_2d_tcp_2d_server = () => {
_n = 3;
_t -= 3;
return _g["##error"]();
});

_j(_bb40_termite_23_start_2d_tcp_2d_server = () => {
_b = (_h = (_o = _a + 1)<<2>>2) === _o && _h;
if (!(_b === !1)) {
return _bb42_termite_23_start_2d_tcp_2d_server();
} else {
return _bb57_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb57_termite_23_start_2d_tcp_2d_server = () => {
_b = 1;
_r = _bb41_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _e["##+"]();
});

_j(_bb50_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-1];
_r = _bb51_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##number->string"]();
});

_j(_bb47_termite_23_start_2d_tcp_2d_server = () => {
_a = _s[_t-1];
return _bb48_termite_23_start_2d_tcp_2d_server();
});

_j(_bb42_termite_23_start_2d_tcp_2d_server = () => {
_c = _s[_t-1].a.length;
_a = _s[_t-1];
_r = _bb43_termite_23_start_2d_tcp_2d_server;
_n = 3;
return _e["##substring"]();
});

_k(_bb41_termite_23_start_2d_tcp_2d_server = () => {
_b = _a;
return _bb42_termite_23_start_2d_tcp_2d_server();
},3,1);

_k(_bb51_termite_23_start_2d_tcp_2d_server = () => {
_c = _a;
_a = _s[_t];
_b = _cst132__termite;
_r = _s[_t-2];
return _p(_bb52_termite_23_start_2d_tcp_2d_server);
},3,1);

_k(_bb43_termite_23_start_2d_tcp_2d_server = () => {
_r = _bb44_termite_23_start_2d_tcp_2d_server;
_n = 1;
return _e["##string->number"]();
},3,1);

_j(_bb52_termite_23_start_2d_tcp_2d_server = () => {
_n = 3;
_t -= 3;
return _e["##string-append"]();
});

_k(_bb44_termite_23_start_2d_tcp_2d_server = () => {
if (!(_a === !1)) {
return _bb45_termite_23_start_2d_tcp_2d_server();
} else {
return _bb55_termite_23_start_2d_tcp_2d_server();
}
},3,1);

_j(_bb45_termite_23_start_2d_tcp_2d_server = () => {
if (_stringp(_s[_t])) {
return _bb54_termite_23_start_2d_tcp_2d_server();
} else {
return _bb48_termite_23_start_2d_tcp_2d_server();
}
});

_j(_bb55_termite_23_start_2d_tcp_2d_server = () => {
_b = _s[_t-1];
_a = _cst139__termite;
_r = _bb56_termite_23_start_2d_tcp_2d_server;
_n = 2;
return _g["##error"]();
});



_m(_bb1_termite_23_initiate_2d_messenger = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_initiate_2d_messenger);
}
var closure0 = _closure_alloc([_bb35_termite_23_initiate_2d_messenger,_a]);
_s[_t+1] = closure0;
_a = _s[_t+1];
_c = _cst230__termite;
_b = _cst15__termite;
++_t;
return _p(_bb2_termite_23_initiate_2d_messenger);
},-1,_i("termite#initiate-messenger"),!1,!0);

_l(_bb35_termite_23_initiate_2d_messenger = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _bb60_termite_23_initiate_2d_messenger;
var closure1 = _closure_alloc([_bb37_termite_23_initiate_2d_messenger,_d(!0)[1]]);
_s[_t+2] = closure1;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb36_termite_23_initiate_2d_messenger);
},1);

_j(_bb2_termite_23_initiate_2d_messenger = () => {
_n = 3;
--_t;
return _bb3_termite_23_initiate_2d_messenger();
});

_l(_bb60_termite_23_initiate_2d_messenger = () => {
if (_n !== 1) {
return _w(_bb60_termite_23_initiate_2d_messenger);
}
_a = _current_processor.a[14];
_a = _X(_cst73__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#dispatcher"];
_t += 2;
return _p(_bb61_termite_23_initiate_2d_messenger);
},-1);

_l(_bb37_termite_23_initiate_2d_messenger = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_r = _d(!0)[1];
if (_stringp(_r)) {
_t += 2;
return _bb38_termite_23_initiate_2d_messenger();
} else {
_t += 2;
return _bb58_termite_23_initiate_2d_messenger();
}
},1);

_j(_bb36_termite_23_initiate_2d_messenger = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_l(_bb3_termite_23_initiate_2d_messenger = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_initiate_2d_messenger,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure2 = _closure_alloc([_bb8_termite_23_initiate_2d_messenger,_a]);
_s[_t+3] = closure2;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb4_termite_23_initiate_2d_messenger);
},-1);

_j(_bb61_termite_23_initiate_2d_messenger = () => {
_r = _bb62_termite_23_initiate_2d_messenger;
_n = 1;
return _g["thread?"]();
});

_j(_bb38_termite_23_initiate_2d_messenger = () => {
_a = _d(!0)[1];
_b = _cst134__termite;
return _p(_bb39_termite_23_initiate_2d_messenger);
});

_j(_bb58_termite_23_initiate_2d_messenger = () => {
_b = _d(!0)[1];
_a = _cst135__termite;
return _p(_bb59_termite_23_initiate_2d_messenger);
});

_l(_bb8_termite_23_initiate_2d_messenger = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb9_termite_23_initiate_2d_messenger);
},1);

_j(_bb4_termite_23_initiate_2d_messenger = () => {
_r = _bb5_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["make-thread"]();
});

_k(_bb62_termite_23_initiate_2d_messenger = () => {
if (!(_a === !1)) {
return _bb69_termite_23_initiate_2d_messenger();
} else {
return _bb63_termite_23_initiate_2d_messenger();
}
},2,1);

_j(_bb39_termite_23_initiate_2d_messenger = () => {
_r = _bb40_termite_23_initiate_2d_messenger;
_n = 2;
return _g["##string-contains"]();
});

_j(_bb59_termite_23_initiate_2d_messenger = () => {
_r = _bb42_termite_23_initiate_2d_messenger;
_n = 2;
return _g["##error"]();
});

_j(_bb9_termite_23_initiate_2d_messenger = () => {
_r = _bb10_termite_23_initiate_2d_messenger;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb5_termite_23_initiate_2d_messenger = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb6_termite_23_initiate_2d_messenger;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb69_termite_23_initiate_2d_messenger = () => {
_b = _s[_t];
_a = _g["termite#dispatcher"];
_r = _bb65_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb63_termite_23_initiate_2d_messenger = () => {
if (_g["termite#dispatcher"] instanceof _Structure && _g["termite#dispatcher"].a[0].a[1] === _cst83__termite) {
return _bb64_termite_23_initiate_2d_messenger();
} else {
return _bb68_termite_23_initiate_2d_messenger();
}
});

_k(_bb40_termite_23_initiate_2d_messenger = () => {
if (!(_a === !1)) {
return _bb57_termite_23_initiate_2d_messenger();
} else {
return _bb41_termite_23_initiate_2d_messenger();
}
},2,1);

_k(_bb42_termite_23_initiate_2d_messenger = () => {
return _bb43_termite_23_initiate_2d_messenger();
},2,1);

_k(_bb10_termite_23_initiate_2d_messenger = () => {
_a = _current_processor.a[14];
_r = _bb11_termite_23_initiate_2d_messenger;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb6_termite_23_initiate_2d_messenger = () => {
_a = _s[_t];
_r = _bb7_termite_23_initiate_2d_messenger;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb65_termite_23_initiate_2d_messenger = () => {
return _bb66_termite_23_initiate_2d_messenger();
},1,1);

_j(_bb64_termite_23_initiate_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_g["termite#dispatcher"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb65_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb68_termite_23_initiate_2d_messenger = () => {
_b = _g["termite#dispatcher"];
_a = _cst87__termite;
_r = _bb65_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["##error"]();
});

_j(_bb57_termite_23_initiate_2d_messenger = () => {
_c = _a;
_a = _s[_t](!0)[1];
_b = 0;
_r = _bb42_termite_23_initiate_2d_messenger;
_n = 3;
return _e["##substring"]();
});

_j(_bb41_termite_23_initiate_2d_messenger = () => {
_a = _s[_t](!0)[1];
return _bb43_termite_23_initiate_2d_messenger();
});

_j(_bb43_termite_23_initiate_2d_messenger = () => {
_s[_t+1] = _a;
_a = _s[_t](!0)[1];
_r = _bb44_termite_23_initiate_2d_messenger;
_n = 1;
++_t;
return _bb1_termite_23_node_2d_port();
});

_k(_bb11_termite_23_initiate_2d_messenger = () => {
_r = _bb33_termite_23_initiate_2d_messenger;
return _bb12_termite_23_initiate_2d_messenger();
},1,1);

_k(_bb7_termite_23_initiate_2d_messenger = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb66_termite_23_initiate_2d_messenger = () => {
_r = _s[_t];
return _p(_bb67_termite_23_initiate_2d_messenger);
});

_k(_bb44_termite_23_initiate_2d_messenger = () => {
_a = _X(_cst231__termite,_X(_s[_t],_X(_cst232__termite,_X(_a,_X(_cst222__termite,_X(!1,null))))));
_r = _bb45_termite_23_initiate_2d_messenger;
_n = 1;
--_t;
return _g["open-tcp-client"]();
},3,1);

_j(_bb12_termite_23_initiate_2d_messenger = () => {
if (_x(_a)) {
return _bb16_termite_23_initiate_2d_messenger();
} else {
return _bb32_termite_23_initiate_2d_messenger();
}
});

_k(_bb33_termite_23_initiate_2d_messenger = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb34_termite_23_initiate_2d_messenger);
},1,1);

_j(_bb67_termite_23_initiate_2d_messenger = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_k(_bb45_termite_23_initiate_2d_messenger = () => {
_s[_t+1] = _a;
_b = _current_processor.a[14];
_r = _bb46_termite_23_initiate_2d_messenger;
_n = 2;
++_t;
return _bb1_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
},2,1);

_j(_bb16_termite_23_initiate_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb17_termite_23_initiate_2d_messenger);
});

_j(_bb32_termite_23_initiate_2d_messenger = () => {
_a = void 0;
return _r;
});

_j(_bb34_termite_23_initiate_2d_messenger = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb46_termite_23_initiate_2d_messenger = () => {
_s[_t+1] = _a;
_a = _s[_t];
_r = _bb47_termite_23_initiate_2d_messenger;
_n = 1;
++_t;
return _bb1_termite_23_start_2d_serializing_2d_output_2d_port();
},3,1);

_j(_bb17_termite_23_initiate_2d_messenger = () => {
_r = _bb18_termite_23_initiate_2d_messenger;
_n = 1;
return _g["thread?"]();
});

_k(_bb47_termite_23_initiate_2d_messenger = () => {
_s[_t-1] = _a;
_r = _bb48_termite_23_initiate_2d_messenger;
_n = 0;
return _g["termite#current-node"]();
},4,1);

_k(_bb18_termite_23_initiate_2d_messenger = () => {
if (!(_a === !1)) {
return _bb31_termite_23_initiate_2d_messenger();
} else {
return _bb19_termite_23_initiate_2d_messenger();
}
},4,1);

_k(_bb48_termite_23_initiate_2d_messenger = () => {
_a = _X(_cst215__termite,_X(_a,null));
_s[_t+1] = _a;
_a = _s[_t-1];
_r = _bb49_termite_23_initiate_2d_messenger;
_n = 1;
++_t;
return _g["thread?"]();
},4,1);

_j(_bb31_termite_23_initiate_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb21_termite_23_initiate_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb19_termite_23_initiate_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb20_termite_23_initiate_2d_messenger();
} else {
return _bb30_termite_23_initiate_2d_messenger();
}
});

_k(_bb49_termite_23_initiate_2d_messenger = () => {
if (!(_a === !1)) {
return _bb56_termite_23_initiate_2d_messenger();
} else {
return _bb50_termite_23_initiate_2d_messenger();
}
},5,1);

_k(_bb21_termite_23_initiate_2d_messenger = () => {
return _bb22_termite_23_initiate_2d_messenger();
},2,1);

_j(_bb20_termite_23_initiate_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb21_termite_23_initiate_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb30_termite_23_initiate_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb21_termite_23_initiate_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb56_termite_23_initiate_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-2];
_r = _bb52_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb50_termite_23_initiate_2d_messenger = () => {
if (_s[_t-2] instanceof _Structure && _s[_t-2].a[0].a[1] === _cst83__termite) {
return _bb51_termite_23_initiate_2d_messenger();
} else {
return _bb55_termite_23_initiate_2d_messenger();
}
});

_j(_bb22_termite_23_initiate_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb23_termite_23_initiate_2d_messenger();
} else {
return _bb29_termite_23_initiate_2d_messenger();
}
});

_k(_bb52_termite_23_initiate_2d_messenger = () => {
return _bb53_termite_23_initiate_2d_messenger();
},4,1);

_j(_bb51_termite_23_initiate_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-2],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb52_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb55_termite_23_initiate_2d_messenger = () => {
_b = _s[_t-2];
_a = _cst87__termite;
_r = _bb52_termite_23_initiate_2d_messenger;
_n = 2;
--_t;
return _g["##error"]();
});

_j(_bb23_termite_23_initiate_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb24_termite_23_initiate_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb29_termite_23_initiate_2d_messenger = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb53_termite_23_initiate_2d_messenger = () => {
_c = _s[_t-1];
_b = _s[_t];
_a = _s[_t-2](!0)[1];
_r = _s[_t-3];
return _p(_bb54_termite_23_initiate_2d_messenger);
});

_k(_bb24_termite_23_initiate_2d_messenger = () => {
if (!(_a === !1)) {
return _bb28_termite_23_initiate_2d_messenger();
} else {
return _bb25_termite_23_initiate_2d_messenger();
}
},4,1);

_j(_bb54_termite_23_initiate_2d_messenger = () => {
_n = 3;
_t -= 4;
return _bb1_termite_23_messenger_2d_loop();
});

_j(_bb28_termite_23_initiate_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb13_termite_23_initiate_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb25_termite_23_initiate_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb26_termite_23_initiate_2d_messenger();
} else {
return _bb27_termite_23_initiate_2d_messenger();
}
});

_k(_bb13_termite_23_initiate_2d_messenger = () => {
return _bb14_termite_23_initiate_2d_messenger();
},2,1);

_j(_bb26_termite_23_initiate_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb13_termite_23_initiate_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb27_termite_23_initiate_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb13_termite_23_initiate_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb14_termite_23_initiate_2d_messenger = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb15_termite_23_initiate_2d_messenger);
});

_j(_bb15_termite_23_initiate_2d_messenger = () => {
if (_x(_a)) {
return _bb16_termite_23_initiate_2d_messenger();
} else {
return _bb32_termite_23_initiate_2d_messenger();
}
});



_m(_bb1_termite_23_start_2d_messenger = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_start_2d_messenger);
}
var closure0 = _closure_alloc([_bb83_termite_23_start_2d_messenger,_a]);
_s[_t+1] = closure0;
_a = _s[_t+1];
_c = _cst234__termite;
_b = _cst15__termite;
++_t;
return _p(_bb2_termite_23_start_2d_messenger);
},-1,_i("termite#start-messenger"),!1,!0);

_l(_bb83_termite_23_start_2d_messenger = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _bb110_termite_23_start_2d_messenger;
var closure1 = _closure_alloc([_bb85_termite_23_start_2d_messenger,_d(!0)[1]]);
_s[_t+2] = closure1;
_b = _s[_t+2];
_a = _s[_t+1];
_t += 2;
return _p(_bb84_termite_23_start_2d_messenger);
},1);

_j(_bb2_termite_23_start_2d_messenger = () => {
_n = 3;
--_t;
return _bb3_termite_23_start_2d_messenger();
});

_l(_bb110_termite_23_start_2d_messenger = () => {
if (_n !== 1) {
return _w(_bb110_termite_23_start_2d_messenger);
}
_a = _current_processor.a[14];
_a = _X(_cst73__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#dispatcher"];
_t += 2;
return _p(_bb111_termite_23_start_2d_messenger);
},-1);

_l(_bb85_termite_23_start_2d_messenger = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_a = _d(!0)[1];
_b = _current_processor.a[14];
_t += 2;
return _p(_bb86_termite_23_start_2d_messenger);
},1);

_j(_bb84_termite_23_start_2d_messenger = () => {
_n = 2;
_t -= 2;
return _e["##with-exception-catcher"]();
});

_l(_bb3_termite_23_start_2d_messenger = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb3_termite_23_start_2d_messenger,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure2 = _closure_alloc([_bb8_termite_23_start_2d_messenger,_a]);
_s[_t+3] = closure2;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb4_termite_23_start_2d_messenger);
},-1);

_j(_bb111_termite_23_start_2d_messenger = () => {
_r = _bb112_termite_23_start_2d_messenger;
_n = 1;
return _g["thread?"]();
});

_j(_bb86_termite_23_start_2d_messenger = () => {
_r = _bb87_termite_23_start_2d_messenger;
_n = 2;
return _bb1_termite_23_start_2d_serializing_2d_active_2d_input_2d_port();
});

_l(_bb8_termite_23_start_2d_messenger = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb9_termite_23_start_2d_messenger);
},1);

_j(_bb4_termite_23_start_2d_messenger = () => {
_r = _bb5_termite_23_start_2d_messenger;
_n = 2;
--_t;
return _g["make-thread"]();
});

_k(_bb112_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb119_termite_23_start_2d_messenger();
} else {
return _bb113_termite_23_start_2d_messenger();
}
},2,1);

_k(_bb87_termite_23_start_2d_messenger = () => {
_s[_t+1] = _a;
_a = _s[_t](!0)[1];
_r = _bb88_termite_23_start_2d_messenger;
_n = 1;
++_t;
return _bb1_termite_23_start_2d_serializing_2d_output_2d_port();
},2,1);

_j(_bb9_termite_23_start_2d_messenger = () => {
_r = _bb10_termite_23_start_2d_messenger;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb5_termite_23_start_2d_messenger = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb6_termite_23_start_2d_messenger;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb119_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _g["termite#dispatcher"];
_r = _bb115_termite_23_start_2d_messenger;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb113_termite_23_start_2d_messenger = () => {
if (_g["termite#dispatcher"] instanceof _Structure && _g["termite#dispatcher"].a[0].a[1] === _cst83__termite) {
return _bb114_termite_23_start_2d_messenger();
} else {
return _bb118_termite_23_start_2d_messenger();
}
});

_k(_bb88_termite_23_start_2d_messenger = () => {
_s[_t-1] = _a;
_r = _bb89_termite_23_start_2d_messenger;
_n = 0;
return _g["thread-mailbox-next"]();
},3,1);

_k(_bb10_termite_23_start_2d_messenger = () => {
_a = _current_processor.a[14];
_r = _bb11_termite_23_start_2d_messenger;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb6_termite_23_start_2d_messenger = () => {
_a = _s[_t];
_r = _bb7_termite_23_start_2d_messenger;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb115_termite_23_start_2d_messenger = () => {
return _bb116_termite_23_start_2d_messenger();
},1,1);

_j(_bb114_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_g["termite#dispatcher"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb115_termite_23_start_2d_messenger;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb118_termite_23_start_2d_messenger = () => {
_b = _g["termite#dispatcher"];
_a = _cst87__termite;
_r = _bb115_termite_23_start_2d_messenger;
_n = 2;
--_t;
return _g["##error"]();
});

_k(_bb89_termite_23_start_2d_messenger = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb90_termite_23_start_2d_messenger);
},3,1);

_k(_bb11_termite_23_start_2d_messenger = () => {
_r = _bb81_termite_23_start_2d_messenger;
return _bb12_termite_23_start_2d_messenger();
},1,1);

_k(_bb7_termite_23_start_2d_messenger = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb116_termite_23_start_2d_messenger = () => {
_r = _s[_t];
return _p(_bb117_termite_23_start_2d_messenger);
});

_j(_bb90_termite_23_start_2d_messenger = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _c;
_t += 4;
return _p(_bb91_termite_23_start_2d_messenger);
});

_j(_bb12_termite_23_start_2d_messenger = () => {
if (_x(_a)) {
return _bb16_termite_23_start_2d_messenger();
} else {
return _bb80_termite_23_start_2d_messenger();
}
});

_k(_bb81_termite_23_start_2d_messenger = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb82_termite_23_start_2d_messenger);
},1,1);

_j(_bb117_termite_23_start_2d_messenger = () => {
_n = 0;
--_t;
return _bb1_termite_23_shutdown_21_();
});

_j(_bb91_termite_23_start_2d_messenger = () => {
_r = _bb92_termite_23_start_2d_messenger;
_n = 1;
return _bb1_termite_23_termite_2d_exception_3f_();
});

_j(_bb16_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb17_termite_23_start_2d_messenger);
});

_j(_bb80_termite_23_start_2d_messenger = () => {
_a = void 0;
return _r;
});

_j(_bb82_termite_23_start_2d_messenger = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb92_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb93_termite_23_start_2d_messenger();
} else {
return _bb94_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb17_termite_23_start_2d_messenger = () => {
_r = _bb18_termite_23_start_2d_messenger;
_n = 1;
return _g["thread?"]();
});

_j(_bb93_termite_23_start_2d_messenger = () => {
_r = _bb108_termite_23_start_2d_messenger;
return _bb99_termite_23_start_2d_messenger();
});

_j(_bb94_termite_23_start_2d_messenger = () => {
if (_x(_s[_t])) {
return _bb95_termite_23_start_2d_messenger();
} else {
return _bb102_termite_23_start_2d_messenger();
}
});

_k(_bb18_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb79_termite_23_start_2d_messenger();
} else {
return _bb19_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb99_termite_23_start_2d_messenger = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb100_termite_23_start_2d_messenger);
});

_k(_bb108_termite_23_start_2d_messenger = () => {
_a = _s[_t];
_r = _s[_t-3];
return _p(_bb109_termite_23_start_2d_messenger);
},4,1);

_j(_bb95_termite_23_start_2d_messenger = () => {
_a = _s[_t].a;
_b = _s[_t].b;
if (_a === _s[_t-1]) {
return _bb96_termite_23_start_2d_messenger();
} else {
return _bb102_termite_23_start_2d_messenger();
}
});

_j(_bb102_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb103_termite_23_start_2d_messenger);
});

_j(_bb79_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb21_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb19_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb20_termite_23_start_2d_messenger();
} else {
return _bb78_termite_23_start_2d_messenger();
}
});

_j(_bb100_termite_23_start_2d_messenger = () => {
_r = _bb101_termite_23_start_2d_messenger;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb109_termite_23_start_2d_messenger = () => {
_n = 1;
_t -= 4;
return _bb1_termite_23_handle_2d_exception_2d_message();
});

_j(_bb96_termite_23_start_2d_messenger = () => {
if (_x(_b)) {
return _bb97_termite_23_start_2d_messenger();
} else {
return _bb102_termite_23_start_2d_messenger();
}
});

_j(_bb103_termite_23_start_2d_messenger = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb104_termite_23_start_2d_messenger);
});

_k(_bb21_termite_23_start_2d_messenger = () => {
return _bb22_termite_23_start_2d_messenger();
},2,1);

_j(_bb20_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb21_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb78_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb21_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb101_termite_23_start_2d_messenger = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb97_termite_23_start_2d_messenger = () => {
_a = _b.a;
_b = _b.b;
if (_b === null) {
return _bb98_termite_23_start_2d_messenger();
} else {
return _bb102_termite_23_start_2d_messenger();
}
});

_j(_bb104_termite_23_start_2d_messenger = () => {
_r = _bb89_termite_23_start_2d_messenger;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb22_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb23_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb98_termite_23_start_2d_messenger = () => {
_s[_t] = _a;
_r = _bb105_termite_23_start_2d_messenger;
return _bb99_termite_23_start_2d_messenger();
});

_j(_bb23_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb24_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb65_termite_23_start_2d_messenger = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb105_termite_23_start_2d_messenger = () => {
_a = _current_processor.a[14];
_b = _X(_cst58__termite,_X(_a,_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb106_termite_23_start_2d_messenger;
_n = 2;
return _bb1_termite_23__21_();
},4,1);

_k(_bb24_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb77_termite_23_start_2d_messenger();
} else {
return _bb25_termite_23_start_2d_messenger();
}
},4,1);

_k(_bb106_termite_23_start_2d_messenger = () => {
_c = _s[_t-2];
_b = _s[_t-1];
_a = _s[_t];
_r = _s[_t-3];
return _p(_bb107_termite_23_start_2d_messenger);
},4,1);

_j(_bb77_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb27_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb25_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb26_termite_23_start_2d_messenger();
} else {
return _bb76_termite_23_start_2d_messenger();
}
});

_j(_bb107_termite_23_start_2d_messenger = () => {
_n = 3;
_t -= 4;
return _bb1_termite_23_messenger_2d_loop();
});

_k(_bb27_termite_23_start_2d_messenger = () => {
return _bb28_termite_23_start_2d_messenger();
},2,1);

_j(_bb26_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb27_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb76_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb27_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb28_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb29_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb29_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb30_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb30_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb75_termite_23_start_2d_messenger();
} else {
return _bb31_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb75_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb33_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb31_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb32_termite_23_start_2d_messenger();
} else {
return _bb74_termite_23_start_2d_messenger();
}
});

_k(_bb33_termite_23_start_2d_messenger = () => {
return _bb34_termite_23_start_2d_messenger();
},2,1);

_j(_bb32_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb33_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb74_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb33_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb34_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb35_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb35_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb36_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb36_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb73_termite_23_start_2d_messenger();
} else {
return _bb37_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb73_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb39_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb37_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb38_termite_23_start_2d_messenger();
} else {
return _bb72_termite_23_start_2d_messenger();
}
});

_k(_bb39_termite_23_start_2d_messenger = () => {
return _bb40_termite_23_start_2d_messenger();
},2,1);

_j(_bb38_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb39_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb72_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb39_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb40_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb41_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb41_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb42_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb42_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb71_termite_23_start_2d_messenger();
} else {
return _bb43_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb71_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb45_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb43_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb44_termite_23_start_2d_messenger();
} else {
return _bb70_termite_23_start_2d_messenger();
}
});

_k(_bb45_termite_23_start_2d_messenger = () => {
return _bb46_termite_23_start_2d_messenger();
},2,1);

_j(_bb44_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb45_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb70_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb45_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb46_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb47_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb47_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb48_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb48_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb69_termite_23_start_2d_messenger();
} else {
return _bb49_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb69_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb51_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb49_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb50_termite_23_start_2d_messenger();
} else {
return _bb68_termite_23_start_2d_messenger();
}
});

_k(_bb51_termite_23_start_2d_messenger = () => {
return _bb52_termite_23_start_2d_messenger();
},2,1);

_j(_bb50_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb51_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb68_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb51_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb52_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb53_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb53_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb54_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb54_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb67_termite_23_start_2d_messenger();
} else {
return _bb55_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb67_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb57_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb55_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb56_termite_23_start_2d_messenger();
} else {
return _bb66_termite_23_start_2d_messenger();
}
});

_k(_bb57_termite_23_start_2d_messenger = () => {
return _bb58_termite_23_start_2d_messenger();
},2,1);

_j(_bb56_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb57_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb66_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb57_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb58_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb59_termite_23_start_2d_messenger();
} else {
return _bb65_termite_23_start_2d_messenger();
}
});

_j(_bb59_termite_23_start_2d_messenger = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb60_termite_23_start_2d_messenger;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb60_termite_23_start_2d_messenger = () => {
if (!(_a === !1)) {
return _bb64_termite_23_start_2d_messenger();
} else {
return _bb61_termite_23_start_2d_messenger();
}
},4,1);

_j(_bb64_termite_23_start_2d_messenger = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb13_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb61_termite_23_start_2d_messenger = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb62_termite_23_start_2d_messenger();
} else {
return _bb63_termite_23_start_2d_messenger();
}
});

_k(_bb13_termite_23_start_2d_messenger = () => {
return _bb14_termite_23_start_2d_messenger();
},2,1);

_j(_bb62_termite_23_start_2d_messenger = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb13_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb63_termite_23_start_2d_messenger = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb13_termite_23_start_2d_messenger;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb14_termite_23_start_2d_messenger = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb15_termite_23_start_2d_messenger);
});

_j(_bb15_termite_23_start_2d_messenger = () => {
if (_x(_a)) {
return _bb16_termite_23_start_2d_messenger();
} else {
return _bb80_termite_23_start_2d_messenger();
}
});



_m(_bb1_termite_23_messenger_2d_loop = () => {
if (_n !== 3) {
return _w(_bb1_termite_23_messenger_2d_loop);
}
return _bb4_termite_23_messenger_2d_loop();
},-1,_i("termite#messenger-loop"),!1,!0);

_j(_bb4_termite_23_messenger_2d_loop = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_t += 4;
return _p(_bb5_termite_23_messenger_2d_loop);
});

_j(_bb5_termite_23_messenger_2d_loop = () => {
_r = _bb6_termite_23_messenger_2d_loop;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb6_termite_23_messenger_2d_loop = () => {
if (_a instanceof _Structure && _a.a[0].a[1] === _cst52__termite) {
return _bb53_termite_23_messenger_2d_loop();
} else {
return _bb7_termite_23_messenger_2d_loop();
}
},4,1);

_j(_bb53_termite_23_messenger_2d_loop = () => {
_s[_t+1] = _a;
_r = _bb54_termite_23_messenger_2d_loop;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb7_termite_23_messenger_2d_loop = () => {
if (_x(_a)) {
return _bb8_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_k(_bb54_termite_23_messenger_2d_loop = () => {
_a = _s[_t];
_r = _bb2_termite_23_messenger_2d_loop;
_n = 1;
--_t;
return _g["##raise"]();
},5,1);

_j(_bb8_termite_23_messenger_2d_loop = () => {
_b = _a.b;
_c = _a.a;
if (_c === _s[_t-1]) {
return _bb9_termite_23_messenger_2d_loop();
} else {
return _bb47_termite_23_messenger_2d_loop();
}
});

_j(_bb51_termite_23_messenger_2d_loop = () => {
_s[_t+1] = _a;
_r = _bb31_termite_23_messenger_2d_loop;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb2_termite_23_messenger_2d_loop = () => {
return _bb3_termite_23_messenger_2d_loop();
},4,1);

_j(_bb9_termite_23_messenger_2d_loop = () => {
if (_x(_b)) {
return _bb10_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_j(_bb47_termite_23_messenger_2d_loop = () => {
if (_c === _cst77__termite) {
return _bb48_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_k(_bb31_termite_23_messenger_2d_loop = () => {
_b = _s[_t];
_a = _cst235__termite;
_r = _bb2_termite_23_messenger_2d_loop;
_n = 2;
--_t;
return _bb32_termite_23_messenger_2d_loop();
},5,1);

_j(_bb3_termite_23_messenger_2d_loop = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb4_termite_23_messenger_2d_loop);
});

_j(_bb10_termite_23_messenger_2d_loop = () => {
_d = _b.b;
_b = _b.a;
if (_x(_b)) {
return _bb11_termite_23_messenger_2d_loop();
} else {
return _bb43_termite_23_messenger_2d_loop();
}
});

_j(_bb48_termite_23_messenger_2d_loop = () => {
if (_x(_b)) {
return _bb49_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_l(_bb32_termite_23_messenger_2d_loop = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb32_termite_23_messenger_2d_loop);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb33_termite_23_messenger_2d_loop);
},-1);

_j(_bb11_termite_23_messenger_2d_loop = () => {
_r = _b.b;
_s[_t+1] = _b.a;
if (_s[_t+1] === _cst77__termite) {
++_t;
return _bb12_termite_23_messenger_2d_loop();
} else {
++_t;
return _bb38_termite_23_messenger_2d_loop();
}
});

_j(_bb43_termite_23_messenger_2d_loop = () => {
if (_c === _cst77__termite) {
return _bb44_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_j(_bb49_termite_23_messenger_2d_loop = () => {
_c = _b.b;
_b = _b.a;
if (_x(_c)) {
return _bb50_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_j(_bb33_termite_23_messenger_2d_loop = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});

_j(_bb12_termite_23_messenger_2d_loop = () => {
if (_x(_r)) {
return _bb13_termite_23_messenger_2d_loop();
} else {
return _bb38_termite_23_messenger_2d_loop();
}
});

_j(_bb38_termite_23_messenger_2d_loop = () => {
if (_c === _cst77__termite) {
return _bb39_termite_23_messenger_2d_loop();
} else {
return _bb42_termite_23_messenger_2d_loop();
}
});

_j(_bb44_termite_23_messenger_2d_loop = () => {
if (_x(_d)) {
return _bb45_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_j(_bb50_termite_23_messenger_2d_loop = () => {
_d = _c.b;
_c = _c.a;
if (_d === null) {
return _bb52_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_j(_bb13_termite_23_messenger_2d_loop = () => {
_s[_t] = _r.b;
_r = _r.a;
if (_x(_s[_t])) {
return _bb14_termite_23_messenger_2d_loop();
} else {
return _bb38_termite_23_messenger_2d_loop();
}
});

_j(_bb39_termite_23_messenger_2d_loop = () => {
if (_x(_d)) {
return _bb40_termite_23_messenger_2d_loop();
} else {
return _bb42_termite_23_messenger_2d_loop();
}
});

_j(_bb42_termite_23_messenger_2d_loop = () => {
_s[_t] = _a;
_r = _bb31_termite_23_messenger_2d_loop;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb45_termite_23_messenger_2d_loop = () => {
_c = _d.b;
_d = _d.a;
if (_c === null) {
return _bb46_termite_23_messenger_2d_loop();
} else {
return _bb51_termite_23_messenger_2d_loop();
}
});

_j(_bb52_termite_23_messenger_2d_loop = () => {
_s[_t+1] = _b;
_s[_t+2] = _c;
_r = _bb20_termite_23_messenger_2d_loop;
_n = 0;
_t += 2;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb14_termite_23_messenger_2d_loop = () => {
_s[_t+1] = _s[_t].b;
_s[_t] = _s[_t].a;
if (_s[_t+1] === null) {
++_t;
return _bb15_termite_23_messenger_2d_loop();
} else {
++_t;
return _bb16_termite_23_messenger_2d_loop();
}
});

_j(_bb40_termite_23_messenger_2d_loop = () => {
_c = _d.b;
_d = _d.a;
if (_c === null) {
return _bb41_termite_23_messenger_2d_loop();
} else {
return _bb42_termite_23_messenger_2d_loop();
}
});

_j(_bb46_termite_23_messenger_2d_loop = () => {
_s[_t+1] = _b;
_s[_t+2] = _d;
_r = _bb20_termite_23_messenger_2d_loop;
_n = 0;
_t += 2;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb20_termite_23_messenger_2d_loop = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _bb2_termite_23_messenger_2d_loop;
_t -= 2;
return _bb21_termite_23_messenger_2d_loop();
},6,1);

_j(_bb15_termite_23_messenger_2d_loop = () => {
if (_d === null) {
return _bb34_termite_23_messenger_2d_loop();
} else {
return _bb16_termite_23_messenger_2d_loop();
}
});

_j(_bb16_termite_23_messenger_2d_loop = () => {
if (_c === _cst77__termite) {
return _bb17_termite_23_messenger_2d_loop();
} else {
return _bb30_termite_23_messenger_2d_loop();
}
});

_j(_bb41_termite_23_messenger_2d_loop = () => {
_s[_t] = _b;
_s[_t+1] = _d;
_r = _bb20_termite_23_messenger_2d_loop;
_n = 0;
++_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb21_termite_23_messenger_2d_loop = () => {
_b = _b.a[1];
_b = _X(_cst77__termite,_X(_b,_X(_c,null)));
_b = _X(_cst215__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb22_termite_23_messenger_2d_loop);
});

_j(_bb34_termite_23_messenger_2d_loop = () => {
_s[_t] = _r;
_r = _bb35_termite_23_messenger_2d_loop;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb17_termite_23_messenger_2d_loop = () => {
if (_x(_d)) {
return _bb18_termite_23_messenger_2d_loop();
} else {
return _bb30_termite_23_messenger_2d_loop();
}
});

_j(_bb30_termite_23_messenger_2d_loop = () => {
_s[_t-1] = _a;
_r = _bb31_termite_23_messenger_2d_loop;
_n = 0;
--_t;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb22_termite_23_messenger_2d_loop = () => {
_r = _bb23_termite_23_messenger_2d_loop;
_n = 1;
return _g["thread?"]();
});

_k(_bb35_termite_23_messenger_2d_loop = () => {
_r = _bb36_termite_23_messenger_2d_loop;
_n = 0;
return _g["termite#current-node"]();
},6,1);

_j(_bb18_termite_23_messenger_2d_loop = () => {
_c = _d.b;
_d = _d.a;
if (_c === null) {
return _bb19_termite_23_messenger_2d_loop();
} else {
return _bb30_termite_23_messenger_2d_loop();
}
});

_k(_bb23_termite_23_messenger_2d_loop = () => {
if (!(_a === !1)) {
return _bb24_termite_23_messenger_2d_loop();
} else {
return _bb25_termite_23_messenger_2d_loop();
}
},3,1);

_k(_bb36_termite_23_messenger_2d_loop = () => {
_a = new _Structure([_cst101__termite,_s[_t],_a]);
_r = _bb37_termite_23_messenger_2d_loop;
_n = 1;
--_t;
return _bb1_termite_23_upid_2d__3e_pid();
},6,1);

_j(_bb19_termite_23_messenger_2d_loop = () => {
_s[_t-1] = _b;
_s[_t] = _d;
_r = _bb20_termite_23_messenger_2d_loop;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb24_termite_23_messenger_2d_loop = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb27_termite_23_messenger_2d_loop);
});

_j(_bb25_termite_23_messenger_2d_loop = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb26_termite_23_messenger_2d_loop();
} else {
return _bb28_termite_23_messenger_2d_loop();
}
});

_k(_bb37_termite_23_messenger_2d_loop = () => {
_b = _s[_t];
_r = _bb2_termite_23_messenger_2d_loop;
_n = 2;
--_t;
return _bb1_termite_23__21_();
},5,1);

_j(_bb27_termite_23_messenger_2d_loop = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb26_termite_23_messenger_2d_loop = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb27_termite_23_messenger_2d_loop);
});

_j(_bb28_termite_23_messenger_2d_loop = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb29_termite_23_messenger_2d_loop);
});

_j(_bb29_termite_23_messenger_2d_loop = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_publish_2d_service = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_publish_2d_service);
}
_a = _X(_cst92__termite,_X(_a,_X(_b,null)));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#publisher"];
_t += 2;
return _p(_bb2_termite_23_publish_2d_service);
},-1,_i("termite#publish-service"),!1,!0);

_j(_bb2_termite_23_publish_2d_service = () => {
_r = _bb3_termite_23_publish_2d_service;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_publish_2d_service = () => {
if (!(_a === !1)) {
return _bb4_termite_23_publish_2d_service();
} else {
return _bb5_termite_23_publish_2d_service();
}
},2,1);

_j(_bb4_termite_23_publish_2d_service = () => {
_b = _s[_t];
_a = _g["termite#publisher"];
_r = _s[_t-1];
return _p(_bb7_termite_23_publish_2d_service);
});

_j(_bb5_termite_23_publish_2d_service = () => {
if (_g["termite#publisher"] instanceof _Structure && _g["termite#publisher"].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_publish_2d_service();
} else {
return _bb8_termite_23_publish_2d_service();
}
});

_j(_bb7_termite_23_publish_2d_service = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb6_termite_23_publish_2d_service = () => {
_b = _X(_cst77__termite,_X(_g["termite#publisher"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb7_termite_23_publish_2d_service);
});

_j(_bb8_termite_23_publish_2d_service = () => {
_b = _g["termite#publisher"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb9_termite_23_publish_2d_service);
});

_j(_bb9_termite_23_publish_2d_service = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});



_m(_bb1_termite_23_unpublish_2d_service = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_unpublish_2d_service);
}
_a = _X(_cst96__termite,_X(_a,_X(_b,null)));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#publisher"];
_t += 2;
return _p(_bb2_termite_23_unpublish_2d_service);
},-1,_i("termite#unpublish-service"),!1,!0);

_j(_bb2_termite_23_unpublish_2d_service = () => {
_r = _bb3_termite_23_unpublish_2d_service;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_unpublish_2d_service = () => {
if (!(_a === !1)) {
return _bb4_termite_23_unpublish_2d_service();
} else {
return _bb5_termite_23_unpublish_2d_service();
}
},2,1);

_j(_bb4_termite_23_unpublish_2d_service = () => {
_b = _s[_t];
_a = _g["termite#publisher"];
_r = _s[_t-1];
return _p(_bb7_termite_23_unpublish_2d_service);
});

_j(_bb5_termite_23_unpublish_2d_service = () => {
if (_g["termite#publisher"] instanceof _Structure && _g["termite#publisher"].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_unpublish_2d_service();
} else {
return _bb8_termite_23_unpublish_2d_service();
}
});

_j(_bb7_termite_23_unpublish_2d_service = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb6_termite_23_unpublish_2d_service = () => {
_b = _X(_cst77__termite,_X(_g["termite#publisher"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb7_termite_23_unpublish_2d_service);
});

_j(_bb8_termite_23_unpublish_2d_service = () => {
_b = _g["termite#publisher"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb9_termite_23_unpublish_2d_service);
});

_j(_bb9_termite_23_unpublish_2d_service = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});



_m(_bb1_termite_23_resolve_2d_service = () => {
if (_n === 1) {
_b = !1;
} else {
if (_n !== 2) {
return _w(_bb1_termite_23_resolve_2d_service);
}
}
_b = _X(_cst113__termite,_X(_a,null));
_a = _g["termite#publisher"];
return _p(_bb2_termite_23_resolve_2d_service);
},-1,_i("termite#resolve-service"),!1,!0);

_j(_bb2_termite_23_resolve_2d_service = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_remote_2d_service = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_remote_2d_service);
}
_a = new _Structure([_cst101__termite,_a,_b]);
return _r;
},-1,_i("termite#remote-service"),!1,!0);



_m(_bb1_termite_23_make_2d_server_2d_plugin = () => {
if (_n !== 4) {
return _w(_bb1_termite_23_make_2d_server_2d_plugin);
}
_a = new _Structure([_cst236__termite,_s[_t],_a,_b,_c]);
--_t;
return _r;
},-1,_i("termite#make-server-plugin"),!1,!0);



_m(_bb1_termite_23_server_2d_plugin_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_server_2d_plugin_2d_copy);
}
return _p(_bb2_termite_23_server_2d_plugin_2d_copy);
},-1,_i("termite#server-plugin-copy"),!1,!0);

_j(_bb2_termite_23_server_2d_plugin_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_server_2d_plugin_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_server_2d_plugin_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst237__termite;
return _r;
},-1,_i("termite#server-plugin?"),!1,!0);



_m(_bb1_termite_23_server_2d_plugin_2d_init = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_server_2d_plugin_2d_init);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#server-plugin-init"),!1,!0);



_m(_bb1_termite_23_server_2d_plugin_2d_init_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_2d_plugin_2d_init_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_server_2d_plugin_2d_init_2d_set;
_b = _cst236__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_server_2d_plugin_2d_init_2d_set);
},-1,_i("termite#server-plugin-init-set"),!1,!0);

_j(_bb2_termite_23_server_2d_plugin_2d_init_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_server_2d_plugin_2d_call = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_server_2d_plugin_2d_call);
}
_a = _a.a[2];
return _r;
},-1,_i("termite#server-plugin-call"),!1,!0);



_m(_bb1_termite_23_server_2d_plugin_2d_call_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_2d_plugin_2d_call_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_server_2d_plugin_2d_call_2d_set;
_b = _cst236__termite;
_a = 2;
_t += 2;
return _p(_bb2_termite_23_server_2d_plugin_2d_call_2d_set);
},-1,_i("termite#server-plugin-call-set"),!1,!0);

_j(_bb2_termite_23_server_2d_plugin_2d_call_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_server_2d_plugin_2d_cast = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_server_2d_plugin_2d_cast);
}
_a = _a.a[3];
return _r;
},-1,_i("termite#server-plugin-cast"),!1,!0);



_m(_bb1_termite_23_server_2d_plugin_2d_cast_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_2d_plugin_2d_cast_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_server_2d_plugin_2d_cast_2d_set;
_b = _cst236__termite;
_a = 3;
_t += 2;
return _p(_bb2_termite_23_server_2d_plugin_2d_cast_2d_set);
},-1,_i("termite#server-plugin-cast-set"),!1,!0);

_j(_bb2_termite_23_server_2d_plugin_2d_cast_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_server_2d_plugin_2d_terminate = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_server_2d_plugin_2d_terminate);
}
_a = _a.a[4];
return _r;
},-1,_i("termite#server-plugin-terminate"),!1,!0);



_m(_bb1_termite_23_server_2d_plugin_2d_terminate_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_2d_plugin_2d_terminate_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_server_2d_plugin_2d_terminate_2d_set;
_b = _cst236__termite;
_a = 4;
_t += 2;
return _p(_bb2_termite_23_server_2d_plugin_2d_terminate_2d_set);
},-1,_i("termite#server-plugin-terminate-set"),!1,!0);

_j(_bb2_termite_23_server_2d_plugin_2d_terminate_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_make_2d_server = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_make_2d_server);
}
_b = !1;
return _p(_bb4_termite_23_make_2d_server);
},-1,_i("termite#make-server"),!1,!0);

_j(_bb4_termite_23_make_2d_server = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb5_termite_23_make_2d_server);
});

_j(_bb5_termite_23_make_2d_server = () => {
_r = _bb6_termite_23_make_2d_server;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb6_termite_23_make_2d_server = () => {
_c = _a;
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb7_termite_23_make_2d_server);
},3,1);

_j(_bb7_termite_23_make_2d_server = () => {
if (_c instanceof _Structure && _c.a[0].a[1] === _cst52__termite) {
return _bb8_termite_23_make_2d_server();
} else {
return _bb12_termite_23_make_2d_server();
}
});

_j(_bb8_termite_23_make_2d_server = () => {
_s[_t+1] = _r;
_s[_t+2] = _c;
_t += 2;
return _p(_bb9_termite_23_make_2d_server);
});

_j(_bb12_termite_23_make_2d_server = () => {
if (_x(_c)) {
return _bb13_termite_23_make_2d_server();
} else {
return _bb4_termite_23_make_2d_server();
}
});

_j(_bb9_termite_23_make_2d_server = () => {
_r = _bb10_termite_23_make_2d_server;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb13_termite_23_make_2d_server = () => {
_d = _c.a;
_c = _c.b;
if (_x(_c)) {
return _bb14_termite_23_make_2d_server();
} else {
return _bb4_termite_23_make_2d_server();
}
});

_k(_bb10_termite_23_make_2d_server = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb11_termite_23_make_2d_server);
},2,1);

_j(_bb14_termite_23_make_2d_server = () => {
_s[_t+1] = _c.a;
_c = _c.b;
if (_x(_c)) {
++_t;
return _bb15_termite_23_make_2d_server();
} else {
++_t;
return _bb50_termite_23_make_2d_server();
}
});

_j(_bb11_termite_23_make_2d_server = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb15_termite_23_make_2d_server = () => {
_s[_t+1] = _c.a;
_c = _c.b;
if (_x(_s[_t+1])) {
++_t;
return _bb16_termite_23_make_2d_server();
} else {
++_t;
return _bb49_termite_23_make_2d_server();
}
});

_j(_bb50_termite_23_make_2d_server = () => {
if (_d === _cst240__termite) {
return _bb51_termite_23_make_2d_server();
} else {
return _bb56_termite_23_make_2d_server();
}
});

_j(_bb16_termite_23_make_2d_server = () => {
_s[_t+1] = _s[_t].a;
_s[_t] = _s[_t].b;
if (_s[_t+1] === _cst46__termite) {
++_t;
return _bb17_termite_23_make_2d_server();
} else {
++_t;
return _bb31_termite_23_make_2d_server();
}
});

_j(_bb49_termite_23_make_2d_server = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _b;
++_t;
return _p(_bb5_termite_23_make_2d_server);
});

_j(_bb51_termite_23_make_2d_server = () => {
if (_c === null) {
return _bb52_termite_23_make_2d_server();
} else {
return _bb58_termite_23_make_2d_server();
}
});

_j(_bb56_termite_23_make_2d_server = () => {
if (_d === _cst241__termite) {
return _bb57_termite_23_make_2d_server();
} else {
return _bb58_termite_23_make_2d_server();
}
});

_j(_bb17_termite_23_make_2d_server = () => {
if (_x(_s[_t-1])) {
return _bb18_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_j(_bb31_termite_23_make_2d_server = () => {
if (_s[_t] === _cst48__termite) {
return _bb32_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_j(_bb52_termite_23_make_2d_server = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb53_termite_23_make_2d_server);
});

_j(_bb58_termite_23_make_2d_server = () => {
_s[_t] = _r;
_s[_t+1] = _a;
_s[_t+2] = _b;
_t += 2;
return _p(_bb5_termite_23_make_2d_server);
});

_j(_bb57_termite_23_make_2d_server = () => {
if (_c === null) {
return _bb59_termite_23_make_2d_server();
} else {
return _bb58_termite_23_make_2d_server();
}
});

_j(_bb18_termite_23_make_2d_server = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb19_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_j(_bb35_termite_23_make_2d_server = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
_s[_t] = _b;
return _p(_bb5_termite_23_make_2d_server);
});

_j(_bb32_termite_23_make_2d_server = () => {
if (_x(_s[_t-1])) {
return _bb33_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_j(_bb53_termite_23_make_2d_server = () => {
_r = _bb54_termite_23_make_2d_server;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb59_termite_23_make_2d_server = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb60_termite_23_make_2d_server);
});

_j(_bb19_termite_23_make_2d_server = () => {
if (_c === null) {
return _bb20_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_j(_bb33_termite_23_make_2d_server = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb34_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_k(_bb54_termite_23_make_2d_server = () => {
_b = _s[_t];
_a = _s[_t-3];
_c = _s[_t-1].a[3];
_r = _bb55_termite_23_make_2d_server;
_n = 2;
--_t;
return _c;
},4,2);

_j(_bb60_termite_23_make_2d_server = () => {
_r = _bb61_termite_23_make_2d_server;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb20_termite_23_make_2d_server = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _d;
_t += 2;
return _p(_bb21_termite_23_make_2d_server);
});

_j(_bb34_termite_23_make_2d_server = () => {
if (_c === null) {
return _bb36_termite_23_make_2d_server();
} else {
return _bb35_termite_23_make_2d_server();
}
});

_k(_bb55_termite_23_make_2d_server = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 3;
return _p(_bb4_termite_23_make_2d_server);
},3,2);

_k(_bb61_termite_23_make_2d_server = () => {
_b = _s[_t];
_a = _s[_t-3];
_r = _s[_t-2];
_c = _s[_t-1].a[4];
return _p(_bb62_termite_23_make_2d_server);
},4,2);

_j(_bb21_termite_23_make_2d_server = () => {
_r = _bb22_termite_23_make_2d_server;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb36_termite_23_make_2d_server = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _b;
_s[_t+3] = _d;
_t += 3;
return _p(_bb37_termite_23_make_2d_server);
});

_j(_bb62_termite_23_make_2d_server = () => {
_n = 2;
_t -= 4;
return _c;
});

_k(_bb22_termite_23_make_2d_server = () => {
_a = _s[_t-2];
_b = _s[_t-1].a[1];
_r = _bb23_termite_23_make_2d_server;
_n = 1;
return _b;
},5,2);

_j(_bb37_termite_23_make_2d_server = () => {
_r = _bb38_termite_23_make_2d_server;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_k(_bb23_termite_23_make_2d_server = () => {
_b = _X(_s[_t-4],_X(_a,null));
_s[_t-4] = _a;
_s[_t-2] = _b;
_a = _s[_t];
_r = _bb24_termite_23_make_2d_server;
_n = 1;
return _g["thread?"]();
},5,2);

_k(_bb38_termite_23_make_2d_server = () => {
var closure0 = _closure_alloc([_bb47_termite_23_make_2d_server,_s[_t-3],_s[_t-2],_s[_t-1]]);
_s[_t+1] = closure0;
_s[_t-3] = _s[_t+1];
var closure1 = _closure_alloc([_bb40_termite_23_make_2d_server,_s[_t],_s[_t-5],_s[_t-2]]);
_s[_t+1] = closure1;
_b = _s[_t+1];
_r = _s[_t-4];
_a = _s[_t-3];
++_t;
return _p(_bb39_termite_23_make_2d_server);
},6,2);

_k(_bb24_termite_23_make_2d_server = () => {
if (!(_a === !1)) {
return _bb30_termite_23_make_2d_server();
} else {
return _bb25_termite_23_make_2d_server();
}
},5,2);

_l(_bb47_termite_23_make_2d_server = () => {
if (_n !== 0) {
return _w(_d);
}
_b = _d(!0)[3];
_a = _d(!0)[1];
_d = _d(!0)[2];
_c = _d.a[2];
return _p(_bb48_termite_23_make_2d_server);
},3);

_l(_bb40_termite_23_make_2d_server = () => {
if (_n !== 2) {
return _w(_d);
}
_c = _d(!0)[2];
_a = _X(_c,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _d;
_a = _d(!0)[1];
_t += 4;
return _p(_bb41_termite_23_make_2d_server);
},3);

_j(_bb39_termite_23_make_2d_server = () => {
_n = 2;
_t -= 7;
return _e["##call-with-values"]();
});

_j(_bb30_termite_23_make_2d_server = () => {
_b = _s[_t-2];
_a = _s[_t];
_r = _bb27_termite_23_make_2d_server;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb25_termite_23_make_2d_server = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb26_termite_23_make_2d_server();
} else {
return _bb29_termite_23_make_2d_server();
}
});

_j(_bb48_termite_23_make_2d_server = () => {
_n = 2;
return _c;
});

_j(_bb41_termite_23_make_2d_server = () => {
_r = _bb42_termite_23_make_2d_server;
_n = 1;
return _g["thread?"]();
});

_k(_bb27_termite_23_make_2d_server = () => {
return _bb28_termite_23_make_2d_server();
},4,2);

_j(_bb26_termite_23_make_2d_server = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-2],null)));
_a = _g["termite#dispatcher"];
_r = _bb27_termite_23_make_2d_server;
_n = 2;
--_t;
return _g["thread-send"]();
});

_j(_bb29_termite_23_make_2d_server = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _bb27_termite_23_make_2d_server;
_n = 2;
--_t;
return _g["##error"]();
});

_k(_bb42_termite_23_make_2d_server = () => {
if (!(_a === !1)) {
return _bb46_termite_23_make_2d_server();
} else {
return _bb43_termite_23_make_2d_server();
}
},4,1);

_j(_bb28_termite_23_make_2d_server = () => {
_b = _s[_t-3];
_a = _s[_t];
_r = _s[_t-2];
_t -= 4;
return _p(_bb4_termite_23_make_2d_server);
});

_j(_bb46_termite_23_make_2d_server = () => {
_b = _s[_t-2];
_a = _s[_t](!0)[1];
_r = _bb2_termite_23_make_2d_server;
_n = 2;
return _g["thread-send"]();
});

_j(_bb43_termite_23_make_2d_server = () => {
_r = _s[_t](!0)[1];
if (_r instanceof _Structure && _r.a[0].a[1] === _cst83__termite) {
return _bb44_termite_23_make_2d_server();
} else {
return _bb45_termite_23_make_2d_server();
}
});

_k(_bb2_termite_23_make_2d_server = () => {
return _bb3_termite_23_make_2d_server();
},4,1);

_j(_bb44_termite_23_make_2d_server = () => {
_r = _s[_t](!0)[1];
_b = _X(_cst77__termite,_X(_r,_X(_s[_t-2],null)));
_a = _g["termite#dispatcher"];
_r = _bb2_termite_23_make_2d_server;
_n = 2;
return _g["thread-send"]();
});

_j(_bb45_termite_23_make_2d_server = () => {
_b = _s[_t](!0)[1];
_a = _cst87__termite;
_r = _bb2_termite_23_make_2d_server;
_n = 2;
return _g["##error"]();
});

_j(_bb3_termite_23_make_2d_server = () => {
_b = _s[_t-1];
_a = _s[_t](!0)[3];
_r = _s[_t-3];
_t -= 4;
return _p(_bb4_termite_23_make_2d_server);
});



_m(_bb1_termite_23_internal_2d_server_2d_start = () => {
if (_n !== 4) {
return _w(_bb1_termite_23_internal_2d_server_2d_start);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb5_termite_23_internal_2d_server_2d_start,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _cst15__termite;
_t += 3;
return _p(_bb2_termite_23_internal_2d_server_2d_start);
},-1,_i("termite#internal-server-start"),!1,!0);

_l(_bb5_termite_23_internal_2d_server_2d_start = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _p(_bb6_termite_23_internal_2d_server_2d_start);
},1);

_j(_bb2_termite_23_internal_2d_server_2d_start = () => {
_r = _bb3_termite_23_internal_2d_server_2d_start;
_n = 3;
--_t;
return _s[_t-2]();
});

_j(_bb6_termite_23_internal_2d_server_2d_start = () => {
_n = 1;
return _bb1_termite_23_make_2d_server();
});

_k(_bb3_termite_23_internal_2d_server_2d_start = () => {
_s[_t-2] = _a;
_b = _X(_cst46__termite,_X(_s[_t],null));
_c = 1;
_r = _bb4_termite_23_internal_2d_server_2d_start;
_n = 3;
--_t;
return _bb1_termite_23__21__3f_();
},3,2);

_k(_bb4_termite_23_internal_2d_server_2d_start = () => {
_a = _s[_t-1];
_t -= 2;
return _s[_t+2]();
},2,2);



_m(_bb1_termite_23_server_3a_start = () => {
var error = _build_key(2,3,[_cst15__termite,_cst243__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_server_3a_start,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb5_termite_23_server_3a_start,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _cst15__termite;
_t += 3;
return _p(_bb2_termite_23_server_3a_start);
},-1,_i("termite#server:start"),!1,!0);

_l(_bb5_termite_23_server_3a_start = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _p(_bb6_termite_23_server_3a_start);
},1);

_j(_bb2_termite_23_server_3a_start = () => {
_r = _bb3_termite_23_server_3a_start;
_n = 3;
--_t;
return _bb1_termite_23_spawn();
});

_j(_bb6_termite_23_server_3a_start = () => {
_n = 1;
return _bb1_termite_23_make_2d_server();
});

_k(_bb3_termite_23_server_3a_start = () => {
_s[_t+1] = _a;
_b = _X(_cst46__termite,_X(_s[_t],null));
_c = 1;
_r = _bb4_termite_23_server_3a_start;
_n = 3;
++_t;
return _bb1_termite_23__21__3f_();
},2,1);

_k(_bb4_termite_23_server_3a_start = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);



_m(_bb1_termite_23_server_3a_start_2d_link = () => {
var error = _build_key(2,3,[_cst15__termite,_cst244__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_server_3a_start_2d_link,error);
}
_c = _b;
_b = _a;
_a = _bb1_termite_23_spawn_2d_link;
return _p(_bb2_termite_23_server_3a_start_2d_link);
},-1,_i("termite#server:start-link"),!1,!0);

_j(_bb2_termite_23_server_3a_start_2d_link = () => {
_n = 3;
return _bb1_termite_23_internal_2d_server_2d_start();
});



_m(_bb1_termite_23_server_3a_call = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_3a_call);
}
_b = _X(_cst48__termite,_X(_b,null));
_c = 1;
return _p(_bb2_termite_23_server_3a_call);
},-1,_i("termite#server:call"),!1,!0);

_j(_bb2_termite_23_server_3a_call = () => {
_n = 3;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_server_3a_cast = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_3a_cast);
}
_b = _X(_cst240__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_server_3a_cast);
},-1,_i("termite#server:cast"),!1,!0);

_j(_bb2_termite_23_server_3a_cast = () => {
_r = _bb3_termite_23_server_3a_cast;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_server_3a_cast = () => {
if (!(_a === !1)) {
return _bb4_termite_23_server_3a_cast();
} else {
return _bb5_termite_23_server_3a_cast();
}
},3,1);

_j(_bb4_termite_23_server_3a_cast = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_server_3a_cast);
});

_j(_bb5_termite_23_server_3a_cast = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_server_3a_cast();
} else {
return _bb8_termite_23_server_3a_cast();
}
});

_j(_bb7_termite_23_server_3a_cast = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_server_3a_cast = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_server_3a_cast);
});

_j(_bb8_termite_23_server_3a_cast = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_server_3a_cast);
});

_j(_bb9_termite_23_server_3a_cast = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_server_3a_stop = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_server_3a_stop);
}
_b = _X(_cst241__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_server_3a_stop);
},-1,_i("termite#server:stop"),!1,!0);

_j(_bb2_termite_23_server_3a_stop = () => {
_r = _bb3_termite_23_server_3a_stop;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_server_3a_stop = () => {
if (!(_a === !1)) {
return _bb4_termite_23_server_3a_stop();
} else {
return _bb5_termite_23_server_3a_stop();
}
},3,1);

_j(_bb4_termite_23_server_3a_stop = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_server_3a_stop);
});

_j(_bb5_termite_23_server_3a_stop = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_server_3a_stop();
} else {
return _bb8_termite_23_server_3a_stop();
}
});

_j(_bb7_termite_23_server_3a_stop = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_server_3a_stop = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_server_3a_stop);
});

_j(_bb8_termite_23_server_3a_stop = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_server_3a_stop);
});

_j(_bb9_termite_23_server_3a_stop = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_make_2d_simple_2d_server_2d_plugin = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_make_2d_simple_2d_server_2d_plugin);
}
var closure0 = _closure_alloc([_bb6_termite_23_make_2d_simple_2d_server_2d_plugin,_a]);
var closure1 = _closure_alloc([_bb4_termite_23_make_2d_simple_2d_server_2d_plugin,_b]);
_s[_t+1] = closure0;
_s[_t+2] = closure1;
_a = new _Structure([_cst236__termite,_s[_t+1],_s[_t+2],_bb3_termite_23_make_2d_simple_2d_server_2d_plugin,_bb2_termite_23_make_2d_simple_2d_server_2d_plugin]);
return _r;
},-1,_i("termite#make-simple-server-plugin"),!1,!0);

_l(_bb6_termite_23_make_2d_simple_2d_server_2d_plugin = () => {
if (_n !== 1) {
return _w(_d);
}
_a = _d(!0)[1];
return _r;
},1);

_l(_bb4_termite_23_make_2d_simple_2d_server_2d_plugin = () => {
if (_n !== 2) {
return _w(_d);
}
return _p(_bb5_termite_23_make_2d_simple_2d_server_2d_plugin);
},1);

_l(_bb3_termite_23_make_2d_simple_2d_server_2d_plugin = () => {
if (_n !== 2) {
return _w(_bb3_termite_23_make_2d_simple_2d_server_2d_plugin);
}
_a = _b;
return _r;
},-1);

_l(_bb2_termite_23_make_2d_simple_2d_server_2d_plugin = () => {
if (_n !== 2) {
return _w(_bb2_termite_23_make_2d_simple_2d_server_2d_plugin);
}
_a = void 0;
return _r;
},-1);

_j(_bb5_termite_23_make_2d_simple_2d_server_2d_plugin = () => {
_n = 2;
return _d(!0)[1]();
});



_m(_bb1_termite_23_make_2d_event_2d_handler = () => {
if (_n !== 4) {
return _w(_bb1_termite_23_make_2d_event_2d_handler);
}
_a = new _Structure([_cst33__termite,_s[_t],_a,_b,_c]);
--_t;
return _r;
},-1,_i("termite#make-event-handler"),!1,!0);



_m(_bb1_termite_23_event_2d_handler_2d_copy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_handler_2d_copy);
}
return _p(_bb2_termite_23_event_2d_handler_2d_copy);
},-1,_i("termite#event-handler-copy"),!1,!0);

_j(_bb2_termite_23_event_2d_handler_2d_copy = () => {
_n = 1;
return _g["##structure-copy"]();
});



_m(_bb1_termite_23_event_2d_handler_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_handler_3f_);
}
_a = _a instanceof _Structure && _a.a[0].a[1] === _cst43__termite;
return _r;
},-1,_i("termite#event-handler?"),!1,!0);



_m(_bb1_termite_23_event_2d_handler_2d_init = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_handler_2d_init);
}
_a = _a.a[1];
return _r;
},-1,_i("termite#event-handler-init"),!1,!0);



_m(_bb1_termite_23_event_2d_handler_2d_init_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_event_2d_handler_2d_init_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_event_2d_handler_2d_init_2d_set;
_b = _cst33__termite;
_a = 1;
_t += 2;
return _p(_bb2_termite_23_event_2d_handler_2d_init_2d_set);
},-1,_i("termite#event-handler-init-set"),!1,!0);

_j(_bb2_termite_23_event_2d_handler_2d_init_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_event_2d_handler_2d_notify = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_handler_2d_notify);
}
_a = _a.a[2];
return _r;
},-1,_i("termite#event-handler-notify"),!1,!0);



_m(_bb1_termite_23_event_2d_handler_2d_notify_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_event_2d_handler_2d_notify_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_event_2d_handler_2d_notify_2d_set;
_b = _cst33__termite;
_a = 2;
_t += 2;
return _p(_bb2_termite_23_event_2d_handler_2d_notify_2d_set);
},-1,_i("termite#event-handler-notify-set"),!1,!0);

_j(_bb2_termite_23_event_2d_handler_2d_notify_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_event_2d_handler_2d_call = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_handler_2d_call);
}
_a = _a.a[3];
return _r;
},-1,_i("termite#event-handler-call"),!1,!0);



_m(_bb1_termite_23_event_2d_handler_2d_call_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_event_2d_handler_2d_call_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_event_2d_handler_2d_call_2d_set;
_b = _cst33__termite;
_a = 3;
_t += 2;
return _p(_bb2_termite_23_event_2d_handler_2d_call_2d_set);
},-1,_i("termite#event-handler-call-set"),!1,!0);

_j(_bb2_termite_23_event_2d_handler_2d_call_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_event_2d_handler_2d_terminate = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_handler_2d_terminate);
}
_a = _a.a[4];
return _r;
},-1,_i("termite#event-handler-terminate"),!1,!0);



_m(_bb1_termite_23_event_2d_handler_2d_terminate_2d_set = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_event_2d_handler_2d_terminate_2d_set);
}
_s[_t+1] = _a;
_s[_t+2] = _b;
_c = _bb1_termite_23_event_2d_handler_2d_terminate_2d_set;
_b = _cst33__termite;
_a = 4;
_t += 2;
return _p(_bb2_termite_23_event_2d_handler_2d_terminate_2d_set);
},-1,_i("termite#event-handler-terminate-set"),!1,!0);

_j(_bb2_termite_23_event_2d_handler_2d_terminate_2d_set = () => {
_n = 5;
return _g["##direct-structure-set"]();
});



_m(_bb1_termite_23_event_2d_manager = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_event_2d_manager);
}
_a = null;
return _p(_bb3_termite_23_event_2d_manager);
},-1,_i("termite#event-manager"),!1,!0);

_j(_bb3_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb4_termite_23_event_2d_manager);
});

_j(_bb4_termite_23_event_2d_manager = () => {
_r = _bb5_termite_23_event_2d_manager;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb5_termite_23_event_2d_manager = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb6_termite_23_event_2d_manager);
},2,1);

_j(_bb6_termite_23_event_2d_manager = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb7_termite_23_event_2d_manager();
} else {
return _bb11_termite_23_event_2d_manager();
}
});

_j(_bb7_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb8_termite_23_event_2d_manager);
});

_j(_bb11_termite_23_event_2d_manager = () => {
if (_x(_b)) {
return _bb12_termite_23_event_2d_manager();
} else {
return _bb3_termite_23_event_2d_manager();
}
});

_j(_bb8_termite_23_event_2d_manager = () => {
_r = _bb9_termite_23_event_2d_manager;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb12_termite_23_event_2d_manager = () => {
_c = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb13_termite_23_event_2d_manager();
} else {
return _bb87_termite_23_event_2d_manager();
}
});

_k(_bb9_termite_23_event_2d_manager = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb10_termite_23_event_2d_manager);
},2,1);

_j(_bb13_termite_23_event_2d_manager = () => {
_d = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb14_termite_23_event_2d_manager();
} else {
return _bb68_termite_23_event_2d_manager();
}
});

_j(_bb87_termite_23_event_2d_manager = () => {
if (_c === _cst245__termite) {
return _bb3_termite_23_event_2d_manager();
} else {
return _bb88_termite_23_event_2d_manager();
}
});

_j(_bb10_termite_23_event_2d_manager = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb14_termite_23_event_2d_manager = () => {
_s[_t+1] = _b.a;
_b = _b.b;
if (_x(_s[_t+1])) {
++_t;
return _bb15_termite_23_event_2d_manager();
} else {
++_t;
return _bb64_termite_23_event_2d_manager();
}
});

_j(_bb68_termite_23_event_2d_manager = () => {
if (_c === _cst245__termite) {
return _bb3_termite_23_event_2d_manager();
} else {
return _bb69_termite_23_event_2d_manager();
}
});

_j(_bb88_termite_23_event_2d_manager = () => {
if (_c === _cst47__termite) {
return _bb3_termite_23_event_2d_manager();
} else {
return _bb89_termite_23_event_2d_manager();
}
});

_j(_bb15_termite_23_event_2d_manager = () => {
_s[_t+1] = _s[_t].a;
_s[_t+2] = _s[_t].b;
if (_s[_t+1] === _cst48__termite) {
_t += 2;
return _bb16_termite_23_event_2d_manager();
} else {
_t += 2;
return _bb54_termite_23_event_2d_manager();
}
});

_j(_bb64_termite_23_event_2d_manager = () => {
if (_c === _cst245__termite) {
return _bb65_termite_23_event_2d_manager();
} else {
return _bb67_termite_23_event_2d_manager();
}
});

_j(_bb69_termite_23_event_2d_manager = () => {
if (_c === _cst47__termite) {
return _bb70_termite_23_event_2d_manager();
} else {
return _bb3_termite_23_event_2d_manager();
}
});

_j(_bb89_termite_23_event_2d_manager = () => {
if (_c === _cst241__termite) {
return _bb90_termite_23_event_2d_manager();
} else {
return _bb3_termite_23_event_2d_manager();
}
});

_j(_bb16_termite_23_event_2d_manager = () => {
if (_x(_s[_t])) {
return _bb17_termite_23_event_2d_manager();
} else {
return _bb54_termite_23_event_2d_manager();
}
});

_j(_bb54_termite_23_event_2d_manager = () => {
if (_c === _cst245__termite) {
return _bb55_termite_23_event_2d_manager();
} else {
return _bb62_termite_23_event_2d_manager();
}
});

_j(_bb65_termite_23_event_2d_manager = () => {
if (_b === null) {
return _bb66_termite_23_event_2d_manager();
} else {
return _bb67_termite_23_event_2d_manager();
}
});

_j(_bb67_termite_23_event_2d_manager = () => {
_s[_t] = _r;
_s[_t+1] = _a;
++_t;
return _p(_bb4_termite_23_event_2d_manager);
});

_j(_bb70_termite_23_event_2d_manager = () => {
if (_b === null) {
return _bb71_termite_23_event_2d_manager();
} else {
return _bb3_termite_23_event_2d_manager();
}
});

_j(_bb90_termite_23_event_2d_manager = () => {
if (_b === null) {
return _bb91_termite_23_event_2d_manager();
} else {
return _bb3_termite_23_event_2d_manager();
}
});

_j(_bb17_termite_23_event_2d_manager = () => {
_s[_t-1] = _s[_t].a;
_s[_t] = _s[_t].b;
if (_x(_s[_t])) {
return _bb18_termite_23_event_2d_manager();
} else {
return _bb54_termite_23_event_2d_manager();
}
});

_j(_bb55_termite_23_event_2d_manager = () => {
if (_b === null) {
return _bb56_termite_23_event_2d_manager();
} else {
return _bb62_termite_23_event_2d_manager();
}
});

_j(_bb62_termite_23_event_2d_manager = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
return _p(_bb63_termite_23_event_2d_manager);
});

_j(_bb66_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_t += 3;
return _p(_bb57_termite_23_event_2d_manager);
});

_j(_bb71_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_t += 3;
return _p(_bb72_termite_23_event_2d_manager);
});

_j(_bb91_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb92_termite_23_event_2d_manager);
});

_j(_bb18_termite_23_event_2d_manager = () => {
_s[_t+1] = _s[_t].a;
_s[_t] = _s[_t].b;
if (_s[_t] === null) {
++_t;
return _bb19_termite_23_event_2d_manager();
} else {
++_t;
return _bb49_termite_23_event_2d_manager();
}
});

_j(_bb56_termite_23_event_2d_manager = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _d;
++_t;
return _p(_bb57_termite_23_event_2d_manager);
});

_j(_bb63_termite_23_event_2d_manager = () => {
_r = _bb5_termite_23_event_2d_manager;
_n = 0;
--_t;
return _g["thread-mailbox-next"]();
});

_j(_bb57_termite_23_event_2d_manager = () => {
_r = _bb58_termite_23_event_2d_manager;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb72_termite_23_event_2d_manager = () => {
_r = _bb73_termite_23_event_2d_manager;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb92_termite_23_event_2d_manager = () => {
_r = _bb93_termite_23_event_2d_manager;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb19_termite_23_event_2d_manager = () => {
if (_b === null) {
return _bb20_termite_23_event_2d_manager();
} else {
return _bb51_termite_23_event_2d_manager();
}
});

_j(_bb49_termite_23_event_2d_manager = () => {
if (_c === _cst245__termite) {
return _bb50_termite_23_event_2d_manager();
} else {
return _bb51_termite_23_event_2d_manager();
}
});

_k(_bb58_termite_23_event_2d_manager = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb59_termite_23_event_2d_manager);
},4,2);

_k(_bb73_termite_23_event_2d_manager = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _bb86_termite_23_event_2d_manager;
_t -= 2;
return _bb74_termite_23_event_2d_manager();
},3,1);

_k(_bb93_termite_23_event_2d_manager = () => {
_a = _s[_t];
_r = _bb110_termite_23_event_2d_manager;
--_t;
return _bb94_termite_23_event_2d_manager();
},2,1);

_j(_bb20_termite_23_event_2d_manager = () => {
_s[_t-3] = _r;
_s[_t-1] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_t += 2;
return _p(_bb21_termite_23_event_2d_manager);
});

_j(_bb51_termite_23_event_2d_manager = () => {
_s[_t-3] = _r;
_s[_t-2] = _a;
return _p(_bb52_termite_23_event_2d_manager);
});

_j(_bb50_termite_23_event_2d_manager = () => {
if (_b === null) {
return _bb53_termite_23_event_2d_manager();
} else {
return _bb51_termite_23_event_2d_manager();
}
});

_j(_bb59_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _c;
_b = _b.a[1];
_t += 3;
return _p(_bb60_termite_23_event_2d_manager);
});

_j(_bb74_termite_23_event_2d_manager = () => {
if (_x(_b)) {
return _bb78_termite_23_event_2d_manager();
} else {
return _bb85_termite_23_event_2d_manager();
}
});

_k(_bb86_termite_23_event_2d_manager = () => {
_r = _s[_t];
--_t;
return _p(_bb3_termite_23_event_2d_manager);
},1,1);

_j(_bb94_termite_23_event_2d_manager = () => {
if (_x(_a)) {
return _bb98_termite_23_event_2d_manager();
} else {
return _bb109_termite_23_event_2d_manager();
}
});

_k(_bb110_termite_23_event_2d_manager = () => {
_a = void 0;
--_t;
return _s[_t+1]();
},1,1);

_j(_bb21_termite_23_event_2d_manager = () => {
_r = _bb22_termite_23_event_2d_manager;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb52_termite_23_event_2d_manager = () => {
_r = _bb5_termite_23_event_2d_manager;
_n = 0;
_t -= 2;
return _g["thread-mailbox-next"]();
});

_j(_bb53_termite_23_event_2d_manager = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
_s[_t] = _d;
return _p(_bb57_termite_23_event_2d_manager);
});

_j(_bb60_termite_23_event_2d_manager = () => {
_r = _bb61_termite_23_event_2d_manager;
_n = 1;
return _b;
});

_j(_bb78_termite_23_event_2d_manager = () => {
_c = _b.a;
if (_x(_c)) {
return _bb79_termite_23_event_2d_manager();
} else {
return _bb82_termite_23_event_2d_manager();
}
});

_j(_bb85_termite_23_event_2d_manager = () => {
_a = null;
return _r;
});

_j(_bb98_termite_23_event_2d_manager = () => {
_b = _a.a;
if (_x(_b)) {
return _bb99_termite_23_event_2d_manager();
} else {
return _bb107_termite_23_event_2d_manager();
}
});

_j(_bb109_termite_23_event_2d_manager = () => {
_a = void 0;
return _r;
});

_k(_bb22_termite_23_event_2d_manager = () => {
_b = _s[_t-3];
_a = _s[_t-4];
_r = _bb29_termite_23_event_2d_manager;
return _bb23_termite_23_event_2d_manager();
},6,1);

_k(_bb61_termite_23_event_2d_manager = () => {
_a = _X(_s[_t],_a);
_a = _X(_a,_s[_t-1]);
_r = _s[_t-2];
_t -= 3;
return _p(_bb3_termite_23_event_2d_manager);
},3,1);

_j(_bb79_termite_23_event_2d_manager = () => {
_d = _c.a;
_c = _c.b;
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _d;
_b = _c;
_c = _d.a[2];
_t += 4;
return _p(_bb80_termite_23_event_2d_manager);
});

_j(_bb82_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _X(_cst56__termite,_X(_c,null));
_t += 3;
return _p(_bb83_termite_23_event_2d_manager);
});

_j(_bb99_termite_23_event_2d_manager = () => {
_c = _b.a;
_b = _b.b;
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _cst65__termite;
_c = _c.a[4];
_t += 2;
return _p(_bb100_termite_23_event_2d_manager);
});

_j(_bb107_termite_23_event_2d_manager = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _X(_cst56__termite,_X(_b,null));
_t += 2;
return _p(_bb108_termite_23_event_2d_manager);
});

_j(_bb23_termite_23_event_2d_manager = () => {
if (_x(_b)) {
return _bb26_termite_23_event_2d_manager();
} else {
return _bb28_termite_23_event_2d_manager();
}
});

_k(_bb29_termite_23_event_2d_manager = () => {
if (_x(_a)) {
return _bb30_termite_23_event_2d_manager();
} else {
return _bb44_termite_23_event_2d_manager();
}
},6,1);

_j(_bb80_termite_23_event_2d_manager = () => {
_r = _bb81_termite_23_event_2d_manager;
_n = 2;
return _c;
});

_j(_bb83_termite_23_event_2d_manager = () => {
_r = _bb75_termite_23_event_2d_manager;
_n = 1;
return _g["##raise"]();
});

_j(_bb100_termite_23_event_2d_manager = () => {
_r = _bb101_termite_23_event_2d_manager;
_n = 2;
return _c;
});

_j(_bb108_termite_23_event_2d_manager = () => {
_r = _bb101_termite_23_event_2d_manager;
_n = 1;
return _g["##raise"]();
});

_j(_bb26_termite_23_event_2d_manager = () => {
_c = _b.a;
_d = _c.a;
if (_a === _d) {
return _bb27_termite_23_event_2d_manager();
} else {
return _bb24_termite_23_event_2d_manager();
}
});

_j(_bb28_termite_23_event_2d_manager = () => {
_a = !1;
return _r;
});

_j(_bb30_termite_23_event_2d_manager = () => {
_b = _a.b;
_a = _a.a;
var closure0 = _closure_alloc([_bb42_termite_23_event_2d_manager,_s[_t-2],_a,_b]);
_s[_t+1] = closure0;
_s[_t-4] = _s[_t+1];
var closure1 = _closure_alloc([_bb32_termite_23_event_2d_manager,_s[_t-1],_s[_t],_a,_s[_t-3]]);
_s[_t+1] = closure1;
_b = _s[_t+1];
_r = _s[_t-5];
_a = _s[_t-4];
++_t;
return _p(_bb31_termite_23_event_2d_manager);
});

_j(_bb44_termite_23_event_2d_manager = () => {
if (_a === !1) {
return _bb45_termite_23_event_2d_manager();
} else {
return _bb47_termite_23_event_2d_manager();
}
});

_k(_bb81_termite_23_event_2d_manager = () => {
_a = _X(_s[_t],_a);
--_t;
return _bb76_termite_23_event_2d_manager();
},4,1);

_k(_bb75_termite_23_event_2d_manager = () => {
return _bb76_termite_23_event_2d_manager();
},3,1);

_k(_bb101_termite_23_event_2d_manager = () => {
return _bb102_termite_23_event_2d_manager();
},2,1);

_j(_bb27_termite_23_event_2d_manager = () => {
_a = _c;
return _r;
});

_j(_bb24_termite_23_event_2d_manager = () => {
_b = _b.b;
return _p(_bb25_termite_23_event_2d_manager);
});

_l(_bb42_termite_23_event_2d_manager = () => {
if (_n !== 0) {
return _w(_d);
}
_b = _d(!0)[3];
_a = _d(!0)[1];
_d = _d(!0)[2];
_c = _d.a[3];
return _p(_bb43_termite_23_event_2d_manager);
},3);

_l(_bb32_termite_23_event_2d_manager = () => {
if (_n !== 2) {
return _w(_d);
}
_c = _d(!0)[2];
_a = _X(_c,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _d;
_a = _d(!0)[1];
_t += 4;
return _p(_bb33_termite_23_event_2d_manager);
},4);

_j(_bb31_termite_23_event_2d_manager = () => {
_n = 2;
_t -= 7;
return _e["##call-with-values"]();
});

_j(_bb45_termite_23_event_2d_manager = () => {
_a = _cst246__termite;
_r = _s[_t-5];
return _p(_bb46_termite_23_event_2d_manager);
});

_j(_bb47_termite_23_event_2d_manager = () => {
_a = _X(_cst56__termite,_X(_a,null));
_r = _s[_t-5];
return _p(_bb48_termite_23_event_2d_manager);
});

_j(_bb76_termite_23_event_2d_manager = () => {
_s[_t+1] = _a;
_b = _s[_t].b;
_a = _s[_t-1];
_r = _bb84_termite_23_event_2d_manager;
++_t;
return _bb77_termite_23_event_2d_manager();
});

_j(_bb102_termite_23_event_2d_manager = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb103_termite_23_event_2d_manager();
} else {
return _bb106_termite_23_event_2d_manager();
}
});

_j(_bb25_termite_23_event_2d_manager = () => {
if (_x(_b)) {
return _bb26_termite_23_event_2d_manager();
} else {
return _bb28_termite_23_event_2d_manager();
}
});

_j(_bb43_termite_23_event_2d_manager = () => {
_n = 2;
return _c;
});

_j(_bb33_termite_23_event_2d_manager = () => {
_r = _bb34_termite_23_event_2d_manager;
_n = 1;
return _g["thread?"]();
});

_j(_bb46_termite_23_event_2d_manager = () => {
_n = 1;
_t -= 6;
return _g["##error"]();
});

_j(_bb48_termite_23_event_2d_manager = () => {
_n = 1;
_t -= 6;
return _g["##raise"]();
});

_j(_bb77_termite_23_event_2d_manager = () => {
if (_x(_b)) {
return _bb78_termite_23_event_2d_manager();
} else {
return _bb85_termite_23_event_2d_manager();
}
});

_k(_bb84_termite_23_event_2d_manager = () => {
_a = _X(_s[_t],_a);
_t -= 4;
return _s[_t+1]();
},4,1);

_j(_bb103_termite_23_event_2d_manager = () => {
_b = _a.a;
if (_x(_b)) {
return _bb104_termite_23_event_2d_manager();
} else {
return _bb105_termite_23_event_2d_manager();
}
});

_j(_bb106_termite_23_event_2d_manager = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb34_termite_23_event_2d_manager = () => {
if (!(_a === !1)) {
return _bb41_termite_23_event_2d_manager();
} else {
return _bb35_termite_23_event_2d_manager();
}
},4,1);

_j(_bb104_termite_23_event_2d_manager = () => {
_c = _b.b;
_b = _b.a;
_s[_t] = _a;
_s[_t+1] = _b;
_b = _c;
_a = _cst65__termite;
_c = _s[_t+1].a[4];
_r = _bb95_termite_23_event_2d_manager;
_n = 2;
return _c;
});

_j(_bb105_termite_23_event_2d_manager = () => {
_s[_t] = _a;
_a = _X(_cst56__termite,_X(_b,null));
_r = _bb95_termite_23_event_2d_manager;
_n = 1;
return _g["##raise"]();
});

_j(_bb41_termite_23_event_2d_manager = () => {
_b = _s[_t-2];
_a = _s[_t](!0)[1];
_r = _bb37_termite_23_event_2d_manager;
_n = 2;
return _g["thread-send"]();
});

_j(_bb35_termite_23_event_2d_manager = () => {
_r = _s[_t](!0)[1];
if (_r instanceof _Structure && _r.a[0].a[1] === _cst83__termite) {
return _bb36_termite_23_event_2d_manager();
} else {
return _bb40_termite_23_event_2d_manager();
}
});

_k(_bb95_termite_23_event_2d_manager = () => {
return _bb96_termite_23_event_2d_manager();
},2,1);

_k(_bb37_termite_23_event_2d_manager = () => {
return _bb38_termite_23_event_2d_manager();
},4,1);

_j(_bb36_termite_23_event_2d_manager = () => {
_r = _s[_t](!0)[1];
_b = _X(_cst77__termite,_X(_r,_X(_s[_t-2],null)));
_a = _g["termite#dispatcher"];
_r = _bb37_termite_23_event_2d_manager;
_n = 2;
return _g["thread-send"]();
});

_j(_bb40_termite_23_event_2d_manager = () => {
_b = _s[_t](!0)[1];
_a = _cst87__termite;
_r = _bb37_termite_23_event_2d_manager;
_n = 2;
return _g["##error"]();
});

_j(_bb96_termite_23_event_2d_manager = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb97_termite_23_event_2d_manager);
});

_j(_bb38_termite_23_event_2d_manager = () => {
var closure2 = _closure_alloc([_bb39_termite_23_event_2d_manager,_s[_t](!0)[3]]);
_s[_t+1] = closure2;
_a = _s[_t+1];
_b = _s[_t](!0)[4];
_r = _bb2_termite_23_event_2d_manager;
_n = 2;
return _g["##remove"]();
});

_j(_bb97_termite_23_event_2d_manager = () => {
if (_x(_a)) {
return _bb98_termite_23_event_2d_manager();
} else {
return _bb109_termite_23_event_2d_manager();
}
});

_l(_bb39_termite_23_event_2d_manager = () => {
if (_n !== 1) {
return _w(_d);
}
_d = _d(!0)[1];
_a = _a.a;
_a = _a === _d;
return _r;
},1);

_k(_bb2_termite_23_event_2d_manager = () => {
_r = _s[_t](!0)[3];
_b = _X(_r,_s[_t-1]);
_a = _X(_b,_a);
_r = _s[_t-3];
_t -= 4;
return _p(_bb3_termite_23_event_2d_manager);
},4,1);



_m(_bb1_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (_n !== 3) {
return _w(_bb1_termite_23_internal_2d_event_2d_manager_2d_start);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
_b = _cst15__termite;
_a = _bb1_termite_23_event_2d_manager;
_t += 2;
return _p(_bb2_termite_23_internal_2d_event_2d_manager_2d_start);
},-1,_i("termite#internal-event-manager-start"),!1,!0);

_j(_bb2_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_r = _bb3_termite_23_internal_2d_event_2d_manager_2d_start;
_n = 3;
return _bb1_termite_23_spawn();
});

_k(_bb3_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb24_termite_23_internal_2d_event_2d_manager_2d_start;
++_t;
return _bb4_termite_23_internal_2d_event_2d_manager_2d_start();
},2,1);

_j(_bb4_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (_x(_b)) {
return _bb7_termite_23_internal_2d_event_2d_manager_2d_start();
} else {
return _bb23_termite_23_internal_2d_event_2d_manager_2d_start();
}
});

_k(_bb24_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb7_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_c = _b.a;
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_b = _c;
_t += 3;
return _p(_bb8_termite_23_internal_2d_event_2d_manager_2d_start);
});

_j(_bb23_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_a = void 0;
return _r;
});

_j(_bb8_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_r = _bb18_termite_23_internal_2d_event_2d_manager_2d_start;
_n = 2;
return _bb9_termite_23_internal_2d_event_2d_manager_2d_start();
});

_l(_bb9_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (_n === 2) {
_c = null;
} else {
if (!_build_rest(2)) {
return _w(_bb9_termite_23_internal_2d_event_2d_manager_2d_start);
}
}
_b = _X(_cst245__termite,_X(_b,_X(_c,null)));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb10_termite_23_internal_2d_event_2d_manager_2d_start);
},-1);

_k(_bb18_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb19_termite_23_internal_2d_event_2d_manager_2d_start();
} else {
return _bb22_termite_23_internal_2d_event_2d_manager_2d_start();
}
},3,1);

_j(_bb10_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_r = _bb11_termite_23_internal_2d_event_2d_manager_2d_start;
_n = 1;
return _g["thread?"]();
});

_j(_bb19_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_b = _a.a;
_s[_t] = _a;
_a = _s[_t-1];
_r = _bb5_termite_23_internal_2d_event_2d_manager_2d_start;
_n = 2;
return _bb20_termite_23_internal_2d_event_2d_manager_2d_start();
});

_j(_bb22_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_a = void 0;
_t -= 3;
return _s[_t+1]();
});

_k(_bb11_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (!(_a === !1)) {
return _bb12_termite_23_internal_2d_event_2d_manager_2d_start();
} else {
return _bb13_termite_23_internal_2d_event_2d_manager_2d_start();
}
},3,1);

_l(_bb20_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (_n === 2) {
_c = null;
} else {
if (!_build_rest(2)) {
return _w(_bb20_termite_23_internal_2d_event_2d_manager_2d_start);
}
}
_b = _X(_cst245__termite,_X(_b,_X(_c,null)));
return _p(_bb21_termite_23_internal_2d_event_2d_manager_2d_start);
},-1);

_k(_bb5_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_b = _s[_t].b;
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 3;
return _p(_bb6_termite_23_internal_2d_event_2d_manager_2d_start);
},3,1);

_j(_bb12_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb15_termite_23_internal_2d_event_2d_manager_2d_start);
});

_j(_bb13_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb14_termite_23_internal_2d_event_2d_manager_2d_start();
} else {
return _bb16_termite_23_internal_2d_event_2d_manager_2d_start();
}
});

_j(_bb21_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_n = 2;
return _bb1_termite_23__21_();
});

_j(_bb6_termite_23_internal_2d_event_2d_manager_2d_start = () => {
if (_x(_b)) {
return _bb7_termite_23_internal_2d_event_2d_manager_2d_start();
} else {
return _bb23_termite_23_internal_2d_event_2d_manager_2d_start();
}
});

_j(_bb15_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb14_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb15_termite_23_internal_2d_event_2d_manager_2d_start);
});

_j(_bb16_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb17_termite_23_internal_2d_event_2d_manager_2d_start);
});

_j(_bb17_termite_23_internal_2d_event_2d_manager_2d_start = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_event_2d_manager_3a_start = () => {
if (_n === 0) {
_a = _cst53__termite;
_b = null;
} else {
var error = _build_key_rest(0,2,[_cst15__termite,_cst53__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_event_2d_manager_3a_start,error);
}
}
_c = _a;
_a = _bb1_termite_23_spawn;
return _p(_bb2_termite_23_event_2d_manager_3a_start);
},-1,_i("termite#event-manager:start"),!1,!0);

_j(_bb2_termite_23_event_2d_manager_3a_start = () => {
_n = 3;
return _bb1_termite_23_internal_2d_event_2d_manager_2d_start();
});



_m(_bb1_termite_23_event_2d_manager_3a_start_2d_link = () => {
if (_n === 0) {
_a = _cst247__termite;
_b = null;
} else {
var error = _build_key_rest(0,2,[_cst15__termite,_cst247__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_event_2d_manager_3a_start_2d_link,error);
}
}
_c = _a;
_a = _bb1_termite_23_spawn_2d_link;
return _p(_bb2_termite_23_event_2d_manager_3a_start_2d_link);
},-1,_i("termite#event-manager:start-link"),!1,!0);

_j(_bb2_termite_23_event_2d_manager_3a_start_2d_link = () => {
_n = 3;
return _bb1_termite_23_internal_2d_event_2d_manager_2d_start();
});



_m(_bb1_termite_23_event_2d_manager_3a_add_2d_handler = () => {
if (_n === 2) {
_c = null;
} else {
if (!_build_rest(2)) {
return _w(_bb1_termite_23_event_2d_manager_3a_add_2d_handler);
}
}
_b = _X(_cst245__termite,_X(_b,_X(_c,null)));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_event_2d_manager_3a_add_2d_handler);
},-1,_i("termite#event-manager:add-handler"),!1,!0);

_j(_bb2_termite_23_event_2d_manager_3a_add_2d_handler = () => {
_r = _bb3_termite_23_event_2d_manager_3a_add_2d_handler;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_event_2d_manager_3a_add_2d_handler = () => {
if (!(_a === !1)) {
return _bb4_termite_23_event_2d_manager_3a_add_2d_handler();
} else {
return _bb5_termite_23_event_2d_manager_3a_add_2d_handler();
}
},3,1);

_j(_bb4_termite_23_event_2d_manager_3a_add_2d_handler = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_event_2d_manager_3a_add_2d_handler);
});

_j(_bb5_termite_23_event_2d_manager_3a_add_2d_handler = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_event_2d_manager_3a_add_2d_handler();
} else {
return _bb8_termite_23_event_2d_manager_3a_add_2d_handler();
}
});

_j(_bb7_termite_23_event_2d_manager_3a_add_2d_handler = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_event_2d_manager_3a_add_2d_handler = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_event_2d_manager_3a_add_2d_handler);
});

_j(_bb8_termite_23_event_2d_manager_3a_add_2d_handler = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_event_2d_manager_3a_add_2d_handler);
});

_j(_bb9_termite_23_event_2d_manager_3a_add_2d_handler = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_event_2d_manager_3a_notify = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_event_2d_manager_3a_notify);
}
_b = _X(_cst47__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_event_2d_manager_3a_notify);
},-1,_i("termite#event-manager:notify"),!1,!0);

_j(_bb2_termite_23_event_2d_manager_3a_notify = () => {
_r = _bb3_termite_23_event_2d_manager_3a_notify;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_event_2d_manager_3a_notify = () => {
if (!(_a === !1)) {
return _bb4_termite_23_event_2d_manager_3a_notify();
} else {
return _bb5_termite_23_event_2d_manager_3a_notify();
}
},3,1);

_j(_bb4_termite_23_event_2d_manager_3a_notify = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_event_2d_manager_3a_notify);
});

_j(_bb5_termite_23_event_2d_manager_3a_notify = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_event_2d_manager_3a_notify();
} else {
return _bb8_termite_23_event_2d_manager_3a_notify();
}
});

_j(_bb7_termite_23_event_2d_manager_3a_notify = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_event_2d_manager_3a_notify = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_event_2d_manager_3a_notify);
});

_j(_bb8_termite_23_event_2d_manager_3a_notify = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_event_2d_manager_3a_notify);
});

_j(_bb9_termite_23_event_2d_manager_3a_notify = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_event_2d_manager_3a_call = () => {
if (_n !== 3) {
return _w(_bb1_termite_23_event_2d_manager_3a_call);
}
_b = _X(_cst48__termite,_X(_b,_X(_c,null)));
_c = 1;
return _p(_bb2_termite_23_event_2d_manager_3a_call);
},-1,_i("termite#event-manager:call"),!1,!0);

_j(_bb2_termite_23_event_2d_manager_3a_call = () => {
_n = 3;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_event_2d_manager_3a_stop = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_event_2d_manager_3a_stop);
}
_b = _X(_cst241__termite,null);
return _p(_bb2_termite_23_event_2d_manager_3a_stop);
},-1,_i("termite#event-manager:stop"),!1,!0);

_j(_bb2_termite_23_event_2d_manager_3a_stop = () => {
_n = 2;
return _bb1_termite_23__21_();
});



_m(_bb1_termite_23_make_2d_simple_2d_event_2d_handler = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_make_2d_simple_2d_event_2d_handler);
}
var closure0 = _closure_alloc([_bb6_termite_23_make_2d_simple_2d_event_2d_handler,_b]);
var closure1 = _closure_alloc([_bb4_termite_23_make_2d_simple_2d_event_2d_handler,_a]);
_s[_t+1] = closure0;
_s[_t+2] = closure1;
_a = new _Structure([_cst33__termite,_s[_t+1],_s[_t+2],_bb3_termite_23_make_2d_simple_2d_event_2d_handler,_bb2_termite_23_make_2d_simple_2d_event_2d_handler]);
return _r;
},-1,_i("termite#make-simple-event-handler"),!1,!0);

_l(_bb6_termite_23_make_2d_simple_2d_event_2d_handler = () => {
if (_n !== 1) {
return _w(_d);
}
_a = _d(!0)[1];
return _r;
},1);

_l(_bb4_termite_23_make_2d_simple_2d_event_2d_handler = () => {
if (_n !== 2) {
return _w(_d);
}
return _p(_bb5_termite_23_make_2d_simple_2d_event_2d_handler);
},1);

_l(_bb3_termite_23_make_2d_simple_2d_event_2d_handler = () => {
if (_n !== 2) {
return _w(_bb3_termite_23_make_2d_simple_2d_event_2d_handler);
}
_a = new _Values([void 0,_b]);
return _r;
},-1);

_l(_bb2_termite_23_make_2d_simple_2d_event_2d_handler = () => {
if (_n !== 2) {
return _w(_bb2_termite_23_make_2d_simple_2d_event_2d_handler);
}
_a = void 0;
return _r;
},-1);

_j(_bb5_termite_23_make_2d_simple_2d_event_2d_handler = () => {
_n = 2;
return _d(!0)[1]();
});



_m(_bb1_termite_23_data_2d_make_2d_process_2d_name = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_data_2d_make_2d_process_2d_name);
}
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _current_processor.a[14];
_t += 2;
return _p(_bb2_termite_23_data_2d_make_2d_process_2d_name);
},-1,_i("termite#data-make-process-name"),!1,!0);

_j(_bb2_termite_23_data_2d_make_2d_process_2d_name = () => {
_r = _bb3_termite_23_data_2d_make_2d_process_2d_name;
_n = 1;
return _g["thread-name"]();
});

_k(_bb3_termite_23_data_2d_make_2d_process_2d_name = () => {
var tmp0 = _a.d;
_b = _y(tmp0) ? !1 : tmp0;
if (!(_b === !1)) {
return _bb5_termite_23_data_2d_make_2d_process_2d_name();
} else {
return _bb10_termite_23_data_2d_make_2d_process_2d_name();
}
},2,1);

_j(_bb5_termite_23_data_2d_make_2d_process_2d_name = () => {
_s[_t+1] = _b;
var tmp1 = _s[_t].d;
_a = _y(tmp1) ? !1 : tmp1;
if (!(_a === !1)) {
++_t;
return _bb8_termite_23_data_2d_make_2d_process_2d_name();
} else {
++_t;
return _bb6_termite_23_data_2d_make_2d_process_2d_name();
}
});

_j(_bb10_termite_23_data_2d_make_2d_process_2d_name = () => {
_r = _bb4_termite_23_data_2d_make_2d_process_2d_name;
_n = 1;
return _e["##symbol->string"]();
});

_j(_bb8_termite_23_data_2d_make_2d_process_2d_name = () => {
_c = _a;
_b = _cst249__termite;
_a = _s[_t];
_r = _bb9_termite_23_data_2d_make_2d_process_2d_name;
_n = 3;
_t -= 2;
return _e["##string-append"]();
});

_j(_bb6_termite_23_data_2d_make_2d_process_2d_name = () => {
_a = _s[_t-1];
_r = _bb7_termite_23_data_2d_make_2d_process_2d_name;
_n = 1;
return _e["##symbol->string"]();
});

_k(_bb4_termite_23_data_2d_make_2d_process_2d_name = () => {
_b = _a;
return _bb5_termite_23_data_2d_make_2d_process_2d_name();
},2,1);

_k(_bb9_termite_23_data_2d_make_2d_process_2d_name = () => {
_a = _i(_a.toString());
--_t;
return _s[_t+1]();
},1,1);

_k(_bb7_termite_23_data_2d_make_2d_process_2d_name = () => {
return _bb8_termite_23_data_2d_make_2d_process_2d_name();
},3,1);



_m(_bb1_termite_23_make_2d_cell = () => {
if (_n === 0) {
_a = _absent_obj;
_b = null;
} else {
var error = _build_key_rest(0,2,[_cst15__termite,_absent_obj]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_make_2d_cell,error);
}
}
if (_a === _absent_obj) {
return _bb2_termite_23_make_2d_cell();
} else {
return _bb5_termite_23_make_2d_cell();
}
},-1,_i("termite#make-cell"),!1,!0);

_j(_bb2_termite_23_make_2d_cell = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_a = _cst250__termite;
_t += 2;
return _p(_bb3_termite_23_make_2d_cell);
});

_j(_bb5_termite_23_make_2d_cell = () => {
var closure0 = _closure_alloc([_bb119_termite_23_make_2d_cell,_b]);
_s[_t+1] = closure0;
_s[_t+2] = _a;
_a = _s[_t+1];
_c = _s[_t+2];
_b = _cst15__termite;
_t += 2;
return _p(_bb6_termite_23_make_2d_cell);
});

_j(_bb3_termite_23_make_2d_cell = () => {
_r = _bb4_termite_23_make_2d_cell;
_n = 1;
return _bb1_termite_23_data_2d_make_2d_process_2d_name();
});

_l(_bb119_termite_23_make_2d_cell = () => {
if (_n !== 0) {
return _w(_d);
}
_c = _d(!0)[1];
if (_x(_c)) {
return _bb120_termite_23_make_2d_cell();
} else {
return _bb151_termite_23_make_2d_cell();
}
},1);

_j(_bb6_termite_23_make_2d_cell = () => {
_n = 3;
_t -= 2;
return _bb7_termite_23_make_2d_cell();
});

_k(_bb4_termite_23_make_2d_cell = () => {
_b = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _bb5_termite_23_make_2d_cell();
},2,1);

_j(_bb120_termite_23_make_2d_cell = () => {
_d = _d(!0)[1];
_a = _d.a;
return _p(_bb122_termite_23_make_2d_cell);
});

_j(_bb151_termite_23_make_2d_cell = () => {
_a = void 0;
return _p(_bb122_termite_23_make_2d_cell);
});

_l(_bb7_termite_23_make_2d_cell = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb7_termite_23_make_2d_cell,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure1 = _closure_alloc([_bb12_termite_23_make_2d_cell,_a]);
_s[_t+3] = closure1;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb8_termite_23_make_2d_cell);
},-1);

_j(_bb122_termite_23_make_2d_cell = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb123_termite_23_make_2d_cell);
});

_l(_bb12_termite_23_make_2d_cell = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb13_termite_23_make_2d_cell);
},1);

_j(_bb8_termite_23_make_2d_cell = () => {
_r = _bb9_termite_23_make_2d_cell;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb123_termite_23_make_2d_cell = () => {
_r = _bb124_termite_23_make_2d_cell;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb13_termite_23_make_2d_cell = () => {
_r = _bb14_termite_23_make_2d_cell;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb9_termite_23_make_2d_cell = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb10_termite_23_make_2d_cell;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_k(_bb124_termite_23_make_2d_cell = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb125_termite_23_make_2d_cell);
},2,1);

_k(_bb14_termite_23_make_2d_cell = () => {
_a = _current_processor.a[14];
_r = _bb15_termite_23_make_2d_cell;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb10_termite_23_make_2d_cell = () => {
_a = _s[_t];
_r = _bb11_termite_23_make_2d_cell;
_n = 1;
return _g["thread-start!"]();
},3,1);

_j(_bb125_termite_23_make_2d_cell = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb126_termite_23_make_2d_cell();
} else {
return _bb130_termite_23_make_2d_cell();
}
});

_k(_bb15_termite_23_make_2d_cell = () => {
_r = _bb117_termite_23_make_2d_cell;
return _bb16_termite_23_make_2d_cell();
},1,1);

_k(_bb11_termite_23_make_2d_cell = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb126_termite_23_make_2d_cell = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb127_termite_23_make_2d_cell);
});

_j(_bb130_termite_23_make_2d_cell = () => {
if (_x(_b)) {
return _bb131_termite_23_make_2d_cell();
} else {
return _bb148_termite_23_make_2d_cell();
}
});

_j(_bb16_termite_23_make_2d_cell = () => {
if (_x(_a)) {
return _bb20_termite_23_make_2d_cell();
} else {
return _bb116_termite_23_make_2d_cell();
}
});

_k(_bb117_termite_23_make_2d_cell = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb118_termite_23_make_2d_cell);
},1,1);

_j(_bb127_termite_23_make_2d_cell = () => {
_r = _bb128_termite_23_make_2d_cell;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb131_termite_23_make_2d_cell = () => {
_c = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb132_termite_23_make_2d_cell();
} else {
return _bb148_termite_23_make_2d_cell();
}
});

_j(_bb148_termite_23_make_2d_cell = () => {
return _p(_bb122_termite_23_make_2d_cell);
});

_j(_bb20_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb21_termite_23_make_2d_cell);
});

_j(_bb116_termite_23_make_2d_cell = () => {
_a = void 0;
return _r;
});

_j(_bb118_termite_23_make_2d_cell = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_k(_bb128_termite_23_make_2d_cell = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb129_termite_23_make_2d_cell);
},2,1);

_j(_bb132_termite_23_make_2d_cell = () => {
_d = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb133_termite_23_make_2d_cell();
} else {
return _bb142_termite_23_make_2d_cell();
}
});

_j(_bb21_termite_23_make_2d_cell = () => {
_r = _bb22_termite_23_make_2d_cell;
_n = 1;
return _g["thread?"]();
});

_j(_bb129_termite_23_make_2d_cell = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb133_termite_23_make_2d_cell = () => {
_s[_t+1] = _b.a;
_b = _b.b;
if (_s[_t+1] === _cst251__termite) {
++_t;
return _bb134_termite_23_make_2d_cell();
} else {
++_t;
return _bb139_termite_23_make_2d_cell();
}
});

_j(_bb142_termite_23_make_2d_cell = () => {
if (_c === _cst252__termite) {
return _bb143_termite_23_make_2d_cell();
} else {
return _bb148_termite_23_make_2d_cell();
}
});

_k(_bb22_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb115_termite_23_make_2d_cell();
} else {
return _bb23_termite_23_make_2d_cell();
}
},4,1);

_j(_bb134_termite_23_make_2d_cell = () => {
if (_b === null) {
return _bb135_termite_23_make_2d_cell();
} else {
return _bb138_termite_23_make_2d_cell();
}
});

_j(_bb139_termite_23_make_2d_cell = () => {
if (_s[_t] === _cst253__termite) {
return _bb140_termite_23_make_2d_cell();
} else {
return _bb150_termite_23_make_2d_cell();
}
});

_j(_bb143_termite_23_make_2d_cell = () => {
if (_b === null) {
return _bb144_termite_23_make_2d_cell();
} else {
return _bb148_termite_23_make_2d_cell();
}
});

_j(_bb115_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb25_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb23_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb24_termite_23_make_2d_cell();
} else {
return _bb114_termite_23_make_2d_cell();
}
});

_j(_bb135_termite_23_make_2d_cell = () => {
_s[_t] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_t += 3;
return _p(_bb136_termite_23_make_2d_cell);
});

_j(_bb138_termite_23_make_2d_cell = () => {
_s[_t] = _r;
_s[_t+1] = _a;
++_t;
return _p(_bb123_termite_23_make_2d_cell);
});

_j(_bb140_termite_23_make_2d_cell = () => {
if (_b === null) {
return _bb141_termite_23_make_2d_cell();
} else {
return _bb150_termite_23_make_2d_cell();
}
});

_j(_bb150_termite_23_make_2d_cell = () => {
--_t;
return _p(_bb122_termite_23_make_2d_cell);
});

_j(_bb144_termite_23_make_2d_cell = () => {
_s[_t+1] = _r;
_s[_t+2] = _d;
_r = _bb121_termite_23_make_2d_cell;
_t += 2;
return _p(_bb145_termite_23_make_2d_cell);
});

_k(_bb25_termite_23_make_2d_cell = () => {
return _bb26_termite_23_make_2d_cell();
},2,1);

_j(_bb24_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb25_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb114_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb25_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb136_termite_23_make_2d_cell = () => {
_r = _bb137_termite_23_make_2d_cell;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb141_termite_23_make_2d_cell = () => {
_s[_t] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb149_termite_23_make_2d_cell;
_t += 3;
return _p(_bb145_termite_23_make_2d_cell);
});

_j(_bb145_termite_23_make_2d_cell = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb146_termite_23_make_2d_cell);
});

_k(_bb121_termite_23_make_2d_cell = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb122_termite_23_make_2d_cell);
},2,1);

_j(_bb26_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb27_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_k(_bb137_termite_23_make_2d_cell = () => {
_a = void 0 === _s[_t-2];
_b = _X(_s[_t],_X(_a,null));
_a = _s[_t-1];
_r = _bb121_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _bb1_termite_23__21_();
},4,1);

_k(_bb149_termite_23_make_2d_cell = () => {
_b = _X(_s[_t],_X(_s[_t-2],null));
_a = _s[_t-1];
_r = _bb121_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _bb1_termite_23__21_();
},4,1);

_j(_bb146_termite_23_make_2d_cell = () => {
_r = _bb147_termite_23_make_2d_cell;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb27_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb28_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb93_termite_23_make_2d_cell = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb147_termite_23_make_2d_cell = () => {
--_t;
return _s[_t+1]();
},1,1);

_k(_bb28_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb113_termite_23_make_2d_cell();
} else {
return _bb29_termite_23_make_2d_cell();
}
},4,1);

_j(_bb113_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb31_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb29_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb30_termite_23_make_2d_cell();
} else {
return _bb112_termite_23_make_2d_cell();
}
});

_k(_bb31_termite_23_make_2d_cell = () => {
return _bb32_termite_23_make_2d_cell();
},2,1);

_j(_bb30_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb31_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb112_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb31_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb32_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb33_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb33_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb34_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb34_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb111_termite_23_make_2d_cell();
} else {
return _bb35_termite_23_make_2d_cell();
}
},4,1);

_j(_bb111_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb37_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb35_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb36_termite_23_make_2d_cell();
} else {
return _bb110_termite_23_make_2d_cell();
}
});

_k(_bb37_termite_23_make_2d_cell = () => {
return _bb38_termite_23_make_2d_cell();
},2,1);

_j(_bb36_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb37_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb110_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb37_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb38_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb39_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb39_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb40_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb40_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb109_termite_23_make_2d_cell();
} else {
return _bb41_termite_23_make_2d_cell();
}
},4,1);

_j(_bb109_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb43_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb41_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb42_termite_23_make_2d_cell();
} else {
return _bb108_termite_23_make_2d_cell();
}
});

_k(_bb43_termite_23_make_2d_cell = () => {
return _bb44_termite_23_make_2d_cell();
},2,1);

_j(_bb42_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb43_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb108_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb43_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb44_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb45_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb45_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb46_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb46_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb107_termite_23_make_2d_cell();
} else {
return _bb47_termite_23_make_2d_cell();
}
},4,1);

_j(_bb107_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb49_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb47_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb48_termite_23_make_2d_cell();
} else {
return _bb106_termite_23_make_2d_cell();
}
});

_k(_bb49_termite_23_make_2d_cell = () => {
return _bb50_termite_23_make_2d_cell();
},2,1);

_j(_bb48_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb49_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb106_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb49_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb50_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb51_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb51_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb52_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb52_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb105_termite_23_make_2d_cell();
} else {
return _bb53_termite_23_make_2d_cell();
}
},4,1);

_j(_bb105_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb55_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb53_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb54_termite_23_make_2d_cell();
} else {
return _bb104_termite_23_make_2d_cell();
}
});

_k(_bb55_termite_23_make_2d_cell = () => {
return _bb56_termite_23_make_2d_cell();
},2,1);

_j(_bb54_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb55_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb104_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb55_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb56_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb57_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb57_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb58_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb58_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb103_termite_23_make_2d_cell();
} else {
return _bb59_termite_23_make_2d_cell();
}
},4,1);

_j(_bb103_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb61_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb59_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb60_termite_23_make_2d_cell();
} else {
return _bb102_termite_23_make_2d_cell();
}
});

_k(_bb61_termite_23_make_2d_cell = () => {
return _bb62_termite_23_make_2d_cell();
},2,1);

_j(_bb60_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb61_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb102_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb61_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb62_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb63_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb63_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb64_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb64_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb101_termite_23_make_2d_cell();
} else {
return _bb65_termite_23_make_2d_cell();
}
},4,1);

_j(_bb101_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb67_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb65_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb66_termite_23_make_2d_cell();
} else {
return _bb100_termite_23_make_2d_cell();
}
});

_k(_bb67_termite_23_make_2d_cell = () => {
return _bb68_termite_23_make_2d_cell();
},2,1);

_j(_bb66_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb67_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb100_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb67_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb68_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb69_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb69_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb70_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb70_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb99_termite_23_make_2d_cell();
} else {
return _bb71_termite_23_make_2d_cell();
}
},4,1);

_j(_bb99_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb73_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb71_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb72_termite_23_make_2d_cell();
} else {
return _bb98_termite_23_make_2d_cell();
}
});

_k(_bb73_termite_23_make_2d_cell = () => {
return _bb74_termite_23_make_2d_cell();
},2,1);

_j(_bb72_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb73_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb98_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb73_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb74_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb75_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb75_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb76_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb76_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb97_termite_23_make_2d_cell();
} else {
return _bb77_termite_23_make_2d_cell();
}
},4,1);

_j(_bb97_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb79_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb77_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb78_termite_23_make_2d_cell();
} else {
return _bb96_termite_23_make_2d_cell();
}
});

_k(_bb79_termite_23_make_2d_cell = () => {
return _bb80_termite_23_make_2d_cell();
},2,1);

_j(_bb78_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb79_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb96_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb79_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb80_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb81_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb81_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb82_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb82_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb95_termite_23_make_2d_cell();
} else {
return _bb83_termite_23_make_2d_cell();
}
},4,1);

_j(_bb95_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb85_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb83_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb84_termite_23_make_2d_cell();
} else {
return _bb94_termite_23_make_2d_cell();
}
});

_k(_bb85_termite_23_make_2d_cell = () => {
return _bb86_termite_23_make_2d_cell();
},2,1);

_j(_bb84_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb85_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb94_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb85_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb86_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb87_termite_23_make_2d_cell();
} else {
return _bb93_termite_23_make_2d_cell();
}
});

_j(_bb87_termite_23_make_2d_cell = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb88_termite_23_make_2d_cell;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_k(_bb88_termite_23_make_2d_cell = () => {
if (!(_a === !1)) {
return _bb92_termite_23_make_2d_cell();
} else {
return _bb89_termite_23_make_2d_cell();
}
},4,1);

_j(_bb92_termite_23_make_2d_cell = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb17_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb89_termite_23_make_2d_cell = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb90_termite_23_make_2d_cell();
} else {
return _bb91_termite_23_make_2d_cell();
}
});

_k(_bb17_termite_23_make_2d_cell = () => {
return _bb18_termite_23_make_2d_cell();
},2,1);

_j(_bb90_termite_23_make_2d_cell = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb17_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb91_termite_23_make_2d_cell = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb17_termite_23_make_2d_cell;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb18_termite_23_make_2d_cell = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb19_termite_23_make_2d_cell);
});

_j(_bb19_termite_23_make_2d_cell = () => {
if (_x(_a)) {
return _bb20_termite_23_make_2d_cell();
} else {
return _bb116_termite_23_make_2d_cell();
}
});



_m(_bb1_termite_23_cell_2d_ref = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_cell_2d_ref);
}
_b = _cst253__termite;
return _p(_bb2_termite_23_cell_2d_ref);
},-1,_i("termite#cell-ref"),!1,!0);

_j(_bb2_termite_23_cell_2d_ref = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_cell_2d_set_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_cell_2d_set_21_);
}
_b = _X(_cst252__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_cell_2d_set_21_);
},-1,_i("termite#cell-set!"),!1,!0);

_j(_bb2_termite_23_cell_2d_set_21_ = () => {
_r = _bb3_termite_23_cell_2d_set_21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_cell_2d_set_21_ = () => {
if (!(_a === !1)) {
return _bb4_termite_23_cell_2d_set_21_();
} else {
return _bb5_termite_23_cell_2d_set_21_();
}
},3,1);

_j(_bb4_termite_23_cell_2d_set_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_cell_2d_set_21_);
});

_j(_bb5_termite_23_cell_2d_set_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_cell_2d_set_21_();
} else {
return _bb8_termite_23_cell_2d_set_21_();
}
});

_j(_bb7_termite_23_cell_2d_set_21_ = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_cell_2d_set_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_cell_2d_set_21_);
});

_j(_bb8_termite_23_cell_2d_set_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_cell_2d_set_21_);
});

_j(_bb9_termite_23_cell_2d_set_21_ = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_cell_2d_empty_21_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_cell_2d_empty_21_);
}
_b = _X(_cst252__termite,_X(void 0,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_cell_2d_empty_21_);
},-1,_i("termite#cell-empty!"),!1,!0);

_j(_bb2_termite_23_cell_2d_empty_21_ = () => {
_r = _bb3_termite_23_cell_2d_empty_21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_cell_2d_empty_21_ = () => {
if (!(_a === !1)) {
return _bb4_termite_23_cell_2d_empty_21_();
} else {
return _bb5_termite_23_cell_2d_empty_21_();
}
},3,1);

_j(_bb4_termite_23_cell_2d_empty_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_cell_2d_empty_21_);
});

_j(_bb5_termite_23_cell_2d_empty_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_cell_2d_empty_21_();
} else {
return _bb8_termite_23_cell_2d_empty_21_();
}
});

_j(_bb7_termite_23_cell_2d_empty_21_ = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_cell_2d_empty_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_cell_2d_empty_21_);
});

_j(_bb8_termite_23_cell_2d_empty_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_cell_2d_empty_21_);
});

_j(_bb9_termite_23_cell_2d_empty_21_ = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_cell_2d_empty_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_cell_2d_empty_3f_);
}
_b = _cst251__termite;
return _p(_bb2_termite_23_cell_2d_empty_3f_);
},-1,_i("termite#cell-empty?"),!1,!0);

_j(_bb2_termite_23_cell_2d_empty_3f_ = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_make_2d_dict = () => {
var error = _build_key(0,1,[_cst15__termite,_absent_obj]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_make_2d_dict,error);
}
if (_a === _absent_obj) {
return _bb2_termite_23_make_2d_dict();
} else {
return _bb5_termite_23_make_2d_dict();
}
},-1,_i("termite#make-dict"),!1,!0);

_j(_bb2_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_a = _cst254__termite;
++_t;
return _p(_bb3_termite_23_make_2d_dict);
});

_j(_bb5_termite_23_make_2d_dict = () => {
_s[_t+1] = _a;
_a = _bb3127_termite_23_make_2d_dict;
_c = _s[_t+1];
_b = _cst15__termite;
++_t;
return _p(_bb6_termite_23_make_2d_dict);
});

_j(_bb3_termite_23_make_2d_dict = () => {
_r = _bb4_termite_23_make_2d_dict;
_n = 1;
return _bb1_termite_23_data_2d_make_2d_process_2d_name();
});

_l(_bb3127_termite_23_make_2d_dict = () => {
if (_n !== 0) {
return _w(_bb3127_termite_23_make_2d_dict);
}
_s[_t+1] = _r;
_s[_t+2] = _cst255__termite;
_c = !1;
_b = _cst256__termite;
_a = _e["##equal?"];
_t += 2;
return _p(_bb3128_termite_23_make_2d_dict);
},-1);

_j(_bb6_termite_23_make_2d_dict = () => {
_n = 3;
--_t;
return _bb7_termite_23_make_2d_dict();
});

_k(_bb4_termite_23_make_2d_dict = () => {
_r = _s[_t];
--_t;
return _bb5_termite_23_make_2d_dict();
},1,1);

_j(_bb3128_termite_23_make_2d_dict = () => {
_r = _bb3129_termite_23_make_2d_dict;
_n = 4;
return _g["##make-table"]();
});

_l(_bb7_termite_23_make_2d_dict = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb7_termite_23_make_2d_dict,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb12_termite_23_make_2d_dict,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb8_termite_23_make_2d_dict);
},-1);

_k(_bb3129_termite_23_make_2d_dict = () => {
_r = _s[_t];
--_t;
return _p(_bb3131_termite_23_make_2d_dict);
},1,1);

_l(_bb12_termite_23_make_2d_dict = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb13_termite_23_make_2d_dict);
},1);

_j(_bb8_termite_23_make_2d_dict = () => {
_r = _bb9_termite_23_make_2d_dict;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb3131_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb3132_termite_23_make_2d_dict);
});

_j(_bb13_termite_23_make_2d_dict = () => {
_r = _bb14_termite_23_make_2d_dict;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb9_termite_23_make_2d_dict = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb10_termite_23_make_2d_dict;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb3132_termite_23_make_2d_dict = () => {
_r = _bb3133_termite_23_make_2d_dict;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb14_termite_23_make_2d_dict = () => {
_a = _current_processor.a[14];
_r = _bb15_termite_23_make_2d_dict;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb10_termite_23_make_2d_dict = () => {
_a = _s[_t];
_r = _bb11_termite_23_make_2d_dict;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb3133_termite_23_make_2d_dict = () => {
_b = _a;
_a = _s[_t];
_r = _bb3130_termite_23_make_2d_dict;
return _bb3134_termite_23_make_2d_dict();
},2,1);

_k(_bb15_termite_23_make_2d_dict = () => {
_r = _bb3125_termite_23_make_2d_dict;
return _bb16_termite_23_make_2d_dict();
},1,1);

_k(_bb11_termite_23_make_2d_dict = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb3134_termite_23_make_2d_dict = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb3137_termite_23_make_2d_dict();
} else {
return _bb3141_termite_23_make_2d_dict();
}
});

_k(_bb3130_termite_23_make_2d_dict = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb3131_termite_23_make_2d_dict);
},2,1);

_j(_bb16_termite_23_make_2d_dict = () => {
if (_x(_a)) {
return _bb20_termite_23_make_2d_dict();
} else {
return _bb3124_termite_23_make_2d_dict();
}
});

_k(_bb3125_termite_23_make_2d_dict = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb3126_termite_23_make_2d_dict);
},1,1);

_j(_bb3137_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_t += 2;
return _p(_bb3138_termite_23_make_2d_dict);
});

_j(_bb3141_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3142_termite_23_make_2d_dict();
} else {
return _bb3867_termite_23_make_2d_dict();
}
});

_j(_bb20_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb21_termite_23_make_2d_dict);
});

_j(_bb3124_termite_23_make_2d_dict = () => {
_a = void 0;
return _r;
});

_j(_bb3126_termite_23_make_2d_dict = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb3138_termite_23_make_2d_dict = () => {
_r = _bb3139_termite_23_make_2d_dict;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb3142_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb3143_termite_23_make_2d_dict();
} else {
return _bb3866_termite_23_make_2d_dict();
}
});

_j(_bb3867_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb21_termite_23_make_2d_dict = () => {
_r = _bb22_termite_23_make_2d_dict;
_n = 1;
return _g["thread?"]();
});

_k(_bb3139_termite_23_make_2d_dict = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb3140_termite_23_make_2d_dict);
},2,1);

_j(_bb3143_termite_23_make_2d_dict = () => {
_d = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb3144_termite_23_make_2d_dict();
} else {
return _bb3190_termite_23_make_2d_dict();
}
});

_j(_bb3866_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3184_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb3185_termite_23_make_2d_dict);
});

_k(_bb22_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3122_termite_23_make_2d_dict();
} else {
return _bb23_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3140_termite_23_make_2d_dict = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb3144_termite_23_make_2d_dict = () => {
_s[_t+1] = _b.a;
_b = _b.b;
if (_x(_s[_t+1])) {
++_t;
return _bb3145_termite_23_make_2d_dict();
} else {
++_t;
return _bb3822_termite_23_make_2d_dict();
}
});

_j(_bb3190_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3206_termite_23_make_2d_dict();
} else {
return _bb3191_termite_23_make_2d_dict();
}
});

_j(_bb3185_termite_23_make_2d_dict = () => {
_r = _bb3186_termite_23_make_2d_dict;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb3122_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3123_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb23_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb24_termite_23_make_2d_dict();
} else {
return _bb3121_termite_23_make_2d_dict();
}
});

_j(_bb3145_termite_23_make_2d_dict = () => {
_s[_t+1] = _s[_t].a;
_s[_t+2] = _s[_t].b;
if (_s[_t+1] === _cst257__termite) {
_t += 2;
return _bb3146_termite_23_make_2d_dict();
} else {
_t += 2;
return _bb3169_termite_23_make_2d_dict();
}
});

_j(_bb3822_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3823_termite_23_make_2d_dict();
} else {
return _bb3839_termite_23_make_2d_dict();
}
});

_j(_bb3206_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3207_termite_23_make_2d_dict();
} else {
return _bb3210_termite_23_make_2d_dict();
}
});

_j(_bb3191_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3223_termite_23_make_2d_dict();
} else {
return _bb3192_termite_23_make_2d_dict();
}
});

_k(_bb3186_termite_23_make_2d_dict = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb3136_termite_23_make_2d_dict);
},2,1);

_k(_bb3123_termite_23_make_2d_dict = () => {
return _bb27_termite_23_make_2d_dict();
},2,1);

_j(_bb24_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb25_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3121_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb26_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb3146_termite_23_make_2d_dict = () => {
if (_s[_t] === null) {
return _bb3147_termite_23_make_2d_dict();
} else {
return _bb3778_termite_23_make_2d_dict();
}
});

_j(_bb3169_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst259__termite) {
return _bb3187_termite_23_make_2d_dict();
} else {
return _bb3170_termite_23_make_2d_dict();
}
});

_j(_bb3823_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3824_termite_23_make_2d_dict();
} else {
return _bb3826_termite_23_make_2d_dict();
}
});

_j(_bb3839_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3840_termite_23_make_2d_dict();
} else {
return _bb3853_termite_23_make_2d_dict();
}
});

_j(_bb3207_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_r = _bb3208_termite_23_make_2d_dict;
_t += 3;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3210_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3211_termite_23_make_2d_dict();
} else {
return _bb3222_termite_23_make_2d_dict();
}
});

_j(_bb3223_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3224_termite_23_make_2d_dict();
} else {
return _bb3227_termite_23_make_2d_dict();
}
});

_j(_bb3192_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3193_termite_23_make_2d_dict();
} else {
return _bb3240_termite_23_make_2d_dict();
}
});

_j(_bb3136_termite_23_make_2d_dict = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb3137_termite_23_make_2d_dict();
} else {
return _bb3141_termite_23_make_2d_dict();
}
});

_j(_bb27_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb28_termite_23_make_2d_dict();
} else {
return _bb3120_termite_23_make_2d_dict();
}
});

_k(_bb25_termite_23_make_2d_dict = () => {
return _bb27_termite_23_make_2d_dict();
},2,1);

_k(_bb26_termite_23_make_2d_dict = () => {
return _bb27_termite_23_make_2d_dict();
},2,1);

_j(_bb3147_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3148_termite_23_make_2d_dict();
} else {
return _bb3159_termite_23_make_2d_dict();
}
});

_j(_bb3778_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3779_termite_23_make_2d_dict();
} else {
return _bb3795_termite_23_make_2d_dict();
}
});

_j(_bb3187_termite_23_make_2d_dict = () => {
if (_s[_t] === null) {
return _bb3188_termite_23_make_2d_dict();
} else {
return _bb3302_termite_23_make_2d_dict();
}
});

_j(_bb3170_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst120__termite) {
return _bb3348_termite_23_make_2d_dict();
} else {
return _bb3171_termite_23_make_2d_dict();
}
});

_j(_bb3824_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_r = _bb3825_termite_23_make_2d_dict;
_t += 3;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3826_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3827_termite_23_make_2d_dict();
} else {
return _bb3838_termite_23_make_2d_dict();
}
});

_j(_bb3840_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3841_termite_23_make_2d_dict();
} else {
return _bb3852_termite_23_make_2d_dict();
}
});

_j(_bb3853_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3854_termite_23_make_2d_dict();
} else {
return _bb3865_termite_23_make_2d_dict();
}
});

_j(_bb3203_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb3204_termite_23_make_2d_dict);
});

_k(_bb3208_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb3209_termite_23_make_2d_dict);
},3,1);

_j(_bb3211_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3212_termite_23_make_2d_dict();
} else {
return _bb3221_termite_23_make_2d_dict();
}
});

_j(_bb3222_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3224_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_r = _bb3225_termite_23_make_2d_dict;
_t += 3;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3227_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3228_termite_23_make_2d_dict();
} else {
return _bb3239_termite_23_make_2d_dict();
}
});

_j(_bb3193_termite_23_make_2d_dict = () => {
_d = _d.b;
if (_x(_d)) {
return _bb3194_termite_23_make_2d_dict();
} else {
return _bb3241_termite_23_make_2d_dict();
}
});

_j(_bb3240_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb28_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb29_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3120_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb3148_termite_23_make_2d_dict = () => {
_s[_t-2] = _r;
_s[_t-1] = _c;
_s[_t] = _d;
return _p(_bb3149_termite_23_make_2d_dict);
});

_j(_bb3159_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3160_termite_23_make_2d_dict();
} else {
return _bb3751_termite_23_make_2d_dict();
}
});

_j(_bb3779_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3780_termite_23_make_2d_dict();
} else {
return _bb3782_termite_23_make_2d_dict();
}
});

_j(_bb3795_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3796_termite_23_make_2d_dict();
} else {
return _bb3809_termite_23_make_2d_dict();
}
});

_j(_bb3188_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3189_termite_23_make_2d_dict();
} else {
return _bb3261_termite_23_make_2d_dict();
}
});

_j(_bb3302_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3303_termite_23_make_2d_dict();
} else {
return _bb3321_termite_23_make_2d_dict();
}
});

_j(_bb3348_termite_23_make_2d_dict = () => {
if (_x(_s[_t])) {
return _bb3349_termite_23_make_2d_dict();
} else {
return _bb3446_termite_23_make_2d_dict();
}
});

_j(_bb3171_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3490_termite_23_make_2d_dict();
} else {
return _bb3172_termite_23_make_2d_dict();
}
});

_k(_bb3825_termite_23_make_2d_dict = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb3307_termite_23_make_2d_dict);
},4,2);

_j(_bb3827_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3828_termite_23_make_2d_dict();
} else {
return _bb3837_termite_23_make_2d_dict();
}
});

_j(_bb3838_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3841_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3842_termite_23_make_2d_dict();
} else {
return _bb3851_termite_23_make_2d_dict();
}
});

_j(_bb3852_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3854_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3855_termite_23_make_2d_dict();
} else {
return _bb3864_termite_23_make_2d_dict();
}
});

_j(_bb3865_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3204_termite_23_make_2d_dict = () => {
_r = _bb3205_termite_23_make_2d_dict;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb3209_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["##table-set!"]();
});

_j(_bb3212_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3213_termite_23_make_2d_dict();
} else {
return _bb3220_termite_23_make_2d_dict();
}
});

_j(_bb3221_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3225_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _s[_t-2];
return _p(_bb3226_termite_23_make_2d_dict);
},3,1);

_j(_bb3228_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3229_termite_23_make_2d_dict();
} else {
return _bb3238_termite_23_make_2d_dict();
}
});

_j(_bb3239_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3194_termite_23_make_2d_dict = () => {
_s[_t+1] = _d.a;
_d = _d.b;
if (_x(_s[_t+1])) {
++_t;
return _bb3195_termite_23_make_2d_dict();
} else {
++_t;
return _bb3242_termite_23_make_2d_dict();
}
});

_j(_bb3241_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb29_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3118_termite_23_make_2d_dict();
} else {
return _bb30_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3149_termite_23_make_2d_dict = () => {
_r = _bb3150_termite_23_make_2d_dict;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb3160_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3161_termite_23_make_2d_dict();
} else {
return _bb3750_termite_23_make_2d_dict();
}
});

_j(_bb3751_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3752_termite_23_make_2d_dict();
} else {
return _bb3765_termite_23_make_2d_dict();
}
});

_j(_bb3780_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _d;
_r = _bb3781_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3782_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3783_termite_23_make_2d_dict();
} else {
return _bb3794_termite_23_make_2d_dict();
}
});

_j(_bb3796_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3797_termite_23_make_2d_dict();
} else {
return _bb3808_termite_23_make_2d_dict();
}
});

_j(_bb3809_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3810_termite_23_make_2d_dict();
} else {
return _bb3821_termite_23_make_2d_dict();
}
});

_j(_bb3189_termite_23_make_2d_dict = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
_s[_t] = _c;
_s[_t+1] = _d;
_r = _bb3251_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3261_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3262_termite_23_make_2d_dict();
} else {
return _bb3275_termite_23_make_2d_dict();
}
});

_j(_bb3303_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3304_termite_23_make_2d_dict();
} else {
return _bb3308_termite_23_make_2d_dict();
}
});

_j(_bb3321_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3322_termite_23_make_2d_dict();
} else {
return _bb3335_termite_23_make_2d_dict();
}
});

_j(_bb3349_termite_23_make_2d_dict = () => {
_s[_t-1] = _s[_t].a;
_s[_t] = _s[_t].b;
if (_s[_t] === null) {
return _bb3350_termite_23_make_2d_dict();
} else {
return _bb3403_termite_23_make_2d_dict();
}
});

_j(_bb3446_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3447_termite_23_make_2d_dict();
} else {
return _bb3463_termite_23_make_2d_dict();
}
});

_j(_bb3490_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3491_termite_23_make_2d_dict();
} else {
return _bb3493_termite_23_make_2d_dict();
}
});

_j(_bb3172_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst260__termite) {
return _bb3576_termite_23_make_2d_dict();
} else {
return _bb3173_termite_23_make_2d_dict();
}
});

_j(_bb3307_termite_23_make_2d_dict = () => {
_n = 3;
return _g["##table-set!"]();
});

_j(_bb3828_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3829_termite_23_make_2d_dict();
} else {
return _bb3836_termite_23_make_2d_dict();
}
});

_j(_bb3837_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3842_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3843_termite_23_make_2d_dict();
} else {
return _bb3850_termite_23_make_2d_dict();
}
});

_j(_bb3851_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3855_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3856_termite_23_make_2d_dict();
} else {
return _bb3863_termite_23_make_2d_dict();
}
});

_j(_bb3864_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3205_termite_23_make_2d_dict = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb3213_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3214_termite_23_make_2d_dict();
} else {
return _bb3219_termite_23_make_2d_dict();
}
});

_j(_bb3220_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3226_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["##table-for-each"]();
});

_j(_bb3229_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3230_termite_23_make_2d_dict();
} else {
return _bb3237_termite_23_make_2d_dict();
}
});

_j(_bb3238_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3195_termite_23_make_2d_dict = () => {
_s[_t] = _s[_t].b;
if (_x(_s[_t])) {
return _bb3196_termite_23_make_2d_dict();
} else {
return _bb3243_termite_23_make_2d_dict();
}
});

_j(_bb3242_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3118_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3119_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb30_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb31_termite_23_make_2d_dict();
} else {
return _bb3117_termite_23_make_2d_dict();
}
});

_k(_bb3150_termite_23_make_2d_dict = () => {
_a = _X(_s[_t],_X(!0,null));
_s[_t] = _a;
_a = _s[_t-1];
_r = _bb3151_termite_23_make_2d_dict;
_n = 1;
return _g["thread?"]();
},3,1);

_j(_bb3161_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3162_termite_23_make_2d_dict();
} else {
return _bb3749_termite_23_make_2d_dict();
}
});

_j(_bb3750_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3752_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3753_termite_23_make_2d_dict();
} else {
return _bb3764_termite_23_make_2d_dict();
}
});

_j(_bb3765_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3766_termite_23_make_2d_dict();
} else {
return _bb3777_termite_23_make_2d_dict();
}
});

_k(_bb3781_termite_23_make_2d_dict = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb3307_termite_23_make_2d_dict);
},4,2);

_j(_bb3783_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3784_termite_23_make_2d_dict();
} else {
return _bb3793_termite_23_make_2d_dict();
}
});

_j(_bb3794_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3797_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3798_termite_23_make_2d_dict();
} else {
return _bb3807_termite_23_make_2d_dict();
}
});

_j(_bb3808_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3810_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3811_termite_23_make_2d_dict();
} else {
return _bb3820_termite_23_make_2d_dict();
}
});

_j(_bb3821_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3251_termite_23_make_2d_dict = () => {
_a = _s[_t-2];
_r = _bb3252_termite_23_make_2d_dict;
_n = 1;
return _g["##table-length"]();
},4,1);

_j(_bb3262_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3263_termite_23_make_2d_dict();
} else {
return _bb3274_termite_23_make_2d_dict();
}
});

_j(_bb3275_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3276_termite_23_make_2d_dict();
} else {
return _bb3289_termite_23_make_2d_dict();
}
});

_j(_bb3304_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _d;
_r = _bb3305_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3308_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3309_termite_23_make_2d_dict();
} else {
return _bb3320_termite_23_make_2d_dict();
}
});

_j(_bb3322_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3323_termite_23_make_2d_dict();
} else {
return _bb3334_termite_23_make_2d_dict();
}
});

_j(_bb3335_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3336_termite_23_make_2d_dict();
} else {
return _bb3347_termite_23_make_2d_dict();
}
});

_j(_bb3350_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3351_termite_23_make_2d_dict();
} else {
return _bb3362_termite_23_make_2d_dict();
}
});

_j(_bb3403_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3404_termite_23_make_2d_dict();
} else {
return _bb3419_termite_23_make_2d_dict();
}
});

_j(_bb3447_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3448_termite_23_make_2d_dict();
} else {
return _bb3450_termite_23_make_2d_dict();
}
});

_j(_bb3463_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3464_termite_23_make_2d_dict();
} else {
return _bb3477_termite_23_make_2d_dict();
}
});

_j(_bb3491_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _d;
_r = _bb3492_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3493_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst260__termite) {
return _bb3494_termite_23_make_2d_dict();
} else {
return _bb3535_termite_23_make_2d_dict();
}
});

_j(_bb3576_termite_23_make_2d_dict = () => {
if (_x(_s[_t])) {
return _bb3577_termite_23_make_2d_dict();
} else {
return _bb3637_termite_23_make_2d_dict();
}
});

_j(_bb3173_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3664_termite_23_make_2d_dict();
} else {
return _bb3174_termite_23_make_2d_dict();
}
});

_j(_bb3829_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3830_termite_23_make_2d_dict();
} else {
return _bb3835_termite_23_make_2d_dict();
}
});

_j(_bb3836_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3843_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3844_termite_23_make_2d_dict();
} else {
return _bb3849_termite_23_make_2d_dict();
}
});

_j(_bb3850_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3856_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3857_termite_23_make_2d_dict();
} else {
return _bb3862_termite_23_make_2d_dict();
}
});

_j(_bb3863_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3214_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3215_termite_23_make_2d_dict();
} else {
return _bb3218_termite_23_make_2d_dict();
}
});

_j(_bb3219_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3230_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3231_termite_23_make_2d_dict();
} else {
return _bb3236_termite_23_make_2d_dict();
}
});

_j(_bb3237_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3196_termite_23_make_2d_dict = () => {
_s[_t+1] = _s[_t].a;
_s[_t] = _s[_t].b;
if (_s[_t+1] === _cst263__termite) {
++_t;
return _bb3197_termite_23_make_2d_dict();
} else {
++_t;
return _bb3244_termite_23_make_2d_dict();
}
});

_j(_bb3243_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3119_termite_23_make_2d_dict = () => {
return _bb34_termite_23_make_2d_dict();
},2,1);

_j(_bb31_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb32_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3117_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb33_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_k(_bb3151_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3152_termite_23_make_2d_dict();
} else {
return _bb3154_termite_23_make_2d_dict();
}
},3,1);

_j(_bb3162_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3163_termite_23_make_2d_dict();
} else {
return _bb3748_termite_23_make_2d_dict();
}
});

_j(_bb3749_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3753_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3754_termite_23_make_2d_dict();
} else {
return _bb3763_termite_23_make_2d_dict();
}
});

_j(_bb3764_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3766_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3767_termite_23_make_2d_dict();
} else {
return _bb3776_termite_23_make_2d_dict();
}
});

_j(_bb3777_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3784_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3785_termite_23_make_2d_dict();
} else {
return _bb3792_termite_23_make_2d_dict();
}
});

_j(_bb3793_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3798_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3799_termite_23_make_2d_dict();
} else {
return _bb3806_termite_23_make_2d_dict();
}
});

_j(_bb3807_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3811_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3812_termite_23_make_2d_dict();
} else {
return _bb3819_termite_23_make_2d_dict();
}
});

_j(_bb3820_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3252_termite_23_make_2d_dict = () => {
_a = _X(_s[_t],_X(_a,null));
_s[_t-2] = _a;
_a = _s[_t-1];
_r = _bb3253_termite_23_make_2d_dict;
_n = 1;
--_t;
return _g["thread?"]();
},4,1);

_j(_bb3263_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3264_termite_23_make_2d_dict();
} else {
return _bb3273_termite_23_make_2d_dict();
}
});

_j(_bb3274_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3276_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3277_termite_23_make_2d_dict();
} else {
return _bb3288_termite_23_make_2d_dict();
}
});

_j(_bb3289_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3290_termite_23_make_2d_dict();
} else {
return _bb3301_termite_23_make_2d_dict();
}
});

_k(_bb3305_termite_23_make_2d_dict = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb3307_termite_23_make_2d_dict);
},4,2);

_j(_bb3309_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3310_termite_23_make_2d_dict();
} else {
return _bb3319_termite_23_make_2d_dict();
}
});

_j(_bb3320_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3323_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3324_termite_23_make_2d_dict();
} else {
return _bb3333_termite_23_make_2d_dict();
}
});

_j(_bb3334_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3336_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3337_termite_23_make_2d_dict();
} else {
return _bb3346_termite_23_make_2d_dict();
}
});

_j(_bb3347_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3351_termite_23_make_2d_dict = () => {
_s[_t-2] = _r;
_s[_t] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb3352_termite_23_make_2d_dict;
_t += 2;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3362_termite_23_make_2d_dict = () => {
if (_c === _cst118__termite) {
return _bb3363_termite_23_make_2d_dict();
} else {
return _bb3376_termite_23_make_2d_dict();
}
});

_j(_bb3404_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3405_termite_23_make_2d_dict();
} else {
return _bb3406_termite_23_make_2d_dict();
}
});

_j(_bb3419_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3420_termite_23_make_2d_dict();
} else {
return _bb3433_termite_23_make_2d_dict();
}
});

_j(_bb3448_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _d;
_r = _bb3449_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3450_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3451_termite_23_make_2d_dict();
} else {
return _bb3462_termite_23_make_2d_dict();
}
});

_j(_bb3464_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3465_termite_23_make_2d_dict();
} else {
return _bb3476_termite_23_make_2d_dict();
}
});

_j(_bb3477_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3478_termite_23_make_2d_dict();
} else {
return _bb3489_termite_23_make_2d_dict();
}
});

_k(_bb3492_termite_23_make_2d_dict = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb3307_termite_23_make_2d_dict);
},4,2);

_j(_bb3494_termite_23_make_2d_dict = () => {
if (_x(_s[_t])) {
return _bb3495_termite_23_make_2d_dict();
} else {
return _bb3522_termite_23_make_2d_dict();
}
});

_j(_bb3535_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst264__termite) {
return _bb3536_termite_23_make_2d_dict();
} else {
return _bb3563_termite_23_make_2d_dict();
}
});

_j(_bb3577_termite_23_make_2d_dict = () => {
_s[_t-2] = _s[_t].a;
_s[_t-1] = _s[_t].b;
if (_s[_t-1] === null) {
return _bb3578_termite_23_make_2d_dict();
} else {
return _bb3610_termite_23_make_2d_dict();
}
});

_j(_bb3637_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3638_termite_23_make_2d_dict();
} else {
return _bb3651_termite_23_make_2d_dict();
}
});

_j(_bb3664_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst264__termite) {
return _bb3665_termite_23_make_2d_dict();
} else {
return _bb3700_termite_23_make_2d_dict();
}
});

_j(_bb3174_termite_23_make_2d_dict = () => {
if (_s[_t-1] === _cst264__termite) {
return _bb3175_termite_23_make_2d_dict();
} else {
return _bb3713_termite_23_make_2d_dict();
}
});

_j(_bb3830_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3831_termite_23_make_2d_dict();
} else {
return _bb3834_termite_23_make_2d_dict();
}
});

_j(_bb3835_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3844_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3845_termite_23_make_2d_dict();
} else {
return _bb3848_termite_23_make_2d_dict();
}
});

_j(_bb3849_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3857_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3858_termite_23_make_2d_dict();
} else {
return _bb3861_termite_23_make_2d_dict();
}
});

_j(_bb3862_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3215_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3216_termite_23_make_2d_dict();
} else {
return _bb3217_termite_23_make_2d_dict();
}
});

_j(_bb3218_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3231_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3232_termite_23_make_2d_dict();
} else {
return _bb3235_termite_23_make_2d_dict();
}
});

_j(_bb3236_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3197_termite_23_make_2d_dict = () => {
if (_x(_s[_t-1])) {
return _bb3198_termite_23_make_2d_dict();
} else {
return _bb3245_termite_23_make_2d_dict();
}
});

_j(_bb3244_termite_23_make_2d_dict = () => {
_t -= 2;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb34_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb35_termite_23_make_2d_dict();
} else {
return _bb3116_termite_23_make_2d_dict();
}
});

_k(_bb32_termite_23_make_2d_dict = () => {
return _bb34_termite_23_make_2d_dict();
},2,1);

_k(_bb33_termite_23_make_2d_dict = () => {
return _bb34_termite_23_make_2d_dict();
},2,1);

_j(_bb3152_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb3153_termite_23_make_2d_dict);
});

_j(_bb3154_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb3155_termite_23_make_2d_dict();
} else {
return _bb3157_termite_23_make_2d_dict();
}
});

_j(_bb3163_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3164_termite_23_make_2d_dict();
} else {
return _bb3747_termite_23_make_2d_dict();
}
});

_j(_bb3748_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3754_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3755_termite_23_make_2d_dict();
} else {
return _bb3762_termite_23_make_2d_dict();
}
});

_j(_bb3763_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3767_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3768_termite_23_make_2d_dict();
} else {
return _bb3775_termite_23_make_2d_dict();
}
});

_j(_bb3776_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3785_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3786_termite_23_make_2d_dict();
} else {
return _bb3791_termite_23_make_2d_dict();
}
});

_j(_bb3792_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3799_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3800_termite_23_make_2d_dict();
} else {
return _bb3805_termite_23_make_2d_dict();
}
});

_j(_bb3806_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3812_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3813_termite_23_make_2d_dict();
} else {
return _bb3818_termite_23_make_2d_dict();
}
});

_j(_bb3819_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3253_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3254_termite_23_make_2d_dict();
} else {
return _bb3256_termite_23_make_2d_dict();
}
},3,1);

_j(_bb3264_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3265_termite_23_make_2d_dict();
} else {
return _bb3272_termite_23_make_2d_dict();
}
});

_j(_bb3273_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3277_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3278_termite_23_make_2d_dict();
} else {
return _bb3287_termite_23_make_2d_dict();
}
});

_j(_bb3288_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3290_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3291_termite_23_make_2d_dict();
} else {
return _bb3300_termite_23_make_2d_dict();
}
});

_j(_bb3301_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3310_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3311_termite_23_make_2d_dict();
} else {
return _bb3318_termite_23_make_2d_dict();
}
});

_j(_bb3319_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3324_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3325_termite_23_make_2d_dict();
} else {
return _bb3332_termite_23_make_2d_dict();
}
});

_j(_bb3333_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3337_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3338_termite_23_make_2d_dict();
} else {
return _bb3345_termite_23_make_2d_dict();
}
});

_j(_bb3346_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3352_termite_23_make_2d_dict = () => {
_b = _s[_t-3];
_a = _s[_t-2];
_r = _bb3353_termite_23_make_2d_dict;
_n = 2;
return _g["##table-ref"]();
},5,1);

_j(_bb3363_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3364_termite_23_make_2d_dict();
} else {
return _bb3375_termite_23_make_2d_dict();
}
});

_j(_bb3376_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3377_termite_23_make_2d_dict();
} else {
return _bb3390_termite_23_make_2d_dict();
}
});

_j(_bb3405_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _d;
_r = _bb3306_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3406_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3407_termite_23_make_2d_dict();
} else {
return _bb3418_termite_23_make_2d_dict();
}
});

_j(_bb3420_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3421_termite_23_make_2d_dict();
} else {
return _bb3432_termite_23_make_2d_dict();
}
});

_j(_bb3433_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3434_termite_23_make_2d_dict();
} else {
return _bb3445_termite_23_make_2d_dict();
}
});

_k(_bb3449_termite_23_make_2d_dict = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb3307_termite_23_make_2d_dict);
},4,2);

_j(_bb3451_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3452_termite_23_make_2d_dict();
} else {
return _bb3461_termite_23_make_2d_dict();
}
});

_j(_bb3462_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3465_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3466_termite_23_make_2d_dict();
} else {
return _bb3475_termite_23_make_2d_dict();
}
});

_j(_bb3476_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3478_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3479_termite_23_make_2d_dict();
} else {
return _bb3488_termite_23_make_2d_dict();
}
});

_j(_bb3489_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3495_termite_23_make_2d_dict = () => {
_b = _s[_t].b;
if (_b === null) {
return _bb3496_termite_23_make_2d_dict();
} else {
return _bb3509_termite_23_make_2d_dict();
}
});

_j(_bb3522_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3523_termite_23_make_2d_dict();
} else {
return _bb3534_termite_23_make_2d_dict();
}
});

_j(_bb3536_termite_23_make_2d_dict = () => {
if (_s[_t] === null) {
return _bb3537_termite_23_make_2d_dict();
} else {
return _bb3550_termite_23_make_2d_dict();
}
});

_j(_bb3563_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3564_termite_23_make_2d_dict();
} else {
return _bb3575_termite_23_make_2d_dict();
}
});

_j(_bb3578_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3579_termite_23_make_2d_dict();
} else {
return _bb3583_termite_23_make_2d_dict();
}
});

_j(_bb3610_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3611_termite_23_make_2d_dict();
} else {
return _bb3624_termite_23_make_2d_dict();
}
});

_j(_bb3638_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3639_termite_23_make_2d_dict();
} else {
return _bb3650_termite_23_make_2d_dict();
}
});

_j(_bb3651_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3652_termite_23_make_2d_dict();
} else {
return _bb3663_termite_23_make_2d_dict();
}
});

_j(_bb3665_termite_23_make_2d_dict = () => {
if (_s[_t] === null) {
return _bb3666_termite_23_make_2d_dict();
} else {
return _bb3687_termite_23_make_2d_dict();
}
});

_j(_bb3700_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3701_termite_23_make_2d_dict();
} else {
return _bb3712_termite_23_make_2d_dict();
}
});

_j(_bb3175_termite_23_make_2d_dict = () => {
if (_s[_t] === null) {
return _bb3176_termite_23_make_2d_dict();
} else {
return _bb3726_termite_23_make_2d_dict();
}
});

_j(_bb3713_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3714_termite_23_make_2d_dict();
} else {
return _bb3725_termite_23_make_2d_dict();
}
});

_j(_bb3831_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3832_termite_23_make_2d_dict();
} else {
return _bb3833_termite_23_make_2d_dict();
}
});

_j(_bb3834_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3845_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3846_termite_23_make_2d_dict();
} else {
return _bb3847_termite_23_make_2d_dict();
}
});

_j(_bb3848_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3858_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3859_termite_23_make_2d_dict();
} else {
return _bb3860_termite_23_make_2d_dict();
}
});

_j(_bb3861_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3216_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3217_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3232_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3233_termite_23_make_2d_dict();
} else {
return _bb3234_termite_23_make_2d_dict();
}
});

_j(_bb3235_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3198_termite_23_make_2d_dict = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t] === _c) {
return _bb3199_termite_23_make_2d_dict();
} else {
return _bb3246_termite_23_make_2d_dict();
}
});

_j(_bb3245_termite_23_make_2d_dict = () => {
_t -= 2;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb35_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb36_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3116_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb3153_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb3155_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb3156_termite_23_make_2d_dict);
});

_j(_bb3157_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb3158_termite_23_make_2d_dict);
});

_j(_bb3164_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3165_termite_23_make_2d_dict();
} else {
return _bb3746_termite_23_make_2d_dict();
}
});

_j(_bb3747_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3755_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3756_termite_23_make_2d_dict();
} else {
return _bb3761_termite_23_make_2d_dict();
}
});

_j(_bb3762_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3768_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3769_termite_23_make_2d_dict();
} else {
return _bb3774_termite_23_make_2d_dict();
}
});

_j(_bb3775_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3786_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3787_termite_23_make_2d_dict();
} else {
return _bb3790_termite_23_make_2d_dict();
}
});

_j(_bb3791_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3800_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3801_termite_23_make_2d_dict();
} else {
return _bb3804_termite_23_make_2d_dict();
}
});

_j(_bb3805_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3813_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3814_termite_23_make_2d_dict();
} else {
return _bb3817_termite_23_make_2d_dict();
}
});

_j(_bb3818_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3254_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _s[_t-2];
return _p(_bb3255_termite_23_make_2d_dict);
});

_j(_bb3256_termite_23_make_2d_dict = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb3257_termite_23_make_2d_dict();
} else {
return _bb3259_termite_23_make_2d_dict();
}
});

_j(_bb3265_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3266_termite_23_make_2d_dict();
} else {
return _bb3271_termite_23_make_2d_dict();
}
});

_j(_bb3272_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3278_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3279_termite_23_make_2d_dict();
} else {
return _bb3286_termite_23_make_2d_dict();
}
});

_j(_bb3287_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3291_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3292_termite_23_make_2d_dict();
} else {
return _bb3299_termite_23_make_2d_dict();
}
});

_j(_bb3300_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3311_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3312_termite_23_make_2d_dict();
} else {
return _bb3317_termite_23_make_2d_dict();
}
});

_j(_bb3318_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3325_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3326_termite_23_make_2d_dict();
} else {
return _bb3331_termite_23_make_2d_dict();
}
});

_j(_bb3332_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3338_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3339_termite_23_make_2d_dict();
} else {
return _bb3344_termite_23_make_2d_dict();
}
});

_j(_bb3345_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3353_termite_23_make_2d_dict = () => {
_a = _X(_s[_t],_X(_a,null));
_s[_t-3] = _a;
_a = _s[_t-1];
_r = _bb3354_termite_23_make_2d_dict;
_n = 1;
--_t;
return _g["thread?"]();
},5,1);

_j(_bb3364_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3365_termite_23_make_2d_dict();
} else {
return _bb3374_termite_23_make_2d_dict();
}
});

_j(_bb3375_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3377_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3378_termite_23_make_2d_dict();
} else {
return _bb3389_termite_23_make_2d_dict();
}
});

_j(_bb3390_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3391_termite_23_make_2d_dict();
} else {
return _bb3402_termite_23_make_2d_dict();
}
});

_k(_bb3306_termite_23_make_2d_dict = () => {
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
_t -= 4;
return _p(_bb3307_termite_23_make_2d_dict);
},4,2);

_j(_bb3407_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3408_termite_23_make_2d_dict();
} else {
return _bb3417_termite_23_make_2d_dict();
}
});

_j(_bb3418_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3421_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3422_termite_23_make_2d_dict();
} else {
return _bb3431_termite_23_make_2d_dict();
}
});

_j(_bb3432_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3434_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3435_termite_23_make_2d_dict();
} else {
return _bb3444_termite_23_make_2d_dict();
}
});

_j(_bb3445_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3452_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3453_termite_23_make_2d_dict();
} else {
return _bb3460_termite_23_make_2d_dict();
}
});

_j(_bb3461_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3466_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3467_termite_23_make_2d_dict();
} else {
return _bb3474_termite_23_make_2d_dict();
}
});

_j(_bb3475_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3479_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3480_termite_23_make_2d_dict();
} else {
return _bb3487_termite_23_make_2d_dict();
}
});

_j(_bb3488_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3496_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3497_termite_23_make_2d_dict();
} else {
return _bb3508_termite_23_make_2d_dict();
}
});

_j(_bb3509_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3510_termite_23_make_2d_dict();
} else {
return _bb3521_termite_23_make_2d_dict();
}
});

_j(_bb3523_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3524_termite_23_make_2d_dict();
} else {
return _bb3533_termite_23_make_2d_dict();
}
});

_j(_bb3534_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3537_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3538_termite_23_make_2d_dict();
} else {
return _bb3549_termite_23_make_2d_dict();
}
});

_j(_bb3550_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3551_termite_23_make_2d_dict();
} else {
return _bb3562_termite_23_make_2d_dict();
}
});

_j(_bb3564_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3565_termite_23_make_2d_dict();
} else {
return _bb3574_termite_23_make_2d_dict();
}
});

_j(_bb3575_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3579_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb3580_termite_23_make_2d_dict;
_t += 2;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3583_termite_23_make_2d_dict = () => {
if (_c === _cst258__termite) {
return _bb3584_termite_23_make_2d_dict();
} else {
return _bb3597_termite_23_make_2d_dict();
}
});

_j(_bb3611_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3612_termite_23_make_2d_dict();
} else {
return _bb3623_termite_23_make_2d_dict();
}
});

_j(_bb3624_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3625_termite_23_make_2d_dict();
} else {
return _bb3636_termite_23_make_2d_dict();
}
});

_j(_bb3639_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3640_termite_23_make_2d_dict();
} else {
return _bb3649_termite_23_make_2d_dict();
}
});

_j(_bb3650_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3652_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3653_termite_23_make_2d_dict();
} else {
return _bb3662_termite_23_make_2d_dict();
}
});

_j(_bb3663_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3666_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3667_termite_23_make_2d_dict();
} else {
return _bb3674_termite_23_make_2d_dict();
}
});

_j(_bb3687_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3688_termite_23_make_2d_dict();
} else {
return _bb3699_termite_23_make_2d_dict();
}
});

_j(_bb3701_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3702_termite_23_make_2d_dict();
} else {
return _bb3711_termite_23_make_2d_dict();
}
});

_j(_bb3712_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3176_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3739_termite_23_make_2d_dict();
} else {
return _bb3177_termite_23_make_2d_dict();
}
});

_j(_bb3726_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3727_termite_23_make_2d_dict();
} else {
return _bb3738_termite_23_make_2d_dict();
}
});

_j(_bb3714_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3715_termite_23_make_2d_dict();
} else {
return _bb3724_termite_23_make_2d_dict();
}
});

_j(_bb3725_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3832_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3833_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3846_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3847_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3859_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3860_termite_23_make_2d_dict = () => {
--_t;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3233_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3234_termite_23_make_2d_dict = () => {
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3199_termite_23_make_2d_dict = () => {
if (_s[_t-1] === null) {
return _bb3200_termite_23_make_2d_dict();
} else {
return _bb3247_termite_23_make_2d_dict();
}
});

_j(_bb3246_termite_23_make_2d_dict = () => {
_t -= 2;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb36_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3114_termite_23_make_2d_dict();
} else {
return _bb37_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3156_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb3158_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});

_j(_bb3165_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3166_termite_23_make_2d_dict();
} else {
return _bb3168_termite_23_make_2d_dict();
}
});

_j(_bb3746_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3756_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3757_termite_23_make_2d_dict();
} else {
return _bb3760_termite_23_make_2d_dict();
}
});

_j(_bb3761_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3769_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3770_termite_23_make_2d_dict();
} else {
return _bb3773_termite_23_make_2d_dict();
}
});

_j(_bb3774_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3787_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3788_termite_23_make_2d_dict();
} else {
return _bb3789_termite_23_make_2d_dict();
}
});

_j(_bb3790_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3801_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3802_termite_23_make_2d_dict();
} else {
return _bb3803_termite_23_make_2d_dict();
}
});

_j(_bb3804_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3814_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3815_termite_23_make_2d_dict();
} else {
return _bb3816_termite_23_make_2d_dict();
}
});

_j(_bb3817_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3255_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb3257_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-1],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb3258_termite_23_make_2d_dict);
});

_j(_bb3259_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb3260_termite_23_make_2d_dict);
});

_j(_bb3266_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3267_termite_23_make_2d_dict();
} else {
return _bb3270_termite_23_make_2d_dict();
}
});

_j(_bb3271_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3279_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3280_termite_23_make_2d_dict();
} else {
return _bb3285_termite_23_make_2d_dict();
}
});

_j(_bb3286_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3292_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3293_termite_23_make_2d_dict();
} else {
return _bb3298_termite_23_make_2d_dict();
}
});

_j(_bb3299_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3312_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3313_termite_23_make_2d_dict();
} else {
return _bb3316_termite_23_make_2d_dict();
}
});

_j(_bb3317_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3326_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3327_termite_23_make_2d_dict();
} else {
return _bb3330_termite_23_make_2d_dict();
}
});

_j(_bb3331_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3339_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3340_termite_23_make_2d_dict();
} else {
return _bb3343_termite_23_make_2d_dict();
}
});

_j(_bb3344_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3354_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3355_termite_23_make_2d_dict();
} else {
return _bb3357_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3365_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3366_termite_23_make_2d_dict();
} else {
return _bb3373_termite_23_make_2d_dict();
}
});

_j(_bb3374_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3378_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3379_termite_23_make_2d_dict();
} else {
return _bb3388_termite_23_make_2d_dict();
}
});

_j(_bb3389_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3391_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3392_termite_23_make_2d_dict();
} else {
return _bb3401_termite_23_make_2d_dict();
}
});

_j(_bb3402_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3408_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3409_termite_23_make_2d_dict();
} else {
return _bb3416_termite_23_make_2d_dict();
}
});

_j(_bb3417_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3422_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3423_termite_23_make_2d_dict();
} else {
return _bb3430_termite_23_make_2d_dict();
}
});

_j(_bb3431_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3435_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3436_termite_23_make_2d_dict();
} else {
return _bb3443_termite_23_make_2d_dict();
}
});

_j(_bb3444_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3453_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3454_termite_23_make_2d_dict();
} else {
return _bb3459_termite_23_make_2d_dict();
}
});

_j(_bb3460_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3467_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3468_termite_23_make_2d_dict();
} else {
return _bb3473_termite_23_make_2d_dict();
}
});

_j(_bb3474_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3480_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3481_termite_23_make_2d_dict();
} else {
return _bb3486_termite_23_make_2d_dict();
}
});

_j(_bb3487_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3497_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3498_termite_23_make_2d_dict();
} else {
return _bb3507_termite_23_make_2d_dict();
}
});

_j(_bb3508_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3510_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3511_termite_23_make_2d_dict();
} else {
return _bb3520_termite_23_make_2d_dict();
}
});

_j(_bb3521_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3524_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3525_termite_23_make_2d_dict();
} else {
return _bb3532_termite_23_make_2d_dict();
}
});

_j(_bb3533_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3538_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3539_termite_23_make_2d_dict();
} else {
return _bb3548_termite_23_make_2d_dict();
}
});

_j(_bb3549_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3551_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3552_termite_23_make_2d_dict();
} else {
return _bb3561_termite_23_make_2d_dict();
}
});

_j(_bb3562_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3565_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3566_termite_23_make_2d_dict();
} else {
return _bb3573_termite_23_make_2d_dict();
}
});

_j(_bb3574_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3580_termite_23_make_2d_dict = () => {
_b = _s[_t-2];
_a = _s[_t-4];
_r = _bb3581_termite_23_make_2d_dict;
_n = 2;
return _g["##table-search"]();
},5,2);

_j(_bb3584_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3585_termite_23_make_2d_dict();
} else {
return _bb3596_termite_23_make_2d_dict();
}
});

_j(_bb3597_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3598_termite_23_make_2d_dict();
} else {
return _bb3609_termite_23_make_2d_dict();
}
});

_j(_bb3612_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3613_termite_23_make_2d_dict();
} else {
return _bb3622_termite_23_make_2d_dict();
}
});

_j(_bb3623_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3625_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3626_termite_23_make_2d_dict();
} else {
return _bb3635_termite_23_make_2d_dict();
}
});

_j(_bb3636_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3640_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3641_termite_23_make_2d_dict();
} else {
return _bb3648_termite_23_make_2d_dict();
}
});

_j(_bb3649_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3653_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3654_termite_23_make_2d_dict();
} else {
return _bb3661_termite_23_make_2d_dict();
}
});

_j(_bb3662_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3667_termite_23_make_2d_dict = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
_s[_t] = _c;
_s[_t+1] = _d;
_r = _bb3668_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3674_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3675_termite_23_make_2d_dict();
} else {
return _bb3686_termite_23_make_2d_dict();
}
});

_j(_bb3688_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3689_termite_23_make_2d_dict();
} else {
return _bb3698_termite_23_make_2d_dict();
}
});

_j(_bb3699_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3702_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3703_termite_23_make_2d_dict();
} else {
return _bb3710_termite_23_make_2d_dict();
}
});

_j(_bb3711_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3739_termite_23_make_2d_dict = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
_s[_t] = _c;
_s[_t+1] = _d;
_r = _bb3669_termite_23_make_2d_dict;
++_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3177_termite_23_make_2d_dict = () => {
if (_x(_d)) {
return _bb3178_termite_23_make_2d_dict();
} else {
return _bb3740_termite_23_make_2d_dict();
}
});

_j(_bb3727_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3728_termite_23_make_2d_dict();
} else {
return _bb3737_termite_23_make_2d_dict();
}
});

_j(_bb3738_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3715_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3716_termite_23_make_2d_dict();
} else {
return _bb3723_termite_23_make_2d_dict();
}
});

_j(_bb3724_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3200_termite_23_make_2d_dict = () => {
if (_d === null) {
return _bb3201_termite_23_make_2d_dict();
} else {
return _bb3248_termite_23_make_2d_dict();
}
});

_j(_bb3247_termite_23_make_2d_dict = () => {
_t -= 2;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3114_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3115_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb37_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb38_termite_23_make_2d_dict();
} else {
return _bb3113_termite_23_make_2d_dict();
}
});

_j(_bb3166_termite_23_make_2d_dict = () => {
_s[_t-2] = _r;
_s[_t-1] = _a;
return _p(_bb3167_termite_23_make_2d_dict);
});

_j(_bb3168_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3757_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3758_termite_23_make_2d_dict();
} else {
return _bb3759_termite_23_make_2d_dict();
}
});

_j(_bb3760_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3770_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3771_termite_23_make_2d_dict();
} else {
return _bb3772_termite_23_make_2d_dict();
}
});

_j(_bb3773_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3788_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3789_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3802_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3803_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3815_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3816_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3258_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb3260_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});

_j(_bb3267_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3268_termite_23_make_2d_dict();
} else {
return _bb3269_termite_23_make_2d_dict();
}
});

_j(_bb3270_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3280_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3281_termite_23_make_2d_dict();
} else {
return _bb3284_termite_23_make_2d_dict();
}
});

_j(_bb3285_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3293_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3294_termite_23_make_2d_dict();
} else {
return _bb3297_termite_23_make_2d_dict();
}
});

_j(_bb3298_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3313_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3314_termite_23_make_2d_dict();
} else {
return _bb3315_termite_23_make_2d_dict();
}
});

_j(_bb3316_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3327_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3328_termite_23_make_2d_dict();
} else {
return _bb3329_termite_23_make_2d_dict();
}
});

_j(_bb3330_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3340_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3341_termite_23_make_2d_dict();
} else {
return _bb3342_termite_23_make_2d_dict();
}
});

_j(_bb3343_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3355_termite_23_make_2d_dict = () => {
_b = _s[_t-2];
_a = _s[_t];
_r = _s[_t-3];
return _p(_bb3356_termite_23_make_2d_dict);
});

_j(_bb3357_termite_23_make_2d_dict = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb3358_termite_23_make_2d_dict();
} else {
return _bb3360_termite_23_make_2d_dict();
}
});

_j(_bb3366_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3367_termite_23_make_2d_dict();
} else {
return _bb3372_termite_23_make_2d_dict();
}
});

_j(_bb3373_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3379_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3380_termite_23_make_2d_dict();
} else {
return _bb3387_termite_23_make_2d_dict();
}
});

_j(_bb3388_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3392_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3393_termite_23_make_2d_dict();
} else {
return _bb3400_termite_23_make_2d_dict();
}
});

_j(_bb3401_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3409_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3410_termite_23_make_2d_dict();
} else {
return _bb3415_termite_23_make_2d_dict();
}
});

_j(_bb3416_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3423_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3424_termite_23_make_2d_dict();
} else {
return _bb3429_termite_23_make_2d_dict();
}
});

_j(_bb3430_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3436_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3437_termite_23_make_2d_dict();
} else {
return _bb3442_termite_23_make_2d_dict();
}
});

_j(_bb3443_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3454_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3455_termite_23_make_2d_dict();
} else {
return _bb3458_termite_23_make_2d_dict();
}
});

_j(_bb3459_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3468_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3469_termite_23_make_2d_dict();
} else {
return _bb3472_termite_23_make_2d_dict();
}
});

_j(_bb3473_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3481_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3482_termite_23_make_2d_dict();
} else {
return _bb3485_termite_23_make_2d_dict();
}
});

_j(_bb3486_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3498_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3499_termite_23_make_2d_dict();
} else {
return _bb3506_termite_23_make_2d_dict();
}
});

_j(_bb3507_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3511_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3512_termite_23_make_2d_dict();
} else {
return _bb3519_termite_23_make_2d_dict();
}
});

_j(_bb3520_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3525_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3526_termite_23_make_2d_dict();
} else {
return _bb3531_termite_23_make_2d_dict();
}
});

_j(_bb3532_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3539_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3540_termite_23_make_2d_dict();
} else {
return _bb3547_termite_23_make_2d_dict();
}
});

_j(_bb3548_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3552_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3553_termite_23_make_2d_dict();
} else {
return _bb3560_termite_23_make_2d_dict();
}
});

_j(_bb3561_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3566_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3567_termite_23_make_2d_dict();
} else {
return _bb3572_termite_23_make_2d_dict();
}
});

_j(_bb3573_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3581_termite_23_make_2d_dict = () => {
_b = _X(_s[_t],_X(_a,null));
_a = _s[_t-1];
_r = _s[_t-3];
return _p(_bb3582_termite_23_make_2d_dict);
},5,2);

_j(_bb3585_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3586_termite_23_make_2d_dict();
} else {
return _bb3595_termite_23_make_2d_dict();
}
});

_j(_bb3596_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3598_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3599_termite_23_make_2d_dict();
} else {
return _bb3608_termite_23_make_2d_dict();
}
});

_j(_bb3609_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3613_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3614_termite_23_make_2d_dict();
} else {
return _bb3621_termite_23_make_2d_dict();
}
});

_j(_bb3622_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3626_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3627_termite_23_make_2d_dict();
} else {
return _bb3634_termite_23_make_2d_dict();
}
});

_j(_bb3635_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3641_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3642_termite_23_make_2d_dict();
} else {
return _bb3647_termite_23_make_2d_dict();
}
});

_j(_bb3648_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3654_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3655_termite_23_make_2d_dict();
} else {
return _bb3660_termite_23_make_2d_dict();
}
});

_j(_bb3661_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3668_termite_23_make_2d_dict = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb3670_termite_23_make_2d_dict);
},4,1);

_j(_bb3675_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3676_termite_23_make_2d_dict();
} else {
return _bb3685_termite_23_make_2d_dict();
}
});

_j(_bb3686_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3689_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3690_termite_23_make_2d_dict();
} else {
return _bb3697_termite_23_make_2d_dict();
}
});

_j(_bb3698_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3703_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3704_termite_23_make_2d_dict();
} else {
return _bb3709_termite_23_make_2d_dict();
}
});

_j(_bb3710_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3669_termite_23_make_2d_dict = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb3670_termite_23_make_2d_dict);
},4,1);

_j(_bb3178_termite_23_make_2d_dict = () => {
_b = _d.b;
if (_x(_b)) {
return _bb3179_termite_23_make_2d_dict();
} else {
return _bb3741_termite_23_make_2d_dict();
}
});

_j(_bb3740_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3728_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3729_termite_23_make_2d_dict();
} else {
return _bb3736_termite_23_make_2d_dict();
}
});

_j(_bb3737_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3716_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3717_termite_23_make_2d_dict();
} else {
return _bb3722_termite_23_make_2d_dict();
}
});

_j(_bb3723_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3201_termite_23_make_2d_dict = () => {
if (_b === null) {
return _bb3202_termite_23_make_2d_dict();
} else {
return _bb3249_termite_23_make_2d_dict();
}
});

_j(_bb3248_termite_23_make_2d_dict = () => {
_t -= 2;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3115_termite_23_make_2d_dict = () => {
return _bb41_termite_23_make_2d_dict();
},2,1);

_j(_bb38_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb39_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3113_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb40_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb3167_termite_23_make_2d_dict = () => {
_r = _bb3135_termite_23_make_2d_dict;
_n = 0;
--_t;
return _g["thread-mailbox-next"]();
});

_j(_bb3758_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3759_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3771_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3772_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3268_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3269_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3281_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3282_termite_23_make_2d_dict();
} else {
return _bb3283_termite_23_make_2d_dict();
}
});

_j(_bb3284_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3294_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3295_termite_23_make_2d_dict();
} else {
return _bb3296_termite_23_make_2d_dict();
}
});

_j(_bb3297_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3314_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3315_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3328_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3329_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3341_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3342_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3356_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 4;
return _g["thread-send"]();
});

_j(_bb3358_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-2],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-3];
return _p(_bb3359_termite_23_make_2d_dict);
});

_j(_bb3360_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _s[_t-3];
return _p(_bb3361_termite_23_make_2d_dict);
});

_j(_bb3367_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3368_termite_23_make_2d_dict();
} else {
return _bb3371_termite_23_make_2d_dict();
}
});

_j(_bb3372_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3380_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3381_termite_23_make_2d_dict();
} else {
return _bb3386_termite_23_make_2d_dict();
}
});

_j(_bb3387_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3393_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3394_termite_23_make_2d_dict();
} else {
return _bb3399_termite_23_make_2d_dict();
}
});

_j(_bb3400_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3410_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3411_termite_23_make_2d_dict();
} else {
return _bb3414_termite_23_make_2d_dict();
}
});

_j(_bb3415_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3424_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3425_termite_23_make_2d_dict();
} else {
return _bb3428_termite_23_make_2d_dict();
}
});

_j(_bb3429_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3437_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3438_termite_23_make_2d_dict();
} else {
return _bb3441_termite_23_make_2d_dict();
}
});

_j(_bb3442_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3455_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3456_termite_23_make_2d_dict();
} else {
return _bb3457_termite_23_make_2d_dict();
}
});

_j(_bb3458_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3469_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3470_termite_23_make_2d_dict();
} else {
return _bb3471_termite_23_make_2d_dict();
}
});

_j(_bb3472_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3482_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3483_termite_23_make_2d_dict();
} else {
return _bb3484_termite_23_make_2d_dict();
}
});

_j(_bb3485_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3499_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3500_termite_23_make_2d_dict();
} else {
return _bb3505_termite_23_make_2d_dict();
}
});

_j(_bb3506_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3512_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3513_termite_23_make_2d_dict();
} else {
return _bb3518_termite_23_make_2d_dict();
}
});

_j(_bb3519_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3526_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3527_termite_23_make_2d_dict();
} else {
return _bb3530_termite_23_make_2d_dict();
}
});

_j(_bb3531_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3540_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3541_termite_23_make_2d_dict();
} else {
return _bb3546_termite_23_make_2d_dict();
}
});

_j(_bb3547_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3553_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3554_termite_23_make_2d_dict();
} else {
return _bb3559_termite_23_make_2d_dict();
}
});

_j(_bb3560_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3567_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3568_termite_23_make_2d_dict();
} else {
return _bb3571_termite_23_make_2d_dict();
}
});

_j(_bb3572_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3582_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 5;
return _bb1_termite_23__21_();
});

_j(_bb3586_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3587_termite_23_make_2d_dict();
} else {
return _bb3594_termite_23_make_2d_dict();
}
});

_j(_bb3595_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3599_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3600_termite_23_make_2d_dict();
} else {
return _bb3607_termite_23_make_2d_dict();
}
});

_j(_bb3608_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3614_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3615_termite_23_make_2d_dict();
} else {
return _bb3620_termite_23_make_2d_dict();
}
});

_j(_bb3621_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3627_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3628_termite_23_make_2d_dict();
} else {
return _bb3633_termite_23_make_2d_dict();
}
});

_j(_bb3634_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3642_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3643_termite_23_make_2d_dict();
} else {
return _bb3646_termite_23_make_2d_dict();
}
});

_j(_bb3647_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3655_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3656_termite_23_make_2d_dict();
} else {
return _bb3659_termite_23_make_2d_dict();
}
});

_j(_bb3660_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3670_termite_23_make_2d_dict = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_s[_t+3] = _c;
_t += 3;
return _p(_bb3671_termite_23_make_2d_dict);
});

_j(_bb3676_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3677_termite_23_make_2d_dict();
} else {
return _bb3684_termite_23_make_2d_dict();
}
});

_j(_bb3685_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3690_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3691_termite_23_make_2d_dict();
} else {
return _bb3696_termite_23_make_2d_dict();
}
});

_j(_bb3697_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3704_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3705_termite_23_make_2d_dict();
} else {
return _bb3708_termite_23_make_2d_dict();
}
});

_j(_bb3709_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3179_termite_23_make_2d_dict = () => {
_c = _b.a;
if (_x(_c)) {
return _bb3180_termite_23_make_2d_dict();
} else {
return _bb3742_termite_23_make_2d_dict();
}
});

_j(_bb3741_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3729_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3730_termite_23_make_2d_dict();
} else {
return _bb3735_termite_23_make_2d_dict();
}
});

_j(_bb3736_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3717_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3718_termite_23_make_2d_dict();
} else {
return _bb3721_termite_23_make_2d_dict();
}
});

_j(_bb3722_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3202_termite_23_make_2d_dict = () => {
_s[_t-1] = _r;
_r = _bb3250_termite_23_make_2d_dict;
--_t;
return _p(_bb3203_termite_23_make_2d_dict);
});

_j(_bb3249_termite_23_make_2d_dict = () => {
_t -= 2;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb41_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb42_termite_23_make_2d_dict();
} else {
return _bb3112_termite_23_make_2d_dict();
}
});

_k(_bb39_termite_23_make_2d_dict = () => {
return _bb41_termite_23_make_2d_dict();
},2,1);

_k(_bb40_termite_23_make_2d_dict = () => {
return _bb41_termite_23_make_2d_dict();
},2,1);

_k(_bb3135_termite_23_make_2d_dict = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb3136_termite_23_make_2d_dict);
},2,1);

_j(_bb3282_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3283_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3295_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3296_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3359_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 4;
return _g["thread-send"]();
});

_j(_bb3361_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 4;
return _g["##error"]();
});

_j(_bb3368_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3369_termite_23_make_2d_dict();
} else {
return _bb3370_termite_23_make_2d_dict();
}
});

_j(_bb3371_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3381_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3382_termite_23_make_2d_dict();
} else {
return _bb3385_termite_23_make_2d_dict();
}
});

_j(_bb3386_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3394_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3395_termite_23_make_2d_dict();
} else {
return _bb3398_termite_23_make_2d_dict();
}
});

_j(_bb3399_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3411_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3412_termite_23_make_2d_dict();
} else {
return _bb3413_termite_23_make_2d_dict();
}
});

_j(_bb3414_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3425_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3426_termite_23_make_2d_dict();
} else {
return _bb3427_termite_23_make_2d_dict();
}
});

_j(_bb3428_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3438_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3439_termite_23_make_2d_dict();
} else {
return _bb3440_termite_23_make_2d_dict();
}
});

_j(_bb3441_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3456_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3457_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3470_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3471_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3483_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3484_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3500_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3501_termite_23_make_2d_dict();
} else {
return _bb3504_termite_23_make_2d_dict();
}
});

_j(_bb3505_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3513_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3514_termite_23_make_2d_dict();
} else {
return _bb3517_termite_23_make_2d_dict();
}
});

_j(_bb3518_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3527_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3528_termite_23_make_2d_dict();
} else {
return _bb3529_termite_23_make_2d_dict();
}
});

_j(_bb3530_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3541_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3542_termite_23_make_2d_dict();
} else {
return _bb3545_termite_23_make_2d_dict();
}
});

_j(_bb3546_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3554_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3555_termite_23_make_2d_dict();
} else {
return _bb3558_termite_23_make_2d_dict();
}
});

_j(_bb3559_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3568_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3569_termite_23_make_2d_dict();
} else {
return _bb3570_termite_23_make_2d_dict();
}
});

_j(_bb3571_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3587_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3588_termite_23_make_2d_dict();
} else {
return _bb3593_termite_23_make_2d_dict();
}
});

_j(_bb3594_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3600_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3601_termite_23_make_2d_dict();
} else {
return _bb3606_termite_23_make_2d_dict();
}
});

_j(_bb3607_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3615_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3616_termite_23_make_2d_dict();
} else {
return _bb3619_termite_23_make_2d_dict();
}
});

_j(_bb3620_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3628_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3629_termite_23_make_2d_dict();
} else {
return _bb3632_termite_23_make_2d_dict();
}
});

_j(_bb3633_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3643_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3644_termite_23_make_2d_dict();
} else {
return _bb3645_termite_23_make_2d_dict();
}
});

_j(_bb3646_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3656_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3657_termite_23_make_2d_dict();
} else {
return _bb3658_termite_23_make_2d_dict();
}
});

_j(_bb3659_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3671_termite_23_make_2d_dict = () => {
_r = _bb3672_termite_23_make_2d_dict;
_n = 1;
return _g["##table->list"]();
});

_j(_bb3677_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3678_termite_23_make_2d_dict();
} else {
return _bb3683_termite_23_make_2d_dict();
}
});

_j(_bb3684_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3691_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3692_termite_23_make_2d_dict();
} else {
return _bb3695_termite_23_make_2d_dict();
}
});

_j(_bb3696_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3705_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3706_termite_23_make_2d_dict();
} else {
return _bb3707_termite_23_make_2d_dict();
}
});

_j(_bb3708_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3180_termite_23_make_2d_dict = () => {
_b = _c.b;
if (_x(_b)) {
return _bb3181_termite_23_make_2d_dict();
} else {
return _bb3743_termite_23_make_2d_dict();
}
});

_j(_bb3742_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3730_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3731_termite_23_make_2d_dict();
} else {
return _bb3734_termite_23_make_2d_dict();
}
});

_j(_bb3735_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3718_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3719_termite_23_make_2d_dict();
} else {
return _bb3720_termite_23_make_2d_dict();
}
});

_j(_bb3721_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3250_termite_23_make_2d_dict = () => {
_a = void 0;
--_t;
return _s[_t+1]();
},1,1);

_j(_bb42_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb43_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3112_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb3369_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3370_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3382_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3383_termite_23_make_2d_dict();
} else {
return _bb3384_termite_23_make_2d_dict();
}
});

_j(_bb3385_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3395_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3396_termite_23_make_2d_dict();
} else {
return _bb3397_termite_23_make_2d_dict();
}
});

_j(_bb3398_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3412_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3413_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3426_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3427_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3439_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3440_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3501_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3502_termite_23_make_2d_dict();
} else {
return _bb3503_termite_23_make_2d_dict();
}
});

_j(_bb3504_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3514_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3515_termite_23_make_2d_dict();
} else {
return _bb3516_termite_23_make_2d_dict();
}
});

_j(_bb3517_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3528_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3529_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3542_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3543_termite_23_make_2d_dict();
} else {
return _bb3544_termite_23_make_2d_dict();
}
});

_j(_bb3545_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3555_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3556_termite_23_make_2d_dict();
} else {
return _bb3557_termite_23_make_2d_dict();
}
});

_j(_bb3558_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3569_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3570_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3588_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3589_termite_23_make_2d_dict();
} else {
return _bb3592_termite_23_make_2d_dict();
}
});

_j(_bb3593_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3601_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3602_termite_23_make_2d_dict();
} else {
return _bb3605_termite_23_make_2d_dict();
}
});

_j(_bb3606_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3616_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3617_termite_23_make_2d_dict();
} else {
return _bb3618_termite_23_make_2d_dict();
}
});

_j(_bb3619_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3629_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3630_termite_23_make_2d_dict();
} else {
return _bb3631_termite_23_make_2d_dict();
}
});

_j(_bb3632_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3644_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3645_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3657_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3658_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3672_termite_23_make_2d_dict = () => {
_b = _X(_s[_t],_X(_a,null));
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb3673_termite_23_make_2d_dict);
},3,1);

_j(_bb3678_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3679_termite_23_make_2d_dict();
} else {
return _bb3682_termite_23_make_2d_dict();
}
});

_j(_bb3683_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3692_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3693_termite_23_make_2d_dict();
} else {
return _bb3694_termite_23_make_2d_dict();
}
});

_j(_bb3695_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3706_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3707_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3181_termite_23_make_2d_dict = () => {
_c = _b.a;
_b = _b.b;
if (_c === _cst263__termite) {
return _bb3182_termite_23_make_2d_dict();
} else {
return _bb3744_termite_23_make_2d_dict();
}
});

_j(_bb3743_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3731_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3732_termite_23_make_2d_dict();
} else {
return _bb3733_termite_23_make_2d_dict();
}
});

_j(_bb3734_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3719_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3720_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb43_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3110_termite_23_make_2d_dict();
} else {
return _bb44_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3383_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3384_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3396_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3397_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3502_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3503_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3515_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3516_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3543_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3544_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3556_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3557_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3589_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3590_termite_23_make_2d_dict();
} else {
return _bb3591_termite_23_make_2d_dict();
}
});

_j(_bb3592_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3602_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3603_termite_23_make_2d_dict();
} else {
return _bb3604_termite_23_make_2d_dict();
}
});

_j(_bb3605_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3617_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3618_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3630_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3631_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3673_termite_23_make_2d_dict = () => {
_n = 2;
_t -= 3;
return _bb1_termite_23__21_();
});

_j(_bb3679_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3680_termite_23_make_2d_dict();
} else {
return _bb3681_termite_23_make_2d_dict();
}
});

_j(_bb3682_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3693_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3694_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3182_termite_23_make_2d_dict = () => {
if (_x(_b)) {
return _bb3745_termite_23_make_2d_dict();
} else {
return _bb3183_termite_23_make_2d_dict();
}
});

_j(_bb3744_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3732_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3733_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3110_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3111_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb44_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb45_termite_23_make_2d_dict();
} else {
return _bb3109_termite_23_make_2d_dict();
}
});

_j(_bb3590_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3591_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3603_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3604_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3680_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3681_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3745_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_j(_bb3183_termite_23_make_2d_dict = () => {
_t -= 3;
return _p(_bb3184_termite_23_make_2d_dict);
});

_k(_bb3111_termite_23_make_2d_dict = () => {
return _bb48_termite_23_make_2d_dict();
},2,1);

_j(_bb45_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb46_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3109_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb47_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb48_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb49_termite_23_make_2d_dict();
} else {
return _bb3108_termite_23_make_2d_dict();
}
});

_k(_bb46_termite_23_make_2d_dict = () => {
return _bb48_termite_23_make_2d_dict();
},2,1);

_k(_bb47_termite_23_make_2d_dict = () => {
return _bb48_termite_23_make_2d_dict();
},2,1);

_j(_bb49_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb50_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3108_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb50_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3106_termite_23_make_2d_dict();
} else {
return _bb51_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3106_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3107_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb51_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb52_termite_23_make_2d_dict();
} else {
return _bb3105_termite_23_make_2d_dict();
}
});

_k(_bb3107_termite_23_make_2d_dict = () => {
return _bb55_termite_23_make_2d_dict();
},2,1);

_j(_bb52_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb53_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3105_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb54_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb55_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb56_termite_23_make_2d_dict();
} else {
return _bb3104_termite_23_make_2d_dict();
}
});

_k(_bb53_termite_23_make_2d_dict = () => {
return _bb55_termite_23_make_2d_dict();
},2,1);

_k(_bb54_termite_23_make_2d_dict = () => {
return _bb55_termite_23_make_2d_dict();
},2,1);

_j(_bb56_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb57_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3104_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb57_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3102_termite_23_make_2d_dict();
} else {
return _bb58_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3102_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3103_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb58_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb59_termite_23_make_2d_dict();
} else {
return _bb3101_termite_23_make_2d_dict();
}
});

_k(_bb3103_termite_23_make_2d_dict = () => {
return _bb62_termite_23_make_2d_dict();
},2,1);

_j(_bb59_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb60_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3101_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb61_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb62_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb63_termite_23_make_2d_dict();
} else {
return _bb3100_termite_23_make_2d_dict();
}
});

_k(_bb60_termite_23_make_2d_dict = () => {
return _bb62_termite_23_make_2d_dict();
},2,1);

_k(_bb61_termite_23_make_2d_dict = () => {
return _bb62_termite_23_make_2d_dict();
},2,1);

_j(_bb63_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb64_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3100_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb64_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3098_termite_23_make_2d_dict();
} else {
return _bb65_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3098_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3099_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb65_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb66_termite_23_make_2d_dict();
} else {
return _bb3097_termite_23_make_2d_dict();
}
});

_k(_bb3099_termite_23_make_2d_dict = () => {
return _bb69_termite_23_make_2d_dict();
},2,1);

_j(_bb66_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb67_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3097_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb68_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb69_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb70_termite_23_make_2d_dict();
} else {
return _bb3096_termite_23_make_2d_dict();
}
});

_k(_bb67_termite_23_make_2d_dict = () => {
return _bb69_termite_23_make_2d_dict();
},2,1);

_k(_bb68_termite_23_make_2d_dict = () => {
return _bb69_termite_23_make_2d_dict();
},2,1);

_j(_bb70_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb71_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3096_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb71_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3094_termite_23_make_2d_dict();
} else {
return _bb72_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3094_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3095_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb72_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb73_termite_23_make_2d_dict();
} else {
return _bb3093_termite_23_make_2d_dict();
}
});

_k(_bb3095_termite_23_make_2d_dict = () => {
return _bb76_termite_23_make_2d_dict();
},2,1);

_j(_bb73_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb74_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3093_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb75_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb76_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb77_termite_23_make_2d_dict();
} else {
return _bb3092_termite_23_make_2d_dict();
}
});

_k(_bb74_termite_23_make_2d_dict = () => {
return _bb76_termite_23_make_2d_dict();
},2,1);

_k(_bb75_termite_23_make_2d_dict = () => {
return _bb76_termite_23_make_2d_dict();
},2,1);

_j(_bb77_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb78_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3092_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb78_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3090_termite_23_make_2d_dict();
} else {
return _bb79_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3090_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3091_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb79_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb80_termite_23_make_2d_dict();
} else {
return _bb3089_termite_23_make_2d_dict();
}
});

_k(_bb3091_termite_23_make_2d_dict = () => {
return _bb83_termite_23_make_2d_dict();
},2,1);

_j(_bb80_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb81_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3089_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb82_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb83_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb84_termite_23_make_2d_dict();
} else {
return _bb3088_termite_23_make_2d_dict();
}
});

_k(_bb81_termite_23_make_2d_dict = () => {
return _bb83_termite_23_make_2d_dict();
},2,1);

_k(_bb82_termite_23_make_2d_dict = () => {
return _bb83_termite_23_make_2d_dict();
},2,1);

_j(_bb84_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb85_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3088_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb85_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3086_termite_23_make_2d_dict();
} else {
return _bb86_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3086_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3087_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb86_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb87_termite_23_make_2d_dict();
} else {
return _bb3085_termite_23_make_2d_dict();
}
});

_k(_bb3087_termite_23_make_2d_dict = () => {
return _bb90_termite_23_make_2d_dict();
},2,1);

_j(_bb87_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb88_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3085_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb89_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb90_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb91_termite_23_make_2d_dict();
} else {
return _bb3084_termite_23_make_2d_dict();
}
});

_k(_bb88_termite_23_make_2d_dict = () => {
return _bb90_termite_23_make_2d_dict();
},2,1);

_k(_bb89_termite_23_make_2d_dict = () => {
return _bb90_termite_23_make_2d_dict();
},2,1);

_j(_bb91_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb92_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3084_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb92_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3082_termite_23_make_2d_dict();
} else {
return _bb93_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3082_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3083_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb93_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb94_termite_23_make_2d_dict();
} else {
return _bb3081_termite_23_make_2d_dict();
}
});

_k(_bb3083_termite_23_make_2d_dict = () => {
return _bb97_termite_23_make_2d_dict();
},2,1);

_j(_bb94_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb95_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3081_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb96_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb97_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb98_termite_23_make_2d_dict();
} else {
return _bb3080_termite_23_make_2d_dict();
}
});

_k(_bb95_termite_23_make_2d_dict = () => {
return _bb97_termite_23_make_2d_dict();
},2,1);

_k(_bb96_termite_23_make_2d_dict = () => {
return _bb97_termite_23_make_2d_dict();
},2,1);

_j(_bb98_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb99_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3080_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb99_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3078_termite_23_make_2d_dict();
} else {
return _bb100_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3078_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3079_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb100_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb101_termite_23_make_2d_dict();
} else {
return _bb3077_termite_23_make_2d_dict();
}
});

_k(_bb3079_termite_23_make_2d_dict = () => {
return _bb104_termite_23_make_2d_dict();
},2,1);

_j(_bb101_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb102_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3077_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb103_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb104_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb105_termite_23_make_2d_dict();
} else {
return _bb3076_termite_23_make_2d_dict();
}
});

_k(_bb102_termite_23_make_2d_dict = () => {
return _bb104_termite_23_make_2d_dict();
},2,1);

_k(_bb103_termite_23_make_2d_dict = () => {
return _bb104_termite_23_make_2d_dict();
},2,1);

_j(_bb105_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb106_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3076_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb106_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3074_termite_23_make_2d_dict();
} else {
return _bb107_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3074_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3075_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb107_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb108_termite_23_make_2d_dict();
} else {
return _bb3073_termite_23_make_2d_dict();
}
});

_k(_bb3075_termite_23_make_2d_dict = () => {
return _bb111_termite_23_make_2d_dict();
},2,1);

_j(_bb108_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb109_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3073_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb110_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb111_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb112_termite_23_make_2d_dict();
} else {
return _bb3072_termite_23_make_2d_dict();
}
});

_k(_bb109_termite_23_make_2d_dict = () => {
return _bb111_termite_23_make_2d_dict();
},2,1);

_k(_bb110_termite_23_make_2d_dict = () => {
return _bb111_termite_23_make_2d_dict();
},2,1);

_j(_bb112_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb113_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3072_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb113_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3070_termite_23_make_2d_dict();
} else {
return _bb114_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3070_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3071_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb114_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb115_termite_23_make_2d_dict();
} else {
return _bb3069_termite_23_make_2d_dict();
}
});

_k(_bb3071_termite_23_make_2d_dict = () => {
return _bb118_termite_23_make_2d_dict();
},2,1);

_j(_bb115_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb116_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3069_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb117_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb118_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb119_termite_23_make_2d_dict();
} else {
return _bb3068_termite_23_make_2d_dict();
}
});

_k(_bb116_termite_23_make_2d_dict = () => {
return _bb118_termite_23_make_2d_dict();
},2,1);

_k(_bb117_termite_23_make_2d_dict = () => {
return _bb118_termite_23_make_2d_dict();
},2,1);

_j(_bb119_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb120_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3068_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb120_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3066_termite_23_make_2d_dict();
} else {
return _bb121_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3066_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3067_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb121_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb122_termite_23_make_2d_dict();
} else {
return _bb3065_termite_23_make_2d_dict();
}
});

_k(_bb3067_termite_23_make_2d_dict = () => {
return _bb125_termite_23_make_2d_dict();
},2,1);

_j(_bb122_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb123_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3065_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb124_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb125_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb126_termite_23_make_2d_dict();
} else {
return _bb3064_termite_23_make_2d_dict();
}
});

_k(_bb123_termite_23_make_2d_dict = () => {
return _bb125_termite_23_make_2d_dict();
},2,1);

_k(_bb124_termite_23_make_2d_dict = () => {
return _bb125_termite_23_make_2d_dict();
},2,1);

_j(_bb126_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb127_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3064_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb127_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3062_termite_23_make_2d_dict();
} else {
return _bb128_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3062_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3063_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb128_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb129_termite_23_make_2d_dict();
} else {
return _bb3061_termite_23_make_2d_dict();
}
});

_k(_bb3063_termite_23_make_2d_dict = () => {
return _bb132_termite_23_make_2d_dict();
},2,1);

_j(_bb129_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb130_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3061_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb131_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb132_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb133_termite_23_make_2d_dict();
} else {
return _bb3060_termite_23_make_2d_dict();
}
});

_k(_bb130_termite_23_make_2d_dict = () => {
return _bb132_termite_23_make_2d_dict();
},2,1);

_k(_bb131_termite_23_make_2d_dict = () => {
return _bb132_termite_23_make_2d_dict();
},2,1);

_j(_bb133_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb134_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3060_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb134_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3058_termite_23_make_2d_dict();
} else {
return _bb135_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3058_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3059_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb135_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb136_termite_23_make_2d_dict();
} else {
return _bb3057_termite_23_make_2d_dict();
}
});

_k(_bb3059_termite_23_make_2d_dict = () => {
return _bb139_termite_23_make_2d_dict();
},2,1);

_j(_bb136_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb137_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3057_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb138_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb139_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb140_termite_23_make_2d_dict();
} else {
return _bb3056_termite_23_make_2d_dict();
}
});

_k(_bb137_termite_23_make_2d_dict = () => {
return _bb139_termite_23_make_2d_dict();
},2,1);

_k(_bb138_termite_23_make_2d_dict = () => {
return _bb139_termite_23_make_2d_dict();
},2,1);

_j(_bb140_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb141_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3056_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb141_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3054_termite_23_make_2d_dict();
} else {
return _bb142_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3054_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3055_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb142_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb143_termite_23_make_2d_dict();
} else {
return _bb3053_termite_23_make_2d_dict();
}
});

_k(_bb3055_termite_23_make_2d_dict = () => {
return _bb146_termite_23_make_2d_dict();
},2,1);

_j(_bb143_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb144_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3053_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb145_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb146_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb147_termite_23_make_2d_dict();
} else {
return _bb3052_termite_23_make_2d_dict();
}
});

_k(_bb144_termite_23_make_2d_dict = () => {
return _bb146_termite_23_make_2d_dict();
},2,1);

_k(_bb145_termite_23_make_2d_dict = () => {
return _bb146_termite_23_make_2d_dict();
},2,1);

_j(_bb147_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb148_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3052_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb148_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3050_termite_23_make_2d_dict();
} else {
return _bb149_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3050_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3051_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb149_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb150_termite_23_make_2d_dict();
} else {
return _bb3049_termite_23_make_2d_dict();
}
});

_k(_bb3051_termite_23_make_2d_dict = () => {
return _bb153_termite_23_make_2d_dict();
},2,1);

_j(_bb150_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb151_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3049_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb152_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb153_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb154_termite_23_make_2d_dict();
} else {
return _bb3048_termite_23_make_2d_dict();
}
});

_k(_bb151_termite_23_make_2d_dict = () => {
return _bb153_termite_23_make_2d_dict();
},2,1);

_k(_bb152_termite_23_make_2d_dict = () => {
return _bb153_termite_23_make_2d_dict();
},2,1);

_j(_bb154_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb155_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3048_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb155_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3046_termite_23_make_2d_dict();
} else {
return _bb156_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3046_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3047_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb156_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb157_termite_23_make_2d_dict();
} else {
return _bb3045_termite_23_make_2d_dict();
}
});

_k(_bb3047_termite_23_make_2d_dict = () => {
return _bb160_termite_23_make_2d_dict();
},2,1);

_j(_bb157_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb158_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3045_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb159_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb160_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb161_termite_23_make_2d_dict();
} else {
return _bb3044_termite_23_make_2d_dict();
}
});

_k(_bb158_termite_23_make_2d_dict = () => {
return _bb160_termite_23_make_2d_dict();
},2,1);

_k(_bb159_termite_23_make_2d_dict = () => {
return _bb160_termite_23_make_2d_dict();
},2,1);

_j(_bb161_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb162_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3044_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb162_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3042_termite_23_make_2d_dict();
} else {
return _bb163_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3042_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3043_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb163_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb164_termite_23_make_2d_dict();
} else {
return _bb3041_termite_23_make_2d_dict();
}
});

_k(_bb3043_termite_23_make_2d_dict = () => {
return _bb167_termite_23_make_2d_dict();
},2,1);

_j(_bb164_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb165_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3041_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb166_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb167_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb168_termite_23_make_2d_dict();
} else {
return _bb3040_termite_23_make_2d_dict();
}
});

_k(_bb165_termite_23_make_2d_dict = () => {
return _bb167_termite_23_make_2d_dict();
},2,1);

_k(_bb166_termite_23_make_2d_dict = () => {
return _bb167_termite_23_make_2d_dict();
},2,1);

_j(_bb168_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb169_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3040_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb169_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3038_termite_23_make_2d_dict();
} else {
return _bb170_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3038_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3039_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb170_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb171_termite_23_make_2d_dict();
} else {
return _bb3037_termite_23_make_2d_dict();
}
});

_k(_bb3039_termite_23_make_2d_dict = () => {
return _bb174_termite_23_make_2d_dict();
},2,1);

_j(_bb171_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb172_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3037_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb173_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb174_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb175_termite_23_make_2d_dict();
} else {
return _bb3036_termite_23_make_2d_dict();
}
});

_k(_bb172_termite_23_make_2d_dict = () => {
return _bb174_termite_23_make_2d_dict();
},2,1);

_k(_bb173_termite_23_make_2d_dict = () => {
return _bb174_termite_23_make_2d_dict();
},2,1);

_j(_bb175_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb176_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3036_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb176_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3034_termite_23_make_2d_dict();
} else {
return _bb177_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3034_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3035_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb177_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb178_termite_23_make_2d_dict();
} else {
return _bb3033_termite_23_make_2d_dict();
}
});

_k(_bb3035_termite_23_make_2d_dict = () => {
return _bb181_termite_23_make_2d_dict();
},2,1);

_j(_bb178_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb179_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3033_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb180_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb181_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb182_termite_23_make_2d_dict();
} else {
return _bb3032_termite_23_make_2d_dict();
}
});

_k(_bb179_termite_23_make_2d_dict = () => {
return _bb181_termite_23_make_2d_dict();
},2,1);

_k(_bb180_termite_23_make_2d_dict = () => {
return _bb181_termite_23_make_2d_dict();
},2,1);

_j(_bb182_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb183_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3032_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb183_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3030_termite_23_make_2d_dict();
} else {
return _bb184_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3030_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3031_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb184_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb185_termite_23_make_2d_dict();
} else {
return _bb3029_termite_23_make_2d_dict();
}
});

_k(_bb3031_termite_23_make_2d_dict = () => {
return _bb188_termite_23_make_2d_dict();
},2,1);

_j(_bb185_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb186_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3029_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb187_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb188_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb189_termite_23_make_2d_dict();
} else {
return _bb3028_termite_23_make_2d_dict();
}
});

_k(_bb186_termite_23_make_2d_dict = () => {
return _bb188_termite_23_make_2d_dict();
},2,1);

_k(_bb187_termite_23_make_2d_dict = () => {
return _bb188_termite_23_make_2d_dict();
},2,1);

_j(_bb189_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb190_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3028_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb190_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3026_termite_23_make_2d_dict();
} else {
return _bb191_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3026_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3027_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb191_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb192_termite_23_make_2d_dict();
} else {
return _bb3025_termite_23_make_2d_dict();
}
});

_k(_bb3027_termite_23_make_2d_dict = () => {
return _bb195_termite_23_make_2d_dict();
},2,1);

_j(_bb192_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb193_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3025_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb194_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb195_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb196_termite_23_make_2d_dict();
} else {
return _bb3024_termite_23_make_2d_dict();
}
});

_k(_bb193_termite_23_make_2d_dict = () => {
return _bb195_termite_23_make_2d_dict();
},2,1);

_k(_bb194_termite_23_make_2d_dict = () => {
return _bb195_termite_23_make_2d_dict();
},2,1);

_j(_bb196_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb197_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3024_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb197_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3022_termite_23_make_2d_dict();
} else {
return _bb198_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3022_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3023_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb198_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb199_termite_23_make_2d_dict();
} else {
return _bb3021_termite_23_make_2d_dict();
}
});

_k(_bb3023_termite_23_make_2d_dict = () => {
return _bb202_termite_23_make_2d_dict();
},2,1);

_j(_bb199_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb200_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3021_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb201_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb202_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb203_termite_23_make_2d_dict();
} else {
return _bb3020_termite_23_make_2d_dict();
}
});

_k(_bb200_termite_23_make_2d_dict = () => {
return _bb202_termite_23_make_2d_dict();
},2,1);

_k(_bb201_termite_23_make_2d_dict = () => {
return _bb202_termite_23_make_2d_dict();
},2,1);

_j(_bb203_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb204_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3020_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb204_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3018_termite_23_make_2d_dict();
} else {
return _bb205_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3018_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3019_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb205_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb206_termite_23_make_2d_dict();
} else {
return _bb3017_termite_23_make_2d_dict();
}
});

_k(_bb3019_termite_23_make_2d_dict = () => {
return _bb209_termite_23_make_2d_dict();
},2,1);

_j(_bb206_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb207_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3017_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb208_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb209_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb210_termite_23_make_2d_dict();
} else {
return _bb3016_termite_23_make_2d_dict();
}
});

_k(_bb207_termite_23_make_2d_dict = () => {
return _bb209_termite_23_make_2d_dict();
},2,1);

_k(_bb208_termite_23_make_2d_dict = () => {
return _bb209_termite_23_make_2d_dict();
},2,1);

_j(_bb210_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb211_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3016_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb211_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3014_termite_23_make_2d_dict();
} else {
return _bb212_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3014_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3015_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb212_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb213_termite_23_make_2d_dict();
} else {
return _bb3013_termite_23_make_2d_dict();
}
});

_k(_bb3015_termite_23_make_2d_dict = () => {
return _bb216_termite_23_make_2d_dict();
},2,1);

_j(_bb213_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb214_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3013_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb215_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb216_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb217_termite_23_make_2d_dict();
} else {
return _bb3012_termite_23_make_2d_dict();
}
});

_k(_bb214_termite_23_make_2d_dict = () => {
return _bb216_termite_23_make_2d_dict();
},2,1);

_k(_bb215_termite_23_make_2d_dict = () => {
return _bb216_termite_23_make_2d_dict();
},2,1);

_j(_bb217_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb218_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3012_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb218_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3010_termite_23_make_2d_dict();
} else {
return _bb219_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3010_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3011_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb219_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb220_termite_23_make_2d_dict();
} else {
return _bb3009_termite_23_make_2d_dict();
}
});

_k(_bb3011_termite_23_make_2d_dict = () => {
return _bb223_termite_23_make_2d_dict();
},2,1);

_j(_bb220_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb221_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3009_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb222_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb223_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb224_termite_23_make_2d_dict();
} else {
return _bb3008_termite_23_make_2d_dict();
}
});

_k(_bb221_termite_23_make_2d_dict = () => {
return _bb223_termite_23_make_2d_dict();
},2,1);

_k(_bb222_termite_23_make_2d_dict = () => {
return _bb223_termite_23_make_2d_dict();
},2,1);

_j(_bb224_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb225_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3008_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb225_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3006_termite_23_make_2d_dict();
} else {
return _bb226_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3006_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3007_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb226_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb227_termite_23_make_2d_dict();
} else {
return _bb3005_termite_23_make_2d_dict();
}
});

_k(_bb3007_termite_23_make_2d_dict = () => {
return _bb230_termite_23_make_2d_dict();
},2,1);

_j(_bb227_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb228_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3005_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb229_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb230_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb231_termite_23_make_2d_dict();
} else {
return _bb3004_termite_23_make_2d_dict();
}
});

_k(_bb228_termite_23_make_2d_dict = () => {
return _bb230_termite_23_make_2d_dict();
},2,1);

_k(_bb229_termite_23_make_2d_dict = () => {
return _bb230_termite_23_make_2d_dict();
},2,1);

_j(_bb231_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb232_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3004_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb232_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb3002_termite_23_make_2d_dict();
} else {
return _bb233_termite_23_make_2d_dict();
}
},4,1);

_j(_bb3002_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb3003_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb233_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb234_termite_23_make_2d_dict();
} else {
return _bb3001_termite_23_make_2d_dict();
}
});

_k(_bb3003_termite_23_make_2d_dict = () => {
return _bb237_termite_23_make_2d_dict();
},2,1);

_j(_bb234_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb235_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb3001_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb236_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb237_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb238_termite_23_make_2d_dict();
} else {
return _bb3000_termite_23_make_2d_dict();
}
});

_k(_bb235_termite_23_make_2d_dict = () => {
return _bb237_termite_23_make_2d_dict();
},2,1);

_k(_bb236_termite_23_make_2d_dict = () => {
return _bb237_termite_23_make_2d_dict();
},2,1);

_j(_bb238_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb239_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb3000_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb239_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2998_termite_23_make_2d_dict();
} else {
return _bb240_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2998_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2999_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb240_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb241_termite_23_make_2d_dict();
} else {
return _bb2997_termite_23_make_2d_dict();
}
});

_k(_bb2999_termite_23_make_2d_dict = () => {
return _bb244_termite_23_make_2d_dict();
},2,1);

_j(_bb241_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb242_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2997_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb243_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb244_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb245_termite_23_make_2d_dict();
} else {
return _bb2996_termite_23_make_2d_dict();
}
});

_k(_bb242_termite_23_make_2d_dict = () => {
return _bb244_termite_23_make_2d_dict();
},2,1);

_k(_bb243_termite_23_make_2d_dict = () => {
return _bb244_termite_23_make_2d_dict();
},2,1);

_j(_bb245_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb246_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2996_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb246_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2994_termite_23_make_2d_dict();
} else {
return _bb247_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2994_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2995_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb247_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb248_termite_23_make_2d_dict();
} else {
return _bb2993_termite_23_make_2d_dict();
}
});

_k(_bb2995_termite_23_make_2d_dict = () => {
return _bb251_termite_23_make_2d_dict();
},2,1);

_j(_bb248_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb249_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2993_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb250_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb251_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb252_termite_23_make_2d_dict();
} else {
return _bb2992_termite_23_make_2d_dict();
}
});

_k(_bb249_termite_23_make_2d_dict = () => {
return _bb251_termite_23_make_2d_dict();
},2,1);

_k(_bb250_termite_23_make_2d_dict = () => {
return _bb251_termite_23_make_2d_dict();
},2,1);

_j(_bb252_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb253_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2992_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb253_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2990_termite_23_make_2d_dict();
} else {
return _bb254_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2990_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2991_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb254_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb255_termite_23_make_2d_dict();
} else {
return _bb2989_termite_23_make_2d_dict();
}
});

_k(_bb2991_termite_23_make_2d_dict = () => {
return _bb258_termite_23_make_2d_dict();
},2,1);

_j(_bb255_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb256_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2989_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb257_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb258_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb259_termite_23_make_2d_dict();
} else {
return _bb2988_termite_23_make_2d_dict();
}
});

_k(_bb256_termite_23_make_2d_dict = () => {
return _bb258_termite_23_make_2d_dict();
},2,1);

_k(_bb257_termite_23_make_2d_dict = () => {
return _bb258_termite_23_make_2d_dict();
},2,1);

_j(_bb259_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb260_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2988_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb260_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2986_termite_23_make_2d_dict();
} else {
return _bb261_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2986_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2987_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb261_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb262_termite_23_make_2d_dict();
} else {
return _bb2985_termite_23_make_2d_dict();
}
});

_k(_bb2987_termite_23_make_2d_dict = () => {
return _bb265_termite_23_make_2d_dict();
},2,1);

_j(_bb262_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb263_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2985_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb264_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb265_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb266_termite_23_make_2d_dict();
} else {
return _bb2984_termite_23_make_2d_dict();
}
});

_k(_bb263_termite_23_make_2d_dict = () => {
return _bb265_termite_23_make_2d_dict();
},2,1);

_k(_bb264_termite_23_make_2d_dict = () => {
return _bb265_termite_23_make_2d_dict();
},2,1);

_j(_bb266_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb267_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2984_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb267_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2982_termite_23_make_2d_dict();
} else {
return _bb268_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2982_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2983_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb268_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb269_termite_23_make_2d_dict();
} else {
return _bb2981_termite_23_make_2d_dict();
}
});

_k(_bb2983_termite_23_make_2d_dict = () => {
return _bb272_termite_23_make_2d_dict();
},2,1);

_j(_bb269_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb270_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2981_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb271_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb272_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb273_termite_23_make_2d_dict();
} else {
return _bb2980_termite_23_make_2d_dict();
}
});

_k(_bb270_termite_23_make_2d_dict = () => {
return _bb272_termite_23_make_2d_dict();
},2,1);

_k(_bb271_termite_23_make_2d_dict = () => {
return _bb272_termite_23_make_2d_dict();
},2,1);

_j(_bb273_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb274_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2980_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb274_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2978_termite_23_make_2d_dict();
} else {
return _bb275_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2978_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2979_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb275_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb276_termite_23_make_2d_dict();
} else {
return _bb2977_termite_23_make_2d_dict();
}
});

_k(_bb2979_termite_23_make_2d_dict = () => {
return _bb279_termite_23_make_2d_dict();
},2,1);

_j(_bb276_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb277_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2977_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb278_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb279_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb280_termite_23_make_2d_dict();
} else {
return _bb2976_termite_23_make_2d_dict();
}
});

_k(_bb277_termite_23_make_2d_dict = () => {
return _bb279_termite_23_make_2d_dict();
},2,1);

_k(_bb278_termite_23_make_2d_dict = () => {
return _bb279_termite_23_make_2d_dict();
},2,1);

_j(_bb280_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb281_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2976_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb281_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2974_termite_23_make_2d_dict();
} else {
return _bb282_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2974_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2975_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb282_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb283_termite_23_make_2d_dict();
} else {
return _bb2973_termite_23_make_2d_dict();
}
});

_k(_bb2975_termite_23_make_2d_dict = () => {
return _bb286_termite_23_make_2d_dict();
},2,1);

_j(_bb283_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb284_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2973_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb285_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb286_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb287_termite_23_make_2d_dict();
} else {
return _bb2972_termite_23_make_2d_dict();
}
});

_k(_bb284_termite_23_make_2d_dict = () => {
return _bb286_termite_23_make_2d_dict();
},2,1);

_k(_bb285_termite_23_make_2d_dict = () => {
return _bb286_termite_23_make_2d_dict();
},2,1);

_j(_bb287_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb288_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2972_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb288_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2970_termite_23_make_2d_dict();
} else {
return _bb289_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2970_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2971_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb289_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb290_termite_23_make_2d_dict();
} else {
return _bb2969_termite_23_make_2d_dict();
}
});

_k(_bb2971_termite_23_make_2d_dict = () => {
return _bb293_termite_23_make_2d_dict();
},2,1);

_j(_bb290_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb291_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2969_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb292_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb293_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb294_termite_23_make_2d_dict();
} else {
return _bb2968_termite_23_make_2d_dict();
}
});

_k(_bb291_termite_23_make_2d_dict = () => {
return _bb293_termite_23_make_2d_dict();
},2,1);

_k(_bb292_termite_23_make_2d_dict = () => {
return _bb293_termite_23_make_2d_dict();
},2,1);

_j(_bb294_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb295_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2968_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb295_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2966_termite_23_make_2d_dict();
} else {
return _bb296_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2966_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2967_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb296_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb297_termite_23_make_2d_dict();
} else {
return _bb2965_termite_23_make_2d_dict();
}
});

_k(_bb2967_termite_23_make_2d_dict = () => {
return _bb300_termite_23_make_2d_dict();
},2,1);

_j(_bb297_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb298_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2965_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb299_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb300_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb301_termite_23_make_2d_dict();
} else {
return _bb2964_termite_23_make_2d_dict();
}
});

_k(_bb298_termite_23_make_2d_dict = () => {
return _bb300_termite_23_make_2d_dict();
},2,1);

_k(_bb299_termite_23_make_2d_dict = () => {
return _bb300_termite_23_make_2d_dict();
},2,1);

_j(_bb301_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb302_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2964_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb302_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2962_termite_23_make_2d_dict();
} else {
return _bb303_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2962_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2963_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb303_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb304_termite_23_make_2d_dict();
} else {
return _bb2961_termite_23_make_2d_dict();
}
});

_k(_bb2963_termite_23_make_2d_dict = () => {
return _bb307_termite_23_make_2d_dict();
},2,1);

_j(_bb304_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb305_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2961_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb306_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb307_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb308_termite_23_make_2d_dict();
} else {
return _bb2960_termite_23_make_2d_dict();
}
});

_k(_bb305_termite_23_make_2d_dict = () => {
return _bb307_termite_23_make_2d_dict();
},2,1);

_k(_bb306_termite_23_make_2d_dict = () => {
return _bb307_termite_23_make_2d_dict();
},2,1);

_j(_bb308_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb309_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2960_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb309_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2958_termite_23_make_2d_dict();
} else {
return _bb310_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2958_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2959_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb310_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb311_termite_23_make_2d_dict();
} else {
return _bb2957_termite_23_make_2d_dict();
}
});

_k(_bb2959_termite_23_make_2d_dict = () => {
return _bb314_termite_23_make_2d_dict();
},2,1);

_j(_bb311_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb312_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2957_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb313_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb314_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb315_termite_23_make_2d_dict();
} else {
return _bb2956_termite_23_make_2d_dict();
}
});

_k(_bb312_termite_23_make_2d_dict = () => {
return _bb314_termite_23_make_2d_dict();
},2,1);

_k(_bb313_termite_23_make_2d_dict = () => {
return _bb314_termite_23_make_2d_dict();
},2,1);

_j(_bb315_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb316_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2956_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb316_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2954_termite_23_make_2d_dict();
} else {
return _bb317_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2954_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2955_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb317_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb318_termite_23_make_2d_dict();
} else {
return _bb2953_termite_23_make_2d_dict();
}
});

_k(_bb2955_termite_23_make_2d_dict = () => {
return _bb321_termite_23_make_2d_dict();
},2,1);

_j(_bb318_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb319_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2953_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb320_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb321_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb322_termite_23_make_2d_dict();
} else {
return _bb2952_termite_23_make_2d_dict();
}
});

_k(_bb319_termite_23_make_2d_dict = () => {
return _bb321_termite_23_make_2d_dict();
},2,1);

_k(_bb320_termite_23_make_2d_dict = () => {
return _bb321_termite_23_make_2d_dict();
},2,1);

_j(_bb322_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb323_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2952_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb323_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2950_termite_23_make_2d_dict();
} else {
return _bb324_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2950_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2951_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb324_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb325_termite_23_make_2d_dict();
} else {
return _bb2949_termite_23_make_2d_dict();
}
});

_k(_bb2951_termite_23_make_2d_dict = () => {
return _bb328_termite_23_make_2d_dict();
},2,1);

_j(_bb325_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb326_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2949_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb327_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb328_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb329_termite_23_make_2d_dict();
} else {
return _bb2948_termite_23_make_2d_dict();
}
});

_k(_bb326_termite_23_make_2d_dict = () => {
return _bb328_termite_23_make_2d_dict();
},2,1);

_k(_bb327_termite_23_make_2d_dict = () => {
return _bb328_termite_23_make_2d_dict();
},2,1);

_j(_bb329_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb330_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2948_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb330_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2946_termite_23_make_2d_dict();
} else {
return _bb331_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2946_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2947_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb331_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb332_termite_23_make_2d_dict();
} else {
return _bb2945_termite_23_make_2d_dict();
}
});

_k(_bb2947_termite_23_make_2d_dict = () => {
return _bb335_termite_23_make_2d_dict();
},2,1);

_j(_bb332_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb333_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2945_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb334_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb335_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb336_termite_23_make_2d_dict();
} else {
return _bb2944_termite_23_make_2d_dict();
}
});

_k(_bb333_termite_23_make_2d_dict = () => {
return _bb335_termite_23_make_2d_dict();
},2,1);

_k(_bb334_termite_23_make_2d_dict = () => {
return _bb335_termite_23_make_2d_dict();
},2,1);

_j(_bb336_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb337_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2944_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb337_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2942_termite_23_make_2d_dict();
} else {
return _bb338_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2942_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2943_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb338_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb339_termite_23_make_2d_dict();
} else {
return _bb2941_termite_23_make_2d_dict();
}
});

_k(_bb2943_termite_23_make_2d_dict = () => {
return _bb342_termite_23_make_2d_dict();
},2,1);

_j(_bb339_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb340_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2941_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb341_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb342_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb343_termite_23_make_2d_dict();
} else {
return _bb2940_termite_23_make_2d_dict();
}
});

_k(_bb340_termite_23_make_2d_dict = () => {
return _bb342_termite_23_make_2d_dict();
},2,1);

_k(_bb341_termite_23_make_2d_dict = () => {
return _bb342_termite_23_make_2d_dict();
},2,1);

_j(_bb343_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb344_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2940_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb344_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2938_termite_23_make_2d_dict();
} else {
return _bb345_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2938_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2939_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb345_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb346_termite_23_make_2d_dict();
} else {
return _bb2937_termite_23_make_2d_dict();
}
});

_k(_bb2939_termite_23_make_2d_dict = () => {
return _bb349_termite_23_make_2d_dict();
},2,1);

_j(_bb346_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb347_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2937_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb348_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb349_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb350_termite_23_make_2d_dict();
} else {
return _bb2936_termite_23_make_2d_dict();
}
});

_k(_bb347_termite_23_make_2d_dict = () => {
return _bb349_termite_23_make_2d_dict();
},2,1);

_k(_bb348_termite_23_make_2d_dict = () => {
return _bb349_termite_23_make_2d_dict();
},2,1);

_j(_bb350_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb351_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2936_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb351_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2934_termite_23_make_2d_dict();
} else {
return _bb352_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2934_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2935_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb352_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb353_termite_23_make_2d_dict();
} else {
return _bb2933_termite_23_make_2d_dict();
}
});

_k(_bb2935_termite_23_make_2d_dict = () => {
return _bb356_termite_23_make_2d_dict();
},2,1);

_j(_bb353_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb354_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2933_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb355_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb356_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb357_termite_23_make_2d_dict();
} else {
return _bb2932_termite_23_make_2d_dict();
}
});

_k(_bb354_termite_23_make_2d_dict = () => {
return _bb356_termite_23_make_2d_dict();
},2,1);

_k(_bb355_termite_23_make_2d_dict = () => {
return _bb356_termite_23_make_2d_dict();
},2,1);

_j(_bb357_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb358_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2932_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb358_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2930_termite_23_make_2d_dict();
} else {
return _bb359_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2930_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2931_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb359_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb360_termite_23_make_2d_dict();
} else {
return _bb2929_termite_23_make_2d_dict();
}
});

_k(_bb2931_termite_23_make_2d_dict = () => {
return _bb363_termite_23_make_2d_dict();
},2,1);

_j(_bb360_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb361_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2929_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb362_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb363_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb364_termite_23_make_2d_dict();
} else {
return _bb2928_termite_23_make_2d_dict();
}
});

_k(_bb361_termite_23_make_2d_dict = () => {
return _bb363_termite_23_make_2d_dict();
},2,1);

_k(_bb362_termite_23_make_2d_dict = () => {
return _bb363_termite_23_make_2d_dict();
},2,1);

_j(_bb364_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb365_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2928_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb365_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2926_termite_23_make_2d_dict();
} else {
return _bb366_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2926_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2927_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb366_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb367_termite_23_make_2d_dict();
} else {
return _bb2925_termite_23_make_2d_dict();
}
});

_k(_bb2927_termite_23_make_2d_dict = () => {
return _bb370_termite_23_make_2d_dict();
},2,1);

_j(_bb367_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb368_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2925_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb369_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb370_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb371_termite_23_make_2d_dict();
} else {
return _bb2924_termite_23_make_2d_dict();
}
});

_k(_bb368_termite_23_make_2d_dict = () => {
return _bb370_termite_23_make_2d_dict();
},2,1);

_k(_bb369_termite_23_make_2d_dict = () => {
return _bb370_termite_23_make_2d_dict();
},2,1);

_j(_bb371_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb372_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2924_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb372_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2922_termite_23_make_2d_dict();
} else {
return _bb373_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2922_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2923_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb373_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb374_termite_23_make_2d_dict();
} else {
return _bb2921_termite_23_make_2d_dict();
}
});

_k(_bb2923_termite_23_make_2d_dict = () => {
return _bb377_termite_23_make_2d_dict();
},2,1);

_j(_bb374_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb375_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2921_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb376_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb377_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb378_termite_23_make_2d_dict();
} else {
return _bb2920_termite_23_make_2d_dict();
}
});

_k(_bb375_termite_23_make_2d_dict = () => {
return _bb377_termite_23_make_2d_dict();
},2,1);

_k(_bb376_termite_23_make_2d_dict = () => {
return _bb377_termite_23_make_2d_dict();
},2,1);

_j(_bb378_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb379_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2920_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb379_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2918_termite_23_make_2d_dict();
} else {
return _bb380_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2918_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2919_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb380_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb381_termite_23_make_2d_dict();
} else {
return _bb2917_termite_23_make_2d_dict();
}
});

_k(_bb2919_termite_23_make_2d_dict = () => {
return _bb384_termite_23_make_2d_dict();
},2,1);

_j(_bb381_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb382_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2917_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb383_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb384_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb385_termite_23_make_2d_dict();
} else {
return _bb2916_termite_23_make_2d_dict();
}
});

_k(_bb382_termite_23_make_2d_dict = () => {
return _bb384_termite_23_make_2d_dict();
},2,1);

_k(_bb383_termite_23_make_2d_dict = () => {
return _bb384_termite_23_make_2d_dict();
},2,1);

_j(_bb385_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb386_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2916_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb386_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2914_termite_23_make_2d_dict();
} else {
return _bb387_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2914_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2915_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb387_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb388_termite_23_make_2d_dict();
} else {
return _bb2913_termite_23_make_2d_dict();
}
});

_k(_bb2915_termite_23_make_2d_dict = () => {
return _bb391_termite_23_make_2d_dict();
},2,1);

_j(_bb388_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb389_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2913_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb390_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb391_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb392_termite_23_make_2d_dict();
} else {
return _bb2912_termite_23_make_2d_dict();
}
});

_k(_bb389_termite_23_make_2d_dict = () => {
return _bb391_termite_23_make_2d_dict();
},2,1);

_k(_bb390_termite_23_make_2d_dict = () => {
return _bb391_termite_23_make_2d_dict();
},2,1);

_j(_bb392_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb393_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2912_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb393_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2910_termite_23_make_2d_dict();
} else {
return _bb394_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2910_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2911_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb394_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb395_termite_23_make_2d_dict();
} else {
return _bb2909_termite_23_make_2d_dict();
}
});

_k(_bb2911_termite_23_make_2d_dict = () => {
return _bb398_termite_23_make_2d_dict();
},2,1);

_j(_bb395_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb396_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2909_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb397_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb398_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb399_termite_23_make_2d_dict();
} else {
return _bb2908_termite_23_make_2d_dict();
}
});

_k(_bb396_termite_23_make_2d_dict = () => {
return _bb398_termite_23_make_2d_dict();
},2,1);

_k(_bb397_termite_23_make_2d_dict = () => {
return _bb398_termite_23_make_2d_dict();
},2,1);

_j(_bb399_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb400_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2908_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb400_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2906_termite_23_make_2d_dict();
} else {
return _bb401_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2906_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2907_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb401_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb402_termite_23_make_2d_dict();
} else {
return _bb2905_termite_23_make_2d_dict();
}
});

_k(_bb2907_termite_23_make_2d_dict = () => {
return _bb405_termite_23_make_2d_dict();
},2,1);

_j(_bb402_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb403_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2905_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb404_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb405_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb406_termite_23_make_2d_dict();
} else {
return _bb2904_termite_23_make_2d_dict();
}
});

_k(_bb403_termite_23_make_2d_dict = () => {
return _bb405_termite_23_make_2d_dict();
},2,1);

_k(_bb404_termite_23_make_2d_dict = () => {
return _bb405_termite_23_make_2d_dict();
},2,1);

_j(_bb406_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb407_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2904_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb407_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2902_termite_23_make_2d_dict();
} else {
return _bb408_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2902_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2903_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb408_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb409_termite_23_make_2d_dict();
} else {
return _bb2901_termite_23_make_2d_dict();
}
});

_k(_bb2903_termite_23_make_2d_dict = () => {
return _bb412_termite_23_make_2d_dict();
},2,1);

_j(_bb409_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb410_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2901_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb411_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb412_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb413_termite_23_make_2d_dict();
} else {
return _bb2900_termite_23_make_2d_dict();
}
});

_k(_bb410_termite_23_make_2d_dict = () => {
return _bb412_termite_23_make_2d_dict();
},2,1);

_k(_bb411_termite_23_make_2d_dict = () => {
return _bb412_termite_23_make_2d_dict();
},2,1);

_j(_bb413_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb414_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2900_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb414_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2898_termite_23_make_2d_dict();
} else {
return _bb415_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2898_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2899_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb415_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb416_termite_23_make_2d_dict();
} else {
return _bb2897_termite_23_make_2d_dict();
}
});

_k(_bb2899_termite_23_make_2d_dict = () => {
return _bb419_termite_23_make_2d_dict();
},2,1);

_j(_bb416_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb417_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2897_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb418_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb419_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb420_termite_23_make_2d_dict();
} else {
return _bb2896_termite_23_make_2d_dict();
}
});

_k(_bb417_termite_23_make_2d_dict = () => {
return _bb419_termite_23_make_2d_dict();
},2,1);

_k(_bb418_termite_23_make_2d_dict = () => {
return _bb419_termite_23_make_2d_dict();
},2,1);

_j(_bb420_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb421_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2896_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb421_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2894_termite_23_make_2d_dict();
} else {
return _bb422_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2894_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2895_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb422_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb423_termite_23_make_2d_dict();
} else {
return _bb2893_termite_23_make_2d_dict();
}
});

_k(_bb2895_termite_23_make_2d_dict = () => {
return _bb426_termite_23_make_2d_dict();
},2,1);

_j(_bb423_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb424_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2893_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb425_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb426_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb427_termite_23_make_2d_dict();
} else {
return _bb2892_termite_23_make_2d_dict();
}
});

_k(_bb424_termite_23_make_2d_dict = () => {
return _bb426_termite_23_make_2d_dict();
},2,1);

_k(_bb425_termite_23_make_2d_dict = () => {
return _bb426_termite_23_make_2d_dict();
},2,1);

_j(_bb427_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb428_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2892_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb428_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2890_termite_23_make_2d_dict();
} else {
return _bb429_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2890_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2891_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb429_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb430_termite_23_make_2d_dict();
} else {
return _bb2889_termite_23_make_2d_dict();
}
});

_k(_bb2891_termite_23_make_2d_dict = () => {
return _bb433_termite_23_make_2d_dict();
},2,1);

_j(_bb430_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb431_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2889_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb432_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb433_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb434_termite_23_make_2d_dict();
} else {
return _bb2888_termite_23_make_2d_dict();
}
});

_k(_bb431_termite_23_make_2d_dict = () => {
return _bb433_termite_23_make_2d_dict();
},2,1);

_k(_bb432_termite_23_make_2d_dict = () => {
return _bb433_termite_23_make_2d_dict();
},2,1);

_j(_bb434_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb435_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2888_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb435_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2886_termite_23_make_2d_dict();
} else {
return _bb436_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2886_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2887_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb436_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb437_termite_23_make_2d_dict();
} else {
return _bb2885_termite_23_make_2d_dict();
}
});

_k(_bb2887_termite_23_make_2d_dict = () => {
return _bb440_termite_23_make_2d_dict();
},2,1);

_j(_bb437_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb438_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2885_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb439_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb440_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb441_termite_23_make_2d_dict();
} else {
return _bb2884_termite_23_make_2d_dict();
}
});

_k(_bb438_termite_23_make_2d_dict = () => {
return _bb440_termite_23_make_2d_dict();
},2,1);

_k(_bb439_termite_23_make_2d_dict = () => {
return _bb440_termite_23_make_2d_dict();
},2,1);

_j(_bb441_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb442_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2884_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb442_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2882_termite_23_make_2d_dict();
} else {
return _bb443_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2882_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2883_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb443_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb444_termite_23_make_2d_dict();
} else {
return _bb2881_termite_23_make_2d_dict();
}
});

_k(_bb2883_termite_23_make_2d_dict = () => {
return _bb447_termite_23_make_2d_dict();
},2,1);

_j(_bb444_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb445_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2881_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb446_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb447_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb448_termite_23_make_2d_dict();
} else {
return _bb2880_termite_23_make_2d_dict();
}
});

_k(_bb445_termite_23_make_2d_dict = () => {
return _bb447_termite_23_make_2d_dict();
},2,1);

_k(_bb446_termite_23_make_2d_dict = () => {
return _bb447_termite_23_make_2d_dict();
},2,1);

_j(_bb448_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb449_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2880_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb449_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2878_termite_23_make_2d_dict();
} else {
return _bb450_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2878_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2879_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb450_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb451_termite_23_make_2d_dict();
} else {
return _bb2877_termite_23_make_2d_dict();
}
});

_k(_bb2879_termite_23_make_2d_dict = () => {
return _bb454_termite_23_make_2d_dict();
},2,1);

_j(_bb451_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb452_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2877_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb453_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb454_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb455_termite_23_make_2d_dict();
} else {
return _bb2876_termite_23_make_2d_dict();
}
});

_k(_bb452_termite_23_make_2d_dict = () => {
return _bb454_termite_23_make_2d_dict();
},2,1);

_k(_bb453_termite_23_make_2d_dict = () => {
return _bb454_termite_23_make_2d_dict();
},2,1);

_j(_bb455_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb456_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2876_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb456_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2874_termite_23_make_2d_dict();
} else {
return _bb457_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2874_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2875_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb457_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb458_termite_23_make_2d_dict();
} else {
return _bb2873_termite_23_make_2d_dict();
}
});

_k(_bb2875_termite_23_make_2d_dict = () => {
return _bb461_termite_23_make_2d_dict();
},2,1);

_j(_bb458_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb459_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2873_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb460_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb461_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb462_termite_23_make_2d_dict();
} else {
return _bb2872_termite_23_make_2d_dict();
}
});

_k(_bb459_termite_23_make_2d_dict = () => {
return _bb461_termite_23_make_2d_dict();
},2,1);

_k(_bb460_termite_23_make_2d_dict = () => {
return _bb461_termite_23_make_2d_dict();
},2,1);

_j(_bb462_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb463_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2872_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb463_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2870_termite_23_make_2d_dict();
} else {
return _bb464_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2870_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2871_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb464_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb465_termite_23_make_2d_dict();
} else {
return _bb2869_termite_23_make_2d_dict();
}
});

_k(_bb2871_termite_23_make_2d_dict = () => {
return _bb468_termite_23_make_2d_dict();
},2,1);

_j(_bb465_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb466_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2869_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb467_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb468_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb469_termite_23_make_2d_dict();
} else {
return _bb2868_termite_23_make_2d_dict();
}
});

_k(_bb466_termite_23_make_2d_dict = () => {
return _bb468_termite_23_make_2d_dict();
},2,1);

_k(_bb467_termite_23_make_2d_dict = () => {
return _bb468_termite_23_make_2d_dict();
},2,1);

_j(_bb469_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb470_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2868_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb470_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2866_termite_23_make_2d_dict();
} else {
return _bb471_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2866_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2867_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb471_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb472_termite_23_make_2d_dict();
} else {
return _bb2865_termite_23_make_2d_dict();
}
});

_k(_bb2867_termite_23_make_2d_dict = () => {
return _bb475_termite_23_make_2d_dict();
},2,1);

_j(_bb472_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb473_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2865_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb474_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb475_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb476_termite_23_make_2d_dict();
} else {
return _bb2864_termite_23_make_2d_dict();
}
});

_k(_bb473_termite_23_make_2d_dict = () => {
return _bb475_termite_23_make_2d_dict();
},2,1);

_k(_bb474_termite_23_make_2d_dict = () => {
return _bb475_termite_23_make_2d_dict();
},2,1);

_j(_bb476_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb477_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2864_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb477_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2862_termite_23_make_2d_dict();
} else {
return _bb478_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2862_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2863_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb478_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb479_termite_23_make_2d_dict();
} else {
return _bb2861_termite_23_make_2d_dict();
}
});

_k(_bb2863_termite_23_make_2d_dict = () => {
return _bb482_termite_23_make_2d_dict();
},2,1);

_j(_bb479_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb480_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2861_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb481_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb482_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb483_termite_23_make_2d_dict();
} else {
return _bb2860_termite_23_make_2d_dict();
}
});

_k(_bb480_termite_23_make_2d_dict = () => {
return _bb482_termite_23_make_2d_dict();
},2,1);

_k(_bb481_termite_23_make_2d_dict = () => {
return _bb482_termite_23_make_2d_dict();
},2,1);

_j(_bb483_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb484_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2860_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb484_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2858_termite_23_make_2d_dict();
} else {
return _bb485_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2858_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2859_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb485_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb486_termite_23_make_2d_dict();
} else {
return _bb2857_termite_23_make_2d_dict();
}
});

_k(_bb2859_termite_23_make_2d_dict = () => {
return _bb489_termite_23_make_2d_dict();
},2,1);

_j(_bb486_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb487_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2857_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb488_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb489_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb490_termite_23_make_2d_dict();
} else {
return _bb2856_termite_23_make_2d_dict();
}
});

_k(_bb487_termite_23_make_2d_dict = () => {
return _bb489_termite_23_make_2d_dict();
},2,1);

_k(_bb488_termite_23_make_2d_dict = () => {
return _bb489_termite_23_make_2d_dict();
},2,1);

_j(_bb490_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb491_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2856_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb491_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2854_termite_23_make_2d_dict();
} else {
return _bb492_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2854_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2855_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb492_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb493_termite_23_make_2d_dict();
} else {
return _bb2853_termite_23_make_2d_dict();
}
});

_k(_bb2855_termite_23_make_2d_dict = () => {
return _bb496_termite_23_make_2d_dict();
},2,1);

_j(_bb493_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb494_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2853_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb495_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb496_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb497_termite_23_make_2d_dict();
} else {
return _bb2852_termite_23_make_2d_dict();
}
});

_k(_bb494_termite_23_make_2d_dict = () => {
return _bb496_termite_23_make_2d_dict();
},2,1);

_k(_bb495_termite_23_make_2d_dict = () => {
return _bb496_termite_23_make_2d_dict();
},2,1);

_j(_bb497_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb498_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2852_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb498_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2850_termite_23_make_2d_dict();
} else {
return _bb499_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2850_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2851_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb499_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb500_termite_23_make_2d_dict();
} else {
return _bb2849_termite_23_make_2d_dict();
}
});

_k(_bb2851_termite_23_make_2d_dict = () => {
return _bb503_termite_23_make_2d_dict();
},2,1);

_j(_bb500_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb501_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2849_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb502_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb503_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb504_termite_23_make_2d_dict();
} else {
return _bb2848_termite_23_make_2d_dict();
}
});

_k(_bb501_termite_23_make_2d_dict = () => {
return _bb503_termite_23_make_2d_dict();
},2,1);

_k(_bb502_termite_23_make_2d_dict = () => {
return _bb503_termite_23_make_2d_dict();
},2,1);

_j(_bb504_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb505_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2848_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb505_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2846_termite_23_make_2d_dict();
} else {
return _bb506_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2846_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2847_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb506_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb507_termite_23_make_2d_dict();
} else {
return _bb2845_termite_23_make_2d_dict();
}
});

_k(_bb2847_termite_23_make_2d_dict = () => {
return _bb510_termite_23_make_2d_dict();
},2,1);

_j(_bb507_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb508_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2845_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb509_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb510_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb511_termite_23_make_2d_dict();
} else {
return _bb2844_termite_23_make_2d_dict();
}
});

_k(_bb508_termite_23_make_2d_dict = () => {
return _bb510_termite_23_make_2d_dict();
},2,1);

_k(_bb509_termite_23_make_2d_dict = () => {
return _bb510_termite_23_make_2d_dict();
},2,1);

_j(_bb511_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb512_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2844_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb512_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2842_termite_23_make_2d_dict();
} else {
return _bb513_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2842_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2843_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb513_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb514_termite_23_make_2d_dict();
} else {
return _bb2841_termite_23_make_2d_dict();
}
});

_k(_bb2843_termite_23_make_2d_dict = () => {
return _bb517_termite_23_make_2d_dict();
},2,1);

_j(_bb514_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb515_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2841_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb516_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb517_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb518_termite_23_make_2d_dict();
} else {
return _bb2840_termite_23_make_2d_dict();
}
});

_k(_bb515_termite_23_make_2d_dict = () => {
return _bb517_termite_23_make_2d_dict();
},2,1);

_k(_bb516_termite_23_make_2d_dict = () => {
return _bb517_termite_23_make_2d_dict();
},2,1);

_j(_bb518_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb519_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2840_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb519_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2838_termite_23_make_2d_dict();
} else {
return _bb520_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2838_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2839_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb520_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb521_termite_23_make_2d_dict();
} else {
return _bb2837_termite_23_make_2d_dict();
}
});

_k(_bb2839_termite_23_make_2d_dict = () => {
return _bb524_termite_23_make_2d_dict();
},2,1);

_j(_bb521_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb522_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2837_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb523_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb524_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb525_termite_23_make_2d_dict();
} else {
return _bb2836_termite_23_make_2d_dict();
}
});

_k(_bb522_termite_23_make_2d_dict = () => {
return _bb524_termite_23_make_2d_dict();
},2,1);

_k(_bb523_termite_23_make_2d_dict = () => {
return _bb524_termite_23_make_2d_dict();
},2,1);

_j(_bb525_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb526_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2836_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb526_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2834_termite_23_make_2d_dict();
} else {
return _bb527_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2834_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2835_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb527_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb528_termite_23_make_2d_dict();
} else {
return _bb2833_termite_23_make_2d_dict();
}
});

_k(_bb2835_termite_23_make_2d_dict = () => {
return _bb531_termite_23_make_2d_dict();
},2,1);

_j(_bb528_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb529_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2833_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb530_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb531_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb532_termite_23_make_2d_dict();
} else {
return _bb2832_termite_23_make_2d_dict();
}
});

_k(_bb529_termite_23_make_2d_dict = () => {
return _bb531_termite_23_make_2d_dict();
},2,1);

_k(_bb530_termite_23_make_2d_dict = () => {
return _bb531_termite_23_make_2d_dict();
},2,1);

_j(_bb532_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb533_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2832_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb533_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2830_termite_23_make_2d_dict();
} else {
return _bb534_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2830_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2831_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb534_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb535_termite_23_make_2d_dict();
} else {
return _bb2829_termite_23_make_2d_dict();
}
});

_k(_bb2831_termite_23_make_2d_dict = () => {
return _bb538_termite_23_make_2d_dict();
},2,1);

_j(_bb535_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb536_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2829_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb537_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb538_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb539_termite_23_make_2d_dict();
} else {
return _bb2828_termite_23_make_2d_dict();
}
});

_k(_bb536_termite_23_make_2d_dict = () => {
return _bb538_termite_23_make_2d_dict();
},2,1);

_k(_bb537_termite_23_make_2d_dict = () => {
return _bb538_termite_23_make_2d_dict();
},2,1);

_j(_bb539_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb540_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2828_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb540_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2826_termite_23_make_2d_dict();
} else {
return _bb541_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2826_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2827_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb541_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb542_termite_23_make_2d_dict();
} else {
return _bb2825_termite_23_make_2d_dict();
}
});

_k(_bb2827_termite_23_make_2d_dict = () => {
return _bb545_termite_23_make_2d_dict();
},2,1);

_j(_bb542_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb543_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2825_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb544_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb545_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb546_termite_23_make_2d_dict();
} else {
return _bb2824_termite_23_make_2d_dict();
}
});

_k(_bb543_termite_23_make_2d_dict = () => {
return _bb545_termite_23_make_2d_dict();
},2,1);

_k(_bb544_termite_23_make_2d_dict = () => {
return _bb545_termite_23_make_2d_dict();
},2,1);

_j(_bb546_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb547_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2824_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb547_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2822_termite_23_make_2d_dict();
} else {
return _bb548_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2822_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2823_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb548_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb549_termite_23_make_2d_dict();
} else {
return _bb2821_termite_23_make_2d_dict();
}
});

_k(_bb2823_termite_23_make_2d_dict = () => {
return _bb552_termite_23_make_2d_dict();
},2,1);

_j(_bb549_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb550_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2821_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb551_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb552_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb553_termite_23_make_2d_dict();
} else {
return _bb2820_termite_23_make_2d_dict();
}
});

_k(_bb550_termite_23_make_2d_dict = () => {
return _bb552_termite_23_make_2d_dict();
},2,1);

_k(_bb551_termite_23_make_2d_dict = () => {
return _bb552_termite_23_make_2d_dict();
},2,1);

_j(_bb553_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb554_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2820_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb554_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2818_termite_23_make_2d_dict();
} else {
return _bb555_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2818_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2819_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb555_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb556_termite_23_make_2d_dict();
} else {
return _bb2817_termite_23_make_2d_dict();
}
});

_k(_bb2819_termite_23_make_2d_dict = () => {
return _bb559_termite_23_make_2d_dict();
},2,1);

_j(_bb556_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb557_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2817_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb558_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb559_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb560_termite_23_make_2d_dict();
} else {
return _bb2816_termite_23_make_2d_dict();
}
});

_k(_bb557_termite_23_make_2d_dict = () => {
return _bb559_termite_23_make_2d_dict();
},2,1);

_k(_bb558_termite_23_make_2d_dict = () => {
return _bb559_termite_23_make_2d_dict();
},2,1);

_j(_bb560_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb561_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2816_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb561_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2814_termite_23_make_2d_dict();
} else {
return _bb562_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2814_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2815_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb562_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb563_termite_23_make_2d_dict();
} else {
return _bb2813_termite_23_make_2d_dict();
}
});

_k(_bb2815_termite_23_make_2d_dict = () => {
return _bb566_termite_23_make_2d_dict();
},2,1);

_j(_bb563_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb564_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2813_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb565_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb566_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb567_termite_23_make_2d_dict();
} else {
return _bb2812_termite_23_make_2d_dict();
}
});

_k(_bb564_termite_23_make_2d_dict = () => {
return _bb566_termite_23_make_2d_dict();
},2,1);

_k(_bb565_termite_23_make_2d_dict = () => {
return _bb566_termite_23_make_2d_dict();
},2,1);

_j(_bb567_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb568_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2812_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb568_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2810_termite_23_make_2d_dict();
} else {
return _bb569_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2810_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2811_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb569_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb570_termite_23_make_2d_dict();
} else {
return _bb2809_termite_23_make_2d_dict();
}
});

_k(_bb2811_termite_23_make_2d_dict = () => {
return _bb573_termite_23_make_2d_dict();
},2,1);

_j(_bb570_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb571_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2809_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb572_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb573_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb574_termite_23_make_2d_dict();
} else {
return _bb2808_termite_23_make_2d_dict();
}
});

_k(_bb571_termite_23_make_2d_dict = () => {
return _bb573_termite_23_make_2d_dict();
},2,1);

_k(_bb572_termite_23_make_2d_dict = () => {
return _bb573_termite_23_make_2d_dict();
},2,1);

_j(_bb574_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb575_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2808_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb575_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2806_termite_23_make_2d_dict();
} else {
return _bb576_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2806_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2807_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb576_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb577_termite_23_make_2d_dict();
} else {
return _bb2805_termite_23_make_2d_dict();
}
});

_k(_bb2807_termite_23_make_2d_dict = () => {
return _bb580_termite_23_make_2d_dict();
},2,1);

_j(_bb577_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb578_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2805_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb579_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb580_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb581_termite_23_make_2d_dict();
} else {
return _bb2804_termite_23_make_2d_dict();
}
});

_k(_bb578_termite_23_make_2d_dict = () => {
return _bb580_termite_23_make_2d_dict();
},2,1);

_k(_bb579_termite_23_make_2d_dict = () => {
return _bb580_termite_23_make_2d_dict();
},2,1);

_j(_bb581_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb582_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2804_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb582_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2802_termite_23_make_2d_dict();
} else {
return _bb583_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2802_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2803_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb583_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb584_termite_23_make_2d_dict();
} else {
return _bb2801_termite_23_make_2d_dict();
}
});

_k(_bb2803_termite_23_make_2d_dict = () => {
return _bb587_termite_23_make_2d_dict();
},2,1);

_j(_bb584_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb585_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2801_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb586_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb587_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb588_termite_23_make_2d_dict();
} else {
return _bb2800_termite_23_make_2d_dict();
}
});

_k(_bb585_termite_23_make_2d_dict = () => {
return _bb587_termite_23_make_2d_dict();
},2,1);

_k(_bb586_termite_23_make_2d_dict = () => {
return _bb587_termite_23_make_2d_dict();
},2,1);

_j(_bb588_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb589_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2800_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb589_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2798_termite_23_make_2d_dict();
} else {
return _bb590_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2798_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2799_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb590_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb591_termite_23_make_2d_dict();
} else {
return _bb2797_termite_23_make_2d_dict();
}
});

_k(_bb2799_termite_23_make_2d_dict = () => {
return _bb594_termite_23_make_2d_dict();
},2,1);

_j(_bb591_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb592_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2797_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb593_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb594_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb595_termite_23_make_2d_dict();
} else {
return _bb2796_termite_23_make_2d_dict();
}
});

_k(_bb592_termite_23_make_2d_dict = () => {
return _bb594_termite_23_make_2d_dict();
},2,1);

_k(_bb593_termite_23_make_2d_dict = () => {
return _bb594_termite_23_make_2d_dict();
},2,1);

_j(_bb595_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb596_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2796_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb596_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2794_termite_23_make_2d_dict();
} else {
return _bb597_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2794_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2795_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb597_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb598_termite_23_make_2d_dict();
} else {
return _bb2793_termite_23_make_2d_dict();
}
});

_k(_bb2795_termite_23_make_2d_dict = () => {
return _bb601_termite_23_make_2d_dict();
},2,1);

_j(_bb598_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb599_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2793_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb600_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb601_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb602_termite_23_make_2d_dict();
} else {
return _bb2792_termite_23_make_2d_dict();
}
});

_k(_bb599_termite_23_make_2d_dict = () => {
return _bb601_termite_23_make_2d_dict();
},2,1);

_k(_bb600_termite_23_make_2d_dict = () => {
return _bb601_termite_23_make_2d_dict();
},2,1);

_j(_bb602_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb603_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2792_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb603_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2790_termite_23_make_2d_dict();
} else {
return _bb604_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2790_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2791_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb604_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb605_termite_23_make_2d_dict();
} else {
return _bb2789_termite_23_make_2d_dict();
}
});

_k(_bb2791_termite_23_make_2d_dict = () => {
return _bb608_termite_23_make_2d_dict();
},2,1);

_j(_bb605_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb606_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2789_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb607_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb608_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb609_termite_23_make_2d_dict();
} else {
return _bb2788_termite_23_make_2d_dict();
}
});

_k(_bb606_termite_23_make_2d_dict = () => {
return _bb608_termite_23_make_2d_dict();
},2,1);

_k(_bb607_termite_23_make_2d_dict = () => {
return _bb608_termite_23_make_2d_dict();
},2,1);

_j(_bb609_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb610_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2788_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb610_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2786_termite_23_make_2d_dict();
} else {
return _bb611_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2786_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2787_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb611_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb612_termite_23_make_2d_dict();
} else {
return _bb2785_termite_23_make_2d_dict();
}
});

_k(_bb2787_termite_23_make_2d_dict = () => {
return _bb615_termite_23_make_2d_dict();
},2,1);

_j(_bb612_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb613_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2785_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb614_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb615_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb616_termite_23_make_2d_dict();
} else {
return _bb2784_termite_23_make_2d_dict();
}
});

_k(_bb613_termite_23_make_2d_dict = () => {
return _bb615_termite_23_make_2d_dict();
},2,1);

_k(_bb614_termite_23_make_2d_dict = () => {
return _bb615_termite_23_make_2d_dict();
},2,1);

_j(_bb616_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb617_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2784_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb617_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2782_termite_23_make_2d_dict();
} else {
return _bb618_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2782_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2783_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb618_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb619_termite_23_make_2d_dict();
} else {
return _bb2781_termite_23_make_2d_dict();
}
});

_k(_bb2783_termite_23_make_2d_dict = () => {
return _bb622_termite_23_make_2d_dict();
},2,1);

_j(_bb619_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb620_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2781_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb621_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb622_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb623_termite_23_make_2d_dict();
} else {
return _bb2780_termite_23_make_2d_dict();
}
});

_k(_bb620_termite_23_make_2d_dict = () => {
return _bb622_termite_23_make_2d_dict();
},2,1);

_k(_bb621_termite_23_make_2d_dict = () => {
return _bb622_termite_23_make_2d_dict();
},2,1);

_j(_bb623_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb624_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2780_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb624_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2778_termite_23_make_2d_dict();
} else {
return _bb625_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2778_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2779_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb625_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb626_termite_23_make_2d_dict();
} else {
return _bb2777_termite_23_make_2d_dict();
}
});

_k(_bb2779_termite_23_make_2d_dict = () => {
return _bb629_termite_23_make_2d_dict();
},2,1);

_j(_bb626_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb627_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2777_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb628_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb629_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb630_termite_23_make_2d_dict();
} else {
return _bb2776_termite_23_make_2d_dict();
}
});

_k(_bb627_termite_23_make_2d_dict = () => {
return _bb629_termite_23_make_2d_dict();
},2,1);

_k(_bb628_termite_23_make_2d_dict = () => {
return _bb629_termite_23_make_2d_dict();
},2,1);

_j(_bb630_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb631_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2776_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb631_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2774_termite_23_make_2d_dict();
} else {
return _bb632_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2774_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2775_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb632_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb633_termite_23_make_2d_dict();
} else {
return _bb2773_termite_23_make_2d_dict();
}
});

_k(_bb2775_termite_23_make_2d_dict = () => {
return _bb636_termite_23_make_2d_dict();
},2,1);

_j(_bb633_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb634_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2773_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb635_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb636_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb637_termite_23_make_2d_dict();
} else {
return _bb2772_termite_23_make_2d_dict();
}
});

_k(_bb634_termite_23_make_2d_dict = () => {
return _bb636_termite_23_make_2d_dict();
},2,1);

_k(_bb635_termite_23_make_2d_dict = () => {
return _bb636_termite_23_make_2d_dict();
},2,1);

_j(_bb637_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb638_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2772_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb638_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2770_termite_23_make_2d_dict();
} else {
return _bb639_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2770_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2771_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb639_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb640_termite_23_make_2d_dict();
} else {
return _bb2769_termite_23_make_2d_dict();
}
});

_k(_bb2771_termite_23_make_2d_dict = () => {
return _bb643_termite_23_make_2d_dict();
},2,1);

_j(_bb640_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb641_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2769_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb642_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb643_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb644_termite_23_make_2d_dict();
} else {
return _bb2768_termite_23_make_2d_dict();
}
});

_k(_bb641_termite_23_make_2d_dict = () => {
return _bb643_termite_23_make_2d_dict();
},2,1);

_k(_bb642_termite_23_make_2d_dict = () => {
return _bb643_termite_23_make_2d_dict();
},2,1);

_j(_bb644_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb645_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2768_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb645_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2766_termite_23_make_2d_dict();
} else {
return _bb646_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2766_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2767_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb646_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb647_termite_23_make_2d_dict();
} else {
return _bb2765_termite_23_make_2d_dict();
}
});

_k(_bb2767_termite_23_make_2d_dict = () => {
return _bb650_termite_23_make_2d_dict();
},2,1);

_j(_bb647_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb648_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2765_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb649_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb650_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb651_termite_23_make_2d_dict();
} else {
return _bb2764_termite_23_make_2d_dict();
}
});

_k(_bb648_termite_23_make_2d_dict = () => {
return _bb650_termite_23_make_2d_dict();
},2,1);

_k(_bb649_termite_23_make_2d_dict = () => {
return _bb650_termite_23_make_2d_dict();
},2,1);

_j(_bb651_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb652_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2764_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb652_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2762_termite_23_make_2d_dict();
} else {
return _bb653_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2762_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2763_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb653_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb654_termite_23_make_2d_dict();
} else {
return _bb2761_termite_23_make_2d_dict();
}
});

_k(_bb2763_termite_23_make_2d_dict = () => {
return _bb657_termite_23_make_2d_dict();
},2,1);

_j(_bb654_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb655_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2761_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb656_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb657_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb658_termite_23_make_2d_dict();
} else {
return _bb2760_termite_23_make_2d_dict();
}
});

_k(_bb655_termite_23_make_2d_dict = () => {
return _bb657_termite_23_make_2d_dict();
},2,1);

_k(_bb656_termite_23_make_2d_dict = () => {
return _bb657_termite_23_make_2d_dict();
},2,1);

_j(_bb658_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb659_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2760_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb659_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2758_termite_23_make_2d_dict();
} else {
return _bb660_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2758_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2759_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb660_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb661_termite_23_make_2d_dict();
} else {
return _bb2757_termite_23_make_2d_dict();
}
});

_k(_bb2759_termite_23_make_2d_dict = () => {
return _bb664_termite_23_make_2d_dict();
},2,1);

_j(_bb661_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb662_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2757_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb663_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb664_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb665_termite_23_make_2d_dict();
} else {
return _bb2756_termite_23_make_2d_dict();
}
});

_k(_bb662_termite_23_make_2d_dict = () => {
return _bb664_termite_23_make_2d_dict();
},2,1);

_k(_bb663_termite_23_make_2d_dict = () => {
return _bb664_termite_23_make_2d_dict();
},2,1);

_j(_bb665_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb666_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2756_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb666_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2754_termite_23_make_2d_dict();
} else {
return _bb667_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2754_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2755_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb667_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb668_termite_23_make_2d_dict();
} else {
return _bb2753_termite_23_make_2d_dict();
}
});

_k(_bb2755_termite_23_make_2d_dict = () => {
return _bb671_termite_23_make_2d_dict();
},2,1);

_j(_bb668_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb669_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2753_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb670_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb671_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb672_termite_23_make_2d_dict();
} else {
return _bb2752_termite_23_make_2d_dict();
}
});

_k(_bb669_termite_23_make_2d_dict = () => {
return _bb671_termite_23_make_2d_dict();
},2,1);

_k(_bb670_termite_23_make_2d_dict = () => {
return _bb671_termite_23_make_2d_dict();
},2,1);

_j(_bb672_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb673_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2752_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb673_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2750_termite_23_make_2d_dict();
} else {
return _bb674_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2750_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2751_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb674_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb675_termite_23_make_2d_dict();
} else {
return _bb2749_termite_23_make_2d_dict();
}
});

_k(_bb2751_termite_23_make_2d_dict = () => {
return _bb678_termite_23_make_2d_dict();
},2,1);

_j(_bb675_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb676_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2749_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb677_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb678_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb679_termite_23_make_2d_dict();
} else {
return _bb2748_termite_23_make_2d_dict();
}
});

_k(_bb676_termite_23_make_2d_dict = () => {
return _bb678_termite_23_make_2d_dict();
},2,1);

_k(_bb677_termite_23_make_2d_dict = () => {
return _bb678_termite_23_make_2d_dict();
},2,1);

_j(_bb679_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb680_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2748_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb680_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2746_termite_23_make_2d_dict();
} else {
return _bb681_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2746_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2747_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb681_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb682_termite_23_make_2d_dict();
} else {
return _bb2745_termite_23_make_2d_dict();
}
});

_k(_bb2747_termite_23_make_2d_dict = () => {
return _bb685_termite_23_make_2d_dict();
},2,1);

_j(_bb682_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb683_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2745_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb684_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb685_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb686_termite_23_make_2d_dict();
} else {
return _bb2744_termite_23_make_2d_dict();
}
});

_k(_bb683_termite_23_make_2d_dict = () => {
return _bb685_termite_23_make_2d_dict();
},2,1);

_k(_bb684_termite_23_make_2d_dict = () => {
return _bb685_termite_23_make_2d_dict();
},2,1);

_j(_bb686_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb687_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2744_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb687_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2742_termite_23_make_2d_dict();
} else {
return _bb688_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2742_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2743_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb688_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb689_termite_23_make_2d_dict();
} else {
return _bb2741_termite_23_make_2d_dict();
}
});

_k(_bb2743_termite_23_make_2d_dict = () => {
return _bb692_termite_23_make_2d_dict();
},2,1);

_j(_bb689_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb690_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2741_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb691_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb692_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb693_termite_23_make_2d_dict();
} else {
return _bb2740_termite_23_make_2d_dict();
}
});

_k(_bb690_termite_23_make_2d_dict = () => {
return _bb692_termite_23_make_2d_dict();
},2,1);

_k(_bb691_termite_23_make_2d_dict = () => {
return _bb692_termite_23_make_2d_dict();
},2,1);

_j(_bb693_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb694_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2740_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb694_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb695_termite_23_make_2d_dict();
} else {
return _bb2734_termite_23_make_2d_dict();
}
},4,1);

_j(_bb695_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
return _p(_bb696_termite_23_make_2d_dict);
});

_j(_bb2734_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb2735_termite_23_make_2d_dict();
} else {
return _bb2738_termite_23_make_2d_dict();
}
});

_j(_bb696_termite_23_make_2d_dict = () => {
_r = _bb697_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2735_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
return _p(_bb2736_termite_23_make_2d_dict);
});

_j(_bb2738_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
return _p(_bb2739_termite_23_make_2d_dict);
});

_k(_bb697_termite_23_make_2d_dict = () => {
return _bb699_termite_23_make_2d_dict();
},2,1);

_j(_bb2736_termite_23_make_2d_dict = () => {
_r = _bb2737_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2739_termite_23_make_2d_dict = () => {
_r = _bb698_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb699_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb700_termite_23_make_2d_dict();
} else {
return _bb2733_termite_23_make_2d_dict();
}
});

_k(_bb2737_termite_23_make_2d_dict = () => {
return _bb699_termite_23_make_2d_dict();
},2,1);

_k(_bb698_termite_23_make_2d_dict = () => {
return _bb699_termite_23_make_2d_dict();
},2,1);

_j(_bb700_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb701_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2733_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb701_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2731_termite_23_make_2d_dict();
} else {
return _bb702_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2731_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2732_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb702_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb703_termite_23_make_2d_dict();
} else {
return _bb2730_termite_23_make_2d_dict();
}
});

_k(_bb2732_termite_23_make_2d_dict = () => {
return _bb706_termite_23_make_2d_dict();
},2,1);

_j(_bb703_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb704_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2730_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb705_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb706_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb707_termite_23_make_2d_dict();
} else {
return _bb2729_termite_23_make_2d_dict();
}
});

_k(_bb704_termite_23_make_2d_dict = () => {
return _bb706_termite_23_make_2d_dict();
},2,1);

_k(_bb705_termite_23_make_2d_dict = () => {
return _bb706_termite_23_make_2d_dict();
},2,1);

_j(_bb707_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb708_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2729_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb708_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2727_termite_23_make_2d_dict();
} else {
return _bb709_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2727_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2728_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb709_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb710_termite_23_make_2d_dict();
} else {
return _bb2726_termite_23_make_2d_dict();
}
});

_k(_bb2728_termite_23_make_2d_dict = () => {
return _bb713_termite_23_make_2d_dict();
},2,1);

_j(_bb710_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb711_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2726_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb712_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb713_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb714_termite_23_make_2d_dict();
} else {
return _bb2725_termite_23_make_2d_dict();
}
});

_k(_bb711_termite_23_make_2d_dict = () => {
return _bb713_termite_23_make_2d_dict();
},2,1);

_k(_bb712_termite_23_make_2d_dict = () => {
return _bb713_termite_23_make_2d_dict();
},2,1);

_j(_bb714_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb715_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2725_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb715_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2723_termite_23_make_2d_dict();
} else {
return _bb716_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2723_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2724_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb716_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb717_termite_23_make_2d_dict();
} else {
return _bb2722_termite_23_make_2d_dict();
}
});

_k(_bb2724_termite_23_make_2d_dict = () => {
return _bb720_termite_23_make_2d_dict();
},2,1);

_j(_bb717_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb718_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2722_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb719_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb720_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb721_termite_23_make_2d_dict();
} else {
return _bb2721_termite_23_make_2d_dict();
}
});

_k(_bb718_termite_23_make_2d_dict = () => {
return _bb720_termite_23_make_2d_dict();
},2,1);

_k(_bb719_termite_23_make_2d_dict = () => {
return _bb720_termite_23_make_2d_dict();
},2,1);

_j(_bb721_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb722_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2721_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb722_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2719_termite_23_make_2d_dict();
} else {
return _bb723_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2719_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2720_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb723_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb724_termite_23_make_2d_dict();
} else {
return _bb2718_termite_23_make_2d_dict();
}
});

_k(_bb2720_termite_23_make_2d_dict = () => {
return _bb727_termite_23_make_2d_dict();
},2,1);

_j(_bb724_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb725_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2718_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb726_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb727_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb728_termite_23_make_2d_dict();
} else {
return _bb2717_termite_23_make_2d_dict();
}
});

_k(_bb725_termite_23_make_2d_dict = () => {
return _bb727_termite_23_make_2d_dict();
},2,1);

_k(_bb726_termite_23_make_2d_dict = () => {
return _bb727_termite_23_make_2d_dict();
},2,1);

_j(_bb728_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb729_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2717_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb729_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2715_termite_23_make_2d_dict();
} else {
return _bb730_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2715_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2716_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb730_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb731_termite_23_make_2d_dict();
} else {
return _bb2714_termite_23_make_2d_dict();
}
});

_k(_bb2716_termite_23_make_2d_dict = () => {
return _bb734_termite_23_make_2d_dict();
},2,1);

_j(_bb731_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb732_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2714_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb733_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb734_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb735_termite_23_make_2d_dict();
} else {
return _bb2713_termite_23_make_2d_dict();
}
});

_k(_bb732_termite_23_make_2d_dict = () => {
return _bb734_termite_23_make_2d_dict();
},2,1);

_k(_bb733_termite_23_make_2d_dict = () => {
return _bb734_termite_23_make_2d_dict();
},2,1);

_j(_bb735_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb736_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2713_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb736_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2711_termite_23_make_2d_dict();
} else {
return _bb737_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2711_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2712_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb737_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb738_termite_23_make_2d_dict();
} else {
return _bb2710_termite_23_make_2d_dict();
}
});

_k(_bb2712_termite_23_make_2d_dict = () => {
return _bb741_termite_23_make_2d_dict();
},2,1);

_j(_bb738_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb739_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2710_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb740_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb741_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb742_termite_23_make_2d_dict();
} else {
return _bb2709_termite_23_make_2d_dict();
}
});

_k(_bb739_termite_23_make_2d_dict = () => {
return _bb741_termite_23_make_2d_dict();
},2,1);

_k(_bb740_termite_23_make_2d_dict = () => {
return _bb741_termite_23_make_2d_dict();
},2,1);

_j(_bb742_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb743_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2709_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb743_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2707_termite_23_make_2d_dict();
} else {
return _bb744_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2707_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2708_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb744_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb745_termite_23_make_2d_dict();
} else {
return _bb2706_termite_23_make_2d_dict();
}
});

_k(_bb2708_termite_23_make_2d_dict = () => {
return _bb748_termite_23_make_2d_dict();
},2,1);

_j(_bb745_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb746_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2706_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb747_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb748_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb749_termite_23_make_2d_dict();
} else {
return _bb2705_termite_23_make_2d_dict();
}
});

_k(_bb746_termite_23_make_2d_dict = () => {
return _bb748_termite_23_make_2d_dict();
},2,1);

_k(_bb747_termite_23_make_2d_dict = () => {
return _bb748_termite_23_make_2d_dict();
},2,1);

_j(_bb749_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb750_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2705_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb750_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2703_termite_23_make_2d_dict();
} else {
return _bb751_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2703_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2704_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb751_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb752_termite_23_make_2d_dict();
} else {
return _bb2702_termite_23_make_2d_dict();
}
});

_k(_bb2704_termite_23_make_2d_dict = () => {
return _bb755_termite_23_make_2d_dict();
},2,1);

_j(_bb752_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb753_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2702_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb754_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb755_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb756_termite_23_make_2d_dict();
} else {
return _bb2701_termite_23_make_2d_dict();
}
});

_k(_bb753_termite_23_make_2d_dict = () => {
return _bb755_termite_23_make_2d_dict();
},2,1);

_k(_bb754_termite_23_make_2d_dict = () => {
return _bb755_termite_23_make_2d_dict();
},2,1);

_j(_bb756_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb757_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2701_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb757_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2699_termite_23_make_2d_dict();
} else {
return _bb758_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2699_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2700_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb758_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb759_termite_23_make_2d_dict();
} else {
return _bb2698_termite_23_make_2d_dict();
}
});

_k(_bb2700_termite_23_make_2d_dict = () => {
return _bb762_termite_23_make_2d_dict();
},2,1);

_j(_bb759_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb760_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2698_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb761_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb762_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb763_termite_23_make_2d_dict();
} else {
return _bb2697_termite_23_make_2d_dict();
}
});

_k(_bb760_termite_23_make_2d_dict = () => {
return _bb762_termite_23_make_2d_dict();
},2,1);

_k(_bb761_termite_23_make_2d_dict = () => {
return _bb762_termite_23_make_2d_dict();
},2,1);

_j(_bb763_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb764_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2697_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb764_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2695_termite_23_make_2d_dict();
} else {
return _bb765_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2695_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2696_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb765_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb766_termite_23_make_2d_dict();
} else {
return _bb2694_termite_23_make_2d_dict();
}
});

_k(_bb2696_termite_23_make_2d_dict = () => {
return _bb769_termite_23_make_2d_dict();
},2,1);

_j(_bb766_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb767_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2694_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb768_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb769_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb770_termite_23_make_2d_dict();
} else {
return _bb2693_termite_23_make_2d_dict();
}
});

_k(_bb767_termite_23_make_2d_dict = () => {
return _bb769_termite_23_make_2d_dict();
},2,1);

_k(_bb768_termite_23_make_2d_dict = () => {
return _bb769_termite_23_make_2d_dict();
},2,1);

_j(_bb770_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb771_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2693_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb771_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2691_termite_23_make_2d_dict();
} else {
return _bb772_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2691_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2692_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb772_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb773_termite_23_make_2d_dict();
} else {
return _bb2690_termite_23_make_2d_dict();
}
});

_k(_bb2692_termite_23_make_2d_dict = () => {
return _bb776_termite_23_make_2d_dict();
},2,1);

_j(_bb773_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb774_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2690_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb775_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb776_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb777_termite_23_make_2d_dict();
} else {
return _bb2689_termite_23_make_2d_dict();
}
});

_k(_bb774_termite_23_make_2d_dict = () => {
return _bb776_termite_23_make_2d_dict();
},2,1);

_k(_bb775_termite_23_make_2d_dict = () => {
return _bb776_termite_23_make_2d_dict();
},2,1);

_j(_bb777_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb778_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2689_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb778_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2687_termite_23_make_2d_dict();
} else {
return _bb779_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2687_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2688_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb779_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb780_termite_23_make_2d_dict();
} else {
return _bb2686_termite_23_make_2d_dict();
}
});

_k(_bb2688_termite_23_make_2d_dict = () => {
return _bb783_termite_23_make_2d_dict();
},2,1);

_j(_bb780_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb781_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2686_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb782_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb783_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb784_termite_23_make_2d_dict();
} else {
return _bb2685_termite_23_make_2d_dict();
}
});

_k(_bb781_termite_23_make_2d_dict = () => {
return _bb783_termite_23_make_2d_dict();
},2,1);

_k(_bb782_termite_23_make_2d_dict = () => {
return _bb783_termite_23_make_2d_dict();
},2,1);

_j(_bb784_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb785_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2685_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb785_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2683_termite_23_make_2d_dict();
} else {
return _bb786_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2683_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2684_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb786_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb787_termite_23_make_2d_dict();
} else {
return _bb2682_termite_23_make_2d_dict();
}
});

_k(_bb2684_termite_23_make_2d_dict = () => {
return _bb790_termite_23_make_2d_dict();
},2,1);

_j(_bb787_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb788_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2682_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb789_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb790_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb791_termite_23_make_2d_dict();
} else {
return _bb2681_termite_23_make_2d_dict();
}
});

_k(_bb788_termite_23_make_2d_dict = () => {
return _bb790_termite_23_make_2d_dict();
},2,1);

_k(_bb789_termite_23_make_2d_dict = () => {
return _bb790_termite_23_make_2d_dict();
},2,1);

_j(_bb791_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb792_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2681_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb792_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2679_termite_23_make_2d_dict();
} else {
return _bb793_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2679_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2680_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb793_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb794_termite_23_make_2d_dict();
} else {
return _bb2678_termite_23_make_2d_dict();
}
});

_k(_bb2680_termite_23_make_2d_dict = () => {
return _bb797_termite_23_make_2d_dict();
},2,1);

_j(_bb794_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb795_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2678_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb796_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb797_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb798_termite_23_make_2d_dict();
} else {
return _bb2677_termite_23_make_2d_dict();
}
});

_k(_bb795_termite_23_make_2d_dict = () => {
return _bb797_termite_23_make_2d_dict();
},2,1);

_k(_bb796_termite_23_make_2d_dict = () => {
return _bb797_termite_23_make_2d_dict();
},2,1);

_j(_bb798_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb799_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2677_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb799_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2675_termite_23_make_2d_dict();
} else {
return _bb800_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2675_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2676_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb800_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb801_termite_23_make_2d_dict();
} else {
return _bb2674_termite_23_make_2d_dict();
}
});

_k(_bb2676_termite_23_make_2d_dict = () => {
return _bb804_termite_23_make_2d_dict();
},2,1);

_j(_bb801_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb802_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2674_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb803_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb804_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb805_termite_23_make_2d_dict();
} else {
return _bb2673_termite_23_make_2d_dict();
}
});

_k(_bb802_termite_23_make_2d_dict = () => {
return _bb804_termite_23_make_2d_dict();
},2,1);

_k(_bb803_termite_23_make_2d_dict = () => {
return _bb804_termite_23_make_2d_dict();
},2,1);

_j(_bb805_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb806_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2673_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb806_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2671_termite_23_make_2d_dict();
} else {
return _bb807_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2671_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2672_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb807_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb808_termite_23_make_2d_dict();
} else {
return _bb2670_termite_23_make_2d_dict();
}
});

_k(_bb2672_termite_23_make_2d_dict = () => {
return _bb811_termite_23_make_2d_dict();
},2,1);

_j(_bb808_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb809_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2670_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb810_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb811_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb812_termite_23_make_2d_dict();
} else {
return _bb2669_termite_23_make_2d_dict();
}
});

_k(_bb809_termite_23_make_2d_dict = () => {
return _bb811_termite_23_make_2d_dict();
},2,1);

_k(_bb810_termite_23_make_2d_dict = () => {
return _bb811_termite_23_make_2d_dict();
},2,1);

_j(_bb812_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb813_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2669_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb813_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2667_termite_23_make_2d_dict();
} else {
return _bb814_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2667_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2668_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb814_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb815_termite_23_make_2d_dict();
} else {
return _bb2666_termite_23_make_2d_dict();
}
});

_k(_bb2668_termite_23_make_2d_dict = () => {
return _bb818_termite_23_make_2d_dict();
},2,1);

_j(_bb815_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb816_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2666_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb817_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb818_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb819_termite_23_make_2d_dict();
} else {
return _bb2665_termite_23_make_2d_dict();
}
});

_k(_bb816_termite_23_make_2d_dict = () => {
return _bb818_termite_23_make_2d_dict();
},2,1);

_k(_bb817_termite_23_make_2d_dict = () => {
return _bb818_termite_23_make_2d_dict();
},2,1);

_j(_bb819_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb820_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2665_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb820_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2663_termite_23_make_2d_dict();
} else {
return _bb821_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2663_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2664_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb821_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb822_termite_23_make_2d_dict();
} else {
return _bb2662_termite_23_make_2d_dict();
}
});

_k(_bb2664_termite_23_make_2d_dict = () => {
return _bb825_termite_23_make_2d_dict();
},2,1);

_j(_bb822_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb823_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2662_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb824_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb825_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb826_termite_23_make_2d_dict();
} else {
return _bb2661_termite_23_make_2d_dict();
}
});

_k(_bb823_termite_23_make_2d_dict = () => {
return _bb825_termite_23_make_2d_dict();
},2,1);

_k(_bb824_termite_23_make_2d_dict = () => {
return _bb825_termite_23_make_2d_dict();
},2,1);

_j(_bb826_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb827_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2661_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb827_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2659_termite_23_make_2d_dict();
} else {
return _bb828_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2659_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2660_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb828_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb829_termite_23_make_2d_dict();
} else {
return _bb2658_termite_23_make_2d_dict();
}
});

_k(_bb2660_termite_23_make_2d_dict = () => {
return _bb832_termite_23_make_2d_dict();
},2,1);

_j(_bb829_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb830_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2658_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb831_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb832_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb833_termite_23_make_2d_dict();
} else {
return _bb2657_termite_23_make_2d_dict();
}
});

_k(_bb830_termite_23_make_2d_dict = () => {
return _bb832_termite_23_make_2d_dict();
},2,1);

_k(_bb831_termite_23_make_2d_dict = () => {
return _bb832_termite_23_make_2d_dict();
},2,1);

_j(_bb833_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb834_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2657_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb834_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2655_termite_23_make_2d_dict();
} else {
return _bb835_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2655_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2656_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb835_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb836_termite_23_make_2d_dict();
} else {
return _bb2654_termite_23_make_2d_dict();
}
});

_k(_bb2656_termite_23_make_2d_dict = () => {
return _bb839_termite_23_make_2d_dict();
},2,1);

_j(_bb836_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb837_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2654_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb838_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb839_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb840_termite_23_make_2d_dict();
} else {
return _bb2653_termite_23_make_2d_dict();
}
});

_k(_bb837_termite_23_make_2d_dict = () => {
return _bb839_termite_23_make_2d_dict();
},2,1);

_k(_bb838_termite_23_make_2d_dict = () => {
return _bb839_termite_23_make_2d_dict();
},2,1);

_j(_bb840_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb841_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2653_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb841_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2651_termite_23_make_2d_dict();
} else {
return _bb842_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2651_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2652_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb842_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb843_termite_23_make_2d_dict();
} else {
return _bb2650_termite_23_make_2d_dict();
}
});

_k(_bb2652_termite_23_make_2d_dict = () => {
return _bb846_termite_23_make_2d_dict();
},2,1);

_j(_bb843_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb844_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2650_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb845_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb846_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb847_termite_23_make_2d_dict();
} else {
return _bb2649_termite_23_make_2d_dict();
}
});

_k(_bb844_termite_23_make_2d_dict = () => {
return _bb846_termite_23_make_2d_dict();
},2,1);

_k(_bb845_termite_23_make_2d_dict = () => {
return _bb846_termite_23_make_2d_dict();
},2,1);

_j(_bb847_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb848_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2649_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb848_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2647_termite_23_make_2d_dict();
} else {
return _bb849_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2647_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2648_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb849_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb850_termite_23_make_2d_dict();
} else {
return _bb2646_termite_23_make_2d_dict();
}
});

_k(_bb2648_termite_23_make_2d_dict = () => {
return _bb853_termite_23_make_2d_dict();
},2,1);

_j(_bb850_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb851_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2646_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb852_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb853_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb854_termite_23_make_2d_dict();
} else {
return _bb2645_termite_23_make_2d_dict();
}
});

_k(_bb851_termite_23_make_2d_dict = () => {
return _bb853_termite_23_make_2d_dict();
},2,1);

_k(_bb852_termite_23_make_2d_dict = () => {
return _bb853_termite_23_make_2d_dict();
},2,1);

_j(_bb854_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb855_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2645_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb855_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2643_termite_23_make_2d_dict();
} else {
return _bb856_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2643_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2644_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb856_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb857_termite_23_make_2d_dict();
} else {
return _bb2642_termite_23_make_2d_dict();
}
});

_k(_bb2644_termite_23_make_2d_dict = () => {
return _bb860_termite_23_make_2d_dict();
},2,1);

_j(_bb857_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb858_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2642_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb859_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb860_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb861_termite_23_make_2d_dict();
} else {
return _bb2641_termite_23_make_2d_dict();
}
});

_k(_bb858_termite_23_make_2d_dict = () => {
return _bb860_termite_23_make_2d_dict();
},2,1);

_k(_bb859_termite_23_make_2d_dict = () => {
return _bb860_termite_23_make_2d_dict();
},2,1);

_j(_bb861_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb862_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2641_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb862_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2639_termite_23_make_2d_dict();
} else {
return _bb863_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2639_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2640_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb863_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb864_termite_23_make_2d_dict();
} else {
return _bb2638_termite_23_make_2d_dict();
}
});

_k(_bb2640_termite_23_make_2d_dict = () => {
return _bb867_termite_23_make_2d_dict();
},2,1);

_j(_bb864_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb865_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2638_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb866_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb867_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb868_termite_23_make_2d_dict();
} else {
return _bb2637_termite_23_make_2d_dict();
}
});

_k(_bb865_termite_23_make_2d_dict = () => {
return _bb867_termite_23_make_2d_dict();
},2,1);

_k(_bb866_termite_23_make_2d_dict = () => {
return _bb867_termite_23_make_2d_dict();
},2,1);

_j(_bb868_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb869_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2637_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb869_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2635_termite_23_make_2d_dict();
} else {
return _bb870_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2635_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2636_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb870_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb871_termite_23_make_2d_dict();
} else {
return _bb2634_termite_23_make_2d_dict();
}
});

_k(_bb2636_termite_23_make_2d_dict = () => {
return _bb874_termite_23_make_2d_dict();
},2,1);

_j(_bb871_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb872_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2634_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb873_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb874_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb875_termite_23_make_2d_dict();
} else {
return _bb2633_termite_23_make_2d_dict();
}
});

_k(_bb872_termite_23_make_2d_dict = () => {
return _bb874_termite_23_make_2d_dict();
},2,1);

_k(_bb873_termite_23_make_2d_dict = () => {
return _bb874_termite_23_make_2d_dict();
},2,1);

_j(_bb875_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb876_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2633_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb876_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2631_termite_23_make_2d_dict();
} else {
return _bb877_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2631_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2632_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb877_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb878_termite_23_make_2d_dict();
} else {
return _bb2630_termite_23_make_2d_dict();
}
});

_k(_bb2632_termite_23_make_2d_dict = () => {
return _bb881_termite_23_make_2d_dict();
},2,1);

_j(_bb878_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb879_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2630_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb880_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb881_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb882_termite_23_make_2d_dict();
} else {
return _bb2629_termite_23_make_2d_dict();
}
});

_k(_bb879_termite_23_make_2d_dict = () => {
return _bb881_termite_23_make_2d_dict();
},2,1);

_k(_bb880_termite_23_make_2d_dict = () => {
return _bb881_termite_23_make_2d_dict();
},2,1);

_j(_bb882_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb883_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2629_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb883_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2627_termite_23_make_2d_dict();
} else {
return _bb884_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2627_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2628_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb884_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb885_termite_23_make_2d_dict();
} else {
return _bb2626_termite_23_make_2d_dict();
}
});

_k(_bb2628_termite_23_make_2d_dict = () => {
return _bb888_termite_23_make_2d_dict();
},2,1);

_j(_bb885_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb886_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2626_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb887_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb888_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb889_termite_23_make_2d_dict();
} else {
return _bb2625_termite_23_make_2d_dict();
}
});

_k(_bb886_termite_23_make_2d_dict = () => {
return _bb888_termite_23_make_2d_dict();
},2,1);

_k(_bb887_termite_23_make_2d_dict = () => {
return _bb888_termite_23_make_2d_dict();
},2,1);

_j(_bb889_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb890_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2625_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb890_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2623_termite_23_make_2d_dict();
} else {
return _bb891_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2623_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2624_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb891_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb892_termite_23_make_2d_dict();
} else {
return _bb2622_termite_23_make_2d_dict();
}
});

_k(_bb2624_termite_23_make_2d_dict = () => {
return _bb895_termite_23_make_2d_dict();
},2,1);

_j(_bb892_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb893_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2622_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb894_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb895_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb896_termite_23_make_2d_dict();
} else {
return _bb2621_termite_23_make_2d_dict();
}
});

_k(_bb893_termite_23_make_2d_dict = () => {
return _bb895_termite_23_make_2d_dict();
},2,1);

_k(_bb894_termite_23_make_2d_dict = () => {
return _bb895_termite_23_make_2d_dict();
},2,1);

_j(_bb896_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb897_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2621_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb897_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2619_termite_23_make_2d_dict();
} else {
return _bb898_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2619_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2620_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb898_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb899_termite_23_make_2d_dict();
} else {
return _bb2618_termite_23_make_2d_dict();
}
});

_k(_bb2620_termite_23_make_2d_dict = () => {
return _bb902_termite_23_make_2d_dict();
},2,1);

_j(_bb899_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb900_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2618_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb901_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb902_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb903_termite_23_make_2d_dict();
} else {
return _bb2617_termite_23_make_2d_dict();
}
});

_k(_bb900_termite_23_make_2d_dict = () => {
return _bb902_termite_23_make_2d_dict();
},2,1);

_k(_bb901_termite_23_make_2d_dict = () => {
return _bb902_termite_23_make_2d_dict();
},2,1);

_j(_bb903_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb904_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2617_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb904_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2615_termite_23_make_2d_dict();
} else {
return _bb905_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2615_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2616_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb905_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb906_termite_23_make_2d_dict();
} else {
return _bb2614_termite_23_make_2d_dict();
}
});

_k(_bb2616_termite_23_make_2d_dict = () => {
return _bb909_termite_23_make_2d_dict();
},2,1);

_j(_bb906_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb907_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2614_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb908_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb909_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb910_termite_23_make_2d_dict();
} else {
return _bb2613_termite_23_make_2d_dict();
}
});

_k(_bb907_termite_23_make_2d_dict = () => {
return _bb909_termite_23_make_2d_dict();
},2,1);

_k(_bb908_termite_23_make_2d_dict = () => {
return _bb909_termite_23_make_2d_dict();
},2,1);

_j(_bb910_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb911_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2613_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb911_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2611_termite_23_make_2d_dict();
} else {
return _bb912_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2611_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2612_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb912_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb913_termite_23_make_2d_dict();
} else {
return _bb2610_termite_23_make_2d_dict();
}
});

_k(_bb2612_termite_23_make_2d_dict = () => {
return _bb916_termite_23_make_2d_dict();
},2,1);

_j(_bb913_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb914_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2610_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb915_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb916_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb917_termite_23_make_2d_dict();
} else {
return _bb2609_termite_23_make_2d_dict();
}
});

_k(_bb914_termite_23_make_2d_dict = () => {
return _bb916_termite_23_make_2d_dict();
},2,1);

_k(_bb915_termite_23_make_2d_dict = () => {
return _bb916_termite_23_make_2d_dict();
},2,1);

_j(_bb917_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb918_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2609_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb918_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2607_termite_23_make_2d_dict();
} else {
return _bb919_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2607_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2608_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb919_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb920_termite_23_make_2d_dict();
} else {
return _bb2606_termite_23_make_2d_dict();
}
});

_k(_bb2608_termite_23_make_2d_dict = () => {
return _bb923_termite_23_make_2d_dict();
},2,1);

_j(_bb920_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb921_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2606_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb922_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb923_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb924_termite_23_make_2d_dict();
} else {
return _bb2605_termite_23_make_2d_dict();
}
});

_k(_bb921_termite_23_make_2d_dict = () => {
return _bb923_termite_23_make_2d_dict();
},2,1);

_k(_bb922_termite_23_make_2d_dict = () => {
return _bb923_termite_23_make_2d_dict();
},2,1);

_j(_bb924_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb925_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2605_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb925_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2603_termite_23_make_2d_dict();
} else {
return _bb926_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2603_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2604_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb926_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb927_termite_23_make_2d_dict();
} else {
return _bb2602_termite_23_make_2d_dict();
}
});

_k(_bb2604_termite_23_make_2d_dict = () => {
return _bb930_termite_23_make_2d_dict();
},2,1);

_j(_bb927_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb928_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2602_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb929_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb930_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb931_termite_23_make_2d_dict();
} else {
return _bb2601_termite_23_make_2d_dict();
}
});

_k(_bb928_termite_23_make_2d_dict = () => {
return _bb930_termite_23_make_2d_dict();
},2,1);

_k(_bb929_termite_23_make_2d_dict = () => {
return _bb930_termite_23_make_2d_dict();
},2,1);

_j(_bb931_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb932_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2601_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb932_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2599_termite_23_make_2d_dict();
} else {
return _bb933_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2599_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2600_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb933_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb934_termite_23_make_2d_dict();
} else {
return _bb2598_termite_23_make_2d_dict();
}
});

_k(_bb2600_termite_23_make_2d_dict = () => {
return _bb937_termite_23_make_2d_dict();
},2,1);

_j(_bb934_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb935_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2598_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb936_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb937_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb938_termite_23_make_2d_dict();
} else {
return _bb2597_termite_23_make_2d_dict();
}
});

_k(_bb935_termite_23_make_2d_dict = () => {
return _bb937_termite_23_make_2d_dict();
},2,1);

_k(_bb936_termite_23_make_2d_dict = () => {
return _bb937_termite_23_make_2d_dict();
},2,1);

_j(_bb938_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb939_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2597_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb939_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2595_termite_23_make_2d_dict();
} else {
return _bb940_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2595_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2596_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb940_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb941_termite_23_make_2d_dict();
} else {
return _bb2594_termite_23_make_2d_dict();
}
});

_k(_bb2596_termite_23_make_2d_dict = () => {
return _bb944_termite_23_make_2d_dict();
},2,1);

_j(_bb941_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb942_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2594_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb943_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb944_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb945_termite_23_make_2d_dict();
} else {
return _bb2593_termite_23_make_2d_dict();
}
});

_k(_bb942_termite_23_make_2d_dict = () => {
return _bb944_termite_23_make_2d_dict();
},2,1);

_k(_bb943_termite_23_make_2d_dict = () => {
return _bb944_termite_23_make_2d_dict();
},2,1);

_j(_bb945_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb946_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2593_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb946_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2591_termite_23_make_2d_dict();
} else {
return _bb947_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2591_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2592_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb947_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb948_termite_23_make_2d_dict();
} else {
return _bb2590_termite_23_make_2d_dict();
}
});

_k(_bb2592_termite_23_make_2d_dict = () => {
return _bb951_termite_23_make_2d_dict();
},2,1);

_j(_bb948_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb949_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2590_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb950_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb951_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb952_termite_23_make_2d_dict();
} else {
return _bb2589_termite_23_make_2d_dict();
}
});

_k(_bb949_termite_23_make_2d_dict = () => {
return _bb951_termite_23_make_2d_dict();
},2,1);

_k(_bb950_termite_23_make_2d_dict = () => {
return _bb951_termite_23_make_2d_dict();
},2,1);

_j(_bb952_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb953_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2589_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb953_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2587_termite_23_make_2d_dict();
} else {
return _bb954_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2587_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2588_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb954_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb955_termite_23_make_2d_dict();
} else {
return _bb2586_termite_23_make_2d_dict();
}
});

_k(_bb2588_termite_23_make_2d_dict = () => {
return _bb958_termite_23_make_2d_dict();
},2,1);

_j(_bb955_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb956_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2586_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb957_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb958_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb959_termite_23_make_2d_dict();
} else {
return _bb2585_termite_23_make_2d_dict();
}
});

_k(_bb956_termite_23_make_2d_dict = () => {
return _bb958_termite_23_make_2d_dict();
},2,1);

_k(_bb957_termite_23_make_2d_dict = () => {
return _bb958_termite_23_make_2d_dict();
},2,1);

_j(_bb959_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb960_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2585_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb960_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2583_termite_23_make_2d_dict();
} else {
return _bb961_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2583_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2584_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb961_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb962_termite_23_make_2d_dict();
} else {
return _bb2582_termite_23_make_2d_dict();
}
});

_k(_bb2584_termite_23_make_2d_dict = () => {
return _bb965_termite_23_make_2d_dict();
},2,1);

_j(_bb962_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb963_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2582_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb964_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb965_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb966_termite_23_make_2d_dict();
} else {
return _bb2581_termite_23_make_2d_dict();
}
});

_k(_bb963_termite_23_make_2d_dict = () => {
return _bb965_termite_23_make_2d_dict();
},2,1);

_k(_bb964_termite_23_make_2d_dict = () => {
return _bb965_termite_23_make_2d_dict();
},2,1);

_j(_bb966_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb967_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2581_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb967_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2579_termite_23_make_2d_dict();
} else {
return _bb968_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2579_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2580_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb968_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb969_termite_23_make_2d_dict();
} else {
return _bb2578_termite_23_make_2d_dict();
}
});

_k(_bb2580_termite_23_make_2d_dict = () => {
return _bb972_termite_23_make_2d_dict();
},2,1);

_j(_bb969_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb970_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2578_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb971_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb972_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb973_termite_23_make_2d_dict();
} else {
return _bb2577_termite_23_make_2d_dict();
}
});

_k(_bb970_termite_23_make_2d_dict = () => {
return _bb972_termite_23_make_2d_dict();
},2,1);

_k(_bb971_termite_23_make_2d_dict = () => {
return _bb972_termite_23_make_2d_dict();
},2,1);

_j(_bb973_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb974_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2577_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb974_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2575_termite_23_make_2d_dict();
} else {
return _bb975_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2575_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2576_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb975_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb976_termite_23_make_2d_dict();
} else {
return _bb2574_termite_23_make_2d_dict();
}
});

_k(_bb2576_termite_23_make_2d_dict = () => {
return _bb979_termite_23_make_2d_dict();
},2,1);

_j(_bb976_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb977_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2574_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb978_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb979_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb980_termite_23_make_2d_dict();
} else {
return _bb2573_termite_23_make_2d_dict();
}
});

_k(_bb977_termite_23_make_2d_dict = () => {
return _bb979_termite_23_make_2d_dict();
},2,1);

_k(_bb978_termite_23_make_2d_dict = () => {
return _bb979_termite_23_make_2d_dict();
},2,1);

_j(_bb980_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb981_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2573_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb981_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2571_termite_23_make_2d_dict();
} else {
return _bb982_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2571_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2572_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb982_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb983_termite_23_make_2d_dict();
} else {
return _bb2570_termite_23_make_2d_dict();
}
});

_k(_bb2572_termite_23_make_2d_dict = () => {
return _bb986_termite_23_make_2d_dict();
},2,1);

_j(_bb983_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb984_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2570_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb985_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb986_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb987_termite_23_make_2d_dict();
} else {
return _bb2569_termite_23_make_2d_dict();
}
});

_k(_bb984_termite_23_make_2d_dict = () => {
return _bb986_termite_23_make_2d_dict();
},2,1);

_k(_bb985_termite_23_make_2d_dict = () => {
return _bb986_termite_23_make_2d_dict();
},2,1);

_j(_bb987_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb988_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2569_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb988_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2567_termite_23_make_2d_dict();
} else {
return _bb989_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2567_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2568_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb989_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb990_termite_23_make_2d_dict();
} else {
return _bb2566_termite_23_make_2d_dict();
}
});

_k(_bb2568_termite_23_make_2d_dict = () => {
return _bb993_termite_23_make_2d_dict();
},2,1);

_j(_bb990_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb991_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2566_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb992_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb993_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb994_termite_23_make_2d_dict();
} else {
return _bb2565_termite_23_make_2d_dict();
}
});

_k(_bb991_termite_23_make_2d_dict = () => {
return _bb993_termite_23_make_2d_dict();
},2,1);

_k(_bb992_termite_23_make_2d_dict = () => {
return _bb993_termite_23_make_2d_dict();
},2,1);

_j(_bb994_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb995_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2565_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb995_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2563_termite_23_make_2d_dict();
} else {
return _bb996_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2563_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2564_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb996_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb997_termite_23_make_2d_dict();
} else {
return _bb2562_termite_23_make_2d_dict();
}
});

_k(_bb2564_termite_23_make_2d_dict = () => {
return _bb1000_termite_23_make_2d_dict();
},2,1);

_j(_bb997_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb998_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2562_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb999_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1000_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1001_termite_23_make_2d_dict();
} else {
return _bb2561_termite_23_make_2d_dict();
}
});

_k(_bb998_termite_23_make_2d_dict = () => {
return _bb1000_termite_23_make_2d_dict();
},2,1);

_k(_bb999_termite_23_make_2d_dict = () => {
return _bb1000_termite_23_make_2d_dict();
},2,1);

_j(_bb1001_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1002_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2561_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1002_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2559_termite_23_make_2d_dict();
} else {
return _bb1003_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2559_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2560_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1003_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1004_termite_23_make_2d_dict();
} else {
return _bb2558_termite_23_make_2d_dict();
}
});

_k(_bb2560_termite_23_make_2d_dict = () => {
return _bb1007_termite_23_make_2d_dict();
},2,1);

_j(_bb1004_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1005_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2558_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1006_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1007_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1008_termite_23_make_2d_dict();
} else {
return _bb2557_termite_23_make_2d_dict();
}
});

_k(_bb1005_termite_23_make_2d_dict = () => {
return _bb1007_termite_23_make_2d_dict();
},2,1);

_k(_bb1006_termite_23_make_2d_dict = () => {
return _bb1007_termite_23_make_2d_dict();
},2,1);

_j(_bb1008_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1009_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2557_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1009_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2555_termite_23_make_2d_dict();
} else {
return _bb1010_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2555_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2556_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1010_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1011_termite_23_make_2d_dict();
} else {
return _bb2554_termite_23_make_2d_dict();
}
});

_k(_bb2556_termite_23_make_2d_dict = () => {
return _bb1014_termite_23_make_2d_dict();
},2,1);

_j(_bb1011_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1012_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2554_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1013_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1014_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1015_termite_23_make_2d_dict();
} else {
return _bb2553_termite_23_make_2d_dict();
}
});

_k(_bb1012_termite_23_make_2d_dict = () => {
return _bb1014_termite_23_make_2d_dict();
},2,1);

_k(_bb1013_termite_23_make_2d_dict = () => {
return _bb1014_termite_23_make_2d_dict();
},2,1);

_j(_bb1015_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1016_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2553_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1016_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2551_termite_23_make_2d_dict();
} else {
return _bb1017_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2551_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2552_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1017_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1018_termite_23_make_2d_dict();
} else {
return _bb2550_termite_23_make_2d_dict();
}
});

_k(_bb2552_termite_23_make_2d_dict = () => {
return _bb1021_termite_23_make_2d_dict();
},2,1);

_j(_bb1018_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1019_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2550_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1020_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1021_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1022_termite_23_make_2d_dict();
} else {
return _bb2549_termite_23_make_2d_dict();
}
});

_k(_bb1019_termite_23_make_2d_dict = () => {
return _bb1021_termite_23_make_2d_dict();
},2,1);

_k(_bb1020_termite_23_make_2d_dict = () => {
return _bb1021_termite_23_make_2d_dict();
},2,1);

_j(_bb1022_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1023_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2549_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1023_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2547_termite_23_make_2d_dict();
} else {
return _bb1024_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2547_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2548_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1024_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1025_termite_23_make_2d_dict();
} else {
return _bb2546_termite_23_make_2d_dict();
}
});

_k(_bb2548_termite_23_make_2d_dict = () => {
return _bb1028_termite_23_make_2d_dict();
},2,1);

_j(_bb1025_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1026_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2546_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1027_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1028_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1029_termite_23_make_2d_dict();
} else {
return _bb2545_termite_23_make_2d_dict();
}
});

_k(_bb1026_termite_23_make_2d_dict = () => {
return _bb1028_termite_23_make_2d_dict();
},2,1);

_k(_bb1027_termite_23_make_2d_dict = () => {
return _bb1028_termite_23_make_2d_dict();
},2,1);

_j(_bb1029_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1030_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2545_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1030_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2543_termite_23_make_2d_dict();
} else {
return _bb1031_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2543_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2544_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1031_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1032_termite_23_make_2d_dict();
} else {
return _bb2542_termite_23_make_2d_dict();
}
});

_k(_bb2544_termite_23_make_2d_dict = () => {
return _bb1035_termite_23_make_2d_dict();
},2,1);

_j(_bb1032_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1033_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2542_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1034_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1035_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1036_termite_23_make_2d_dict();
} else {
return _bb2541_termite_23_make_2d_dict();
}
});

_k(_bb1033_termite_23_make_2d_dict = () => {
return _bb1035_termite_23_make_2d_dict();
},2,1);

_k(_bb1034_termite_23_make_2d_dict = () => {
return _bb1035_termite_23_make_2d_dict();
},2,1);

_j(_bb1036_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1037_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2541_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1037_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2539_termite_23_make_2d_dict();
} else {
return _bb1038_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2539_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2540_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1038_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1039_termite_23_make_2d_dict();
} else {
return _bb2538_termite_23_make_2d_dict();
}
});

_k(_bb2540_termite_23_make_2d_dict = () => {
return _bb1042_termite_23_make_2d_dict();
},2,1);

_j(_bb1039_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1040_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2538_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1041_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1042_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1043_termite_23_make_2d_dict();
} else {
return _bb2537_termite_23_make_2d_dict();
}
});

_k(_bb1040_termite_23_make_2d_dict = () => {
return _bb1042_termite_23_make_2d_dict();
},2,1);

_k(_bb1041_termite_23_make_2d_dict = () => {
return _bb1042_termite_23_make_2d_dict();
},2,1);

_j(_bb1043_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1044_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2537_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1044_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2535_termite_23_make_2d_dict();
} else {
return _bb1045_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2535_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2536_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1045_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1046_termite_23_make_2d_dict();
} else {
return _bb2534_termite_23_make_2d_dict();
}
});

_k(_bb2536_termite_23_make_2d_dict = () => {
return _bb1049_termite_23_make_2d_dict();
},2,1);

_j(_bb1046_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1047_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2534_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1048_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1049_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1050_termite_23_make_2d_dict();
} else {
return _bb2533_termite_23_make_2d_dict();
}
});

_k(_bb1047_termite_23_make_2d_dict = () => {
return _bb1049_termite_23_make_2d_dict();
},2,1);

_k(_bb1048_termite_23_make_2d_dict = () => {
return _bb1049_termite_23_make_2d_dict();
},2,1);

_j(_bb1050_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1051_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2533_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1051_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2531_termite_23_make_2d_dict();
} else {
return _bb1052_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2531_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2532_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1052_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1053_termite_23_make_2d_dict();
} else {
return _bb2530_termite_23_make_2d_dict();
}
});

_k(_bb2532_termite_23_make_2d_dict = () => {
return _bb1056_termite_23_make_2d_dict();
},2,1);

_j(_bb1053_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1054_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2530_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1055_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1056_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1057_termite_23_make_2d_dict();
} else {
return _bb2529_termite_23_make_2d_dict();
}
});

_k(_bb1054_termite_23_make_2d_dict = () => {
return _bb1056_termite_23_make_2d_dict();
},2,1);

_k(_bb1055_termite_23_make_2d_dict = () => {
return _bb1056_termite_23_make_2d_dict();
},2,1);

_j(_bb1057_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1058_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2529_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1058_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2527_termite_23_make_2d_dict();
} else {
return _bb1059_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2527_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2528_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1059_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1060_termite_23_make_2d_dict();
} else {
return _bb2526_termite_23_make_2d_dict();
}
});

_k(_bb2528_termite_23_make_2d_dict = () => {
return _bb1063_termite_23_make_2d_dict();
},2,1);

_j(_bb1060_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1061_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2526_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1062_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1063_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1064_termite_23_make_2d_dict();
} else {
return _bb2525_termite_23_make_2d_dict();
}
});

_k(_bb1061_termite_23_make_2d_dict = () => {
return _bb1063_termite_23_make_2d_dict();
},2,1);

_k(_bb1062_termite_23_make_2d_dict = () => {
return _bb1063_termite_23_make_2d_dict();
},2,1);

_j(_bb1064_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1065_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2525_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1065_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2523_termite_23_make_2d_dict();
} else {
return _bb1066_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2523_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2524_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1066_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1067_termite_23_make_2d_dict();
} else {
return _bb2522_termite_23_make_2d_dict();
}
});

_k(_bb2524_termite_23_make_2d_dict = () => {
return _bb1070_termite_23_make_2d_dict();
},2,1);

_j(_bb1067_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1068_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2522_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1069_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1070_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1071_termite_23_make_2d_dict();
} else {
return _bb2521_termite_23_make_2d_dict();
}
});

_k(_bb1068_termite_23_make_2d_dict = () => {
return _bb1070_termite_23_make_2d_dict();
},2,1);

_k(_bb1069_termite_23_make_2d_dict = () => {
return _bb1070_termite_23_make_2d_dict();
},2,1);

_j(_bb1071_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1072_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2521_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1072_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2519_termite_23_make_2d_dict();
} else {
return _bb1073_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2519_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2520_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1073_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1074_termite_23_make_2d_dict();
} else {
return _bb2518_termite_23_make_2d_dict();
}
});

_k(_bb2520_termite_23_make_2d_dict = () => {
return _bb1077_termite_23_make_2d_dict();
},2,1);

_j(_bb1074_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1075_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2518_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1076_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1077_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1078_termite_23_make_2d_dict();
} else {
return _bb2517_termite_23_make_2d_dict();
}
});

_k(_bb1075_termite_23_make_2d_dict = () => {
return _bb1077_termite_23_make_2d_dict();
},2,1);

_k(_bb1076_termite_23_make_2d_dict = () => {
return _bb1077_termite_23_make_2d_dict();
},2,1);

_j(_bb1078_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1079_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2517_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1079_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2515_termite_23_make_2d_dict();
} else {
return _bb1080_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2515_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2516_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1080_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1081_termite_23_make_2d_dict();
} else {
return _bb2514_termite_23_make_2d_dict();
}
});

_k(_bb2516_termite_23_make_2d_dict = () => {
return _bb1084_termite_23_make_2d_dict();
},2,1);

_j(_bb1081_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1082_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2514_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1083_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1084_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1085_termite_23_make_2d_dict();
} else {
return _bb2513_termite_23_make_2d_dict();
}
});

_k(_bb1082_termite_23_make_2d_dict = () => {
return _bb1084_termite_23_make_2d_dict();
},2,1);

_k(_bb1083_termite_23_make_2d_dict = () => {
return _bb1084_termite_23_make_2d_dict();
},2,1);

_j(_bb1085_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1086_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2513_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1086_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2511_termite_23_make_2d_dict();
} else {
return _bb1087_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2511_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2512_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1087_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1088_termite_23_make_2d_dict();
} else {
return _bb2510_termite_23_make_2d_dict();
}
});

_k(_bb2512_termite_23_make_2d_dict = () => {
return _bb1091_termite_23_make_2d_dict();
},2,1);

_j(_bb1088_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1089_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2510_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1090_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1091_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1092_termite_23_make_2d_dict();
} else {
return _bb2509_termite_23_make_2d_dict();
}
});

_k(_bb1089_termite_23_make_2d_dict = () => {
return _bb1091_termite_23_make_2d_dict();
},2,1);

_k(_bb1090_termite_23_make_2d_dict = () => {
return _bb1091_termite_23_make_2d_dict();
},2,1);

_j(_bb1092_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1093_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2509_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1093_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2507_termite_23_make_2d_dict();
} else {
return _bb1094_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2507_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2508_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1094_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1095_termite_23_make_2d_dict();
} else {
return _bb2506_termite_23_make_2d_dict();
}
});

_k(_bb2508_termite_23_make_2d_dict = () => {
return _bb1098_termite_23_make_2d_dict();
},2,1);

_j(_bb1095_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1096_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2506_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1097_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1098_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1099_termite_23_make_2d_dict();
} else {
return _bb2505_termite_23_make_2d_dict();
}
});

_k(_bb1096_termite_23_make_2d_dict = () => {
return _bb1098_termite_23_make_2d_dict();
},2,1);

_k(_bb1097_termite_23_make_2d_dict = () => {
return _bb1098_termite_23_make_2d_dict();
},2,1);

_j(_bb1099_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1100_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2505_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1100_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2503_termite_23_make_2d_dict();
} else {
return _bb1101_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2503_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2504_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1101_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1102_termite_23_make_2d_dict();
} else {
return _bb2502_termite_23_make_2d_dict();
}
});

_k(_bb2504_termite_23_make_2d_dict = () => {
return _bb1105_termite_23_make_2d_dict();
},2,1);

_j(_bb1102_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1103_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2502_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1104_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1105_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1106_termite_23_make_2d_dict();
} else {
return _bb2501_termite_23_make_2d_dict();
}
});

_k(_bb1103_termite_23_make_2d_dict = () => {
return _bb1105_termite_23_make_2d_dict();
},2,1);

_k(_bb1104_termite_23_make_2d_dict = () => {
return _bb1105_termite_23_make_2d_dict();
},2,1);

_j(_bb1106_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1107_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2501_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1107_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2499_termite_23_make_2d_dict();
} else {
return _bb1108_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2499_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2500_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1108_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1109_termite_23_make_2d_dict();
} else {
return _bb2498_termite_23_make_2d_dict();
}
});

_k(_bb2500_termite_23_make_2d_dict = () => {
return _bb1112_termite_23_make_2d_dict();
},2,1);

_j(_bb1109_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1110_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2498_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1111_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1112_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1113_termite_23_make_2d_dict();
} else {
return _bb2497_termite_23_make_2d_dict();
}
});

_k(_bb1110_termite_23_make_2d_dict = () => {
return _bb1112_termite_23_make_2d_dict();
},2,1);

_k(_bb1111_termite_23_make_2d_dict = () => {
return _bb1112_termite_23_make_2d_dict();
},2,1);

_j(_bb1113_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1114_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2497_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1114_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2495_termite_23_make_2d_dict();
} else {
return _bb1115_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2495_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2496_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1115_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1116_termite_23_make_2d_dict();
} else {
return _bb2494_termite_23_make_2d_dict();
}
});

_k(_bb2496_termite_23_make_2d_dict = () => {
return _bb1119_termite_23_make_2d_dict();
},2,1);

_j(_bb1116_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1117_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2494_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1118_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1119_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1120_termite_23_make_2d_dict();
} else {
return _bb2493_termite_23_make_2d_dict();
}
});

_k(_bb1117_termite_23_make_2d_dict = () => {
return _bb1119_termite_23_make_2d_dict();
},2,1);

_k(_bb1118_termite_23_make_2d_dict = () => {
return _bb1119_termite_23_make_2d_dict();
},2,1);

_j(_bb1120_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1121_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2493_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1121_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2491_termite_23_make_2d_dict();
} else {
return _bb1122_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2491_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2492_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1122_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1123_termite_23_make_2d_dict();
} else {
return _bb2490_termite_23_make_2d_dict();
}
});

_k(_bb2492_termite_23_make_2d_dict = () => {
return _bb1126_termite_23_make_2d_dict();
},2,1);

_j(_bb1123_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1124_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2490_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1125_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1126_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1127_termite_23_make_2d_dict();
} else {
return _bb2489_termite_23_make_2d_dict();
}
});

_k(_bb1124_termite_23_make_2d_dict = () => {
return _bb1126_termite_23_make_2d_dict();
},2,1);

_k(_bb1125_termite_23_make_2d_dict = () => {
return _bb1126_termite_23_make_2d_dict();
},2,1);

_j(_bb1127_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1128_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2489_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1128_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2487_termite_23_make_2d_dict();
} else {
return _bb1129_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2487_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2488_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1129_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1130_termite_23_make_2d_dict();
} else {
return _bb2486_termite_23_make_2d_dict();
}
});

_k(_bb2488_termite_23_make_2d_dict = () => {
return _bb1133_termite_23_make_2d_dict();
},2,1);

_j(_bb1130_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1131_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2486_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1132_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1133_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1134_termite_23_make_2d_dict();
} else {
return _bb2485_termite_23_make_2d_dict();
}
});

_k(_bb1131_termite_23_make_2d_dict = () => {
return _bb1133_termite_23_make_2d_dict();
},2,1);

_k(_bb1132_termite_23_make_2d_dict = () => {
return _bb1133_termite_23_make_2d_dict();
},2,1);

_j(_bb1134_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1135_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2485_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1135_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2483_termite_23_make_2d_dict();
} else {
return _bb1136_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2483_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2484_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1136_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1137_termite_23_make_2d_dict();
} else {
return _bb2482_termite_23_make_2d_dict();
}
});

_k(_bb2484_termite_23_make_2d_dict = () => {
return _bb1140_termite_23_make_2d_dict();
},2,1);

_j(_bb1137_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1138_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2482_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1139_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1140_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1141_termite_23_make_2d_dict();
} else {
return _bb2481_termite_23_make_2d_dict();
}
});

_k(_bb1138_termite_23_make_2d_dict = () => {
return _bb1140_termite_23_make_2d_dict();
},2,1);

_k(_bb1139_termite_23_make_2d_dict = () => {
return _bb1140_termite_23_make_2d_dict();
},2,1);

_j(_bb1141_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1142_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2481_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1142_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2479_termite_23_make_2d_dict();
} else {
return _bb1143_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2479_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2480_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1143_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1144_termite_23_make_2d_dict();
} else {
return _bb2478_termite_23_make_2d_dict();
}
});

_k(_bb2480_termite_23_make_2d_dict = () => {
return _bb1147_termite_23_make_2d_dict();
},2,1);

_j(_bb1144_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1145_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2478_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1146_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1147_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1148_termite_23_make_2d_dict();
} else {
return _bb2477_termite_23_make_2d_dict();
}
});

_k(_bb1145_termite_23_make_2d_dict = () => {
return _bb1147_termite_23_make_2d_dict();
},2,1);

_k(_bb1146_termite_23_make_2d_dict = () => {
return _bb1147_termite_23_make_2d_dict();
},2,1);

_j(_bb1148_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1149_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2477_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1149_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2475_termite_23_make_2d_dict();
} else {
return _bb1150_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2475_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2476_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1150_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1151_termite_23_make_2d_dict();
} else {
return _bb2474_termite_23_make_2d_dict();
}
});

_k(_bb2476_termite_23_make_2d_dict = () => {
return _bb1154_termite_23_make_2d_dict();
},2,1);

_j(_bb1151_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1152_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2474_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1153_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1154_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1155_termite_23_make_2d_dict();
} else {
return _bb2473_termite_23_make_2d_dict();
}
});

_k(_bb1152_termite_23_make_2d_dict = () => {
return _bb1154_termite_23_make_2d_dict();
},2,1);

_k(_bb1153_termite_23_make_2d_dict = () => {
return _bb1154_termite_23_make_2d_dict();
},2,1);

_j(_bb1155_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1156_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2473_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1156_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2471_termite_23_make_2d_dict();
} else {
return _bb1157_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2471_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2472_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1157_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1158_termite_23_make_2d_dict();
} else {
return _bb2470_termite_23_make_2d_dict();
}
});

_k(_bb2472_termite_23_make_2d_dict = () => {
return _bb1161_termite_23_make_2d_dict();
},2,1);

_j(_bb1158_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1159_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2470_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1160_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1161_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1162_termite_23_make_2d_dict();
} else {
return _bb2469_termite_23_make_2d_dict();
}
});

_k(_bb1159_termite_23_make_2d_dict = () => {
return _bb1161_termite_23_make_2d_dict();
},2,1);

_k(_bb1160_termite_23_make_2d_dict = () => {
return _bb1161_termite_23_make_2d_dict();
},2,1);

_j(_bb1162_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1163_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2469_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1163_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2467_termite_23_make_2d_dict();
} else {
return _bb1164_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2467_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2468_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1164_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1165_termite_23_make_2d_dict();
} else {
return _bb2466_termite_23_make_2d_dict();
}
});

_k(_bb2468_termite_23_make_2d_dict = () => {
return _bb1168_termite_23_make_2d_dict();
},2,1);

_j(_bb1165_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1166_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2466_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1167_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1168_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1169_termite_23_make_2d_dict();
} else {
return _bb2465_termite_23_make_2d_dict();
}
});

_k(_bb1166_termite_23_make_2d_dict = () => {
return _bb1168_termite_23_make_2d_dict();
},2,1);

_k(_bb1167_termite_23_make_2d_dict = () => {
return _bb1168_termite_23_make_2d_dict();
},2,1);

_j(_bb1169_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1170_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2465_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1170_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2463_termite_23_make_2d_dict();
} else {
return _bb1171_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2463_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2464_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1171_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1172_termite_23_make_2d_dict();
} else {
return _bb2462_termite_23_make_2d_dict();
}
});

_k(_bb2464_termite_23_make_2d_dict = () => {
return _bb1175_termite_23_make_2d_dict();
},2,1);

_j(_bb1172_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1173_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2462_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1174_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1175_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1176_termite_23_make_2d_dict();
} else {
return _bb2461_termite_23_make_2d_dict();
}
});

_k(_bb1173_termite_23_make_2d_dict = () => {
return _bb1175_termite_23_make_2d_dict();
},2,1);

_k(_bb1174_termite_23_make_2d_dict = () => {
return _bb1175_termite_23_make_2d_dict();
},2,1);

_j(_bb1176_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1177_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2461_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1177_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2459_termite_23_make_2d_dict();
} else {
return _bb1178_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2459_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2460_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1178_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1179_termite_23_make_2d_dict();
} else {
return _bb2458_termite_23_make_2d_dict();
}
});

_k(_bb2460_termite_23_make_2d_dict = () => {
return _bb1182_termite_23_make_2d_dict();
},2,1);

_j(_bb1179_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1180_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2458_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1181_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1182_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1183_termite_23_make_2d_dict();
} else {
return _bb2457_termite_23_make_2d_dict();
}
});

_k(_bb1180_termite_23_make_2d_dict = () => {
return _bb1182_termite_23_make_2d_dict();
},2,1);

_k(_bb1181_termite_23_make_2d_dict = () => {
return _bb1182_termite_23_make_2d_dict();
},2,1);

_j(_bb1183_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1184_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2457_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1184_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2455_termite_23_make_2d_dict();
} else {
return _bb1185_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2455_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2456_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1185_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1186_termite_23_make_2d_dict();
} else {
return _bb2454_termite_23_make_2d_dict();
}
});

_k(_bb2456_termite_23_make_2d_dict = () => {
return _bb1189_termite_23_make_2d_dict();
},2,1);

_j(_bb1186_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1187_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2454_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1188_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1189_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1190_termite_23_make_2d_dict();
} else {
return _bb2453_termite_23_make_2d_dict();
}
});

_k(_bb1187_termite_23_make_2d_dict = () => {
return _bb1189_termite_23_make_2d_dict();
},2,1);

_k(_bb1188_termite_23_make_2d_dict = () => {
return _bb1189_termite_23_make_2d_dict();
},2,1);

_j(_bb1190_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1191_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2453_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1191_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2451_termite_23_make_2d_dict();
} else {
return _bb1192_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2451_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2452_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1192_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1193_termite_23_make_2d_dict();
} else {
return _bb2450_termite_23_make_2d_dict();
}
});

_k(_bb2452_termite_23_make_2d_dict = () => {
return _bb1196_termite_23_make_2d_dict();
},2,1);

_j(_bb1193_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1194_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2450_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1195_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1196_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1197_termite_23_make_2d_dict();
} else {
return _bb2449_termite_23_make_2d_dict();
}
});

_k(_bb1194_termite_23_make_2d_dict = () => {
return _bb1196_termite_23_make_2d_dict();
},2,1);

_k(_bb1195_termite_23_make_2d_dict = () => {
return _bb1196_termite_23_make_2d_dict();
},2,1);

_j(_bb1197_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1198_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2449_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1198_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2447_termite_23_make_2d_dict();
} else {
return _bb1199_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2447_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2448_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1199_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1200_termite_23_make_2d_dict();
} else {
return _bb2446_termite_23_make_2d_dict();
}
});

_k(_bb2448_termite_23_make_2d_dict = () => {
return _bb1203_termite_23_make_2d_dict();
},2,1);

_j(_bb1200_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1201_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2446_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1202_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1203_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1204_termite_23_make_2d_dict();
} else {
return _bb2445_termite_23_make_2d_dict();
}
});

_k(_bb1201_termite_23_make_2d_dict = () => {
return _bb1203_termite_23_make_2d_dict();
},2,1);

_k(_bb1202_termite_23_make_2d_dict = () => {
return _bb1203_termite_23_make_2d_dict();
},2,1);

_j(_bb1204_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1205_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2445_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1205_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2443_termite_23_make_2d_dict();
} else {
return _bb1206_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2443_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2444_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1206_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1207_termite_23_make_2d_dict();
} else {
return _bb2442_termite_23_make_2d_dict();
}
});

_k(_bb2444_termite_23_make_2d_dict = () => {
return _bb1210_termite_23_make_2d_dict();
},2,1);

_j(_bb1207_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1208_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2442_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1209_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1210_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1211_termite_23_make_2d_dict();
} else {
return _bb2441_termite_23_make_2d_dict();
}
});

_k(_bb1208_termite_23_make_2d_dict = () => {
return _bb1210_termite_23_make_2d_dict();
},2,1);

_k(_bb1209_termite_23_make_2d_dict = () => {
return _bb1210_termite_23_make_2d_dict();
},2,1);

_j(_bb1211_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1212_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2441_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1212_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2439_termite_23_make_2d_dict();
} else {
return _bb1213_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2439_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2440_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1213_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1214_termite_23_make_2d_dict();
} else {
return _bb2438_termite_23_make_2d_dict();
}
});

_k(_bb2440_termite_23_make_2d_dict = () => {
return _bb1217_termite_23_make_2d_dict();
},2,1);

_j(_bb1214_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1215_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2438_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1216_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1217_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1218_termite_23_make_2d_dict();
} else {
return _bb2437_termite_23_make_2d_dict();
}
});

_k(_bb1215_termite_23_make_2d_dict = () => {
return _bb1217_termite_23_make_2d_dict();
},2,1);

_k(_bb1216_termite_23_make_2d_dict = () => {
return _bb1217_termite_23_make_2d_dict();
},2,1);

_j(_bb1218_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1219_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2437_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1219_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2435_termite_23_make_2d_dict();
} else {
return _bb1220_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2435_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2436_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1220_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1221_termite_23_make_2d_dict();
} else {
return _bb2434_termite_23_make_2d_dict();
}
});

_k(_bb2436_termite_23_make_2d_dict = () => {
return _bb1224_termite_23_make_2d_dict();
},2,1);

_j(_bb1221_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1222_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2434_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1223_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1224_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1225_termite_23_make_2d_dict();
} else {
return _bb2433_termite_23_make_2d_dict();
}
});

_k(_bb1222_termite_23_make_2d_dict = () => {
return _bb1224_termite_23_make_2d_dict();
},2,1);

_k(_bb1223_termite_23_make_2d_dict = () => {
return _bb1224_termite_23_make_2d_dict();
},2,1);

_j(_bb1225_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1226_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2433_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1226_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2431_termite_23_make_2d_dict();
} else {
return _bb1227_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2431_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2432_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1227_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1228_termite_23_make_2d_dict();
} else {
return _bb2430_termite_23_make_2d_dict();
}
});

_k(_bb2432_termite_23_make_2d_dict = () => {
return _bb1231_termite_23_make_2d_dict();
},2,1);

_j(_bb1228_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1229_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2430_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1230_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1231_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1232_termite_23_make_2d_dict();
} else {
return _bb2429_termite_23_make_2d_dict();
}
});

_k(_bb1229_termite_23_make_2d_dict = () => {
return _bb1231_termite_23_make_2d_dict();
},2,1);

_k(_bb1230_termite_23_make_2d_dict = () => {
return _bb1231_termite_23_make_2d_dict();
},2,1);

_j(_bb1232_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1233_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2429_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1233_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2427_termite_23_make_2d_dict();
} else {
return _bb1234_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2427_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2428_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1234_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1235_termite_23_make_2d_dict();
} else {
return _bb2426_termite_23_make_2d_dict();
}
});

_k(_bb2428_termite_23_make_2d_dict = () => {
return _bb1238_termite_23_make_2d_dict();
},2,1);

_j(_bb1235_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1236_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2426_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1237_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1238_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1239_termite_23_make_2d_dict();
} else {
return _bb2425_termite_23_make_2d_dict();
}
});

_k(_bb1236_termite_23_make_2d_dict = () => {
return _bb1238_termite_23_make_2d_dict();
},2,1);

_k(_bb1237_termite_23_make_2d_dict = () => {
return _bb1238_termite_23_make_2d_dict();
},2,1);

_j(_bb1239_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1240_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2425_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1240_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2423_termite_23_make_2d_dict();
} else {
return _bb1241_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2423_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2424_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1241_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1242_termite_23_make_2d_dict();
} else {
return _bb2422_termite_23_make_2d_dict();
}
});

_k(_bb2424_termite_23_make_2d_dict = () => {
return _bb1245_termite_23_make_2d_dict();
},2,1);

_j(_bb1242_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1243_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2422_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1244_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1245_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1246_termite_23_make_2d_dict();
} else {
return _bb2421_termite_23_make_2d_dict();
}
});

_k(_bb1243_termite_23_make_2d_dict = () => {
return _bb1245_termite_23_make_2d_dict();
},2,1);

_k(_bb1244_termite_23_make_2d_dict = () => {
return _bb1245_termite_23_make_2d_dict();
},2,1);

_j(_bb1246_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1247_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2421_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1247_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2419_termite_23_make_2d_dict();
} else {
return _bb1248_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2419_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2420_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1248_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1249_termite_23_make_2d_dict();
} else {
return _bb2418_termite_23_make_2d_dict();
}
});

_k(_bb2420_termite_23_make_2d_dict = () => {
return _bb1252_termite_23_make_2d_dict();
},2,1);

_j(_bb1249_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1250_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2418_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1251_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1252_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1253_termite_23_make_2d_dict();
} else {
return _bb2417_termite_23_make_2d_dict();
}
});

_k(_bb1250_termite_23_make_2d_dict = () => {
return _bb1252_termite_23_make_2d_dict();
},2,1);

_k(_bb1251_termite_23_make_2d_dict = () => {
return _bb1252_termite_23_make_2d_dict();
},2,1);

_j(_bb1253_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1254_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2417_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1254_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2415_termite_23_make_2d_dict();
} else {
return _bb1255_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2415_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2416_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1255_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1256_termite_23_make_2d_dict();
} else {
return _bb2414_termite_23_make_2d_dict();
}
});

_k(_bb2416_termite_23_make_2d_dict = () => {
return _bb1259_termite_23_make_2d_dict();
},2,1);

_j(_bb1256_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1257_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2414_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1258_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1259_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1260_termite_23_make_2d_dict();
} else {
return _bb2413_termite_23_make_2d_dict();
}
});

_k(_bb1257_termite_23_make_2d_dict = () => {
return _bb1259_termite_23_make_2d_dict();
},2,1);

_k(_bb1258_termite_23_make_2d_dict = () => {
return _bb1259_termite_23_make_2d_dict();
},2,1);

_j(_bb1260_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1261_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2413_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1261_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2411_termite_23_make_2d_dict();
} else {
return _bb1262_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2411_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2412_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1262_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1263_termite_23_make_2d_dict();
} else {
return _bb2410_termite_23_make_2d_dict();
}
});

_k(_bb2412_termite_23_make_2d_dict = () => {
return _bb1266_termite_23_make_2d_dict();
},2,1);

_j(_bb1263_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1264_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2410_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1265_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1266_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1267_termite_23_make_2d_dict();
} else {
return _bb2409_termite_23_make_2d_dict();
}
});

_k(_bb1264_termite_23_make_2d_dict = () => {
return _bb1266_termite_23_make_2d_dict();
},2,1);

_k(_bb1265_termite_23_make_2d_dict = () => {
return _bb1266_termite_23_make_2d_dict();
},2,1);

_j(_bb1267_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1268_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2409_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1268_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2407_termite_23_make_2d_dict();
} else {
return _bb1269_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2407_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2408_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1269_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1270_termite_23_make_2d_dict();
} else {
return _bb2406_termite_23_make_2d_dict();
}
});

_k(_bb2408_termite_23_make_2d_dict = () => {
return _bb1273_termite_23_make_2d_dict();
},2,1);

_j(_bb1270_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1271_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2406_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1272_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1273_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1274_termite_23_make_2d_dict();
} else {
return _bb2405_termite_23_make_2d_dict();
}
});

_k(_bb1271_termite_23_make_2d_dict = () => {
return _bb1273_termite_23_make_2d_dict();
},2,1);

_k(_bb1272_termite_23_make_2d_dict = () => {
return _bb1273_termite_23_make_2d_dict();
},2,1);

_j(_bb1274_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1275_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2405_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1275_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2403_termite_23_make_2d_dict();
} else {
return _bb1276_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2403_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2404_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1276_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1277_termite_23_make_2d_dict();
} else {
return _bb2402_termite_23_make_2d_dict();
}
});

_k(_bb2404_termite_23_make_2d_dict = () => {
return _bb1280_termite_23_make_2d_dict();
},2,1);

_j(_bb1277_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1278_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2402_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1279_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1280_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1281_termite_23_make_2d_dict();
} else {
return _bb2401_termite_23_make_2d_dict();
}
});

_k(_bb1278_termite_23_make_2d_dict = () => {
return _bb1280_termite_23_make_2d_dict();
},2,1);

_k(_bb1279_termite_23_make_2d_dict = () => {
return _bb1280_termite_23_make_2d_dict();
},2,1);

_j(_bb1281_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1282_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2401_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1282_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2399_termite_23_make_2d_dict();
} else {
return _bb1283_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2399_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2400_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1283_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1284_termite_23_make_2d_dict();
} else {
return _bb2398_termite_23_make_2d_dict();
}
});

_k(_bb2400_termite_23_make_2d_dict = () => {
return _bb1287_termite_23_make_2d_dict();
},2,1);

_j(_bb1284_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1285_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2398_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1286_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1287_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1288_termite_23_make_2d_dict();
} else {
return _bb2397_termite_23_make_2d_dict();
}
});

_k(_bb1285_termite_23_make_2d_dict = () => {
return _bb1287_termite_23_make_2d_dict();
},2,1);

_k(_bb1286_termite_23_make_2d_dict = () => {
return _bb1287_termite_23_make_2d_dict();
},2,1);

_j(_bb1288_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1289_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2397_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1289_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2395_termite_23_make_2d_dict();
} else {
return _bb1290_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2395_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2396_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1290_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1291_termite_23_make_2d_dict();
} else {
return _bb2394_termite_23_make_2d_dict();
}
});

_k(_bb2396_termite_23_make_2d_dict = () => {
return _bb1294_termite_23_make_2d_dict();
},2,1);

_j(_bb1291_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1292_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2394_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1293_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1294_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1295_termite_23_make_2d_dict();
} else {
return _bb2393_termite_23_make_2d_dict();
}
});

_k(_bb1292_termite_23_make_2d_dict = () => {
return _bb1294_termite_23_make_2d_dict();
},2,1);

_k(_bb1293_termite_23_make_2d_dict = () => {
return _bb1294_termite_23_make_2d_dict();
},2,1);

_j(_bb1295_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1296_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2393_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1296_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2391_termite_23_make_2d_dict();
} else {
return _bb1297_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2391_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2392_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1297_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1298_termite_23_make_2d_dict();
} else {
return _bb2390_termite_23_make_2d_dict();
}
});

_k(_bb2392_termite_23_make_2d_dict = () => {
return _bb1301_termite_23_make_2d_dict();
},2,1);

_j(_bb1298_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1299_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2390_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1300_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1301_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1302_termite_23_make_2d_dict();
} else {
return _bb2389_termite_23_make_2d_dict();
}
});

_k(_bb1299_termite_23_make_2d_dict = () => {
return _bb1301_termite_23_make_2d_dict();
},2,1);

_k(_bb1300_termite_23_make_2d_dict = () => {
return _bb1301_termite_23_make_2d_dict();
},2,1);

_j(_bb1302_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1303_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2389_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1303_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2387_termite_23_make_2d_dict();
} else {
return _bb1304_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2387_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2388_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1304_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1305_termite_23_make_2d_dict();
} else {
return _bb2386_termite_23_make_2d_dict();
}
});

_k(_bb2388_termite_23_make_2d_dict = () => {
return _bb1308_termite_23_make_2d_dict();
},2,1);

_j(_bb1305_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1306_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2386_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1307_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1308_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1309_termite_23_make_2d_dict();
} else {
return _bb2385_termite_23_make_2d_dict();
}
});

_k(_bb1306_termite_23_make_2d_dict = () => {
return _bb1308_termite_23_make_2d_dict();
},2,1);

_k(_bb1307_termite_23_make_2d_dict = () => {
return _bb1308_termite_23_make_2d_dict();
},2,1);

_j(_bb1309_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1310_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2385_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1310_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2383_termite_23_make_2d_dict();
} else {
return _bb1311_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2383_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2384_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1311_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1312_termite_23_make_2d_dict();
} else {
return _bb2382_termite_23_make_2d_dict();
}
});

_k(_bb2384_termite_23_make_2d_dict = () => {
return _bb1315_termite_23_make_2d_dict();
},2,1);

_j(_bb1312_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1313_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2382_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1314_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1315_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1316_termite_23_make_2d_dict();
} else {
return _bb2381_termite_23_make_2d_dict();
}
});

_k(_bb1313_termite_23_make_2d_dict = () => {
return _bb1315_termite_23_make_2d_dict();
},2,1);

_k(_bb1314_termite_23_make_2d_dict = () => {
return _bb1315_termite_23_make_2d_dict();
},2,1);

_j(_bb1316_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1317_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2381_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1317_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2379_termite_23_make_2d_dict();
} else {
return _bb1318_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2379_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2380_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1318_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1319_termite_23_make_2d_dict();
} else {
return _bb2378_termite_23_make_2d_dict();
}
});

_k(_bb2380_termite_23_make_2d_dict = () => {
return _bb1322_termite_23_make_2d_dict();
},2,1);

_j(_bb1319_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1320_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2378_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1321_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1322_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1323_termite_23_make_2d_dict();
} else {
return _bb2377_termite_23_make_2d_dict();
}
});

_k(_bb1320_termite_23_make_2d_dict = () => {
return _bb1322_termite_23_make_2d_dict();
},2,1);

_k(_bb1321_termite_23_make_2d_dict = () => {
return _bb1322_termite_23_make_2d_dict();
},2,1);

_j(_bb1323_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1324_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2377_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1324_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2375_termite_23_make_2d_dict();
} else {
return _bb1325_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2375_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2376_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1325_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1326_termite_23_make_2d_dict();
} else {
return _bb2374_termite_23_make_2d_dict();
}
});

_k(_bb2376_termite_23_make_2d_dict = () => {
return _bb1329_termite_23_make_2d_dict();
},2,1);

_j(_bb1326_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1327_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2374_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1328_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1329_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1330_termite_23_make_2d_dict();
} else {
return _bb2373_termite_23_make_2d_dict();
}
});

_k(_bb1327_termite_23_make_2d_dict = () => {
return _bb1329_termite_23_make_2d_dict();
},2,1);

_k(_bb1328_termite_23_make_2d_dict = () => {
return _bb1329_termite_23_make_2d_dict();
},2,1);

_j(_bb1330_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1331_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2373_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1331_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2371_termite_23_make_2d_dict();
} else {
return _bb1332_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2371_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2372_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1332_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1333_termite_23_make_2d_dict();
} else {
return _bb2370_termite_23_make_2d_dict();
}
});

_k(_bb2372_termite_23_make_2d_dict = () => {
return _bb1336_termite_23_make_2d_dict();
},2,1);

_j(_bb1333_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1334_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2370_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1335_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1336_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1337_termite_23_make_2d_dict();
} else {
return _bb2369_termite_23_make_2d_dict();
}
});

_k(_bb1334_termite_23_make_2d_dict = () => {
return _bb1336_termite_23_make_2d_dict();
},2,1);

_k(_bb1335_termite_23_make_2d_dict = () => {
return _bb1336_termite_23_make_2d_dict();
},2,1);

_j(_bb1337_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1338_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2369_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1338_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2367_termite_23_make_2d_dict();
} else {
return _bb1339_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2367_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2368_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1339_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1340_termite_23_make_2d_dict();
} else {
return _bb2366_termite_23_make_2d_dict();
}
});

_k(_bb2368_termite_23_make_2d_dict = () => {
return _bb1343_termite_23_make_2d_dict();
},2,1);

_j(_bb1340_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1341_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2366_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1342_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1343_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1344_termite_23_make_2d_dict();
} else {
return _bb2365_termite_23_make_2d_dict();
}
});

_k(_bb1341_termite_23_make_2d_dict = () => {
return _bb1343_termite_23_make_2d_dict();
},2,1);

_k(_bb1342_termite_23_make_2d_dict = () => {
return _bb1343_termite_23_make_2d_dict();
},2,1);

_j(_bb1344_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1345_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2365_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1345_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2363_termite_23_make_2d_dict();
} else {
return _bb1346_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2363_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2364_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1346_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1347_termite_23_make_2d_dict();
} else {
return _bb2362_termite_23_make_2d_dict();
}
});

_k(_bb2364_termite_23_make_2d_dict = () => {
return _bb1350_termite_23_make_2d_dict();
},2,1);

_j(_bb1347_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1348_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2362_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1349_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1350_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1351_termite_23_make_2d_dict();
} else {
return _bb2361_termite_23_make_2d_dict();
}
});

_k(_bb1348_termite_23_make_2d_dict = () => {
return _bb1350_termite_23_make_2d_dict();
},2,1);

_k(_bb1349_termite_23_make_2d_dict = () => {
return _bb1350_termite_23_make_2d_dict();
},2,1);

_j(_bb1351_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1352_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2361_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1352_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2359_termite_23_make_2d_dict();
} else {
return _bb1353_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2359_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2360_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1353_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1354_termite_23_make_2d_dict();
} else {
return _bb2358_termite_23_make_2d_dict();
}
});

_k(_bb2360_termite_23_make_2d_dict = () => {
return _bb1357_termite_23_make_2d_dict();
},2,1);

_j(_bb1354_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1355_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2358_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1356_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1357_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1358_termite_23_make_2d_dict();
} else {
return _bb2357_termite_23_make_2d_dict();
}
});

_k(_bb1355_termite_23_make_2d_dict = () => {
return _bb1357_termite_23_make_2d_dict();
},2,1);

_k(_bb1356_termite_23_make_2d_dict = () => {
return _bb1357_termite_23_make_2d_dict();
},2,1);

_j(_bb1358_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1359_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2357_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1359_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2355_termite_23_make_2d_dict();
} else {
return _bb1360_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2355_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2356_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1360_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1361_termite_23_make_2d_dict();
} else {
return _bb2354_termite_23_make_2d_dict();
}
});

_k(_bb2356_termite_23_make_2d_dict = () => {
return _bb1364_termite_23_make_2d_dict();
},2,1);

_j(_bb1361_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1362_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2354_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1363_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1364_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1365_termite_23_make_2d_dict();
} else {
return _bb2353_termite_23_make_2d_dict();
}
});

_k(_bb1362_termite_23_make_2d_dict = () => {
return _bb1364_termite_23_make_2d_dict();
},2,1);

_k(_bb1363_termite_23_make_2d_dict = () => {
return _bb1364_termite_23_make_2d_dict();
},2,1);

_j(_bb1365_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1366_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2353_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1366_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2351_termite_23_make_2d_dict();
} else {
return _bb1367_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2351_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2352_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1367_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1368_termite_23_make_2d_dict();
} else {
return _bb2350_termite_23_make_2d_dict();
}
});

_k(_bb2352_termite_23_make_2d_dict = () => {
return _bb1371_termite_23_make_2d_dict();
},2,1);

_j(_bb1368_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1369_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2350_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1370_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1371_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1372_termite_23_make_2d_dict();
} else {
return _bb2349_termite_23_make_2d_dict();
}
});

_k(_bb1369_termite_23_make_2d_dict = () => {
return _bb1371_termite_23_make_2d_dict();
},2,1);

_k(_bb1370_termite_23_make_2d_dict = () => {
return _bb1371_termite_23_make_2d_dict();
},2,1);

_j(_bb1372_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_t += 2;
return _p(_bb1373_termite_23_make_2d_dict);
});

_j(_bb2349_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb1373_termite_23_make_2d_dict = () => {
_r = _bb1374_termite_23_make_2d_dict;
_n = 1;
return _g["thread?"]();
});

_k(_bb1374_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2347_termite_23_make_2d_dict();
} else {
return _bb1375_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2347_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2348_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1375_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1376_termite_23_make_2d_dict();
} else {
return _bb2346_termite_23_make_2d_dict();
}
});

_k(_bb2348_termite_23_make_2d_dict = () => {
return _bb1379_termite_23_make_2d_dict();
},2,1);

_j(_bb1376_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1377_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2346_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1378_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1379_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1380_termite_23_make_2d_dict();
} else {
return _bb2345_termite_23_make_2d_dict();
}
});

_k(_bb1377_termite_23_make_2d_dict = () => {
return _bb1379_termite_23_make_2d_dict();
},2,1);

_k(_bb1378_termite_23_make_2d_dict = () => {
return _bb1379_termite_23_make_2d_dict();
},2,1);

_j(_bb1380_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1381_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2345_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1381_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2343_termite_23_make_2d_dict();
} else {
return _bb1382_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2343_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2344_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1382_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1383_termite_23_make_2d_dict();
} else {
return _bb2342_termite_23_make_2d_dict();
}
});

_k(_bb2344_termite_23_make_2d_dict = () => {
return _bb1386_termite_23_make_2d_dict();
},2,1);

_j(_bb1383_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1384_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2342_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1385_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1386_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1387_termite_23_make_2d_dict();
} else {
return _bb2341_termite_23_make_2d_dict();
}
});

_k(_bb1384_termite_23_make_2d_dict = () => {
return _bb1386_termite_23_make_2d_dict();
},2,1);

_k(_bb1385_termite_23_make_2d_dict = () => {
return _bb1386_termite_23_make_2d_dict();
},2,1);

_j(_bb1387_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1388_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2341_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1388_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2339_termite_23_make_2d_dict();
} else {
return _bb1389_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2339_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2340_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1389_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1390_termite_23_make_2d_dict();
} else {
return _bb2338_termite_23_make_2d_dict();
}
});

_k(_bb2340_termite_23_make_2d_dict = () => {
return _bb1393_termite_23_make_2d_dict();
},2,1);

_j(_bb1390_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1391_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2338_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1392_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1393_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1394_termite_23_make_2d_dict();
} else {
return _bb2337_termite_23_make_2d_dict();
}
});

_k(_bb1391_termite_23_make_2d_dict = () => {
return _bb1393_termite_23_make_2d_dict();
},2,1);

_k(_bb1392_termite_23_make_2d_dict = () => {
return _bb1393_termite_23_make_2d_dict();
},2,1);

_j(_bb1394_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1395_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2337_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1395_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2335_termite_23_make_2d_dict();
} else {
return _bb1396_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2335_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2336_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1396_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1397_termite_23_make_2d_dict();
} else {
return _bb2334_termite_23_make_2d_dict();
}
});

_k(_bb2336_termite_23_make_2d_dict = () => {
return _bb1400_termite_23_make_2d_dict();
},2,1);

_j(_bb1397_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1398_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2334_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1399_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1400_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1401_termite_23_make_2d_dict();
} else {
return _bb2333_termite_23_make_2d_dict();
}
});

_k(_bb1398_termite_23_make_2d_dict = () => {
return _bb1400_termite_23_make_2d_dict();
},2,1);

_k(_bb1399_termite_23_make_2d_dict = () => {
return _bb1400_termite_23_make_2d_dict();
},2,1);

_j(_bb1401_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1402_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2333_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1402_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2331_termite_23_make_2d_dict();
} else {
return _bb1403_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2331_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2332_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1403_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1404_termite_23_make_2d_dict();
} else {
return _bb2330_termite_23_make_2d_dict();
}
});

_k(_bb2332_termite_23_make_2d_dict = () => {
return _bb1407_termite_23_make_2d_dict();
},2,1);

_j(_bb1404_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1405_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2330_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1406_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1407_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1408_termite_23_make_2d_dict();
} else {
return _bb2329_termite_23_make_2d_dict();
}
});

_k(_bb1405_termite_23_make_2d_dict = () => {
return _bb1407_termite_23_make_2d_dict();
},2,1);

_k(_bb1406_termite_23_make_2d_dict = () => {
return _bb1407_termite_23_make_2d_dict();
},2,1);

_j(_bb1408_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1409_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2329_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1409_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2327_termite_23_make_2d_dict();
} else {
return _bb1410_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2327_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2328_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1410_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1411_termite_23_make_2d_dict();
} else {
return _bb2326_termite_23_make_2d_dict();
}
});

_k(_bb2328_termite_23_make_2d_dict = () => {
return _bb1414_termite_23_make_2d_dict();
},2,1);

_j(_bb1411_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1412_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2326_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1413_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1414_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1415_termite_23_make_2d_dict();
} else {
return _bb2325_termite_23_make_2d_dict();
}
});

_k(_bb1412_termite_23_make_2d_dict = () => {
return _bb1414_termite_23_make_2d_dict();
},2,1);

_k(_bb1413_termite_23_make_2d_dict = () => {
return _bb1414_termite_23_make_2d_dict();
},2,1);

_j(_bb1415_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1416_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2325_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1416_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2323_termite_23_make_2d_dict();
} else {
return _bb1417_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2323_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2324_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1417_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1418_termite_23_make_2d_dict();
} else {
return _bb2322_termite_23_make_2d_dict();
}
});

_k(_bb2324_termite_23_make_2d_dict = () => {
return _bb1421_termite_23_make_2d_dict();
},2,1);

_j(_bb1418_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1419_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2322_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1420_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1421_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1422_termite_23_make_2d_dict();
} else {
return _bb2321_termite_23_make_2d_dict();
}
});

_k(_bb1419_termite_23_make_2d_dict = () => {
return _bb1421_termite_23_make_2d_dict();
},2,1);

_k(_bb1420_termite_23_make_2d_dict = () => {
return _bb1421_termite_23_make_2d_dict();
},2,1);

_j(_bb1422_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1423_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2321_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1423_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2319_termite_23_make_2d_dict();
} else {
return _bb1424_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2319_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2320_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1424_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1425_termite_23_make_2d_dict();
} else {
return _bb2318_termite_23_make_2d_dict();
}
});

_k(_bb2320_termite_23_make_2d_dict = () => {
return _bb1428_termite_23_make_2d_dict();
},2,1);

_j(_bb1425_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1426_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2318_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1427_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1428_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1429_termite_23_make_2d_dict();
} else {
return _bb2317_termite_23_make_2d_dict();
}
});

_k(_bb1426_termite_23_make_2d_dict = () => {
return _bb1428_termite_23_make_2d_dict();
},2,1);

_k(_bb1427_termite_23_make_2d_dict = () => {
return _bb1428_termite_23_make_2d_dict();
},2,1);

_j(_bb1429_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1430_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2317_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1430_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2315_termite_23_make_2d_dict();
} else {
return _bb1431_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2315_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2316_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1431_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1432_termite_23_make_2d_dict();
} else {
return _bb2314_termite_23_make_2d_dict();
}
});

_k(_bb2316_termite_23_make_2d_dict = () => {
return _bb1435_termite_23_make_2d_dict();
},2,1);

_j(_bb1432_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1433_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2314_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1434_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1435_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1436_termite_23_make_2d_dict();
} else {
return _bb2313_termite_23_make_2d_dict();
}
});

_k(_bb1433_termite_23_make_2d_dict = () => {
return _bb1435_termite_23_make_2d_dict();
},2,1);

_k(_bb1434_termite_23_make_2d_dict = () => {
return _bb1435_termite_23_make_2d_dict();
},2,1);

_j(_bb1436_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1437_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2313_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1437_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2311_termite_23_make_2d_dict();
} else {
return _bb1438_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2311_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2312_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1438_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1439_termite_23_make_2d_dict();
} else {
return _bb2310_termite_23_make_2d_dict();
}
});

_k(_bb2312_termite_23_make_2d_dict = () => {
return _bb1442_termite_23_make_2d_dict();
},2,1);

_j(_bb1439_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1440_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2310_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1441_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1442_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1443_termite_23_make_2d_dict();
} else {
return _bb2309_termite_23_make_2d_dict();
}
});

_k(_bb1440_termite_23_make_2d_dict = () => {
return _bb1442_termite_23_make_2d_dict();
},2,1);

_k(_bb1441_termite_23_make_2d_dict = () => {
return _bb1442_termite_23_make_2d_dict();
},2,1);

_j(_bb1443_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1444_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2309_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1444_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2307_termite_23_make_2d_dict();
} else {
return _bb1445_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2307_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2308_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1445_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1446_termite_23_make_2d_dict();
} else {
return _bb2306_termite_23_make_2d_dict();
}
});

_k(_bb2308_termite_23_make_2d_dict = () => {
return _bb1449_termite_23_make_2d_dict();
},2,1);

_j(_bb1446_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1447_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2306_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1448_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1449_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1450_termite_23_make_2d_dict();
} else {
return _bb2305_termite_23_make_2d_dict();
}
});

_k(_bb1447_termite_23_make_2d_dict = () => {
return _bb1449_termite_23_make_2d_dict();
},2,1);

_k(_bb1448_termite_23_make_2d_dict = () => {
return _bb1449_termite_23_make_2d_dict();
},2,1);

_j(_bb1450_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1451_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2305_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1451_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2303_termite_23_make_2d_dict();
} else {
return _bb1452_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2303_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2304_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1452_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1453_termite_23_make_2d_dict();
} else {
return _bb2302_termite_23_make_2d_dict();
}
});

_k(_bb2304_termite_23_make_2d_dict = () => {
return _bb1456_termite_23_make_2d_dict();
},2,1);

_j(_bb1453_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1454_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2302_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1455_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1456_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1457_termite_23_make_2d_dict();
} else {
return _bb2301_termite_23_make_2d_dict();
}
});

_k(_bb1454_termite_23_make_2d_dict = () => {
return _bb1456_termite_23_make_2d_dict();
},2,1);

_k(_bb1455_termite_23_make_2d_dict = () => {
return _bb1456_termite_23_make_2d_dict();
},2,1);

_j(_bb1457_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1458_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2301_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1458_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2299_termite_23_make_2d_dict();
} else {
return _bb1459_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2299_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2300_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1459_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1460_termite_23_make_2d_dict();
} else {
return _bb2298_termite_23_make_2d_dict();
}
});

_k(_bb2300_termite_23_make_2d_dict = () => {
return _bb1463_termite_23_make_2d_dict();
},2,1);

_j(_bb1460_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1461_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2298_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1462_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1463_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1464_termite_23_make_2d_dict();
} else {
return _bb2297_termite_23_make_2d_dict();
}
});

_k(_bb1461_termite_23_make_2d_dict = () => {
return _bb1463_termite_23_make_2d_dict();
},2,1);

_k(_bb1462_termite_23_make_2d_dict = () => {
return _bb1463_termite_23_make_2d_dict();
},2,1);

_j(_bb1464_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1465_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2297_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1465_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2295_termite_23_make_2d_dict();
} else {
return _bb1466_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2295_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2296_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1466_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1467_termite_23_make_2d_dict();
} else {
return _bb2294_termite_23_make_2d_dict();
}
});

_k(_bb2296_termite_23_make_2d_dict = () => {
return _bb1470_termite_23_make_2d_dict();
},2,1);

_j(_bb1467_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1468_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2294_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1469_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1470_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1471_termite_23_make_2d_dict();
} else {
return _bb2293_termite_23_make_2d_dict();
}
});

_k(_bb1468_termite_23_make_2d_dict = () => {
return _bb1470_termite_23_make_2d_dict();
},2,1);

_k(_bb1469_termite_23_make_2d_dict = () => {
return _bb1470_termite_23_make_2d_dict();
},2,1);

_j(_bb1471_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1472_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2293_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1472_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2291_termite_23_make_2d_dict();
} else {
return _bb1473_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2291_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2292_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1473_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1474_termite_23_make_2d_dict();
} else {
return _bb2290_termite_23_make_2d_dict();
}
});

_k(_bb2292_termite_23_make_2d_dict = () => {
return _bb1477_termite_23_make_2d_dict();
},2,1);

_j(_bb1474_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1475_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2290_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1476_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1477_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1478_termite_23_make_2d_dict();
} else {
return _bb2289_termite_23_make_2d_dict();
}
});

_k(_bb1475_termite_23_make_2d_dict = () => {
return _bb1477_termite_23_make_2d_dict();
},2,1);

_k(_bb1476_termite_23_make_2d_dict = () => {
return _bb1477_termite_23_make_2d_dict();
},2,1);

_j(_bb1478_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1479_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2289_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1479_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2287_termite_23_make_2d_dict();
} else {
return _bb1480_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2287_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2288_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1480_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1481_termite_23_make_2d_dict();
} else {
return _bb2286_termite_23_make_2d_dict();
}
});

_k(_bb2288_termite_23_make_2d_dict = () => {
return _bb1484_termite_23_make_2d_dict();
},2,1);

_j(_bb1481_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1482_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2286_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1483_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1484_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1485_termite_23_make_2d_dict();
} else {
return _bb2285_termite_23_make_2d_dict();
}
});

_k(_bb1482_termite_23_make_2d_dict = () => {
return _bb1484_termite_23_make_2d_dict();
},2,1);

_k(_bb1483_termite_23_make_2d_dict = () => {
return _bb1484_termite_23_make_2d_dict();
},2,1);

_j(_bb1485_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1486_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2285_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1486_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2283_termite_23_make_2d_dict();
} else {
return _bb1487_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2283_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2284_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1487_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1488_termite_23_make_2d_dict();
} else {
return _bb2282_termite_23_make_2d_dict();
}
});

_k(_bb2284_termite_23_make_2d_dict = () => {
return _bb1491_termite_23_make_2d_dict();
},2,1);

_j(_bb1488_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1489_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2282_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1490_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1491_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1492_termite_23_make_2d_dict();
} else {
return _bb2281_termite_23_make_2d_dict();
}
});

_k(_bb1489_termite_23_make_2d_dict = () => {
return _bb1491_termite_23_make_2d_dict();
},2,1);

_k(_bb1490_termite_23_make_2d_dict = () => {
return _bb1491_termite_23_make_2d_dict();
},2,1);

_j(_bb1492_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1493_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2281_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1493_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2279_termite_23_make_2d_dict();
} else {
return _bb1494_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2279_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2280_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1494_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1495_termite_23_make_2d_dict();
} else {
return _bb2278_termite_23_make_2d_dict();
}
});

_k(_bb2280_termite_23_make_2d_dict = () => {
return _bb1498_termite_23_make_2d_dict();
},2,1);

_j(_bb1495_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1496_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2278_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1497_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1498_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1499_termite_23_make_2d_dict();
} else {
return _bb2277_termite_23_make_2d_dict();
}
});

_k(_bb1496_termite_23_make_2d_dict = () => {
return _bb1498_termite_23_make_2d_dict();
},2,1);

_k(_bb1497_termite_23_make_2d_dict = () => {
return _bb1498_termite_23_make_2d_dict();
},2,1);

_j(_bb1499_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1500_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2277_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1500_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2275_termite_23_make_2d_dict();
} else {
return _bb1501_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2275_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2276_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1501_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1502_termite_23_make_2d_dict();
} else {
return _bb2274_termite_23_make_2d_dict();
}
});

_k(_bb2276_termite_23_make_2d_dict = () => {
return _bb1505_termite_23_make_2d_dict();
},2,1);

_j(_bb1502_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1503_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2274_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1504_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1505_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1506_termite_23_make_2d_dict();
} else {
return _bb2273_termite_23_make_2d_dict();
}
});

_k(_bb1503_termite_23_make_2d_dict = () => {
return _bb1505_termite_23_make_2d_dict();
},2,1);

_k(_bb1504_termite_23_make_2d_dict = () => {
return _bb1505_termite_23_make_2d_dict();
},2,1);

_j(_bb1506_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1507_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2273_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1507_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2271_termite_23_make_2d_dict();
} else {
return _bb1508_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2271_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2272_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1508_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1509_termite_23_make_2d_dict();
} else {
return _bb2270_termite_23_make_2d_dict();
}
});

_k(_bb2272_termite_23_make_2d_dict = () => {
return _bb1512_termite_23_make_2d_dict();
},2,1);

_j(_bb1509_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1510_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2270_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1511_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1512_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1513_termite_23_make_2d_dict();
} else {
return _bb2269_termite_23_make_2d_dict();
}
});

_k(_bb1510_termite_23_make_2d_dict = () => {
return _bb1512_termite_23_make_2d_dict();
},2,1);

_k(_bb1511_termite_23_make_2d_dict = () => {
return _bb1512_termite_23_make_2d_dict();
},2,1);

_j(_bb1513_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1514_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2269_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1514_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2267_termite_23_make_2d_dict();
} else {
return _bb1515_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2267_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2268_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1515_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1516_termite_23_make_2d_dict();
} else {
return _bb2266_termite_23_make_2d_dict();
}
});

_k(_bb2268_termite_23_make_2d_dict = () => {
return _bb1519_termite_23_make_2d_dict();
},2,1);

_j(_bb1516_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1517_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2266_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1518_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1519_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1520_termite_23_make_2d_dict();
} else {
return _bb2265_termite_23_make_2d_dict();
}
});

_k(_bb1517_termite_23_make_2d_dict = () => {
return _bb1519_termite_23_make_2d_dict();
},2,1);

_k(_bb1518_termite_23_make_2d_dict = () => {
return _bb1519_termite_23_make_2d_dict();
},2,1);

_j(_bb1520_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1521_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2265_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1521_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2263_termite_23_make_2d_dict();
} else {
return _bb1522_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2263_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2264_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1522_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1523_termite_23_make_2d_dict();
} else {
return _bb2262_termite_23_make_2d_dict();
}
});

_k(_bb2264_termite_23_make_2d_dict = () => {
return _bb1526_termite_23_make_2d_dict();
},2,1);

_j(_bb1523_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1524_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2262_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1525_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1526_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1527_termite_23_make_2d_dict();
} else {
return _bb2261_termite_23_make_2d_dict();
}
});

_k(_bb1524_termite_23_make_2d_dict = () => {
return _bb1526_termite_23_make_2d_dict();
},2,1);

_k(_bb1525_termite_23_make_2d_dict = () => {
return _bb1526_termite_23_make_2d_dict();
},2,1);

_j(_bb1527_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1528_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2261_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1528_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2259_termite_23_make_2d_dict();
} else {
return _bb1529_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2259_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2260_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1529_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1530_termite_23_make_2d_dict();
} else {
return _bb2258_termite_23_make_2d_dict();
}
});

_k(_bb2260_termite_23_make_2d_dict = () => {
return _bb1533_termite_23_make_2d_dict();
},2,1);

_j(_bb1530_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1531_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2258_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1532_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1533_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1534_termite_23_make_2d_dict();
} else {
return _bb2257_termite_23_make_2d_dict();
}
});

_k(_bb1531_termite_23_make_2d_dict = () => {
return _bb1533_termite_23_make_2d_dict();
},2,1);

_k(_bb1532_termite_23_make_2d_dict = () => {
return _bb1533_termite_23_make_2d_dict();
},2,1);

_j(_bb1534_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1535_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2257_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1535_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2255_termite_23_make_2d_dict();
} else {
return _bb1536_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2255_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2256_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1536_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1537_termite_23_make_2d_dict();
} else {
return _bb2254_termite_23_make_2d_dict();
}
});

_k(_bb2256_termite_23_make_2d_dict = () => {
return _bb1540_termite_23_make_2d_dict();
},2,1);

_j(_bb1537_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1538_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2254_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1539_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1540_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1541_termite_23_make_2d_dict();
} else {
return _bb2253_termite_23_make_2d_dict();
}
});

_k(_bb1538_termite_23_make_2d_dict = () => {
return _bb1540_termite_23_make_2d_dict();
},2,1);

_k(_bb1539_termite_23_make_2d_dict = () => {
return _bb1540_termite_23_make_2d_dict();
},2,1);

_j(_bb1541_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1542_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2253_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1542_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2251_termite_23_make_2d_dict();
} else {
return _bb1543_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2251_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2252_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1543_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1544_termite_23_make_2d_dict();
} else {
return _bb2250_termite_23_make_2d_dict();
}
});

_k(_bb2252_termite_23_make_2d_dict = () => {
return _bb1547_termite_23_make_2d_dict();
},2,1);

_j(_bb1544_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1545_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2250_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1546_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1547_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1548_termite_23_make_2d_dict();
} else {
return _bb2249_termite_23_make_2d_dict();
}
});

_k(_bb1545_termite_23_make_2d_dict = () => {
return _bb1547_termite_23_make_2d_dict();
},2,1);

_k(_bb1546_termite_23_make_2d_dict = () => {
return _bb1547_termite_23_make_2d_dict();
},2,1);

_j(_bb1548_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1549_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2249_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1549_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2247_termite_23_make_2d_dict();
} else {
return _bb1550_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2247_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2248_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1550_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1551_termite_23_make_2d_dict();
} else {
return _bb2246_termite_23_make_2d_dict();
}
});

_k(_bb2248_termite_23_make_2d_dict = () => {
return _bb1554_termite_23_make_2d_dict();
},2,1);

_j(_bb1551_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1552_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2246_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1553_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1554_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1555_termite_23_make_2d_dict();
} else {
return _bb2245_termite_23_make_2d_dict();
}
});

_k(_bb1552_termite_23_make_2d_dict = () => {
return _bb1554_termite_23_make_2d_dict();
},2,1);

_k(_bb1553_termite_23_make_2d_dict = () => {
return _bb1554_termite_23_make_2d_dict();
},2,1);

_j(_bb1555_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1556_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2245_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1556_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2243_termite_23_make_2d_dict();
} else {
return _bb1557_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2243_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2244_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1557_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1558_termite_23_make_2d_dict();
} else {
return _bb2242_termite_23_make_2d_dict();
}
});

_k(_bb2244_termite_23_make_2d_dict = () => {
return _bb1561_termite_23_make_2d_dict();
},2,1);

_j(_bb1558_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1559_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2242_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1560_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1561_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1562_termite_23_make_2d_dict();
} else {
return _bb2241_termite_23_make_2d_dict();
}
});

_k(_bb1559_termite_23_make_2d_dict = () => {
return _bb1561_termite_23_make_2d_dict();
},2,1);

_k(_bb1560_termite_23_make_2d_dict = () => {
return _bb1561_termite_23_make_2d_dict();
},2,1);

_j(_bb1562_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1563_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2241_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1563_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2239_termite_23_make_2d_dict();
} else {
return _bb1564_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2239_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2240_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1564_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1565_termite_23_make_2d_dict();
} else {
return _bb2238_termite_23_make_2d_dict();
}
});

_k(_bb2240_termite_23_make_2d_dict = () => {
return _bb1568_termite_23_make_2d_dict();
},2,1);

_j(_bb1565_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1566_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2238_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1567_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1568_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1569_termite_23_make_2d_dict();
} else {
return _bb2237_termite_23_make_2d_dict();
}
});

_k(_bb1566_termite_23_make_2d_dict = () => {
return _bb1568_termite_23_make_2d_dict();
},2,1);

_k(_bb1567_termite_23_make_2d_dict = () => {
return _bb1568_termite_23_make_2d_dict();
},2,1);

_j(_bb1569_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1570_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2237_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1570_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2235_termite_23_make_2d_dict();
} else {
return _bb1571_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2235_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2236_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1571_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1572_termite_23_make_2d_dict();
} else {
return _bb2234_termite_23_make_2d_dict();
}
});

_k(_bb2236_termite_23_make_2d_dict = () => {
return _bb1575_termite_23_make_2d_dict();
},2,1);

_j(_bb1572_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1573_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2234_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1574_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1575_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1576_termite_23_make_2d_dict();
} else {
return _bb2233_termite_23_make_2d_dict();
}
});

_k(_bb1573_termite_23_make_2d_dict = () => {
return _bb1575_termite_23_make_2d_dict();
},2,1);

_k(_bb1574_termite_23_make_2d_dict = () => {
return _bb1575_termite_23_make_2d_dict();
},2,1);

_j(_bb1576_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1577_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2233_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1577_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2231_termite_23_make_2d_dict();
} else {
return _bb1578_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2231_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2232_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1578_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1579_termite_23_make_2d_dict();
} else {
return _bb2230_termite_23_make_2d_dict();
}
});

_k(_bb2232_termite_23_make_2d_dict = () => {
return _bb1582_termite_23_make_2d_dict();
},2,1);

_j(_bb1579_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1580_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2230_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1581_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1582_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1583_termite_23_make_2d_dict();
} else {
return _bb2229_termite_23_make_2d_dict();
}
});

_k(_bb1580_termite_23_make_2d_dict = () => {
return _bb1582_termite_23_make_2d_dict();
},2,1);

_k(_bb1581_termite_23_make_2d_dict = () => {
return _bb1582_termite_23_make_2d_dict();
},2,1);

_j(_bb1583_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1584_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2229_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1584_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2227_termite_23_make_2d_dict();
} else {
return _bb1585_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2227_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2228_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1585_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1586_termite_23_make_2d_dict();
} else {
return _bb2226_termite_23_make_2d_dict();
}
});

_k(_bb2228_termite_23_make_2d_dict = () => {
return _bb1589_termite_23_make_2d_dict();
},2,1);

_j(_bb1586_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1587_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2226_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1588_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1589_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1590_termite_23_make_2d_dict();
} else {
return _bb2225_termite_23_make_2d_dict();
}
});

_k(_bb1587_termite_23_make_2d_dict = () => {
return _bb1589_termite_23_make_2d_dict();
},2,1);

_k(_bb1588_termite_23_make_2d_dict = () => {
return _bb1589_termite_23_make_2d_dict();
},2,1);

_j(_bb1590_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1591_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2225_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1591_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2223_termite_23_make_2d_dict();
} else {
return _bb1592_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2223_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2224_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1592_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1593_termite_23_make_2d_dict();
} else {
return _bb2222_termite_23_make_2d_dict();
}
});

_k(_bb2224_termite_23_make_2d_dict = () => {
return _bb1596_termite_23_make_2d_dict();
},2,1);

_j(_bb1593_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1594_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2222_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1595_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1596_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1597_termite_23_make_2d_dict();
} else {
return _bb2221_termite_23_make_2d_dict();
}
});

_k(_bb1594_termite_23_make_2d_dict = () => {
return _bb1596_termite_23_make_2d_dict();
},2,1);

_k(_bb1595_termite_23_make_2d_dict = () => {
return _bb1596_termite_23_make_2d_dict();
},2,1);

_j(_bb1597_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1598_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2221_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1598_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2219_termite_23_make_2d_dict();
} else {
return _bb1599_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2219_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2220_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1599_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1600_termite_23_make_2d_dict();
} else {
return _bb2218_termite_23_make_2d_dict();
}
});

_k(_bb2220_termite_23_make_2d_dict = () => {
return _bb1603_termite_23_make_2d_dict();
},2,1);

_j(_bb1600_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1601_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2218_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1602_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1603_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1604_termite_23_make_2d_dict();
} else {
return _bb2217_termite_23_make_2d_dict();
}
});

_k(_bb1601_termite_23_make_2d_dict = () => {
return _bb1603_termite_23_make_2d_dict();
},2,1);

_k(_bb1602_termite_23_make_2d_dict = () => {
return _bb1603_termite_23_make_2d_dict();
},2,1);

_j(_bb1604_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1605_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2217_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1605_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2215_termite_23_make_2d_dict();
} else {
return _bb1606_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2215_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2216_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1606_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1607_termite_23_make_2d_dict();
} else {
return _bb2214_termite_23_make_2d_dict();
}
});

_k(_bb2216_termite_23_make_2d_dict = () => {
return _bb1610_termite_23_make_2d_dict();
},2,1);

_j(_bb1607_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1608_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2214_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1609_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1610_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1611_termite_23_make_2d_dict();
} else {
return _bb2213_termite_23_make_2d_dict();
}
});

_k(_bb1608_termite_23_make_2d_dict = () => {
return _bb1610_termite_23_make_2d_dict();
},2,1);

_k(_bb1609_termite_23_make_2d_dict = () => {
return _bb1610_termite_23_make_2d_dict();
},2,1);

_j(_bb1611_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1612_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2213_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1612_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2211_termite_23_make_2d_dict();
} else {
return _bb1613_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2211_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2212_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1613_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1614_termite_23_make_2d_dict();
} else {
return _bb2210_termite_23_make_2d_dict();
}
});

_k(_bb2212_termite_23_make_2d_dict = () => {
return _bb1617_termite_23_make_2d_dict();
},2,1);

_j(_bb1614_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1615_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2210_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1616_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1617_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1618_termite_23_make_2d_dict();
} else {
return _bb2209_termite_23_make_2d_dict();
}
});

_k(_bb1615_termite_23_make_2d_dict = () => {
return _bb1617_termite_23_make_2d_dict();
},2,1);

_k(_bb1616_termite_23_make_2d_dict = () => {
return _bb1617_termite_23_make_2d_dict();
},2,1);

_j(_bb1618_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1619_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2209_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1619_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2207_termite_23_make_2d_dict();
} else {
return _bb1620_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2207_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2208_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1620_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1621_termite_23_make_2d_dict();
} else {
return _bb2206_termite_23_make_2d_dict();
}
});

_k(_bb2208_termite_23_make_2d_dict = () => {
return _bb1624_termite_23_make_2d_dict();
},2,1);

_j(_bb1621_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1622_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2206_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1623_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1624_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1625_termite_23_make_2d_dict();
} else {
return _bb2205_termite_23_make_2d_dict();
}
});

_k(_bb1622_termite_23_make_2d_dict = () => {
return _bb1624_termite_23_make_2d_dict();
},2,1);

_k(_bb1623_termite_23_make_2d_dict = () => {
return _bb1624_termite_23_make_2d_dict();
},2,1);

_j(_bb1625_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1626_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2205_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1626_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2203_termite_23_make_2d_dict();
} else {
return _bb1627_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2203_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2204_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1627_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1628_termite_23_make_2d_dict();
} else {
return _bb2202_termite_23_make_2d_dict();
}
});

_k(_bb2204_termite_23_make_2d_dict = () => {
return _bb1631_termite_23_make_2d_dict();
},2,1);

_j(_bb1628_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1629_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2202_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1630_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1631_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1632_termite_23_make_2d_dict();
} else {
return _bb2201_termite_23_make_2d_dict();
}
});

_k(_bb1629_termite_23_make_2d_dict = () => {
return _bb1631_termite_23_make_2d_dict();
},2,1);

_k(_bb1630_termite_23_make_2d_dict = () => {
return _bb1631_termite_23_make_2d_dict();
},2,1);

_j(_bb1632_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1633_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2201_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1633_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2199_termite_23_make_2d_dict();
} else {
return _bb1634_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2199_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2200_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1634_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1635_termite_23_make_2d_dict();
} else {
return _bb2198_termite_23_make_2d_dict();
}
});

_k(_bb2200_termite_23_make_2d_dict = () => {
return _bb1638_termite_23_make_2d_dict();
},2,1);

_j(_bb1635_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1636_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2198_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1637_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1638_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1639_termite_23_make_2d_dict();
} else {
return _bb2197_termite_23_make_2d_dict();
}
});

_k(_bb1636_termite_23_make_2d_dict = () => {
return _bb1638_termite_23_make_2d_dict();
},2,1);

_k(_bb1637_termite_23_make_2d_dict = () => {
return _bb1638_termite_23_make_2d_dict();
},2,1);

_j(_bb1639_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1640_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2197_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1640_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2195_termite_23_make_2d_dict();
} else {
return _bb1641_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2195_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2196_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1641_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1642_termite_23_make_2d_dict();
} else {
return _bb2194_termite_23_make_2d_dict();
}
});

_k(_bb2196_termite_23_make_2d_dict = () => {
return _bb1645_termite_23_make_2d_dict();
},2,1);

_j(_bb1642_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1643_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2194_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1644_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1645_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1646_termite_23_make_2d_dict();
} else {
return _bb2193_termite_23_make_2d_dict();
}
});

_k(_bb1643_termite_23_make_2d_dict = () => {
return _bb1645_termite_23_make_2d_dict();
},2,1);

_k(_bb1644_termite_23_make_2d_dict = () => {
return _bb1645_termite_23_make_2d_dict();
},2,1);

_j(_bb1646_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1647_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2193_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1647_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2191_termite_23_make_2d_dict();
} else {
return _bb1648_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2191_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2192_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1648_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1649_termite_23_make_2d_dict();
} else {
return _bb2190_termite_23_make_2d_dict();
}
});

_k(_bb2192_termite_23_make_2d_dict = () => {
return _bb1652_termite_23_make_2d_dict();
},2,1);

_j(_bb1649_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1650_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2190_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1651_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1652_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1653_termite_23_make_2d_dict();
} else {
return _bb2189_termite_23_make_2d_dict();
}
});

_k(_bb1650_termite_23_make_2d_dict = () => {
return _bb1652_termite_23_make_2d_dict();
},2,1);

_k(_bb1651_termite_23_make_2d_dict = () => {
return _bb1652_termite_23_make_2d_dict();
},2,1);

_j(_bb1653_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1654_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2189_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1654_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2187_termite_23_make_2d_dict();
} else {
return _bb1655_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2187_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2188_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1655_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1656_termite_23_make_2d_dict();
} else {
return _bb2186_termite_23_make_2d_dict();
}
});

_k(_bb2188_termite_23_make_2d_dict = () => {
return _bb1659_termite_23_make_2d_dict();
},2,1);

_j(_bb1656_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1657_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2186_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1658_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1659_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1660_termite_23_make_2d_dict();
} else {
return _bb2185_termite_23_make_2d_dict();
}
});

_k(_bb1657_termite_23_make_2d_dict = () => {
return _bb1659_termite_23_make_2d_dict();
},2,1);

_k(_bb1658_termite_23_make_2d_dict = () => {
return _bb1659_termite_23_make_2d_dict();
},2,1);

_j(_bb1660_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1661_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2185_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1661_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2183_termite_23_make_2d_dict();
} else {
return _bb1662_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2183_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2184_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1662_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1663_termite_23_make_2d_dict();
} else {
return _bb2182_termite_23_make_2d_dict();
}
});

_k(_bb2184_termite_23_make_2d_dict = () => {
return _bb1666_termite_23_make_2d_dict();
},2,1);

_j(_bb1663_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1664_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2182_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1665_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1666_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1667_termite_23_make_2d_dict();
} else {
return _bb2181_termite_23_make_2d_dict();
}
});

_k(_bb1664_termite_23_make_2d_dict = () => {
return _bb1666_termite_23_make_2d_dict();
},2,1);

_k(_bb1665_termite_23_make_2d_dict = () => {
return _bb1666_termite_23_make_2d_dict();
},2,1);

_j(_bb1667_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1668_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2181_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1668_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2179_termite_23_make_2d_dict();
} else {
return _bb1669_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2179_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2180_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1669_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1670_termite_23_make_2d_dict();
} else {
return _bb2178_termite_23_make_2d_dict();
}
});

_k(_bb2180_termite_23_make_2d_dict = () => {
return _bb1673_termite_23_make_2d_dict();
},2,1);

_j(_bb1670_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1671_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2178_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1672_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1673_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1674_termite_23_make_2d_dict();
} else {
return _bb2177_termite_23_make_2d_dict();
}
});

_k(_bb1671_termite_23_make_2d_dict = () => {
return _bb1673_termite_23_make_2d_dict();
},2,1);

_k(_bb1672_termite_23_make_2d_dict = () => {
return _bb1673_termite_23_make_2d_dict();
},2,1);

_j(_bb1674_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1675_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2177_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1675_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2175_termite_23_make_2d_dict();
} else {
return _bb1676_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2175_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2176_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1676_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1677_termite_23_make_2d_dict();
} else {
return _bb2174_termite_23_make_2d_dict();
}
});

_k(_bb2176_termite_23_make_2d_dict = () => {
return _bb1680_termite_23_make_2d_dict();
},2,1);

_j(_bb1677_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1678_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2174_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1679_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1680_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1681_termite_23_make_2d_dict();
} else {
return _bb2173_termite_23_make_2d_dict();
}
});

_k(_bb1678_termite_23_make_2d_dict = () => {
return _bb1680_termite_23_make_2d_dict();
},2,1);

_k(_bb1679_termite_23_make_2d_dict = () => {
return _bb1680_termite_23_make_2d_dict();
},2,1);

_j(_bb1681_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1682_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2173_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1682_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2171_termite_23_make_2d_dict();
} else {
return _bb1683_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2171_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2172_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1683_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1684_termite_23_make_2d_dict();
} else {
return _bb2170_termite_23_make_2d_dict();
}
});

_k(_bb2172_termite_23_make_2d_dict = () => {
return _bb1687_termite_23_make_2d_dict();
},2,1);

_j(_bb1684_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1685_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2170_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1686_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1687_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1688_termite_23_make_2d_dict();
} else {
return _bb2169_termite_23_make_2d_dict();
}
});

_k(_bb1685_termite_23_make_2d_dict = () => {
return _bb1687_termite_23_make_2d_dict();
},2,1);

_k(_bb1686_termite_23_make_2d_dict = () => {
return _bb1687_termite_23_make_2d_dict();
},2,1);

_j(_bb1688_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1689_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2169_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1689_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2167_termite_23_make_2d_dict();
} else {
return _bb1690_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2167_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2168_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1690_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1691_termite_23_make_2d_dict();
} else {
return _bb2166_termite_23_make_2d_dict();
}
});

_k(_bb2168_termite_23_make_2d_dict = () => {
return _bb1694_termite_23_make_2d_dict();
},2,1);

_j(_bb1691_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1692_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2166_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1693_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1694_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1695_termite_23_make_2d_dict();
} else {
return _bb2165_termite_23_make_2d_dict();
}
});

_k(_bb1692_termite_23_make_2d_dict = () => {
return _bb1694_termite_23_make_2d_dict();
},2,1);

_k(_bb1693_termite_23_make_2d_dict = () => {
return _bb1694_termite_23_make_2d_dict();
},2,1);

_j(_bb1695_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1696_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2165_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1696_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2163_termite_23_make_2d_dict();
} else {
return _bb1697_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2163_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2164_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1697_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1698_termite_23_make_2d_dict();
} else {
return _bb2162_termite_23_make_2d_dict();
}
});

_k(_bb2164_termite_23_make_2d_dict = () => {
return _bb1701_termite_23_make_2d_dict();
},2,1);

_j(_bb1698_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1699_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2162_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1700_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1701_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1702_termite_23_make_2d_dict();
} else {
return _bb2161_termite_23_make_2d_dict();
}
});

_k(_bb1699_termite_23_make_2d_dict = () => {
return _bb1701_termite_23_make_2d_dict();
},2,1);

_k(_bb1700_termite_23_make_2d_dict = () => {
return _bb1701_termite_23_make_2d_dict();
},2,1);

_j(_bb1702_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1703_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2161_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1703_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2159_termite_23_make_2d_dict();
} else {
return _bb1704_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2159_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2160_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1704_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1705_termite_23_make_2d_dict();
} else {
return _bb2158_termite_23_make_2d_dict();
}
});

_k(_bb2160_termite_23_make_2d_dict = () => {
return _bb1708_termite_23_make_2d_dict();
},2,1);

_j(_bb1705_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1706_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2158_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1707_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1708_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1709_termite_23_make_2d_dict();
} else {
return _bb2157_termite_23_make_2d_dict();
}
});

_k(_bb1706_termite_23_make_2d_dict = () => {
return _bb1708_termite_23_make_2d_dict();
},2,1);

_k(_bb1707_termite_23_make_2d_dict = () => {
return _bb1708_termite_23_make_2d_dict();
},2,1);

_j(_bb1709_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1710_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2157_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1710_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2155_termite_23_make_2d_dict();
} else {
return _bb1711_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2155_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2156_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1711_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1712_termite_23_make_2d_dict();
} else {
return _bb2154_termite_23_make_2d_dict();
}
});

_k(_bb2156_termite_23_make_2d_dict = () => {
return _bb1715_termite_23_make_2d_dict();
},2,1);

_j(_bb1712_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1713_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2154_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1714_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1715_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1716_termite_23_make_2d_dict();
} else {
return _bb2153_termite_23_make_2d_dict();
}
});

_k(_bb1713_termite_23_make_2d_dict = () => {
return _bb1715_termite_23_make_2d_dict();
},2,1);

_k(_bb1714_termite_23_make_2d_dict = () => {
return _bb1715_termite_23_make_2d_dict();
},2,1);

_j(_bb1716_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1717_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2153_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1717_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2151_termite_23_make_2d_dict();
} else {
return _bb1718_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2151_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2152_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1718_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1719_termite_23_make_2d_dict();
} else {
return _bb2150_termite_23_make_2d_dict();
}
});

_k(_bb2152_termite_23_make_2d_dict = () => {
return _bb1722_termite_23_make_2d_dict();
},2,1);

_j(_bb1719_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1720_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2150_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1721_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1722_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1723_termite_23_make_2d_dict();
} else {
return _bb2149_termite_23_make_2d_dict();
}
});

_k(_bb1720_termite_23_make_2d_dict = () => {
return _bb1722_termite_23_make_2d_dict();
},2,1);

_k(_bb1721_termite_23_make_2d_dict = () => {
return _bb1722_termite_23_make_2d_dict();
},2,1);

_j(_bb1723_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1724_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2149_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1724_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2147_termite_23_make_2d_dict();
} else {
return _bb1725_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2147_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2148_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1725_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1726_termite_23_make_2d_dict();
} else {
return _bb2146_termite_23_make_2d_dict();
}
});

_k(_bb2148_termite_23_make_2d_dict = () => {
return _bb1729_termite_23_make_2d_dict();
},2,1);

_j(_bb1726_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1727_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2146_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1728_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1729_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1730_termite_23_make_2d_dict();
} else {
return _bb2145_termite_23_make_2d_dict();
}
});

_k(_bb1727_termite_23_make_2d_dict = () => {
return _bb1729_termite_23_make_2d_dict();
},2,1);

_k(_bb1728_termite_23_make_2d_dict = () => {
return _bb1729_termite_23_make_2d_dict();
},2,1);

_j(_bb1730_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1731_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2145_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1731_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2143_termite_23_make_2d_dict();
} else {
return _bb1732_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2143_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2144_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1732_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1733_termite_23_make_2d_dict();
} else {
return _bb2142_termite_23_make_2d_dict();
}
});

_k(_bb2144_termite_23_make_2d_dict = () => {
return _bb1736_termite_23_make_2d_dict();
},2,1);

_j(_bb1733_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1734_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2142_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1735_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1736_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1737_termite_23_make_2d_dict();
} else {
return _bb2141_termite_23_make_2d_dict();
}
});

_k(_bb1734_termite_23_make_2d_dict = () => {
return _bb1736_termite_23_make_2d_dict();
},2,1);

_k(_bb1735_termite_23_make_2d_dict = () => {
return _bb1736_termite_23_make_2d_dict();
},2,1);

_j(_bb1737_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1738_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2141_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1738_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2139_termite_23_make_2d_dict();
} else {
return _bb1739_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2139_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2140_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1739_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1740_termite_23_make_2d_dict();
} else {
return _bb2138_termite_23_make_2d_dict();
}
});

_k(_bb2140_termite_23_make_2d_dict = () => {
return _bb1743_termite_23_make_2d_dict();
},2,1);

_j(_bb1740_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1741_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2138_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1742_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1743_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1744_termite_23_make_2d_dict();
} else {
return _bb2137_termite_23_make_2d_dict();
}
});

_k(_bb1741_termite_23_make_2d_dict = () => {
return _bb1743_termite_23_make_2d_dict();
},2,1);

_k(_bb1742_termite_23_make_2d_dict = () => {
return _bb1743_termite_23_make_2d_dict();
},2,1);

_j(_bb1744_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1745_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2137_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1745_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2135_termite_23_make_2d_dict();
} else {
return _bb1746_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2135_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2136_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1746_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1747_termite_23_make_2d_dict();
} else {
return _bb2134_termite_23_make_2d_dict();
}
});

_k(_bb2136_termite_23_make_2d_dict = () => {
return _bb1750_termite_23_make_2d_dict();
},2,1);

_j(_bb1747_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1748_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2134_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1749_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1750_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1751_termite_23_make_2d_dict();
} else {
return _bb2133_termite_23_make_2d_dict();
}
});

_k(_bb1748_termite_23_make_2d_dict = () => {
return _bb1750_termite_23_make_2d_dict();
},2,1);

_k(_bb1749_termite_23_make_2d_dict = () => {
return _bb1750_termite_23_make_2d_dict();
},2,1);

_j(_bb1751_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1752_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2133_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1752_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2131_termite_23_make_2d_dict();
} else {
return _bb1753_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2131_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2132_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1753_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1754_termite_23_make_2d_dict();
} else {
return _bb2130_termite_23_make_2d_dict();
}
});

_k(_bb2132_termite_23_make_2d_dict = () => {
return _bb1757_termite_23_make_2d_dict();
},2,1);

_j(_bb1754_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1755_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2130_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1756_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1757_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1758_termite_23_make_2d_dict();
} else {
return _bb2129_termite_23_make_2d_dict();
}
});

_k(_bb1755_termite_23_make_2d_dict = () => {
return _bb1757_termite_23_make_2d_dict();
},2,1);

_k(_bb1756_termite_23_make_2d_dict = () => {
return _bb1757_termite_23_make_2d_dict();
},2,1);

_j(_bb1758_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1759_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2129_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1759_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2127_termite_23_make_2d_dict();
} else {
return _bb1760_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2127_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2128_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1760_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1761_termite_23_make_2d_dict();
} else {
return _bb2126_termite_23_make_2d_dict();
}
});

_k(_bb2128_termite_23_make_2d_dict = () => {
return _bb1764_termite_23_make_2d_dict();
},2,1);

_j(_bb1761_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1762_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2126_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1763_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1764_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1765_termite_23_make_2d_dict();
} else {
return _bb2125_termite_23_make_2d_dict();
}
});

_k(_bb1762_termite_23_make_2d_dict = () => {
return _bb1764_termite_23_make_2d_dict();
},2,1);

_k(_bb1763_termite_23_make_2d_dict = () => {
return _bb1764_termite_23_make_2d_dict();
},2,1);

_j(_bb1765_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1766_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2125_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1766_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2123_termite_23_make_2d_dict();
} else {
return _bb1767_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2123_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2124_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1767_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1768_termite_23_make_2d_dict();
} else {
return _bb2122_termite_23_make_2d_dict();
}
});

_k(_bb2124_termite_23_make_2d_dict = () => {
return _bb1771_termite_23_make_2d_dict();
},2,1);

_j(_bb1768_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1769_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2122_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1770_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1771_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1772_termite_23_make_2d_dict();
} else {
return _bb2121_termite_23_make_2d_dict();
}
});

_k(_bb1769_termite_23_make_2d_dict = () => {
return _bb1771_termite_23_make_2d_dict();
},2,1);

_k(_bb1770_termite_23_make_2d_dict = () => {
return _bb1771_termite_23_make_2d_dict();
},2,1);

_j(_bb1772_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1773_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2121_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1773_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2119_termite_23_make_2d_dict();
} else {
return _bb1774_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2119_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2120_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1774_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1775_termite_23_make_2d_dict();
} else {
return _bb2118_termite_23_make_2d_dict();
}
});

_k(_bb2120_termite_23_make_2d_dict = () => {
return _bb1778_termite_23_make_2d_dict();
},2,1);

_j(_bb1775_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1776_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2118_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1777_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1778_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1779_termite_23_make_2d_dict();
} else {
return _bb2117_termite_23_make_2d_dict();
}
});

_k(_bb1776_termite_23_make_2d_dict = () => {
return _bb1778_termite_23_make_2d_dict();
},2,1);

_k(_bb1777_termite_23_make_2d_dict = () => {
return _bb1778_termite_23_make_2d_dict();
},2,1);

_j(_bb1779_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1780_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2117_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1780_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2115_termite_23_make_2d_dict();
} else {
return _bb1781_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2115_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2116_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1781_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1782_termite_23_make_2d_dict();
} else {
return _bb2114_termite_23_make_2d_dict();
}
});

_k(_bb2116_termite_23_make_2d_dict = () => {
return _bb1785_termite_23_make_2d_dict();
},2,1);

_j(_bb1782_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1783_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2114_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1784_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1785_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1786_termite_23_make_2d_dict();
} else {
return _bb2113_termite_23_make_2d_dict();
}
});

_k(_bb1783_termite_23_make_2d_dict = () => {
return _bb1785_termite_23_make_2d_dict();
},2,1);

_k(_bb1784_termite_23_make_2d_dict = () => {
return _bb1785_termite_23_make_2d_dict();
},2,1);

_j(_bb1786_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1787_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2113_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1787_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2111_termite_23_make_2d_dict();
} else {
return _bb1788_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2111_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2112_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1788_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1789_termite_23_make_2d_dict();
} else {
return _bb2110_termite_23_make_2d_dict();
}
});

_k(_bb2112_termite_23_make_2d_dict = () => {
return _bb1792_termite_23_make_2d_dict();
},2,1);

_j(_bb1789_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1790_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2110_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1791_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1792_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1793_termite_23_make_2d_dict();
} else {
return _bb2109_termite_23_make_2d_dict();
}
});

_k(_bb1790_termite_23_make_2d_dict = () => {
return _bb1792_termite_23_make_2d_dict();
},2,1);

_k(_bb1791_termite_23_make_2d_dict = () => {
return _bb1792_termite_23_make_2d_dict();
},2,1);

_j(_bb1793_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1794_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2109_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1794_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2107_termite_23_make_2d_dict();
} else {
return _bb1795_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2107_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2108_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1795_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1796_termite_23_make_2d_dict();
} else {
return _bb2106_termite_23_make_2d_dict();
}
});

_k(_bb2108_termite_23_make_2d_dict = () => {
return _bb1799_termite_23_make_2d_dict();
},2,1);

_j(_bb1796_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1797_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2106_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1798_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1799_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1800_termite_23_make_2d_dict();
} else {
return _bb2105_termite_23_make_2d_dict();
}
});

_k(_bb1797_termite_23_make_2d_dict = () => {
return _bb1799_termite_23_make_2d_dict();
},2,1);

_k(_bb1798_termite_23_make_2d_dict = () => {
return _bb1799_termite_23_make_2d_dict();
},2,1);

_j(_bb1800_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1801_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2105_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1801_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2103_termite_23_make_2d_dict();
} else {
return _bb1802_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2103_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2104_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1802_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1803_termite_23_make_2d_dict();
} else {
return _bb2102_termite_23_make_2d_dict();
}
});

_k(_bb2104_termite_23_make_2d_dict = () => {
return _bb1806_termite_23_make_2d_dict();
},2,1);

_j(_bb1803_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1804_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2102_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1805_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1806_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1807_termite_23_make_2d_dict();
} else {
return _bb2101_termite_23_make_2d_dict();
}
});

_k(_bb1804_termite_23_make_2d_dict = () => {
return _bb1806_termite_23_make_2d_dict();
},2,1);

_k(_bb1805_termite_23_make_2d_dict = () => {
return _bb1806_termite_23_make_2d_dict();
},2,1);

_j(_bb1807_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1808_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2101_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1808_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2099_termite_23_make_2d_dict();
} else {
return _bb1809_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2099_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2100_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1809_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1810_termite_23_make_2d_dict();
} else {
return _bb2098_termite_23_make_2d_dict();
}
});

_k(_bb2100_termite_23_make_2d_dict = () => {
return _bb1813_termite_23_make_2d_dict();
},2,1);

_j(_bb1810_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1811_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2098_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1812_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1813_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1814_termite_23_make_2d_dict();
} else {
return _bb2097_termite_23_make_2d_dict();
}
});

_k(_bb1811_termite_23_make_2d_dict = () => {
return _bb1813_termite_23_make_2d_dict();
},2,1);

_k(_bb1812_termite_23_make_2d_dict = () => {
return _bb1813_termite_23_make_2d_dict();
},2,1);

_j(_bb1814_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1815_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2097_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1815_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2095_termite_23_make_2d_dict();
} else {
return _bb1816_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2095_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2096_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1816_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1817_termite_23_make_2d_dict();
} else {
return _bb2094_termite_23_make_2d_dict();
}
});

_k(_bb2096_termite_23_make_2d_dict = () => {
return _bb1820_termite_23_make_2d_dict();
},2,1);

_j(_bb1817_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1818_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2094_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1819_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1820_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1821_termite_23_make_2d_dict();
} else {
return _bb2093_termite_23_make_2d_dict();
}
});

_k(_bb1818_termite_23_make_2d_dict = () => {
return _bb1820_termite_23_make_2d_dict();
},2,1);

_k(_bb1819_termite_23_make_2d_dict = () => {
return _bb1820_termite_23_make_2d_dict();
},2,1);

_j(_bb1821_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1822_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2093_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1822_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2091_termite_23_make_2d_dict();
} else {
return _bb1823_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2091_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2092_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1823_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1824_termite_23_make_2d_dict();
} else {
return _bb2090_termite_23_make_2d_dict();
}
});

_k(_bb2092_termite_23_make_2d_dict = () => {
return _bb1827_termite_23_make_2d_dict();
},2,1);

_j(_bb1824_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1825_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2090_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1826_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1827_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1828_termite_23_make_2d_dict();
} else {
return _bb2089_termite_23_make_2d_dict();
}
});

_k(_bb1825_termite_23_make_2d_dict = () => {
return _bb1827_termite_23_make_2d_dict();
},2,1);

_k(_bb1826_termite_23_make_2d_dict = () => {
return _bb1827_termite_23_make_2d_dict();
},2,1);

_j(_bb1828_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1829_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2089_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1829_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2087_termite_23_make_2d_dict();
} else {
return _bb1830_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2087_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2088_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1830_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1831_termite_23_make_2d_dict();
} else {
return _bb2086_termite_23_make_2d_dict();
}
});

_k(_bb2088_termite_23_make_2d_dict = () => {
return _bb1834_termite_23_make_2d_dict();
},2,1);

_j(_bb1831_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1832_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2086_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1833_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1834_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1835_termite_23_make_2d_dict();
} else {
return _bb2085_termite_23_make_2d_dict();
}
});

_k(_bb1832_termite_23_make_2d_dict = () => {
return _bb1834_termite_23_make_2d_dict();
},2,1);

_k(_bb1833_termite_23_make_2d_dict = () => {
return _bb1834_termite_23_make_2d_dict();
},2,1);

_j(_bb1835_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1836_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2085_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1836_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2083_termite_23_make_2d_dict();
} else {
return _bb1837_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2083_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2084_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1837_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1838_termite_23_make_2d_dict();
} else {
return _bb2082_termite_23_make_2d_dict();
}
});

_k(_bb2084_termite_23_make_2d_dict = () => {
return _bb1841_termite_23_make_2d_dict();
},2,1);

_j(_bb1838_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1839_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2082_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1840_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1841_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1842_termite_23_make_2d_dict();
} else {
return _bb2081_termite_23_make_2d_dict();
}
});

_k(_bb1839_termite_23_make_2d_dict = () => {
return _bb1841_termite_23_make_2d_dict();
},2,1);

_k(_bb1840_termite_23_make_2d_dict = () => {
return _bb1841_termite_23_make_2d_dict();
},2,1);

_j(_bb1842_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1843_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2081_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1843_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2079_termite_23_make_2d_dict();
} else {
return _bb1844_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2079_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2080_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1844_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1845_termite_23_make_2d_dict();
} else {
return _bb2078_termite_23_make_2d_dict();
}
});

_k(_bb2080_termite_23_make_2d_dict = () => {
return _bb1848_termite_23_make_2d_dict();
},2,1);

_j(_bb1845_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1846_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2078_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1847_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1848_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1849_termite_23_make_2d_dict();
} else {
return _bb2077_termite_23_make_2d_dict();
}
});

_k(_bb1846_termite_23_make_2d_dict = () => {
return _bb1848_termite_23_make_2d_dict();
},2,1);

_k(_bb1847_termite_23_make_2d_dict = () => {
return _bb1848_termite_23_make_2d_dict();
},2,1);

_j(_bb1849_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1850_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2077_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1850_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2075_termite_23_make_2d_dict();
} else {
return _bb1851_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2075_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2076_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1851_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1852_termite_23_make_2d_dict();
} else {
return _bb2074_termite_23_make_2d_dict();
}
});

_k(_bb2076_termite_23_make_2d_dict = () => {
return _bb1855_termite_23_make_2d_dict();
},2,1);

_j(_bb1852_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1853_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2074_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1854_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1855_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1856_termite_23_make_2d_dict();
} else {
return _bb2073_termite_23_make_2d_dict();
}
});

_k(_bb1853_termite_23_make_2d_dict = () => {
return _bb1855_termite_23_make_2d_dict();
},2,1);

_k(_bb1854_termite_23_make_2d_dict = () => {
return _bb1855_termite_23_make_2d_dict();
},2,1);

_j(_bb1856_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1857_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2073_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1857_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2071_termite_23_make_2d_dict();
} else {
return _bb1858_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2071_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2072_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1858_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1859_termite_23_make_2d_dict();
} else {
return _bb2070_termite_23_make_2d_dict();
}
});

_k(_bb2072_termite_23_make_2d_dict = () => {
return _bb1862_termite_23_make_2d_dict();
},2,1);

_j(_bb1859_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1860_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2070_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1861_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1862_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1863_termite_23_make_2d_dict();
} else {
return _bb2069_termite_23_make_2d_dict();
}
});

_k(_bb1860_termite_23_make_2d_dict = () => {
return _bb1862_termite_23_make_2d_dict();
},2,1);

_k(_bb1861_termite_23_make_2d_dict = () => {
return _bb1862_termite_23_make_2d_dict();
},2,1);

_j(_bb1863_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1864_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2069_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1864_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2067_termite_23_make_2d_dict();
} else {
return _bb1865_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2067_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2068_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1865_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1866_termite_23_make_2d_dict();
} else {
return _bb2066_termite_23_make_2d_dict();
}
});

_k(_bb2068_termite_23_make_2d_dict = () => {
return _bb1869_termite_23_make_2d_dict();
},2,1);

_j(_bb1866_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1867_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2066_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1868_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1869_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1870_termite_23_make_2d_dict();
} else {
return _bb2065_termite_23_make_2d_dict();
}
});

_k(_bb1867_termite_23_make_2d_dict = () => {
return _bb1869_termite_23_make_2d_dict();
},2,1);

_k(_bb1868_termite_23_make_2d_dict = () => {
return _bb1869_termite_23_make_2d_dict();
},2,1);

_j(_bb1870_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1871_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2065_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1871_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2063_termite_23_make_2d_dict();
} else {
return _bb1872_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2063_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2064_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1872_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1873_termite_23_make_2d_dict();
} else {
return _bb2062_termite_23_make_2d_dict();
}
});

_k(_bb2064_termite_23_make_2d_dict = () => {
return _bb1876_termite_23_make_2d_dict();
},2,1);

_j(_bb1873_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1874_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2062_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1875_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1876_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1877_termite_23_make_2d_dict();
} else {
return _bb2061_termite_23_make_2d_dict();
}
});

_k(_bb1874_termite_23_make_2d_dict = () => {
return _bb1876_termite_23_make_2d_dict();
},2,1);

_k(_bb1875_termite_23_make_2d_dict = () => {
return _bb1876_termite_23_make_2d_dict();
},2,1);

_j(_bb1877_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1878_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2061_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1878_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2059_termite_23_make_2d_dict();
} else {
return _bb1879_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2059_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2060_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1879_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1880_termite_23_make_2d_dict();
} else {
return _bb2058_termite_23_make_2d_dict();
}
});

_k(_bb2060_termite_23_make_2d_dict = () => {
return _bb1883_termite_23_make_2d_dict();
},2,1);

_j(_bb1880_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1881_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2058_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1882_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1883_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1884_termite_23_make_2d_dict();
} else {
return _bb2057_termite_23_make_2d_dict();
}
});

_k(_bb1881_termite_23_make_2d_dict = () => {
return _bb1883_termite_23_make_2d_dict();
},2,1);

_k(_bb1882_termite_23_make_2d_dict = () => {
return _bb1883_termite_23_make_2d_dict();
},2,1);

_j(_bb1884_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1885_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2057_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1885_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2055_termite_23_make_2d_dict();
} else {
return _bb1886_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2055_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2056_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1886_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1887_termite_23_make_2d_dict();
} else {
return _bb2054_termite_23_make_2d_dict();
}
});

_k(_bb2056_termite_23_make_2d_dict = () => {
return _bb1890_termite_23_make_2d_dict();
},2,1);

_j(_bb1887_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1888_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2054_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1889_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1890_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1891_termite_23_make_2d_dict();
} else {
return _bb2053_termite_23_make_2d_dict();
}
});

_k(_bb1888_termite_23_make_2d_dict = () => {
return _bb1890_termite_23_make_2d_dict();
},2,1);

_k(_bb1889_termite_23_make_2d_dict = () => {
return _bb1890_termite_23_make_2d_dict();
},2,1);

_j(_bb1891_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1892_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2053_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1892_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2051_termite_23_make_2d_dict();
} else {
return _bb1893_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2051_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2052_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1893_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1894_termite_23_make_2d_dict();
} else {
return _bb2050_termite_23_make_2d_dict();
}
});

_k(_bb2052_termite_23_make_2d_dict = () => {
return _bb1897_termite_23_make_2d_dict();
},2,1);

_j(_bb1894_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1895_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2050_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1896_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1897_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1898_termite_23_make_2d_dict();
} else {
return _bb2049_termite_23_make_2d_dict();
}
});

_k(_bb1895_termite_23_make_2d_dict = () => {
return _bb1897_termite_23_make_2d_dict();
},2,1);

_k(_bb1896_termite_23_make_2d_dict = () => {
return _bb1897_termite_23_make_2d_dict();
},2,1);

_j(_bb1898_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1899_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2049_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1899_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2047_termite_23_make_2d_dict();
} else {
return _bb1900_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2047_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2048_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1900_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1901_termite_23_make_2d_dict();
} else {
return _bb2046_termite_23_make_2d_dict();
}
});

_k(_bb2048_termite_23_make_2d_dict = () => {
return _bb1904_termite_23_make_2d_dict();
},2,1);

_j(_bb1901_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1902_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2046_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1903_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1904_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1905_termite_23_make_2d_dict();
} else {
return _bb2045_termite_23_make_2d_dict();
}
});

_k(_bb1902_termite_23_make_2d_dict = () => {
return _bb1904_termite_23_make_2d_dict();
},2,1);

_k(_bb1903_termite_23_make_2d_dict = () => {
return _bb1904_termite_23_make_2d_dict();
},2,1);

_j(_bb1905_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1906_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2045_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1906_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2043_termite_23_make_2d_dict();
} else {
return _bb1907_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2043_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2044_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1907_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1908_termite_23_make_2d_dict();
} else {
return _bb2042_termite_23_make_2d_dict();
}
});

_k(_bb2044_termite_23_make_2d_dict = () => {
return _bb1911_termite_23_make_2d_dict();
},2,1);

_j(_bb1908_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1909_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2042_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1910_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1911_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1912_termite_23_make_2d_dict();
} else {
return _bb2041_termite_23_make_2d_dict();
}
});

_k(_bb1909_termite_23_make_2d_dict = () => {
return _bb1911_termite_23_make_2d_dict();
},2,1);

_k(_bb1910_termite_23_make_2d_dict = () => {
return _bb1911_termite_23_make_2d_dict();
},2,1);

_j(_bb1912_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1913_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2041_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1913_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2039_termite_23_make_2d_dict();
} else {
return _bb1914_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2039_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2040_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1914_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1915_termite_23_make_2d_dict();
} else {
return _bb2038_termite_23_make_2d_dict();
}
});

_k(_bb2040_termite_23_make_2d_dict = () => {
return _bb1918_termite_23_make_2d_dict();
},2,1);

_j(_bb1915_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1916_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2038_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1917_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1918_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1919_termite_23_make_2d_dict();
} else {
return _bb2037_termite_23_make_2d_dict();
}
});

_k(_bb1916_termite_23_make_2d_dict = () => {
return _bb1918_termite_23_make_2d_dict();
},2,1);

_k(_bb1917_termite_23_make_2d_dict = () => {
return _bb1918_termite_23_make_2d_dict();
},2,1);

_j(_bb1919_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1920_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2037_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1920_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2035_termite_23_make_2d_dict();
} else {
return _bb1921_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2035_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2036_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1921_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1922_termite_23_make_2d_dict();
} else {
return _bb2034_termite_23_make_2d_dict();
}
});

_k(_bb2036_termite_23_make_2d_dict = () => {
return _bb1925_termite_23_make_2d_dict();
},2,1);

_j(_bb1922_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1923_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2034_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1924_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1925_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1926_termite_23_make_2d_dict();
} else {
return _bb2033_termite_23_make_2d_dict();
}
});

_k(_bb1923_termite_23_make_2d_dict = () => {
return _bb1925_termite_23_make_2d_dict();
},2,1);

_k(_bb1924_termite_23_make_2d_dict = () => {
return _bb1925_termite_23_make_2d_dict();
},2,1);

_j(_bb1926_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1927_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2033_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1927_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2031_termite_23_make_2d_dict();
} else {
return _bb1928_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2031_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2032_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1928_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1929_termite_23_make_2d_dict();
} else {
return _bb2030_termite_23_make_2d_dict();
}
});

_k(_bb2032_termite_23_make_2d_dict = () => {
return _bb1932_termite_23_make_2d_dict();
},2,1);

_j(_bb1929_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1930_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2030_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1931_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1932_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1933_termite_23_make_2d_dict();
} else {
return _bb2029_termite_23_make_2d_dict();
}
});

_k(_bb1930_termite_23_make_2d_dict = () => {
return _bb1932_termite_23_make_2d_dict();
},2,1);

_k(_bb1931_termite_23_make_2d_dict = () => {
return _bb1932_termite_23_make_2d_dict();
},2,1);

_j(_bb1933_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1934_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2029_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1934_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2027_termite_23_make_2d_dict();
} else {
return _bb1935_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2027_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2028_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1935_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1936_termite_23_make_2d_dict();
} else {
return _bb2026_termite_23_make_2d_dict();
}
});

_k(_bb2028_termite_23_make_2d_dict = () => {
return _bb1939_termite_23_make_2d_dict();
},2,1);

_j(_bb1936_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1937_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2026_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1938_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1939_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1940_termite_23_make_2d_dict();
} else {
return _bb2025_termite_23_make_2d_dict();
}
});

_k(_bb1937_termite_23_make_2d_dict = () => {
return _bb1939_termite_23_make_2d_dict();
},2,1);

_k(_bb1938_termite_23_make_2d_dict = () => {
return _bb1939_termite_23_make_2d_dict();
},2,1);

_j(_bb1940_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1941_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2025_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1941_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2023_termite_23_make_2d_dict();
} else {
return _bb1942_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2023_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2024_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1942_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1943_termite_23_make_2d_dict();
} else {
return _bb2022_termite_23_make_2d_dict();
}
});

_k(_bb2024_termite_23_make_2d_dict = () => {
return _bb1946_termite_23_make_2d_dict();
},2,1);

_j(_bb1943_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1944_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2022_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1945_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1946_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1947_termite_23_make_2d_dict();
} else {
return _bb2021_termite_23_make_2d_dict();
}
});

_k(_bb1944_termite_23_make_2d_dict = () => {
return _bb1946_termite_23_make_2d_dict();
},2,1);

_k(_bb1945_termite_23_make_2d_dict = () => {
return _bb1946_termite_23_make_2d_dict();
},2,1);

_j(_bb1947_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1948_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2021_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1948_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2019_termite_23_make_2d_dict();
} else {
return _bb1949_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2019_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2020_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1949_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1950_termite_23_make_2d_dict();
} else {
return _bb2018_termite_23_make_2d_dict();
}
});

_k(_bb2020_termite_23_make_2d_dict = () => {
return _bb1953_termite_23_make_2d_dict();
},2,1);

_j(_bb1950_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1951_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2018_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1952_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1953_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1954_termite_23_make_2d_dict();
} else {
return _bb2017_termite_23_make_2d_dict();
}
});

_k(_bb1951_termite_23_make_2d_dict = () => {
return _bb1953_termite_23_make_2d_dict();
},2,1);

_k(_bb1952_termite_23_make_2d_dict = () => {
return _bb1953_termite_23_make_2d_dict();
},2,1);

_j(_bb1954_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1955_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2017_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1955_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2015_termite_23_make_2d_dict();
} else {
return _bb1956_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2015_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2016_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1956_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1957_termite_23_make_2d_dict();
} else {
return _bb2014_termite_23_make_2d_dict();
}
});

_k(_bb2016_termite_23_make_2d_dict = () => {
return _bb1960_termite_23_make_2d_dict();
},2,1);

_j(_bb1957_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1958_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2014_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1959_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1960_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1961_termite_23_make_2d_dict();
} else {
return _bb2013_termite_23_make_2d_dict();
}
});

_k(_bb1958_termite_23_make_2d_dict = () => {
return _bb1960_termite_23_make_2d_dict();
},2,1);

_k(_bb1959_termite_23_make_2d_dict = () => {
return _bb1960_termite_23_make_2d_dict();
},2,1);

_j(_bb1961_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1962_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2013_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1962_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2011_termite_23_make_2d_dict();
} else {
return _bb1963_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2011_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2012_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1963_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1964_termite_23_make_2d_dict();
} else {
return _bb2010_termite_23_make_2d_dict();
}
});

_k(_bb2012_termite_23_make_2d_dict = () => {
return _bb1967_termite_23_make_2d_dict();
},2,1);

_j(_bb1964_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1965_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2010_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1966_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1967_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1968_termite_23_make_2d_dict();
} else {
return _bb2009_termite_23_make_2d_dict();
}
});

_k(_bb1965_termite_23_make_2d_dict = () => {
return _bb1967_termite_23_make_2d_dict();
},2,1);

_k(_bb1966_termite_23_make_2d_dict = () => {
return _bb1967_termite_23_make_2d_dict();
},2,1);

_j(_bb1968_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1969_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2009_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1969_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2007_termite_23_make_2d_dict();
} else {
return _bb1970_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2007_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2008_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1970_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1971_termite_23_make_2d_dict();
} else {
return _bb2006_termite_23_make_2d_dict();
}
});

_k(_bb2008_termite_23_make_2d_dict = () => {
return _bb1974_termite_23_make_2d_dict();
},2,1);

_j(_bb1971_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1972_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2006_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1973_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1974_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1975_termite_23_make_2d_dict();
} else {
return _bb2005_termite_23_make_2d_dict();
}
});

_k(_bb1972_termite_23_make_2d_dict = () => {
return _bb1974_termite_23_make_2d_dict();
},2,1);

_k(_bb1973_termite_23_make_2d_dict = () => {
return _bb1974_termite_23_make_2d_dict();
},2,1);

_j(_bb1975_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1976_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2005_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1976_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb2003_termite_23_make_2d_dict();
} else {
return _bb1977_termite_23_make_2d_dict();
}
},4,1);

_j(_bb2003_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2004_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1977_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1978_termite_23_make_2d_dict();
} else {
return _bb2002_termite_23_make_2d_dict();
}
});

_k(_bb2004_termite_23_make_2d_dict = () => {
return _bb1981_termite_23_make_2d_dict();
},2,1);

_j(_bb1978_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1979_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb2002_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1980_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1981_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1982_termite_23_make_2d_dict();
} else {
return _bb2001_termite_23_make_2d_dict();
}
});

_k(_bb1979_termite_23_make_2d_dict = () => {
return _bb1981_termite_23_make_2d_dict();
},2,1);

_k(_bb1980_termite_23_make_2d_dict = () => {
return _bb1981_termite_23_make_2d_dict();
},2,1);

_j(_bb1982_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1983_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb2001_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1983_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb1999_termite_23_make_2d_dict();
} else {
return _bb1984_termite_23_make_2d_dict();
}
},4,1);

_j(_bb1999_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb2000_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1984_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1985_termite_23_make_2d_dict();
} else {
return _bb1998_termite_23_make_2d_dict();
}
});

_k(_bb2000_termite_23_make_2d_dict = () => {
return _bb1988_termite_23_make_2d_dict();
},2,1);

_j(_bb1985_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1986_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1998_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb1987_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb1988_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb1989_termite_23_make_2d_dict();
} else {
return _bb1997_termite_23_make_2d_dict();
}
});

_k(_bb1986_termite_23_make_2d_dict = () => {
return _bb1988_termite_23_make_2d_dict();
},2,1);

_k(_bb1987_termite_23_make_2d_dict = () => {
return _bb1988_termite_23_make_2d_dict();
},2,1);

_j(_bb1989_termite_23_make_2d_dict = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb1990_termite_23_make_2d_dict;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb1997_termite_23_make_2d_dict = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb1990_termite_23_make_2d_dict = () => {
if (!(_a === !1)) {
return _bb1995_termite_23_make_2d_dict();
} else {
return _bb1991_termite_23_make_2d_dict();
}
},4,1);

_j(_bb1995_termite_23_make_2d_dict = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb1996_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1991_termite_23_make_2d_dict = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb1992_termite_23_make_2d_dict();
} else {
return _bb1994_termite_23_make_2d_dict();
}
});

_k(_bb1996_termite_23_make_2d_dict = () => {
return _bb18_termite_23_make_2d_dict();
},2,1);

_j(_bb1992_termite_23_make_2d_dict = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb1993_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb1994_termite_23_make_2d_dict = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb17_termite_23_make_2d_dict;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb18_termite_23_make_2d_dict = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb19_termite_23_make_2d_dict);
});

_k(_bb1993_termite_23_make_2d_dict = () => {
return _bb18_termite_23_make_2d_dict();
},2,1);

_k(_bb17_termite_23_make_2d_dict = () => {
return _bb18_termite_23_make_2d_dict();
},2,1);

_j(_bb19_termite_23_make_2d_dict = () => {
if (_x(_a)) {
return _bb20_termite_23_make_2d_dict();
} else {
return _bb3124_termite_23_make_2d_dict();
}
});



_m(_bb1_termite_23_dict_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_dict_3f_);
}
_s[_t+1] = _a;
_c = !1;
_b = 1;
_a = _X(_cst257__termite,null);
++_t;
return _p(_bb2_termite_23_dict_3f_);
},-1,_i("termite#dict?"),!1,!0);

_j(_bb2_termite_23_dict_3f_ = () => {
_n = 4;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_dict_2d_length = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_dict_2d_length);
}
_b = _X(_cst259__termite,null);
return _p(_bb2_termite_23_dict_2d_length);
},-1,_i("termite#dict-length"),!1,!0);

_j(_bb2_termite_23_dict_2d_length = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_dict_2d_ref = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_dict_2d_ref);
}
_b = _X(_cst120__termite,_X(_b,null));
return _p(_bb2_termite_23_dict_2d_ref);
},-1,_i("termite#dict-ref"),!1,!0);

_j(_bb2_termite_23_dict_2d_ref = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_dict_2d_set_21_ = () => {
if (_n === 1) {
_b = null;
} else {
if (!_build_rest(1)) {
return _w(_bb1_termite_23_dict_2d_set_21_);
}
}
if (_x(_b)) {
return _bb2_termite_23_dict_2d_set_21_();
} else {
return _bb15_termite_23_dict_2d_set_21_();
}
},-1,_i("termite#dict-set!"),!1,!0);

_j(_bb2_termite_23_dict_2d_set_21_ = () => {
_c = _b.a;
_d = _b.b;
if (_d === null) {
return _bb3_termite_23_dict_2d_set_21_();
} else {
return _bb4_termite_23_dict_2d_set_21_();
}
});

_j(_bb15_termite_23_dict_2d_set_21_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb16_termite_23_dict_2d_set_21_);
});

_j(_bb3_termite_23_dict_2d_set_21_ = () => {
_b = _X(_cst118__termite,_X(_c,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb7_termite_23_dict_2d_set_21_);
});

_j(_bb4_termite_23_dict_2d_set_21_ = () => {
if (_x(_d)) {
return _bb5_termite_23_dict_2d_set_21_();
} else {
return _bb15_termite_23_dict_2d_set_21_();
}
});

_j(_bb16_termite_23_dict_2d_set_21_ = () => {
_n = 1;
return _g["##raise"]();
});

_j(_bb7_termite_23_dict_2d_set_21_ = () => {
_r = _bb8_termite_23_dict_2d_set_21_;
_n = 1;
return _g["thread?"]();
});

_j(_bb5_termite_23_dict_2d_set_21_ = () => {
_s[_t+1] = _d.a;
_d = _d.b;
if (_d === null) {
++_t;
return _bb6_termite_23_dict_2d_set_21_();
} else {
++_t;
return _bb17_termite_23_dict_2d_set_21_();
}
});

_k(_bb8_termite_23_dict_2d_set_21_ = () => {
if (!(_a === !1)) {
return _bb9_termite_23_dict_2d_set_21_();
} else {
return _bb10_termite_23_dict_2d_set_21_();
}
},3,1);

_j(_bb6_termite_23_dict_2d_set_21_ = () => {
_b = _X(_cst118__termite,_X(_c,_X(_s[_t],null)));
_s[_t] = _r;
_s[_t+1] = _a;
_s[_t+2] = _b;
_t += 2;
return _p(_bb7_termite_23_dict_2d_set_21_);
});

_j(_bb17_termite_23_dict_2d_set_21_ = () => {
_a = _X(_cst56__termite,_X(_b,null));
return _p(_bb18_termite_23_dict_2d_set_21_);
});

_j(_bb9_termite_23_dict_2d_set_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb12_termite_23_dict_2d_set_21_);
});

_j(_bb10_termite_23_dict_2d_set_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb11_termite_23_dict_2d_set_21_();
} else {
return _bb13_termite_23_dict_2d_set_21_();
}
});

_j(_bb18_termite_23_dict_2d_set_21_ = () => {
_n = 1;
--_t;
return _g["##raise"]();
});

_j(_bb12_termite_23_dict_2d_set_21_ = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb11_termite_23_dict_2d_set_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb12_termite_23_dict_2d_set_21_);
});

_j(_bb13_termite_23_dict_2d_set_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb14_termite_23_dict_2d_set_21_);
});

_j(_bb14_termite_23_dict_2d_set_21_ = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_dict_2d_search = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_dict_2d_search);
}
_a = _X(_cst260__termite,_X(_a,null));
_s[_t+1] = _b;
_b = _a;
_a = _s[_t+1];
++_t;
return _p(_bb2_termite_23_dict_2d_search);
},-1,_i("termite#dict-search"),!1,!0);

_j(_bb2_termite_23_dict_2d_search = () => {
_n = 2;
--_t;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_dict_2d_for_2d_each = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_dict_2d_for_2d_each);
}
_a = _X(_cst258__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_t += 3;
return _p(_bb2_termite_23_dict_2d_for_2d_each);
},-1,_i("termite#dict-for-each"),!1,!0);

_j(_bb2_termite_23_dict_2d_for_2d_each = () => {
_r = _bb3_termite_23_dict_2d_for_2d_each;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_dict_2d_for_2d_each = () => {
if (!(_a === !1)) {
return _bb4_termite_23_dict_2d_for_2d_each();
} else {
return _bb5_termite_23_dict_2d_for_2d_each();
}
},3,1);

_j(_bb4_termite_23_dict_2d_for_2d_each = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _s[_t-2];
return _p(_bb7_termite_23_dict_2d_for_2d_each);
});

_j(_bb5_termite_23_dict_2d_for_2d_each = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_dict_2d_for_2d_each();
} else {
return _bb8_termite_23_dict_2d_for_2d_each();
}
});

_j(_bb7_termite_23_dict_2d_for_2d_each = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_dict_2d_for_2d_each = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-1],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_dict_2d_for_2d_each);
});

_j(_bb8_termite_23_dict_2d_for_2d_each = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_dict_2d_for_2d_each);
});

_j(_bb9_termite_23_dict_2d_for_2d_each = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_dict_2d__3e_list = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_dict_2d__3e_list);
}
_b = _X(_cst264__termite,null);
return _p(_bb2_termite_23_dict_2d__3e_list);
},-1,_i("termite#dict->list"),!1,!0);

_j(_bb2_termite_23_dict_2d__3e_list = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_make_2d_bag = () => {
var error = _build_key(0,1,[_cst15__termite,_absent_obj]);
if (!(error === null)) {
return _wrong_key_args(_bb1_termite_23_make_2d_bag,error);
}
if (_a === _absent_obj) {
return _bb2_termite_23_make_2d_bag();
} else {
return _bb5_termite_23_make_2d_bag();
}
},-1,_i("termite#make-bag"),!1,!0);

_j(_bb2_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_a = _cst267__termite;
++_t;
return _p(_bb3_termite_23_make_2d_bag);
});

_j(_bb5_termite_23_make_2d_bag = () => {
_s[_t+1] = _a;
_a = _bb483_termite_23_make_2d_bag;
_c = _s[_t+1];
_b = _cst15__termite;
++_t;
return _p(_bb6_termite_23_make_2d_bag);
});

_j(_bb3_termite_23_make_2d_bag = () => {
_r = _bb4_termite_23_make_2d_bag;
_n = 1;
return _bb1_termite_23_data_2d_make_2d_process_2d_name();
});

_l(_bb483_termite_23_make_2d_bag = () => {
if (_n !== 0) {
return _w(_bb483_termite_23_make_2d_bag);
}
_s[_t+1] = _r;
_s[_t+2] = _cst255__termite;
_c = !1;
_b = _cst256__termite;
_a = _e["##equal?"];
_t += 2;
return _p(_bb484_termite_23_make_2d_bag);
},-1);

_j(_bb6_termite_23_make_2d_bag = () => {
_n = 3;
--_t;
return _bb7_termite_23_make_2d_bag();
});

_k(_bb4_termite_23_make_2d_bag = () => {
_r = _s[_t];
--_t;
return _bb5_termite_23_make_2d_bag();
},1,1);

_j(_bb484_termite_23_make_2d_bag = () => {
_r = _bb485_termite_23_make_2d_bag;
_n = 4;
return _g["##make-table"]();
});

_l(_bb7_termite_23_make_2d_bag = () => {
var error = _build_key(1,3,[_cst16__termite,null,_cst15__termite,_cst17__termite]);
if (!(error === null)) {
return _wrong_key_args(_bb7_termite_23_make_2d_bag,error);
}
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb12_termite_23_make_2d_bag,_a]);
_s[_t+3] = closure0;
_a = _s[_t+3];
_b = _c;
_t += 3;
return _p(_bb8_termite_23_make_2d_bag);
},-1);

_k(_bb485_termite_23_make_2d_bag = () => {
_r = _s[_t];
--_t;
return _p(_bb487_termite_23_make_2d_bag);
},1,1);

_l(_bb12_termite_23_make_2d_bag = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_b = _d(!0)[1];
_a = _bb1_termite_23_base_2d_exception_2d_handler;
++_t;
return _p(_bb13_termite_23_make_2d_bag);
},1);

_j(_bb8_termite_23_make_2d_bag = () => {
_r = _bb9_termite_23_make_2d_bag;
_n = 2;
--_t;
return _g["make-thread"]();
});

_j(_bb487_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb488_termite_23_make_2d_bag);
});

_j(_bb13_termite_23_make_2d_bag = () => {
_r = _bb14_termite_23_make_2d_bag;
_n = 2;
return _g["##with-exception-handler"]();
});

_k(_bb9_termite_23_make_2d_bag = () => {
_s[_t+1] = _a;
_b = _s[_t];
_r = _bb10_termite_23_make_2d_bag;
_n = 2;
++_t;
return _g["thread-specific-set!"]();
},2,1);

_j(_bb488_termite_23_make_2d_bag = () => {
_r = _bb489_termite_23_make_2d_bag;
_n = 0;
return _g["thread-mailbox-next"]();
});

_k(_bb14_termite_23_make_2d_bag = () => {
_a = _current_processor.a[14];
_r = _bb15_termite_23_make_2d_bag;
_n = 1;
return _g["thread-specific"]();
},1,1);

_k(_bb10_termite_23_make_2d_bag = () => {
_a = _s[_t];
_r = _bb11_termite_23_make_2d_bag;
_n = 1;
return _g["thread-start!"]();
},3,1);

_k(_bb489_termite_23_make_2d_bag = () => {
_b = _a;
_a = _s[_t];
_r = _bb486_termite_23_make_2d_bag;
return _bb490_termite_23_make_2d_bag();
},2,1);

_k(_bb15_termite_23_make_2d_bag = () => {
_r = _bb481_termite_23_make_2d_bag;
return _bb16_termite_23_make_2d_bag();
},1,1);

_k(_bb11_termite_23_make_2d_bag = () => {
_a = _s[_t];
_t -= 3;
return _s[_t+1]();
},3,1);

_j(_bb490_termite_23_make_2d_bag = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb493_termite_23_make_2d_bag();
} else {
return _bb499_termite_23_make_2d_bag();
}
});

_k(_bb486_termite_23_make_2d_bag = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb487_termite_23_make_2d_bag);
},2,1);

_j(_bb16_termite_23_make_2d_bag = () => {
if (_x(_a)) {
return _bb20_termite_23_make_2d_bag();
} else {
return _bb480_termite_23_make_2d_bag();
}
});

_k(_bb481_termite_23_make_2d_bag = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb482_termite_23_make_2d_bag);
},1,1);

_j(_bb493_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_r = _bb497_termite_23_make_2d_bag;
_t += 2;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb499_termite_23_make_2d_bag = () => {
if (_x(_b)) {
return _bb500_termite_23_make_2d_bag();
} else {
return _bb666_termite_23_make_2d_bag();
}
});

_j(_bb20_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_s[_t+4] = _c;
_a = _b;
_t += 4;
return _p(_bb21_termite_23_make_2d_bag);
});

_j(_bb480_termite_23_make_2d_bag = () => {
_a = void 0;
return _r;
});

_j(_bb482_termite_23_make_2d_bag = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});

_j(_bb494_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
++_t;
return _p(_bb495_termite_23_make_2d_bag);
});

_k(_bb497_termite_23_make_2d_bag = () => {
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb498_termite_23_make_2d_bag);
},2,1);

_j(_bb500_termite_23_make_2d_bag = () => {
_c = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb501_termite_23_make_2d_bag();
} else {
return _bb665_termite_23_make_2d_bag();
}
});

_j(_bb666_termite_23_make_2d_bag = () => {
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb21_termite_23_make_2d_bag = () => {
_r = _bb22_termite_23_make_2d_bag;
_n = 1;
return _g["thread?"]();
});

_j(_bb495_termite_23_make_2d_bag = () => {
_r = _bb496_termite_23_make_2d_bag;
_n = 0;
return _g["thread-mailbox-extract-and-rewind"]();
});

_j(_bb498_termite_23_make_2d_bag = () => {
_n = 1;
_t -= 2;
return _g["##raise"]();
});

_j(_bb501_termite_23_make_2d_bag = () => {
_d = _b.a;
_b = _b.b;
if (_x(_b)) {
return _bb502_termite_23_make_2d_bag();
} else {
return _bb644_termite_23_make_2d_bag();
}
});

_j(_bb665_termite_23_make_2d_bag = () => {
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb528_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb529_termite_23_make_2d_bag);
});

_k(_bb22_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb478_termite_23_make_2d_bag();
} else {
return _bb23_termite_23_make_2d_bag();
}
},4,1);

_k(_bb496_termite_23_make_2d_bag = () => {
--_t;
return _s[_t+1]();
},1,1);

_j(_bb502_termite_23_make_2d_bag = () => {
_s[_t+1] = _b.a;
_b = _b.b;
if (_x(_s[_t+1])) {
++_t;
return _bb503_termite_23_make_2d_bag();
} else {
++_t;
return _bb643_termite_23_make_2d_bag();
}
});

_j(_bb644_termite_23_make_2d_bag = () => {
if (_c === _cst268__termite) {
return _bb645_termite_23_make_2d_bag();
} else {
return _bb650_termite_23_make_2d_bag();
}
});

_j(_bb529_termite_23_make_2d_bag = () => {
_r = _bb530_termite_23_make_2d_bag;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb478_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb479_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb23_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb24_termite_23_make_2d_bag();
} else {
return _bb477_termite_23_make_2d_bag();
}
});

_j(_bb503_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t].a;
_s[_t] = _s[_t].b;
if (_s[_t+1] === _cst269__termite) {
++_t;
return _bb504_termite_23_make_2d_bag();
} else {
++_t;
return _bb519_termite_23_make_2d_bag();
}
});

_j(_bb643_termite_23_make_2d_bag = () => {
--_t;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb645_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb646_termite_23_make_2d_bag();
} else {
return _bb649_termite_23_make_2d_bag();
}
});

_j(_bb650_termite_23_make_2d_bag = () => {
if (_c === _cst270__termite) {
return _bb651_termite_23_make_2d_bag();
} else {
return _bb656_termite_23_make_2d_bag();
}
});

_k(_bb530_termite_23_make_2d_bag = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb492_termite_23_make_2d_bag);
},2,1);

_k(_bb479_termite_23_make_2d_bag = () => {
return _bb27_termite_23_make_2d_bag();
},2,1);

_j(_bb24_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb25_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb477_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb26_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb504_termite_23_make_2d_bag = () => {
if (_s[_t-1] === null) {
return _bb505_termite_23_make_2d_bag();
} else {
return _bb518_termite_23_make_2d_bag();
}
});

_j(_bb519_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst271__termite) {
return _bb531_termite_23_make_2d_bag();
} else {
return _bb520_termite_23_make_2d_bag();
}
});

_j(_bb646_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_r = _bb647_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb649_termite_23_make_2d_bag = () => {
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb651_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb652_termite_23_make_2d_bag();
} else {
return _bb655_termite_23_make_2d_bag();
}
});

_j(_bb656_termite_23_make_2d_bag = () => {
if (_c === _cst272__termite) {
return _bb657_termite_23_make_2d_bag();
} else {
return _bb664_termite_23_make_2d_bag();
}
});

_j(_bb492_termite_23_make_2d_bag = () => {
if (_b instanceof _Structure && _b.a[0].a[1] === _cst52__termite) {
return _bb493_termite_23_make_2d_bag();
} else {
return _bb499_termite_23_make_2d_bag();
}
});

_j(_bb27_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb28_termite_23_make_2d_bag();
} else {
return _bb476_termite_23_make_2d_bag();
}
});

_k(_bb25_termite_23_make_2d_bag = () => {
return _bb27_termite_23_make_2d_bag();
},2,1);

_k(_bb26_termite_23_make_2d_bag = () => {
return _bb27_termite_23_make_2d_bag();
},2,1);

_j(_bb505_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb506_termite_23_make_2d_bag();
} else {
return _bb516_termite_23_make_2d_bag();
}
});

_j(_bb518_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb531_termite_23_make_2d_bag = () => {
if (_s[_t-1] === null) {
return _bb532_termite_23_make_2d_bag();
} else {
return _bb545_termite_23_make_2d_bag();
}
});

_j(_bb520_termite_23_make_2d_bag = () => {
if (_c === _cst268__termite) {
return _bb546_termite_23_make_2d_bag();
} else {
return _bb521_termite_23_make_2d_bag();
}
});

_k(_bb647_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_c = !0;
_r = _s[_t-2];
return _p(_bb648_termite_23_make_2d_bag);
},3,1);

_j(_bb652_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_r = _bb653_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb655_termite_23_make_2d_bag = () => {
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb657_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb658_termite_23_make_2d_bag();
} else {
return _bb663_termite_23_make_2d_bag();
}
});

_j(_bb664_termite_23_make_2d_bag = () => {
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb28_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb29_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb476_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb506_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t] = _c;
_s[_t+1] = _d;
_r = _bb507_termite_23_make_2d_bag;
++_t;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb516_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t] = _a;
return _p(_bb517_termite_23_make_2d_bag);
});

_j(_bb532_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb533_termite_23_make_2d_bag();
} else {
return _bb544_termite_23_make_2d_bag();
}
});

_j(_bb545_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb546_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst273__termite) {
return _bb547_termite_23_make_2d_bag();
} else {
return _bb558_termite_23_make_2d_bag();
}
});

_j(_bb521_termite_23_make_2d_bag = () => {
if (_c === _cst270__termite) {
return _bb600_termite_23_make_2d_bag();
} else {
return _bb522_termite_23_make_2d_bag();
}
});

_j(_bb648_termite_23_make_2d_bag = () => {
_n = 3;
_t -= 3;
return _g["##table-set!"]();
});

_k(_bb653_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb654_termite_23_make_2d_bag);
},3,1);

_j(_bb658_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _d;
_r = _bb659_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb663_termite_23_make_2d_bag = () => {
return _p(_bb528_termite_23_make_2d_bag);
});

_k(_bb29_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb474_termite_23_make_2d_bag();
} else {
return _bb30_termite_23_make_2d_bag();
}
},4,1);

_k(_bb507_termite_23_make_2d_bag = () => {
_a = _X(_s[_t],_X(!0,null));
_s[_t] = _a;
_a = _s[_t-1];
_r = _bb508_termite_23_make_2d_bag;
_n = 1;
return _g["thread?"]();
},3,1);

_j(_bb517_termite_23_make_2d_bag = () => {
_r = _bb491_termite_23_make_2d_bag;
_n = 0;
return _g["thread-mailbox-next"]();
});

_j(_bb533_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb534_termite_23_make_2d_bag;
_t += 2;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb544_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb547_termite_23_make_2d_bag = () => {
if (_x(_s[_t-1])) {
return _bb548_termite_23_make_2d_bag();
} else {
return _bb557_termite_23_make_2d_bag();
}
});

_j(_bb558_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst274__termite) {
return _bb559_termite_23_make_2d_bag();
} else {
return _bb581_termite_23_make_2d_bag();
}
});

_j(_bb600_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst273__termite) {
return _bb601_termite_23_make_2d_bag();
} else {
return _bb609_termite_23_make_2d_bag();
}
});

_j(_bb522_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst273__termite) {
return _bb626_termite_23_make_2d_bag();
} else {
return _bb523_termite_23_make_2d_bag();
}
});

_j(_bb654_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["##table-set!"]();
});

_k(_bb659_termite_23_make_2d_bag = () => {
var closure1 = _closure_alloc([_bb661_termite_23_make_2d_bag,_s[_t]]);
_s[_t+1] = closure1;
_a = _s[_t+1];
_b = _s[_t-1];
_r = _s[_t-2];
++_t;
return _p(_bb660_termite_23_make_2d_bag);
},3,1);

_j(_bb474_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb475_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb30_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb31_termite_23_make_2d_bag();
} else {
return _bb473_termite_23_make_2d_bag();
}
});

_k(_bb508_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb509_termite_23_make_2d_bag();
} else {
return _bb511_termite_23_make_2d_bag();
}
},3,1);

_k(_bb491_termite_23_make_2d_bag = () => {
_b = _a;
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb492_termite_23_make_2d_bag);
},2,1);

_k(_bb534_termite_23_make_2d_bag = () => {
_a = _s[_t-2];
_r = _bb535_termite_23_make_2d_bag;
_n = 1;
return _g["##table-length"]();
},4,1);

_j(_bb548_termite_23_make_2d_bag = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb549_termite_23_make_2d_bag();
} else {
return _bb556_termite_23_make_2d_bag();
}
});

_j(_bb557_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb559_termite_23_make_2d_bag = () => {
if (_x(_s[_t-1])) {
return _bb560_termite_23_make_2d_bag();
} else {
return _bb580_termite_23_make_2d_bag();
}
});

_j(_bb581_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst275__termite) {
return _bb582_termite_23_make_2d_bag();
} else {
return _bb599_termite_23_make_2d_bag();
}
});

_j(_bb601_termite_23_make_2d_bag = () => {
if (_x(_s[_t-1])) {
return _bb602_termite_23_make_2d_bag();
} else {
return _bb608_termite_23_make_2d_bag();
}
});

_j(_bb609_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst274__termite) {
return _bb610_termite_23_make_2d_bag();
} else {
return _bb618_termite_23_make_2d_bag();
}
});

_j(_bb626_termite_23_make_2d_bag = () => {
if (_x(_s[_t-1])) {
return _bb627_termite_23_make_2d_bag();
} else {
return _bb632_termite_23_make_2d_bag();
}
});

_j(_bb523_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst274__termite) {
return _bb633_termite_23_make_2d_bag();
} else {
return _bb524_termite_23_make_2d_bag();
}
});

_l(_bb661_termite_23_make_2d_bag = () => {
if (_n !== 2) {
return _w(_d);
}
return _p(_bb662_termite_23_make_2d_bag);
},1);

_j(_bb660_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 4;
return _g["##table-for-each"]();
});

_k(_bb475_termite_23_make_2d_bag = () => {
return _bb34_termite_23_make_2d_bag();
},2,1);

_j(_bb31_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb32_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb473_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb33_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb509_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb510_termite_23_make_2d_bag);
});

_j(_bb511_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb512_termite_23_make_2d_bag();
} else {
return _bb514_termite_23_make_2d_bag();
}
});

_k(_bb535_termite_23_make_2d_bag = () => {
_a = _X(_s[_t],_X(_a,null));
_s[_t-2] = _a;
_a = _s[_t-1];
_r = _bb536_termite_23_make_2d_bag;
_n = 1;
--_t;
return _g["thread?"]();
},4,1);

_j(_bb549_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb550_termite_23_make_2d_bag();
} else {
return _bb555_termite_23_make_2d_bag();
}
});

_j(_bb556_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb560_termite_23_make_2d_bag = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb561_termite_23_make_2d_bag();
} else {
return _bb579_termite_23_make_2d_bag();
}
});

_j(_bb580_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb582_termite_23_make_2d_bag = () => {
if (_s[_t-1] === null) {
return _bb583_termite_23_make_2d_bag();
} else {
return _bb598_termite_23_make_2d_bag();
}
});

_j(_bb599_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb602_termite_23_make_2d_bag = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb603_termite_23_make_2d_bag();
} else {
return _bb607_termite_23_make_2d_bag();
}
});

_j(_bb608_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb610_termite_23_make_2d_bag = () => {
if (_x(_s[_t-1])) {
return _bb611_termite_23_make_2d_bag();
} else {
return _bb617_termite_23_make_2d_bag();
}
});

_j(_bb618_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst275__termite) {
return _bb619_termite_23_make_2d_bag();
} else {
return _bb625_termite_23_make_2d_bag();
}
});

_j(_bb627_termite_23_make_2d_bag = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb628_termite_23_make_2d_bag();
} else {
return _bb631_termite_23_make_2d_bag();
}
});

_j(_bb632_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb633_termite_23_make_2d_bag = () => {
if (_x(_s[_t-1])) {
return _bb634_termite_23_make_2d_bag();
} else {
return _bb639_termite_23_make_2d_bag();
}
});

_j(_bb524_termite_23_make_2d_bag = () => {
if (_s[_t] === _cst275__termite) {
return _bb525_termite_23_make_2d_bag();
} else {
return _bb640_termite_23_make_2d_bag();
}
});

_j(_bb662_termite_23_make_2d_bag = () => {
_n = 1;
return _d(!0)[1]();
});

_j(_bb34_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb35_termite_23_make_2d_bag();
} else {
return _bb472_termite_23_make_2d_bag();
}
});

_k(_bb32_termite_23_make_2d_bag = () => {
return _bb34_termite_23_make_2d_bag();
},2,1);

_k(_bb33_termite_23_make_2d_bag = () => {
return _bb34_termite_23_make_2d_bag();
},2,1);

_j(_bb510_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb512_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb513_termite_23_make_2d_bag);
});

_j(_bb514_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb515_termite_23_make_2d_bag);
});

_k(_bb536_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb537_termite_23_make_2d_bag();
} else {
return _bb539_termite_23_make_2d_bag();
}
},3,1);

_j(_bb550_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb551_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb555_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb561_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb562_termite_23_make_2d_bag();
} else {
return _bb578_termite_23_make_2d_bag();
}
});

_j(_bb579_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb583_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb584_termite_23_make_2d_bag();
} else {
return _bb597_termite_23_make_2d_bag();
}
});

_j(_bb598_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb603_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb604_termite_23_make_2d_bag();
} else {
return _bb606_termite_23_make_2d_bag();
}
});

_j(_bb607_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb611_termite_23_make_2d_bag = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb612_termite_23_make_2d_bag();
} else {
return _bb616_termite_23_make_2d_bag();
}
});

_j(_bb617_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb619_termite_23_make_2d_bag = () => {
if (_s[_t-1] === null) {
return _bb620_termite_23_make_2d_bag();
} else {
return _bb624_termite_23_make_2d_bag();
}
});

_j(_bb625_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb628_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb629_termite_23_make_2d_bag();
} else {
return _bb630_termite_23_make_2d_bag();
}
});

_j(_bb631_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb634_termite_23_make_2d_bag = () => {
_s[_t] = _s[_t-1].a;
_s[_t-1] = _s[_t-1].b;
if (_s[_t-1] === null) {
return _bb635_termite_23_make_2d_bag();
} else {
return _bb638_termite_23_make_2d_bag();
}
});

_j(_bb639_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb525_termite_23_make_2d_bag = () => {
if (_s[_t-1] === null) {
return _bb526_termite_23_make_2d_bag();
} else {
return _bb641_termite_23_make_2d_bag();
}
});

_j(_bb640_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb35_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb36_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb472_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_j(_bb513_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb515_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});

_j(_bb537_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _s[_t-2];
return _p(_bb538_termite_23_make_2d_bag);
});

_j(_bb539_termite_23_make_2d_bag = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb540_termite_23_make_2d_bag();
} else {
return _bb542_termite_23_make_2d_bag();
}
});

_k(_bb551_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t-4];
_s[_t-4] = _s[_t-2];
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t+1];
_t -= 4;
return _p(_bb553_termite_23_make_2d_bag);
},5,1);

_j(_bb562_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb563_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb578_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb584_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb585_termite_23_make_2d_bag;
_t += 2;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb597_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb604_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb605_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb606_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb612_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb613_termite_23_make_2d_bag();
} else {
return _bb615_termite_23_make_2d_bag();
}
});

_j(_bb616_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb620_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb621_termite_23_make_2d_bag();
} else {
return _bb623_termite_23_make_2d_bag();
}
});

_j(_bb624_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb629_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb552_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb630_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb635_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb636_termite_23_make_2d_bag();
} else {
return _bb637_termite_23_make_2d_bag();
}
});

_j(_bb638_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb526_termite_23_make_2d_bag = () => {
if (_b === null) {
return _bb642_termite_23_make_2d_bag();
} else {
return _bb527_termite_23_make_2d_bag();
}
});

_j(_bb641_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_k(_bb36_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb470_termite_23_make_2d_bag();
} else {
return _bb37_termite_23_make_2d_bag();
}
},4,1);

_j(_bb538_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb540_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-1],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb541_termite_23_make_2d_bag);
});

_j(_bb542_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb543_termite_23_make_2d_bag);
});

_j(_bb553_termite_23_make_2d_bag = () => {
_b = _c;
_a = _s[_t];
return _p(_bb554_termite_23_make_2d_bag);
});

_k(_bb563_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t-4];
_s[_t-4] = _s[_t-2];
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t+1];
_t -= 4;
return _p(_bb565_termite_23_make_2d_bag);
},5,1);

_k(_bb585_termite_23_make_2d_bag = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb587_termite_23_make_2d_bag);
},4,1);

_k(_bb605_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t-4];
_s[_t-4] = _s[_t-2];
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t+1];
_t -= 4;
return _p(_bb553_termite_23_make_2d_bag);
},5,1);

_j(_bb613_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb614_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb615_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb621_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb622_termite_23_make_2d_bag;
_t += 2;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb623_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_k(_bb552_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t-4];
_s[_t-4] = _s[_t-2];
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t+1];
_t -= 4;
return _p(_bb553_termite_23_make_2d_bag);
},5,1);

_j(_bb636_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t+1] = _a;
_s[_t+2] = _c;
_s[_t+3] = _d;
_r = _bb564_termite_23_make_2d_bag;
_t += 3;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb637_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb642_termite_23_make_2d_bag = () => {
_s[_t-1] = _r;
_s[_t] = _a;
_s[_t+1] = _c;
_s[_t+2] = _d;
_r = _bb586_termite_23_make_2d_bag;
_t += 2;
return _p(_bb494_termite_23_make_2d_bag);
});

_j(_bb527_termite_23_make_2d_bag = () => {
_t -= 2;
return _p(_bb528_termite_23_make_2d_bag);
});

_j(_bb470_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb471_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb37_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb38_termite_23_make_2d_bag();
} else {
return _bb469_termite_23_make_2d_bag();
}
});

_j(_bb541_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb543_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});

_j(_bb554_termite_23_make_2d_bag = () => {
_n = 2;
--_t;
return _g["##table-ref"]();
});

_j(_bb565_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
var closure2 = _closure_alloc([_bb576_termite_23_make_2d_bag,_c]);
_s[_t+4] = closure2;
_a = _s[_t+4];
_b = _s[_t];
_t += 4;
return _p(_bb566_termite_23_make_2d_bag);
});

_j(_bb587_termite_23_make_2d_bag = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_s[_t+3] = _c;
_t += 3;
return _p(_bb588_termite_23_make_2d_bag);
});

_k(_bb614_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t-4];
_s[_t-4] = _s[_t-2];
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t+1];
_t -= 4;
return _p(_bb565_termite_23_make_2d_bag);
},5,1);

_k(_bb622_termite_23_make_2d_bag = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb587_termite_23_make_2d_bag);
},4,1);

_k(_bb564_termite_23_make_2d_bag = () => {
_s[_t+1] = _s[_t-4];
_s[_t-4] = _s[_t-2];
_c = _s[_t-3];
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t+1];
_t -= 4;
return _p(_bb565_termite_23_make_2d_bag);
},5,1);

_k(_bb586_termite_23_make_2d_bag = () => {
_c = _s[_t];
_b = _s[_t-1];
_a = _s[_t-2];
_r = _s[_t-3];
_t -= 4;
return _p(_bb587_termite_23_make_2d_bag);
},4,1);

_k(_bb471_termite_23_make_2d_bag = () => {
return _bb41_termite_23_make_2d_bag();
},2,1);

_j(_bb38_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb39_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb469_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb40_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_l(_bb576_termite_23_make_2d_bag = () => {
if (_n !== 2) {
return _w(_d);
}
return _p(_bb577_termite_23_make_2d_bag);
},1);

_j(_bb566_termite_23_make_2d_bag = () => {
_r = _bb567_termite_23_make_2d_bag;
_n = 2;
--_t;
return _g["##table-search"]();
});

_j(_bb588_termite_23_make_2d_bag = () => {
_r = _bb589_termite_23_make_2d_bag;
_n = 1;
return _g["##table->list"]();
});

_j(_bb41_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb42_termite_23_make_2d_bag();
} else {
return _bb468_termite_23_make_2d_bag();
}
});

_k(_bb39_termite_23_make_2d_bag = () => {
return _bb41_termite_23_make_2d_bag();
},2,1);

_k(_bb40_termite_23_make_2d_bag = () => {
return _bb41_termite_23_make_2d_bag();
},2,1);

_j(_bb577_termite_23_make_2d_bag = () => {
_n = 1;
return _d(!0)[1]();
});

_k(_bb567_termite_23_make_2d_bag = () => {
_a = _X(_s[_t],_X(_a,null));
_s[_t-3] = _a;
_a = _s[_t-1];
_r = _bb568_termite_23_make_2d_bag;
_n = 1;
--_t;
return _g["thread?"]();
},4,2);

_k(_bb589_termite_23_make_2d_bag = () => {
_r = _bb595_termite_23_make_2d_bag;
return _bb590_termite_23_make_2d_bag();
},3,1);

_j(_bb42_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb43_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb468_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb568_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb569_termite_23_make_2d_bag();
} else {
return _bb571_termite_23_make_2d_bag();
}
},3,2);

_j(_bb590_termite_23_make_2d_bag = () => {
if (_x(_a)) {
return _bb592_termite_23_make_2d_bag();
} else {
return _bb594_termite_23_make_2d_bag();
}
});

_k(_bb595_termite_23_make_2d_bag = () => {
_b = _X(_s[_t],_X(_a,null));
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb596_termite_23_make_2d_bag);
},3,1);

_k(_bb43_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb466_termite_23_make_2d_bag();
} else {
return _bb44_termite_23_make_2d_bag();
}
},4,1);

_j(_bb569_termite_23_make_2d_bag = () => {
_b = _s[_t-2];
_a = _s[_t];
_r = _s[_t-1];
return _p(_bb570_termite_23_make_2d_bag);
});

_j(_bb571_termite_23_make_2d_bag = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb572_termite_23_make_2d_bag();
} else {
return _bb574_termite_23_make_2d_bag();
}
});

_j(_bb592_termite_23_make_2d_bag = () => {
_b = _a.a;
_b = _b.a;
_s[_t+1] = _r;
_s[_t+2] = _b;
_a = _a.b;
_r = _bb593_termite_23_make_2d_bag;
_t += 2;
return _p(_bb591_termite_23_make_2d_bag);
});

_j(_bb594_termite_23_make_2d_bag = () => {
_a = null;
return _r;
});

_j(_bb596_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _bb1_termite_23__21_();
});

_j(_bb466_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb467_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb44_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb45_termite_23_make_2d_bag();
} else {
return _bb465_termite_23_make_2d_bag();
}
});

_j(_bb570_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb572_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-2],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb573_termite_23_make_2d_bag);
});

_j(_bb574_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb575_termite_23_make_2d_bag);
});

_j(_bb591_termite_23_make_2d_bag = () => {
if (_x(_a)) {
return _bb592_termite_23_make_2d_bag();
} else {
return _bb594_termite_23_make_2d_bag();
}
});

_k(_bb593_termite_23_make_2d_bag = () => {
_a = _X(_s[_t],_a);
_t -= 2;
return _s[_t+1]();
},2,1);

_k(_bb467_termite_23_make_2d_bag = () => {
return _bb48_termite_23_make_2d_bag();
},2,1);

_j(_bb45_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb46_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb465_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb47_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb573_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb575_termite_23_make_2d_bag = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});

_j(_bb48_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb49_termite_23_make_2d_bag();
} else {
return _bb464_termite_23_make_2d_bag();
}
});

_k(_bb46_termite_23_make_2d_bag = () => {
return _bb48_termite_23_make_2d_bag();
},2,1);

_k(_bb47_termite_23_make_2d_bag = () => {
return _bb48_termite_23_make_2d_bag();
},2,1);

_j(_bb49_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb50_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb464_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb50_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb462_termite_23_make_2d_bag();
} else {
return _bb51_termite_23_make_2d_bag();
}
},4,1);

_j(_bb462_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb463_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb51_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb52_termite_23_make_2d_bag();
} else {
return _bb461_termite_23_make_2d_bag();
}
});

_k(_bb463_termite_23_make_2d_bag = () => {
return _bb55_termite_23_make_2d_bag();
},2,1);

_j(_bb52_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb53_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb461_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb54_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb55_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb56_termite_23_make_2d_bag();
} else {
return _bb460_termite_23_make_2d_bag();
}
});

_k(_bb53_termite_23_make_2d_bag = () => {
return _bb55_termite_23_make_2d_bag();
},2,1);

_k(_bb54_termite_23_make_2d_bag = () => {
return _bb55_termite_23_make_2d_bag();
},2,1);

_j(_bb56_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb57_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb460_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb57_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb458_termite_23_make_2d_bag();
} else {
return _bb58_termite_23_make_2d_bag();
}
},4,1);

_j(_bb458_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb459_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb58_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb59_termite_23_make_2d_bag();
} else {
return _bb457_termite_23_make_2d_bag();
}
});

_k(_bb459_termite_23_make_2d_bag = () => {
return _bb62_termite_23_make_2d_bag();
},2,1);

_j(_bb59_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb60_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb457_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb61_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb62_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb63_termite_23_make_2d_bag();
} else {
return _bb456_termite_23_make_2d_bag();
}
});

_k(_bb60_termite_23_make_2d_bag = () => {
return _bb62_termite_23_make_2d_bag();
},2,1);

_k(_bb61_termite_23_make_2d_bag = () => {
return _bb62_termite_23_make_2d_bag();
},2,1);

_j(_bb63_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb64_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb456_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb64_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb454_termite_23_make_2d_bag();
} else {
return _bb65_termite_23_make_2d_bag();
}
},4,1);

_j(_bb454_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb455_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb65_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb66_termite_23_make_2d_bag();
} else {
return _bb453_termite_23_make_2d_bag();
}
});

_k(_bb455_termite_23_make_2d_bag = () => {
return _bb69_termite_23_make_2d_bag();
},2,1);

_j(_bb66_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb67_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb453_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb68_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb69_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb70_termite_23_make_2d_bag();
} else {
return _bb452_termite_23_make_2d_bag();
}
});

_k(_bb67_termite_23_make_2d_bag = () => {
return _bb69_termite_23_make_2d_bag();
},2,1);

_k(_bb68_termite_23_make_2d_bag = () => {
return _bb69_termite_23_make_2d_bag();
},2,1);

_j(_bb70_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb71_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb452_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb71_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb450_termite_23_make_2d_bag();
} else {
return _bb72_termite_23_make_2d_bag();
}
},4,1);

_j(_bb450_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb451_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb72_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb73_termite_23_make_2d_bag();
} else {
return _bb449_termite_23_make_2d_bag();
}
});

_k(_bb451_termite_23_make_2d_bag = () => {
return _bb76_termite_23_make_2d_bag();
},2,1);

_j(_bb73_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb74_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb449_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb75_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb76_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb77_termite_23_make_2d_bag();
} else {
return _bb448_termite_23_make_2d_bag();
}
});

_k(_bb74_termite_23_make_2d_bag = () => {
return _bb76_termite_23_make_2d_bag();
},2,1);

_k(_bb75_termite_23_make_2d_bag = () => {
return _bb76_termite_23_make_2d_bag();
},2,1);

_j(_bb77_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb78_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb448_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb78_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb446_termite_23_make_2d_bag();
} else {
return _bb79_termite_23_make_2d_bag();
}
},4,1);

_j(_bb446_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb447_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb79_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb80_termite_23_make_2d_bag();
} else {
return _bb445_termite_23_make_2d_bag();
}
});

_k(_bb447_termite_23_make_2d_bag = () => {
return _bb83_termite_23_make_2d_bag();
},2,1);

_j(_bb80_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb81_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb445_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb82_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb83_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb84_termite_23_make_2d_bag();
} else {
return _bb444_termite_23_make_2d_bag();
}
});

_k(_bb81_termite_23_make_2d_bag = () => {
return _bb83_termite_23_make_2d_bag();
},2,1);

_k(_bb82_termite_23_make_2d_bag = () => {
return _bb83_termite_23_make_2d_bag();
},2,1);

_j(_bb84_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb85_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb444_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb85_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb442_termite_23_make_2d_bag();
} else {
return _bb86_termite_23_make_2d_bag();
}
},4,1);

_j(_bb442_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb443_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb86_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb87_termite_23_make_2d_bag();
} else {
return _bb441_termite_23_make_2d_bag();
}
});

_k(_bb443_termite_23_make_2d_bag = () => {
return _bb90_termite_23_make_2d_bag();
},2,1);

_j(_bb87_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb88_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb441_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb89_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb90_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb91_termite_23_make_2d_bag();
} else {
return _bb440_termite_23_make_2d_bag();
}
});

_k(_bb88_termite_23_make_2d_bag = () => {
return _bb90_termite_23_make_2d_bag();
},2,1);

_k(_bb89_termite_23_make_2d_bag = () => {
return _bb90_termite_23_make_2d_bag();
},2,1);

_j(_bb91_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb92_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb440_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb92_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb438_termite_23_make_2d_bag();
} else {
return _bb93_termite_23_make_2d_bag();
}
},4,1);

_j(_bb438_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb439_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb93_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb94_termite_23_make_2d_bag();
} else {
return _bb437_termite_23_make_2d_bag();
}
});

_k(_bb439_termite_23_make_2d_bag = () => {
return _bb97_termite_23_make_2d_bag();
},2,1);

_j(_bb94_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb95_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb437_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb96_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb97_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb98_termite_23_make_2d_bag();
} else {
return _bb436_termite_23_make_2d_bag();
}
});

_k(_bb95_termite_23_make_2d_bag = () => {
return _bb97_termite_23_make_2d_bag();
},2,1);

_k(_bb96_termite_23_make_2d_bag = () => {
return _bb97_termite_23_make_2d_bag();
},2,1);

_j(_bb98_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb99_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb436_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb99_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb434_termite_23_make_2d_bag();
} else {
return _bb100_termite_23_make_2d_bag();
}
},4,1);

_j(_bb434_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb435_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb100_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb101_termite_23_make_2d_bag();
} else {
return _bb433_termite_23_make_2d_bag();
}
});

_k(_bb435_termite_23_make_2d_bag = () => {
return _bb104_termite_23_make_2d_bag();
},2,1);

_j(_bb101_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb102_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb433_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb103_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb104_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb105_termite_23_make_2d_bag();
} else {
return _bb432_termite_23_make_2d_bag();
}
});

_k(_bb102_termite_23_make_2d_bag = () => {
return _bb104_termite_23_make_2d_bag();
},2,1);

_k(_bb103_termite_23_make_2d_bag = () => {
return _bb104_termite_23_make_2d_bag();
},2,1);

_j(_bb105_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb106_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb432_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb106_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb430_termite_23_make_2d_bag();
} else {
return _bb107_termite_23_make_2d_bag();
}
},4,1);

_j(_bb430_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb431_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb107_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb108_termite_23_make_2d_bag();
} else {
return _bb429_termite_23_make_2d_bag();
}
});

_k(_bb431_termite_23_make_2d_bag = () => {
return _bb111_termite_23_make_2d_bag();
},2,1);

_j(_bb108_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb109_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb429_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb110_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb111_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb112_termite_23_make_2d_bag();
} else {
return _bb428_termite_23_make_2d_bag();
}
});

_k(_bb109_termite_23_make_2d_bag = () => {
return _bb111_termite_23_make_2d_bag();
},2,1);

_k(_bb110_termite_23_make_2d_bag = () => {
return _bb111_termite_23_make_2d_bag();
},2,1);

_j(_bb112_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb113_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb428_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb113_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb426_termite_23_make_2d_bag();
} else {
return _bb114_termite_23_make_2d_bag();
}
},4,1);

_j(_bb426_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb427_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb114_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb115_termite_23_make_2d_bag();
} else {
return _bb425_termite_23_make_2d_bag();
}
});

_k(_bb427_termite_23_make_2d_bag = () => {
return _bb118_termite_23_make_2d_bag();
},2,1);

_j(_bb115_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb116_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb425_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb117_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb118_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb119_termite_23_make_2d_bag();
} else {
return _bb424_termite_23_make_2d_bag();
}
});

_k(_bb116_termite_23_make_2d_bag = () => {
return _bb118_termite_23_make_2d_bag();
},2,1);

_k(_bb117_termite_23_make_2d_bag = () => {
return _bb118_termite_23_make_2d_bag();
},2,1);

_j(_bb119_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb120_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb424_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb120_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb422_termite_23_make_2d_bag();
} else {
return _bb121_termite_23_make_2d_bag();
}
},4,1);

_j(_bb422_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb423_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb121_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb122_termite_23_make_2d_bag();
} else {
return _bb421_termite_23_make_2d_bag();
}
});

_k(_bb423_termite_23_make_2d_bag = () => {
return _bb125_termite_23_make_2d_bag();
},2,1);

_j(_bb122_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb123_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb421_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb124_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb125_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb126_termite_23_make_2d_bag();
} else {
return _bb420_termite_23_make_2d_bag();
}
});

_k(_bb123_termite_23_make_2d_bag = () => {
return _bb125_termite_23_make_2d_bag();
},2,1);

_k(_bb124_termite_23_make_2d_bag = () => {
return _bb125_termite_23_make_2d_bag();
},2,1);

_j(_bb126_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb127_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb420_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb127_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb418_termite_23_make_2d_bag();
} else {
return _bb128_termite_23_make_2d_bag();
}
},4,1);

_j(_bb418_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb419_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb128_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb129_termite_23_make_2d_bag();
} else {
return _bb417_termite_23_make_2d_bag();
}
});

_k(_bb419_termite_23_make_2d_bag = () => {
return _bb132_termite_23_make_2d_bag();
},2,1);

_j(_bb129_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb130_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb417_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb131_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb132_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb133_termite_23_make_2d_bag();
} else {
return _bb416_termite_23_make_2d_bag();
}
});

_k(_bb130_termite_23_make_2d_bag = () => {
return _bb132_termite_23_make_2d_bag();
},2,1);

_k(_bb131_termite_23_make_2d_bag = () => {
return _bb132_termite_23_make_2d_bag();
},2,1);

_j(_bb133_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb134_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb416_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb134_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb414_termite_23_make_2d_bag();
} else {
return _bb135_termite_23_make_2d_bag();
}
},4,1);

_j(_bb414_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb415_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb135_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb136_termite_23_make_2d_bag();
} else {
return _bb413_termite_23_make_2d_bag();
}
});

_k(_bb415_termite_23_make_2d_bag = () => {
return _bb139_termite_23_make_2d_bag();
},2,1);

_j(_bb136_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb137_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb413_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb138_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb139_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb140_termite_23_make_2d_bag();
} else {
return _bb412_termite_23_make_2d_bag();
}
});

_k(_bb137_termite_23_make_2d_bag = () => {
return _bb139_termite_23_make_2d_bag();
},2,1);

_k(_bb138_termite_23_make_2d_bag = () => {
return _bb139_termite_23_make_2d_bag();
},2,1);

_j(_bb140_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb141_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb412_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb141_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb410_termite_23_make_2d_bag();
} else {
return _bb142_termite_23_make_2d_bag();
}
},4,1);

_j(_bb410_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb411_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb142_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb143_termite_23_make_2d_bag();
} else {
return _bb409_termite_23_make_2d_bag();
}
});

_k(_bb411_termite_23_make_2d_bag = () => {
return _bb146_termite_23_make_2d_bag();
},2,1);

_j(_bb143_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb144_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb409_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb145_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb146_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb147_termite_23_make_2d_bag();
} else {
return _bb408_termite_23_make_2d_bag();
}
});

_k(_bb144_termite_23_make_2d_bag = () => {
return _bb146_termite_23_make_2d_bag();
},2,1);

_k(_bb145_termite_23_make_2d_bag = () => {
return _bb146_termite_23_make_2d_bag();
},2,1);

_j(_bb147_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb148_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb408_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb148_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb406_termite_23_make_2d_bag();
} else {
return _bb149_termite_23_make_2d_bag();
}
},4,1);

_j(_bb406_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb407_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb149_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb150_termite_23_make_2d_bag();
} else {
return _bb405_termite_23_make_2d_bag();
}
});

_k(_bb407_termite_23_make_2d_bag = () => {
return _bb153_termite_23_make_2d_bag();
},2,1);

_j(_bb150_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb151_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb405_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb152_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb153_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb154_termite_23_make_2d_bag();
} else {
return _bb404_termite_23_make_2d_bag();
}
});

_k(_bb151_termite_23_make_2d_bag = () => {
return _bb153_termite_23_make_2d_bag();
},2,1);

_k(_bb152_termite_23_make_2d_bag = () => {
return _bb153_termite_23_make_2d_bag();
},2,1);

_j(_bb154_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb155_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb404_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb155_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb402_termite_23_make_2d_bag();
} else {
return _bb156_termite_23_make_2d_bag();
}
},4,1);

_j(_bb402_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb403_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb156_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb157_termite_23_make_2d_bag();
} else {
return _bb401_termite_23_make_2d_bag();
}
});

_k(_bb403_termite_23_make_2d_bag = () => {
return _bb160_termite_23_make_2d_bag();
},2,1);

_j(_bb157_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb158_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb401_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb159_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb160_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb161_termite_23_make_2d_bag();
} else {
return _bb400_termite_23_make_2d_bag();
}
});

_k(_bb158_termite_23_make_2d_bag = () => {
return _bb160_termite_23_make_2d_bag();
},2,1);

_k(_bb159_termite_23_make_2d_bag = () => {
return _bb160_termite_23_make_2d_bag();
},2,1);

_j(_bb161_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb162_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb400_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb162_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb398_termite_23_make_2d_bag();
} else {
return _bb163_termite_23_make_2d_bag();
}
},4,1);

_j(_bb398_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb399_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb163_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb164_termite_23_make_2d_bag();
} else {
return _bb397_termite_23_make_2d_bag();
}
});

_k(_bb399_termite_23_make_2d_bag = () => {
return _bb167_termite_23_make_2d_bag();
},2,1);

_j(_bb164_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb165_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb397_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb166_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb167_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb168_termite_23_make_2d_bag();
} else {
return _bb396_termite_23_make_2d_bag();
}
});

_k(_bb165_termite_23_make_2d_bag = () => {
return _bb167_termite_23_make_2d_bag();
},2,1);

_k(_bb166_termite_23_make_2d_bag = () => {
return _bb167_termite_23_make_2d_bag();
},2,1);

_j(_bb168_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb169_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb396_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb169_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb394_termite_23_make_2d_bag();
} else {
return _bb170_termite_23_make_2d_bag();
}
},4,1);

_j(_bb394_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb395_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb170_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb171_termite_23_make_2d_bag();
} else {
return _bb393_termite_23_make_2d_bag();
}
});

_k(_bb395_termite_23_make_2d_bag = () => {
return _bb174_termite_23_make_2d_bag();
},2,1);

_j(_bb171_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb172_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb393_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb173_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb174_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb175_termite_23_make_2d_bag();
} else {
return _bb392_termite_23_make_2d_bag();
}
});

_k(_bb172_termite_23_make_2d_bag = () => {
return _bb174_termite_23_make_2d_bag();
},2,1);

_k(_bb173_termite_23_make_2d_bag = () => {
return _bb174_termite_23_make_2d_bag();
},2,1);

_j(_bb175_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb176_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb392_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb176_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb390_termite_23_make_2d_bag();
} else {
return _bb177_termite_23_make_2d_bag();
}
},4,1);

_j(_bb390_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb391_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb177_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb178_termite_23_make_2d_bag();
} else {
return _bb389_termite_23_make_2d_bag();
}
});

_k(_bb391_termite_23_make_2d_bag = () => {
return _bb181_termite_23_make_2d_bag();
},2,1);

_j(_bb178_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb179_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb389_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb180_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb181_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb182_termite_23_make_2d_bag();
} else {
return _bb388_termite_23_make_2d_bag();
}
});

_k(_bb179_termite_23_make_2d_bag = () => {
return _bb181_termite_23_make_2d_bag();
},2,1);

_k(_bb180_termite_23_make_2d_bag = () => {
return _bb181_termite_23_make_2d_bag();
},2,1);

_j(_bb182_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb183_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb388_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb183_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb386_termite_23_make_2d_bag();
} else {
return _bb184_termite_23_make_2d_bag();
}
},4,1);

_j(_bb386_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb387_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb184_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb185_termite_23_make_2d_bag();
} else {
return _bb385_termite_23_make_2d_bag();
}
});

_k(_bb387_termite_23_make_2d_bag = () => {
return _bb188_termite_23_make_2d_bag();
},2,1);

_j(_bb185_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb186_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb385_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb187_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb188_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb189_termite_23_make_2d_bag();
} else {
return _bb384_termite_23_make_2d_bag();
}
});

_k(_bb186_termite_23_make_2d_bag = () => {
return _bb188_termite_23_make_2d_bag();
},2,1);

_k(_bb187_termite_23_make_2d_bag = () => {
return _bb188_termite_23_make_2d_bag();
},2,1);

_j(_bb189_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb190_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb384_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb190_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb382_termite_23_make_2d_bag();
} else {
return _bb191_termite_23_make_2d_bag();
}
},4,1);

_j(_bb382_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb383_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb191_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb192_termite_23_make_2d_bag();
} else {
return _bb381_termite_23_make_2d_bag();
}
});

_k(_bb383_termite_23_make_2d_bag = () => {
return _bb195_termite_23_make_2d_bag();
},2,1);

_j(_bb192_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb193_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb381_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb194_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb195_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb196_termite_23_make_2d_bag();
} else {
return _bb380_termite_23_make_2d_bag();
}
});

_k(_bb193_termite_23_make_2d_bag = () => {
return _bb195_termite_23_make_2d_bag();
},2,1);

_k(_bb194_termite_23_make_2d_bag = () => {
return _bb195_termite_23_make_2d_bag();
},2,1);

_j(_bb196_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb197_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb380_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb197_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb378_termite_23_make_2d_bag();
} else {
return _bb198_termite_23_make_2d_bag();
}
},4,1);

_j(_bb378_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb379_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb198_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb199_termite_23_make_2d_bag();
} else {
return _bb377_termite_23_make_2d_bag();
}
});

_k(_bb379_termite_23_make_2d_bag = () => {
return _bb202_termite_23_make_2d_bag();
},2,1);

_j(_bb199_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb200_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb377_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb201_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb202_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb203_termite_23_make_2d_bag();
} else {
return _bb376_termite_23_make_2d_bag();
}
});

_k(_bb200_termite_23_make_2d_bag = () => {
return _bb202_termite_23_make_2d_bag();
},2,1);

_k(_bb201_termite_23_make_2d_bag = () => {
return _bb202_termite_23_make_2d_bag();
},2,1);

_j(_bb203_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb204_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb376_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb204_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb374_termite_23_make_2d_bag();
} else {
return _bb205_termite_23_make_2d_bag();
}
},4,1);

_j(_bb374_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb375_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb205_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb206_termite_23_make_2d_bag();
} else {
return _bb373_termite_23_make_2d_bag();
}
});

_k(_bb375_termite_23_make_2d_bag = () => {
return _bb209_termite_23_make_2d_bag();
},2,1);

_j(_bb206_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb207_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb373_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb208_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb209_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb210_termite_23_make_2d_bag();
} else {
return _bb372_termite_23_make_2d_bag();
}
});

_k(_bb207_termite_23_make_2d_bag = () => {
return _bb209_termite_23_make_2d_bag();
},2,1);

_k(_bb208_termite_23_make_2d_bag = () => {
return _bb209_termite_23_make_2d_bag();
},2,1);

_j(_bb210_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb211_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb372_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb211_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb370_termite_23_make_2d_bag();
} else {
return _bb212_termite_23_make_2d_bag();
}
},4,1);

_j(_bb370_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb371_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb212_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb213_termite_23_make_2d_bag();
} else {
return _bb369_termite_23_make_2d_bag();
}
});

_k(_bb371_termite_23_make_2d_bag = () => {
return _bb216_termite_23_make_2d_bag();
},2,1);

_j(_bb213_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb214_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb369_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb215_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb216_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb217_termite_23_make_2d_bag();
} else {
return _bb368_termite_23_make_2d_bag();
}
});

_k(_bb214_termite_23_make_2d_bag = () => {
return _bb216_termite_23_make_2d_bag();
},2,1);

_k(_bb215_termite_23_make_2d_bag = () => {
return _bb216_termite_23_make_2d_bag();
},2,1);

_j(_bb217_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb218_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb368_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb218_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb366_termite_23_make_2d_bag();
} else {
return _bb219_termite_23_make_2d_bag();
}
},4,1);

_j(_bb366_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb367_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb219_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb220_termite_23_make_2d_bag();
} else {
return _bb365_termite_23_make_2d_bag();
}
});

_k(_bb367_termite_23_make_2d_bag = () => {
return _bb223_termite_23_make_2d_bag();
},2,1);

_j(_bb220_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb221_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb365_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb222_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb223_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb224_termite_23_make_2d_bag();
} else {
return _bb364_termite_23_make_2d_bag();
}
});

_k(_bb221_termite_23_make_2d_bag = () => {
return _bb223_termite_23_make_2d_bag();
},2,1);

_k(_bb222_termite_23_make_2d_bag = () => {
return _bb223_termite_23_make_2d_bag();
},2,1);

_j(_bb224_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb225_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb364_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb225_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb362_termite_23_make_2d_bag();
} else {
return _bb226_termite_23_make_2d_bag();
}
},4,1);

_j(_bb362_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb363_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb226_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb227_termite_23_make_2d_bag();
} else {
return _bb361_termite_23_make_2d_bag();
}
});

_k(_bb363_termite_23_make_2d_bag = () => {
return _bb230_termite_23_make_2d_bag();
},2,1);

_j(_bb227_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb228_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb361_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb229_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb230_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb231_termite_23_make_2d_bag();
} else {
return _bb360_termite_23_make_2d_bag();
}
});

_k(_bb228_termite_23_make_2d_bag = () => {
return _bb230_termite_23_make_2d_bag();
},2,1);

_k(_bb229_termite_23_make_2d_bag = () => {
return _bb230_termite_23_make_2d_bag();
},2,1);

_j(_bb231_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb232_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb360_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb232_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb358_termite_23_make_2d_bag();
} else {
return _bb233_termite_23_make_2d_bag();
}
},4,1);

_j(_bb358_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb359_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb233_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb234_termite_23_make_2d_bag();
} else {
return _bb357_termite_23_make_2d_bag();
}
});

_k(_bb359_termite_23_make_2d_bag = () => {
return _bb237_termite_23_make_2d_bag();
},2,1);

_j(_bb234_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb235_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb357_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb236_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb237_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb238_termite_23_make_2d_bag();
} else {
return _bb356_termite_23_make_2d_bag();
}
});

_k(_bb235_termite_23_make_2d_bag = () => {
return _bb237_termite_23_make_2d_bag();
},2,1);

_k(_bb236_termite_23_make_2d_bag = () => {
return _bb237_termite_23_make_2d_bag();
},2,1);

_j(_bb238_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb239_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb356_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb239_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb354_termite_23_make_2d_bag();
} else {
return _bb240_termite_23_make_2d_bag();
}
},4,1);

_j(_bb354_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb355_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb240_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb241_termite_23_make_2d_bag();
} else {
return _bb353_termite_23_make_2d_bag();
}
});

_k(_bb355_termite_23_make_2d_bag = () => {
return _bb244_termite_23_make_2d_bag();
},2,1);

_j(_bb241_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb242_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb353_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb243_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb244_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb245_termite_23_make_2d_bag();
} else {
return _bb352_termite_23_make_2d_bag();
}
});

_k(_bb242_termite_23_make_2d_bag = () => {
return _bb244_termite_23_make_2d_bag();
},2,1);

_k(_bb243_termite_23_make_2d_bag = () => {
return _bb244_termite_23_make_2d_bag();
},2,1);

_j(_bb245_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb246_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb352_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb246_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb350_termite_23_make_2d_bag();
} else {
return _bb247_termite_23_make_2d_bag();
}
},4,1);

_j(_bb350_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb351_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb247_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb248_termite_23_make_2d_bag();
} else {
return _bb349_termite_23_make_2d_bag();
}
});

_k(_bb351_termite_23_make_2d_bag = () => {
return _bb251_termite_23_make_2d_bag();
},2,1);

_j(_bb248_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb249_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb349_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb250_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb251_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb252_termite_23_make_2d_bag();
} else {
return _bb348_termite_23_make_2d_bag();
}
});

_k(_bb249_termite_23_make_2d_bag = () => {
return _bb251_termite_23_make_2d_bag();
},2,1);

_k(_bb250_termite_23_make_2d_bag = () => {
return _bb251_termite_23_make_2d_bag();
},2,1);

_j(_bb252_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb253_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb348_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb253_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb346_termite_23_make_2d_bag();
} else {
return _bb254_termite_23_make_2d_bag();
}
},4,1);

_j(_bb346_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb347_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb254_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb255_termite_23_make_2d_bag();
} else {
return _bb345_termite_23_make_2d_bag();
}
});

_k(_bb347_termite_23_make_2d_bag = () => {
return _bb258_termite_23_make_2d_bag();
},2,1);

_j(_bb255_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb256_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb345_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb257_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb258_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb259_termite_23_make_2d_bag();
} else {
return _bb344_termite_23_make_2d_bag();
}
});

_k(_bb256_termite_23_make_2d_bag = () => {
return _bb258_termite_23_make_2d_bag();
},2,1);

_k(_bb257_termite_23_make_2d_bag = () => {
return _bb258_termite_23_make_2d_bag();
},2,1);

_j(_bb259_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb260_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb344_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb260_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb342_termite_23_make_2d_bag();
} else {
return _bb261_termite_23_make_2d_bag();
}
},4,1);

_j(_bb342_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb343_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb261_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb262_termite_23_make_2d_bag();
} else {
return _bb341_termite_23_make_2d_bag();
}
});

_k(_bb343_termite_23_make_2d_bag = () => {
return _bb265_termite_23_make_2d_bag();
},2,1);

_j(_bb262_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb263_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb341_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb264_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb265_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb266_termite_23_make_2d_bag();
} else {
return _bb340_termite_23_make_2d_bag();
}
});

_k(_bb263_termite_23_make_2d_bag = () => {
return _bb265_termite_23_make_2d_bag();
},2,1);

_k(_bb264_termite_23_make_2d_bag = () => {
return _bb265_termite_23_make_2d_bag();
},2,1);

_j(_bb266_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb267_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb340_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb267_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb338_termite_23_make_2d_bag();
} else {
return _bb268_termite_23_make_2d_bag();
}
},4,1);

_j(_bb338_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb339_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb268_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb269_termite_23_make_2d_bag();
} else {
return _bb337_termite_23_make_2d_bag();
}
});

_k(_bb339_termite_23_make_2d_bag = () => {
return _bb272_termite_23_make_2d_bag();
},2,1);

_j(_bb269_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb270_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb337_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb271_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb272_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb273_termite_23_make_2d_bag();
} else {
return _bb336_termite_23_make_2d_bag();
}
});

_k(_bb270_termite_23_make_2d_bag = () => {
return _bb272_termite_23_make_2d_bag();
},2,1);

_k(_bb271_termite_23_make_2d_bag = () => {
return _bb272_termite_23_make_2d_bag();
},2,1);

_j(_bb273_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb274_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb336_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb274_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb334_termite_23_make_2d_bag();
} else {
return _bb275_termite_23_make_2d_bag();
}
},4,1);

_j(_bb334_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb335_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb275_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb276_termite_23_make_2d_bag();
} else {
return _bb333_termite_23_make_2d_bag();
}
});

_k(_bb335_termite_23_make_2d_bag = () => {
return _bb279_termite_23_make_2d_bag();
},2,1);

_j(_bb276_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb277_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb333_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb278_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb279_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb280_termite_23_make_2d_bag();
} else {
return _bb332_termite_23_make_2d_bag();
}
});

_k(_bb277_termite_23_make_2d_bag = () => {
return _bb279_termite_23_make_2d_bag();
},2,1);

_k(_bb278_termite_23_make_2d_bag = () => {
return _bb279_termite_23_make_2d_bag();
},2,1);

_j(_bb280_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb281_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb332_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb281_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb330_termite_23_make_2d_bag();
} else {
return _bb282_termite_23_make_2d_bag();
}
},4,1);

_j(_bb330_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb331_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb282_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb283_termite_23_make_2d_bag();
} else {
return _bb329_termite_23_make_2d_bag();
}
});

_k(_bb331_termite_23_make_2d_bag = () => {
return _bb286_termite_23_make_2d_bag();
},2,1);

_j(_bb283_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb284_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb329_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb285_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb286_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb287_termite_23_make_2d_bag();
} else {
return _bb328_termite_23_make_2d_bag();
}
});

_k(_bb284_termite_23_make_2d_bag = () => {
return _bb286_termite_23_make_2d_bag();
},2,1);

_k(_bb285_termite_23_make_2d_bag = () => {
return _bb286_termite_23_make_2d_bag();
},2,1);

_j(_bb287_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb288_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb328_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb288_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb326_termite_23_make_2d_bag();
} else {
return _bb289_termite_23_make_2d_bag();
}
},4,1);

_j(_bb326_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb327_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb289_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb290_termite_23_make_2d_bag();
} else {
return _bb325_termite_23_make_2d_bag();
}
});

_k(_bb327_termite_23_make_2d_bag = () => {
return _bb293_termite_23_make_2d_bag();
},2,1);

_j(_bb290_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb291_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb325_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb292_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb293_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb294_termite_23_make_2d_bag();
} else {
return _bb324_termite_23_make_2d_bag();
}
});

_k(_bb291_termite_23_make_2d_bag = () => {
return _bb293_termite_23_make_2d_bag();
},2,1);

_k(_bb292_termite_23_make_2d_bag = () => {
return _bb293_termite_23_make_2d_bag();
},2,1);

_j(_bb294_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb295_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb324_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb295_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb322_termite_23_make_2d_bag();
} else {
return _bb296_termite_23_make_2d_bag();
}
},4,1);

_j(_bb322_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb323_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb296_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb297_termite_23_make_2d_bag();
} else {
return _bb321_termite_23_make_2d_bag();
}
});

_k(_bb323_termite_23_make_2d_bag = () => {
return _bb300_termite_23_make_2d_bag();
},2,1);

_j(_bb297_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb298_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb321_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb299_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb300_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb301_termite_23_make_2d_bag();
} else {
return _bb320_termite_23_make_2d_bag();
}
});

_k(_bb298_termite_23_make_2d_bag = () => {
return _bb300_termite_23_make_2d_bag();
},2,1);

_k(_bb299_termite_23_make_2d_bag = () => {
return _bb300_termite_23_make_2d_bag();
},2,1);

_j(_bb301_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb302_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb320_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb302_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb318_termite_23_make_2d_bag();
} else {
return _bb303_termite_23_make_2d_bag();
}
},4,1);

_j(_bb318_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb319_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb303_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb304_termite_23_make_2d_bag();
} else {
return _bb317_termite_23_make_2d_bag();
}
});

_k(_bb319_termite_23_make_2d_bag = () => {
return _bb307_termite_23_make_2d_bag();
},2,1);

_j(_bb304_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb305_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb317_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb306_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb307_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb308_termite_23_make_2d_bag();
} else {
return _bb316_termite_23_make_2d_bag();
}
});

_k(_bb305_termite_23_make_2d_bag = () => {
return _bb307_termite_23_make_2d_bag();
},2,1);

_k(_bb306_termite_23_make_2d_bag = () => {
return _bb307_termite_23_make_2d_bag();
},2,1);

_j(_bb308_termite_23_make_2d_bag = () => {
_b = _a.a;
_c = _current_processor.a[14];
_c = new _Structure([_cst59__termite,_c,_cst65__termite,!1]);
_s[_t] = _a;
_s[_t+1] = _b;
_s[_t+2] = _c;
_a = _b;
_r = _bb309_termite_23_make_2d_bag;
_n = 1;
_t += 2;
return _g["thread?"]();
});

_j(_bb316_termite_23_make_2d_bag = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb309_termite_23_make_2d_bag = () => {
if (!(_a === !1)) {
return _bb314_termite_23_make_2d_bag();
} else {
return _bb310_termite_23_make_2d_bag();
}
},4,1);

_j(_bb314_termite_23_make_2d_bag = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _bb315_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb310_termite_23_make_2d_bag = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb311_termite_23_make_2d_bag();
} else {
return _bb313_termite_23_make_2d_bag();
}
});

_k(_bb315_termite_23_make_2d_bag = () => {
return _bb18_termite_23_make_2d_bag();
},2,1);

_j(_bb311_termite_23_make_2d_bag = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _bb312_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_j(_bb313_termite_23_make_2d_bag = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _bb17_termite_23_make_2d_bag;
_n = 2;
_t -= 2;
return _g["##error"]();
});

_j(_bb18_termite_23_make_2d_bag = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb19_termite_23_make_2d_bag);
});

_k(_bb312_termite_23_make_2d_bag = () => {
return _bb18_termite_23_make_2d_bag();
},2,1);

_k(_bb17_termite_23_make_2d_bag = () => {
return _bb18_termite_23_make_2d_bag();
},2,1);

_j(_bb19_termite_23_make_2d_bag = () => {
if (_x(_a)) {
return _bb20_termite_23_make_2d_bag();
} else {
return _bb480_termite_23_make_2d_bag();
}
});



_m(_bb1_termite_23_bag_3f_ = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_bag_3f_);
}
_s[_t+1] = _a;
_c = !1;
_b = 1;
_a = _X(_cst269__termite,null);
++_t;
return _p(_bb2_termite_23_bag_3f_);
},-1,_i("termite#bag?"),!1,!0);

_j(_bb2_termite_23_bag_3f_ = () => {
_n = 4;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_bag_2d_length = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_bag_2d_length);
}
_b = _X(_cst271__termite,null);
return _p(_bb2_termite_23_bag_2d_length);
},-1,_i("termite#bag-length"),!1,!0);

_j(_bb2_termite_23_bag_2d_length = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_bag_2d_add_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_bag_2d_add_21_);
}
_b = _X(_cst268__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_bag_2d_add_21_);
},-1,_i("termite#bag-add!"),!1,!0);

_j(_bb2_termite_23_bag_2d_add_21_ = () => {
_r = _bb3_termite_23_bag_2d_add_21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_bag_2d_add_21_ = () => {
if (!(_a === !1)) {
return _bb4_termite_23_bag_2d_add_21_();
} else {
return _bb5_termite_23_bag_2d_add_21_();
}
},3,1);

_j(_bb4_termite_23_bag_2d_add_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_bag_2d_add_21_);
});

_j(_bb5_termite_23_bag_2d_add_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_bag_2d_add_21_();
} else {
return _bb8_termite_23_bag_2d_add_21_();
}
});

_j(_bb7_termite_23_bag_2d_add_21_ = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_bag_2d_add_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_bag_2d_add_21_);
});

_j(_bb8_termite_23_bag_2d_add_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_bag_2d_add_21_);
});

_j(_bb9_termite_23_bag_2d_add_21_ = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_bag_2d_remove_21_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_bag_2d_remove_21_);
}
_b = _X(_cst270__termite,_X(_b,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_t += 3;
return _p(_bb2_termite_23_bag_2d_remove_21_);
},-1,_i("termite#bag-remove!"),!1,!0);

_j(_bb2_termite_23_bag_2d_remove_21_ = () => {
_r = _bb3_termite_23_bag_2d_remove_21_;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_bag_2d_remove_21_ = () => {
if (!(_a === !1)) {
return _bb4_termite_23_bag_2d_remove_21_();
} else {
return _bb5_termite_23_bag_2d_remove_21_();
}
},3,1);

_j(_bb4_termite_23_bag_2d_remove_21_ = () => {
_b = _s[_t];
_a = _s[_t-1];
_r = _s[_t-2];
return _p(_bb7_termite_23_bag_2d_remove_21_);
});

_j(_bb5_termite_23_bag_2d_remove_21_ = () => {
if (_s[_t-1] instanceof _Structure && _s[_t-1].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_bag_2d_remove_21_();
} else {
return _bb8_termite_23_bag_2d_remove_21_();
}
});

_j(_bb7_termite_23_bag_2d_remove_21_ = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_bag_2d_remove_21_ = () => {
_b = _X(_cst77__termite,_X(_s[_t-1],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_bag_2d_remove_21_);
});

_j(_bb8_termite_23_bag_2d_remove_21_ = () => {
_b = _s[_t-1];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_bag_2d_remove_21_);
});

_j(_bb9_termite_23_bag_2d_remove_21_ = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_bag_2d_member_3f_ = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_bag_2d_member_3f_);
}
_b = _X(_cst273__termite,_X(_b,null));
return _p(_bb2_termite_23_bag_2d_member_3f_);
},-1,_i("termite#bag-member?"),!1,!0);

_j(_bb2_termite_23_bag_2d_member_3f_ = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_bag_2d_search = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_bag_2d_search);
}
_a = _X(_cst274__termite,_X(_a,null));
_s[_t+1] = _b;
_b = _a;
_a = _s[_t+1];
++_t;
return _p(_bb2_termite_23_bag_2d_search);
},-1,_i("termite#bag-search"),!1,!0);

_j(_bb2_termite_23_bag_2d_search = () => {
_n = 2;
--_t;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_bag_2d_for_2d_each = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_bag_2d_for_2d_each);
}
_a = _X(_cst272__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_s[_t+3] = _b;
_a = _b;
_t += 3;
return _p(_bb2_termite_23_bag_2d_for_2d_each);
},-1,_i("termite#bag-for-each"),!1,!0);

_j(_bb2_termite_23_bag_2d_for_2d_each = () => {
_r = _bb3_termite_23_bag_2d_for_2d_each;
_n = 1;
return _g["thread?"]();
});

_k(_bb3_termite_23_bag_2d_for_2d_each = () => {
if (!(_a === !1)) {
return _bb4_termite_23_bag_2d_for_2d_each();
} else {
return _bb5_termite_23_bag_2d_for_2d_each();
}
},3,1);

_j(_bb4_termite_23_bag_2d_for_2d_each = () => {
_b = _s[_t-1];
_a = _s[_t];
_r = _s[_t-2];
return _p(_bb7_termite_23_bag_2d_for_2d_each);
});

_j(_bb5_termite_23_bag_2d_for_2d_each = () => {
if (_s[_t] instanceof _Structure && _s[_t].a[0].a[1] === _cst83__termite) {
return _bb6_termite_23_bag_2d_for_2d_each();
} else {
return _bb8_termite_23_bag_2d_for_2d_each();
}
});

_j(_bb7_termite_23_bag_2d_for_2d_each = () => {
_n = 2;
_t -= 3;
return _g["thread-send"]();
});

_j(_bb6_termite_23_bag_2d_for_2d_each = () => {
_b = _X(_cst77__termite,_X(_s[_t],_X(_s[_t-1],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-2];
return _p(_bb7_termite_23_bag_2d_for_2d_each);
});

_j(_bb8_termite_23_bag_2d_for_2d_each = () => {
_b = _s[_t];
_a = _cst87__termite;
_r = _s[_t-2];
return _p(_bb9_termite_23_bag_2d_for_2d_each);
});

_j(_bb9_termite_23_bag_2d_for_2d_each = () => {
_n = 2;
_t -= 3;
return _g["##error"]();
});



_m(_bb1_termite_23_bag_2d__3e_list = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_bag_2d__3e_list);
}
_b = _X(_cst275__termite,null);
return _p(_bb2_termite_23_bag_2d__3e_list);
},-1,_i("termite#bag->list"),!1,!0);

_j(_bb2_termite_23_bag_2d__3e_list = () => {
_n = 2;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_migrate_2d_task = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_migrate_2d_task);
}
_s[_t+1] = _a;
_a = _bb3_termite_23_migrate_2d_task;
_b = _s[_t+1];
++_t;
return _p(_bb2_termite_23_migrate_2d_task);
},-1,_i("termite#migrate-task"),!1,!0);

_l(_bb3_termite_23_migrate_2d_task = () => {
if (_n !== 2) {
return _w(_bb3_termite_23_migrate_2d_task);
}
_s[_t+1] = _r;
var closure0 = _closure_alloc([_bb7_termite_23_migrate_2d_task,_a]);
_s[_t+2] = closure0;
_s[_t+3] = _b;
_b = _s[_t+2];
_a = _s[_t+3];
_t += 3;
return _p(_bb4_termite_23_migrate_2d_task);
},-1);

_j(_bb2_termite_23_migrate_2d_task = () => {
_n = 2;
--_t;
return _e["##call-with-current-continuation"]();
});

_l(_bb7_termite_23_migrate_2d_task = () => {
if (_n !== 0) {
return _w(_d);
}
_a = !0;
return _p(_bb8_termite_23_migrate_2d_task);
},1);

_j(_bb4_termite_23_migrate_2d_task = () => {
_r = _bb5_termite_23_migrate_2d_task;
_n = 2;
_t -= 2;
return _bb1_termite_23_remote_2d_spawn();
});

_j(_bb8_termite_23_migrate_2d_task = () => {
_n = 1;
return _d(!0)[1]();
});

_k(_bb5_termite_23_migrate_2d_task = () => {
_a = _current_processor.a[14];
_r = _s[_t];
return _p(_bb6_termite_23_migrate_2d_task);
},1,1);

_j(_bb6_termite_23_migrate_2d_task = () => {
_n = 1;
--_t;
return _g["thread-terminate!"]();
});



_m(_bb1_termite_23_migrate_2f_proxy = () => {
if (_n !== 1) {
return _w(_bb1_termite_23_migrate_2f_proxy);
}
_s[_t+1] = _a;
_a = _bb3_termite_23_migrate_2f_proxy;
_b = _s[_t+1];
++_t;
return _p(_bb2_termite_23_migrate_2f_proxy);
},-1,_i("termite#migrate/proxy"),!1,!0);

_l(_bb3_termite_23_migrate_2f_proxy = () => {
if (_n !== 2) {
return _w(_bb3_termite_23_migrate_2f_proxy);
}
_s[_t+1] = _r;
var closure0 = _closure_alloc([_bb10_termite_23_migrate_2f_proxy,_a]);
_s[_t+2] = closure0;
_s[_t+3] = _b;
_b = _s[_t+2];
_a = _s[_t+3];
_t += 3;
return _p(_bb4_termite_23_migrate_2f_proxy);
},-1);

_j(_bb2_termite_23_migrate_2f_proxy = () => {
_n = 2;
--_t;
return _e["##call-with-current-continuation"]();
});

_l(_bb10_termite_23_migrate_2f_proxy = () => {
if (_n !== 0) {
return _w(_d);
}
_a = !0;
return _p(_bb11_termite_23_migrate_2f_proxy);
},1);

_j(_bb4_termite_23_migrate_2f_proxy = () => {
_r = _bb5_termite_23_migrate_2f_proxy;
_n = 2;
_t -= 2;
return _bb1_termite_23_remote_2d_spawn_2d_link();
});

_j(_bb11_termite_23_migrate_2f_proxy = () => {
_n = 1;
return _d(!0)[1]();
});

_k(_bb5_termite_23_migrate_2f_proxy = () => {
_r = _s[_t];
--_t;
return _p(_bb7_termite_23_migrate_2f_proxy);
},1,1);

_j(_bb7_termite_23_migrate_2f_proxy = () => {
_s[_t+1] = _r;
_s[_t+2] = _a;
_t += 2;
return _p(_bb8_termite_23_migrate_2f_proxy);
});

_j(_bb8_termite_23_migrate_2f_proxy = () => {
_r = _bb9_termite_23_migrate_2f_proxy;
_n = 0;
return _bb1_termite_23__3f_();
});

_k(_bb9_termite_23_migrate_2f_proxy = () => {
_b = _a;
_a = _s[_t];
_r = _bb6_termite_23_migrate_2f_proxy;
_n = 2;
return _bb1_termite_23__21_();
},2,1);

_k(_bb6_termite_23_migrate_2f_proxy = () => {
_a = _s[_t];
_r = _s[_t-1];
_t -= 2;
return _p(_bb7_termite_23_migrate_2f_proxy);
},2,1);



_m(_bb1_termite_23_report_2d_event = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_report_2d_event);
}
if (_x(_a)) {
return _bb2_termite_23_report_2d_event();
} else {
return _bb34_termite_23_report_2d_event();
}
},-1,_i("termite#report-event"),!1,!0);

_j(_bb2_termite_23_report_2d_event = () => {
_c = _a.a;
_a = _a.b;
if (_x(_a)) {
return _bb3_termite_23_report_2d_event();
} else {
return _bb34_termite_23_report_2d_event();
}
});

_j(_bb34_termite_23_report_2d_event = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
_a = _cst277__termite;
_r = _bb8_termite_23_report_2d_event;
_n = 1;
_t += 2;
return _e["##display"]();
});

_j(_bb3_termite_23_report_2d_event = () => {
_d = _a.a;
_a = _a.b;
if (_x(_a)) {
return _bb4_termite_23_report_2d_event();
} else {
return _bb34_termite_23_report_2d_event();
}
});

_k(_bb8_termite_23_report_2d_event = () => {
return _bb9_termite_23_report_2d_event();
},2,1);

_j(_bb4_termite_23_report_2d_event = () => {
_s[_t+1] = _a.a;
_a = _a.b;
if (_a === null) {
++_t;
return _bb5_termite_23_report_2d_event();
} else {
++_t;
return _bb33_termite_23_report_2d_event();
}
});

_j(_bb9_termite_23_report_2d_event = () => {
_a = _s[_t];
_t -= 2;
return _s[_t+1]();
});

_j(_bb5_termite_23_report_2d_event = () => {
_s[_t+1] = _r;
_s[_t+2] = _b;
var closure0 = _closure_alloc([_bb10_termite_23_report_2d_event,_c,_d,_s[_t]]);
_s[_t+3] = closure0;
_b = _s[_t+3];
_a = _s[_t+2];
_t += 3;
return _p(_bb6_termite_23_report_2d_event);
});

_j(_bb33_termite_23_report_2d_event = () => {
_s[_t] = _r;
_s[_t+1] = _b;
_a = _cst277__termite;
_r = _bb8_termite_23_report_2d_event;
_n = 1;
++_t;
return _e["##display"]();
});

_l(_bb10_termite_23_report_2d_event = () => {
if (_n !== 0) {
return _w(_d);
}
_s[_t+1] = _r;
_s[_t+2] = _d;
_r = _bb11_termite_23_report_2d_event;
_n = 0;
_t += 2;
return _e["##newline0"]();
},3);

_j(_bb6_termite_23_report_2d_event = () => {
_r = _bb7_termite_23_report_2d_event;
_n = 2;
--_t;
return _g["##with-output-to-port"]();
});

_k(_bb11_termite_23_report_2d_event = () => {
_a = _cst281__termite;
_r = _bb12_termite_23_report_2d_event;
_n = 1;
return _e["##display"]();
},2,1);

_k(_bb7_termite_23_report_2d_event = () => {
_s[_t-2] = _s[_t-1];
_s[_t-1] = _s[_t];
--_t;
return _bb9_termite_23_report_2d_event();
},3,2);

_k(_bb12_termite_23_report_2d_event = () => {
_a = _s[_t](!0)[1];
_r = _bb13_termite_23_report_2d_event;
_n = 1;
return _e["##display"]();
},2,1);

_k(_bb13_termite_23_report_2d_event = () => {
_a = _cst282__termite;
_r = _bb14_termite_23_report_2d_event;
_n = 1;
return _e["##display"]();
},2,1);

_k(_bb14_termite_23_report_2d_event = () => {
return _p(_bb15_termite_23_report_2d_event);
},2,1);

_j(_bb15_termite_23_report_2d_event = () => {
_r = _bb16_termite_23_report_2d_event;
_n = 0;
return _bb1_termite_23_formatted_2d_current_2d_time();
});

_k(_bb16_termite_23_report_2d_event = () => {
_r = _bb17_termite_23_report_2d_event;
_n = 1;
return _e["##display"]();
},2,1);

_k(_bb17_termite_23_report_2d_event = () => {
_r = _bb18_termite_23_report_2d_event;
_n = 0;
return _e["##newline0"]();
},2,1);

_k(_bb18_termite_23_report_2d_event = () => {
_a = _s[_t](!0)[2];
_r = _bb19_termite_23_report_2d_event;
_n = 1;
return _e["##display"]();
},2,1);

_k(_bb19_termite_23_report_2d_event = () => {
_r = _bb20_termite_23_report_2d_event;
_n = 0;
return _e["##newline0"]();
},2,1);

_k(_bb20_termite_23_report_2d_event = () => {
_a = _s[_t](!0)[3];
_r = _bb31_termite_23_report_2d_event;
--_t;
return _bb21_termite_23_report_2d_event();
},2,1);

_j(_bb21_termite_23_report_2d_event = () => {
if (_x(_a)) {
return _bb24_termite_23_report_2d_event();
} else {
return _bb30_termite_23_report_2d_event();
}
});

_k(_bb31_termite_23_report_2d_event = () => {
_r = _s[_t];
return _p(_bb32_termite_23_report_2d_event);
},1,1);

_j(_bb24_termite_23_report_2d_event = () => {
_b = _a.a;
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _b;
_r = _bb25_termite_23_report_2d_event;
_n = 1;
_t += 2;
return _e["##display"]();
});

_j(_bb30_termite_23_report_2d_event = () => {
_a = void 0;
return _r;
});

_j(_bb32_termite_23_report_2d_event = () => {
_n = 0;
--_t;
return _g["##force-output"]();
});

_k(_bb25_termite_23_report_2d_event = () => {
_r = _bb26_termite_23_report_2d_event;
_n = 0;
return _e["##newline0"]();
},2,1);

_k(_bb26_termite_23_report_2d_event = () => {
_a = _s[_t].b;
if (_x(_a)) {
return _bb27_termite_23_report_2d_event();
} else {
return _bb29_termite_23_report_2d_event();
}
},2,1);

_j(_bb27_termite_23_report_2d_event = () => {
_b = _a.a;
_s[_t] = _a;
_a = _b;
_r = _bb28_termite_23_report_2d_event;
_n = 1;
return _e["##display"]();
});

_j(_bb29_termite_23_report_2d_event = () => {
_a = void 0;
_t -= 2;
return _s[_t+1]();
});

_k(_bb28_termite_23_report_2d_event = () => {
_r = _bb22_termite_23_report_2d_event;
_n = 0;
return _e["##newline0"]();
},2,1);

_k(_bb22_termite_23_report_2d_event = () => {
_a = _s[_t].b;
_r = _s[_t-1];
_t -= 2;
return _p(_bb23_termite_23_report_2d_event);
},2,1);

_j(_bb23_termite_23_report_2d_event = () => {
if (_x(_a)) {
return _bb24_termite_23_report_2d_event();
} else {
return _bb30_termite_23_report_2d_event();
}
});



_m(_bb1_termite_23_termite_2d_log = () => {
if (_n !== 2) {
return _w(_bb1_termite_23_termite_2d_log);
}
_c = _current_processor.a[14];
_a = _X(_a,_X(_c,_X(_b,null)));
_a = _X(_cst47__termite,_X(_a,null));
_s[_t+1] = _r;
_s[_t+2] = _a;
_a = _g["termite#logger"];
_t += 2;
return _p(_bb2_termite_23_termite_2d_log);
},-1,_i("termite#termite-log"),!1,!0);

_j(_bb2_termite_23_termite_2d_log = () => {
_r = _bb3_termite_23_termite_2d_log;
_n = 1;
return _bb1_termite_23_process_3f_();
});

_k(_bb3_termite_23_termite_2d_log = () => {
if (!(_a === !1)) {
return _bb4_termite_23_termite_2d_log();
} else {
return _bb10_termite_23_termite_2d_log();
}
},2,1);

_j(_bb4_termite_23_termite_2d_log = () => {
_b = _s[_t];
_a = _g["termite#logger"];
_r = _s[_t-1];
return _p(_bb7_termite_23_termite_2d_log);
});

_j(_bb10_termite_23_termite_2d_log = () => {
_a = _g["termite#logger"];
_r = _bb5_termite_23_termite_2d_log;
_n = 1;
return _bb1_termite_23_upid_3f_();
});

_j(_bb7_termite_23_termite_2d_log = () => {
_n = 2;
_t -= 2;
return _g["thread-send"]();
});

_k(_bb5_termite_23_termite_2d_log = () => {
if (!(_a === !1)) {
return _bb6_termite_23_termite_2d_log();
} else {
return _bb8_termite_23_termite_2d_log();
}
},2,1);

_j(_bb6_termite_23_termite_2d_log = () => {
_b = _X(_cst77__termite,_X(_g["termite#logger"],_X(_s[_t],null)));
_a = _g["termite#dispatcher"];
_r = _s[_t-1];
return _p(_bb7_termite_23_termite_2d_log);
});

_j(_bb8_termite_23_termite_2d_log = () => {
_b = _g["termite#logger"];
_a = _cst87__termite;
_r = _s[_t-1];
return _p(_bb9_termite_23_termite_2d_log);
});

_j(_bb9_termite_23_termite_2d_log = () => {
_n = 2;
_t -= 2;
return _g["##error"]();
});



_m(_bb1_termite_23_warning = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1_termite_23_warning);
}
}
_b = _a;
_a = _cst89__termite;
return _p(_bb2_termite_23_warning);
},-1,_i("termite#warning"),!1,!0);

_j(_bb2_termite_23_warning = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});



_m(_bb1_termite_23_info = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1_termite_23_info);
}
}
_b = _a;
_a = _cst283__termite;
return _p(_bb2_termite_23_info);
},-1,_i("termite#info"),!1,!0);

_j(_bb2_termite_23_info = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});



_m(_bb1_termite_23_debug = () => {
if (_n === 0) {
_a = null;
} else {
if (!_build_rest(0)) {
return _w(_bb1_termite_23_debug);
}
}
_b = _a;
_a = _cst117__termite;
return _p(_bb2_termite_23_debug);
},-1,_i("termite#debug"),!1,!0);

_j(_bb2_termite_23_debug = () => {
_n = 2;
return _bb1_termite_23_termite_2d_log();
});



_m(_bb1_termite_23_ping = () => {
if (_n === 1) {
_b = _F(1.0);
} else {
if (_n !== 2) {
return _w(_bb1_termite_23_ping);
}
}
_s[_t+1] = new _Structure([_cst101__termite,_cst284__termite,_a]);
_c = _cst285__termite;
_a = _cst114__termite;
++_t;
return _p(_bb2_termite_23_ping);
},-1,_i("termite#ping"),!1,!0);

_j(_bb2_termite_23_ping = () => {
_n = 4;
return _bb1_termite_23__21__3f_();
});



_m(_bb1_termite_23_node_2d_init = () => {
if (_n === 0) {
_a = _absent_obj;
} else {
if (_n !== 1) {
return _w(_bb1_termite_23_node_2d_init);
}
}
if (_a === _absent_obj) {
return _bb2_termite_23_node_2d_init();
} else {
return _bb5_termite_23_node_2d_init();
}
},-1,_i("termite#node-init"),!1,!0);

_j(_bb2_termite_23_node_2d_init = () => {
_s[_t+1] = _r;
_b = 0;
_a = _cst286__termite;
++_t;
return _p(_bb3_termite_23_node_2d_init);
});

_j(_bb5_termite_23_node_2d_init = () => {
_s[_t+1] = _r;
_b = _bb1_termite_23_start_2d_messenger;
++_t;
return _p(_bb6_termite_23_node_2d_init);
});

_j(_bb3_termite_23_node_2d_init = () => {
_r = _bb4_termite_23_node_2d_init;
_n = 2;
return _bb1_termite_23_make_2d_node();
});

_j(_bb6_termite_23_node_2d_init = () => {
_r = _bb7_termite_23_node_2d_init;
_n = 2;
return _bb1_termite_23_start_2d_tcp_2d_server();
});

_k(_bb4_termite_23_node_2d_init = () => {
_r = _s[_t];
--_t;
return _bb5_termite_23_node_2d_init();
},1,1);

_k(_bb7_termite_23_node_2d_init = () => {
var closure0 = _closure_alloc([_bb9_termite_23_node_2d_init,_a]);
_s[_t+1] = closure0;
_g["termite#current-node"] = _s[_t+1];
_r = _bb8_termite_23_node_2d_init;
_n = 0;
return _bb1_termite_23_publish_2d_external_2d_services();
},1,1);

_l(_bb9_termite_23_node_2d_init = () => {
if (_n !== 0) {
return _w(_d);
}
_a = _d(!0)[1];
return _r;
},1);

_k(_bb8_termite_23_node_2d_init = () => {
_a = _cst219__termite;
--_t;
return _s[_t+1]();
},1,1);



_m(_bb1_termite_23_publish_2d_external_2d_services = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_publish_2d_external_2d_services);
}
_s[_t+1] = _r;
_b = _g["termite#spawner"];
_a = _cst162__termite;
++_t;
return _p(_bb2_termite_23_publish_2d_external_2d_services);
},-1,_i("termite#publish-external-services"),!1,!0);

_j(_bb2_termite_23_publish_2d_external_2d_services = () => {
_r = _bb3_termite_23_publish_2d_external_2d_services;
_n = 2;
return _bb1_termite_23_publish_2d_service();
});

_k(_bb3_termite_23_publish_2d_external_2d_services = () => {
_b = _g["termite#linker"];
_a = _cst108__termite;
_r = _bb4_termite_23_publish_2d_external_2d_services;
_n = 2;
return _bb1_termite_23_publish_2d_service();
},1,1);

_k(_bb4_termite_23_publish_2d_external_2d_services = () => {
_b = _g["termite#ping-server"];
_a = _cst284__termite;
_r = _s[_t];
return _p(_bb5_termite_23_publish_2d_external_2d_services);
},1,1);

_j(_bb5_termite_23_publish_2d_external_2d_services = () => {
_n = 2;
--_t;
return _bb1_termite_23_publish_2d_service();
});



_m(_bb1_termite_23_current_2d_node = () => {
if (_n !== 0) {
return _w(_bb1_termite_23_current_2d_node);
}
_a = _cst287__termite;
return _p(_bb2_termite_23_current_2d_node);
},-1,_cst0__termite,!1,!1);

_j(_bb2_termite_23_current_2d_node = () => {
_n = 1;
return _g["##error"]();
});



_module_register([[_i("termite")],[_i("termite/match"),_i("termite/utils")],null,1,_bb1_termite_23_,!1]);

